@@ -1,5 +1,3 @@
-from __future__ import with_statement
-
 import os.path
 import glob
 
@@ -12,11 +10,8 @@ except ImportError:
 for f in glob.glob("*.py"):
     if "buildplots" in f or os.path.exists(f[:-3]+".png"):
         continue
-    print("Processing", f)
-
-    with open(f) as file:
-        code = file.readlines()
-
+    print "Processing", f
+    code = open(f).readlines()
     code = ["from mpmath import *; mp.dps=5"] + code
     for i in range(len(code)):
         l = code[i].rstrip()
