@@ -1,5 +1,4 @@
-"""
-SymPy is a Python library for symbolic mathematics. It aims to become a
+"""SymPy is a Python library for symbolic mathematics. It aims to become a
 full-featured computer algebra system (CAS) while keeping the code as
 simple as possible in order to be comprehensible and easily extensible.
 SymPy is written entirely in Python and does not require any external
@@ -7,11 +6,12 @@ libraries, except optionally for plotting support.
 
 See the webpage for more information and documentation:
 
-    http://code.google.com/p/sympy/"""
+    http://sympy.org
+"""
 
 from __future__ import absolute_import, print_function
 
-__version__ = "0.7.4.1"
+from sympy.release import __version__
 
 import sys
 if sys.version_info[0] == 2 and sys.version_info[1] < 6:
@@ -26,7 +26,12 @@ del sys
 def __sympy_debug():
     # helper function so we don't import os globally
     import os
-    return eval(os.getenv('SYMPY_DEBUG', 'False'))
+    debug_str = os.getenv('SYMPY_DEBUG', 'False')
+    if debug_str in ('True', 'False'):
+        return eval(debug_str)
+    else:
+        raise RuntimeError("unrecognized value for SYMPY_DEBUG: %s" %
+                           debug_str)
 SYMPY_DEBUG = __sympy_debug()
 
 from .core import *
@@ -46,14 +51,16 @@ from .utilities import *
 from .integrals import *
 from .tensor import *
 from .parsing import *
+from .calculus import *
 # Adds about .04-.05 seconds of import time
 # from combinatorics import *
 # This module is slow to import:
 #from physics import units
-from .plotting import plot, Plot, textplot, plot_backends, plot_implicit
+from .plotting import plot, textplot, plot_backends, plot_implicit
 from .printing import pretty, pretty_print, pprint, pprint_use_unicode, \
     pprint_try_use_unicode, print_gtk, print_tree, pager_print, TableForm
-from .printing import ccode, fcode, jscode, latex, preview
+from .printing import ccode, fcode, jscode, mathematica_code, octave_code, \
+    latex, preview
 from .printing import python, print_python, srepr, sstr, sstrrepr
 from .interactive import init_session, init_printing
 
