@@ -26,10 +26,23 @@ class AskNegativeHandler(CommonHandler):
 
     @staticmethod
     def _number(expr, assumptions):
-        if not expr.as_real_imag()[1]:
-            return expr.evalf() < 0
+        r, i = expr.as_real_imag()
+        # If the imaginary part can symbolically be shown to be zero then
+        # we just evaluate the real part; otherwise we evaluate the imaginary
+        # part to see if it actually evaluates to zero and if it does then
+        # we make the comparison between the real part and zero.
+        if not i:
+            r = r.evalf(2)
+            if r._prec != 1:
+                return r < 0
         else:
-            return False
+            i = i.evalf(2)
+            if i._prec != 1:
+                if i != 0:
+                    return False
+                r = r.evalf(2)
+                if r._prec != 1:
+                    return r < 0
 
     @staticmethod
     def Basic(expr, assumptions):
@@ -44,6 +57,11 @@ class AskNegativeHandler(CommonHandler):
         """
         if expr.is_number:
             return AskNegativeHandler._number(expr, assumptions)
+
+        r = ask(Q.real(expr), assumptions)
+        if r is not True:
+            return r
+
         nonpos = 0
         for arg in expr.args:
             if ask(Q.negative(arg), assumptions) is not True:
@@ -118,7 +136,11 @@ class AskNonZeroHandler(CommonHandler):
     def Basic(expr, assumptions):
         if expr.is_number:
             # if there are no symbols just evalf
-            return expr.evalf() != 0
+            i = expr.evalf(2)
+            def nonz(i):
+                if i._prec != 1:
+                    return i != 0
+            return fuzzy_or(nonz(i) for i in i.as_real_imag())
 
     @staticmethod
     def Add(expr, assumptions):
@@ -174,10 +196,23 @@ class AskPositiveHandler(CommonHandler):
 
     @staticmethod
     def _number(expr, assumptions):
-        if not expr.as_real_imag()[1]:
-            return expr.evalf() > 0
+        r, i = expr.as_real_imag()
+        # If the imaginary part can symbolically be shown to be zero then
+        # we just evaluate the real part; otherwise we evaluate the imaginary
+        # part to see if it actually evaluates to zero and if it does then
+        # we make the comparison between the real part and zero.
+        if not i:
+            r = r.evalf(2)
+            if r._prec != 1:
+                return r > 0
         else:
-            return False
+            i = i.evalf(2)
+            if i._prec != 1:
+                if i != 0:
+                    return False
+                r = r.evalf(2)
+                if r._prec != 1:
+                    return r > 0
 
     @staticmethod
     def Basic(expr, assumptions):
@@ -202,6 +237,11 @@ class AskPositiveHandler(CommonHandler):
     def Add(expr, assumptions):
         if expr.is_number:
             return AskPositiveHandler._number(expr, assumptions)
+
+        r = ask(Q.real(expr), assumptions)
+        if r is not True:
+            return r
+
         nonneg = 0
         for arg in expr.args:
             if ask(Q.positive(arg), assumptions) is not True:
@@ -216,20 +256,32 @@ class AskPositiveHandler(CommonHandler):
     @staticmethod
     def Pow(expr, assumptions):
         if expr.is_number:
-            return expr.evalf() > 0
+            return AskPositiveHandler._number(expr, assumptions)
         if ask(Q.positive(expr.base), assumptions):
             if ask(Q.real(expr.exp), assumptions):
                 return True
         if ask(Q.negative(expr.base), assumptions):
             if ask(Q.even(expr.exp), assumptions):
                 return True
-            if ask(Q.even(expr.exp), assumptions):
+            if ask(Q.odd(expr.exp), assumptions):
                 return False
 
     @staticmethod
     def exp(expr, assumptions):
         if ask(Q.real(expr.args[0]), assumptions):
             return True
+        if ask(Q.imaginary(expr.args[0]), assumptions):
+            return False
+
+    @staticmethod
+    def log(expr, assumptions):
+        r = ask(Q.real(expr.args[0]), assumptions)
+        if r is not True:
+            return r
+        if ask(Q.positive(expr.args[0] - 1), assumptions):
+            return True
+        if ask(Q.negative(expr.args[0] - 1), assumptions):
+            return False
 
     @staticmethod
     def factorial(expr, assumptions):
@@ -258,3 +310,25 @@ class AskPositiveHandler(CommonHandler):
         if (expr.i == expr.j
                 and ask(Q.positive_definite(expr.parent), assumptions)):
             return True
+
+    @staticmethod
+    def atan(expr, assumptions):
+        return ask(Q.positive(expr.args[0]), assumptions)
+
+    @staticmethod
+    def asin(expr, assumptions):
+        x = expr.args[0]
+        if ask(Q.positive(x) & Q.nonpositive(x - 1), assumptions):
+            return True
+        if ask(Q.negative(x) & Q.nonnegative(x + 1), assumptions):
+            return False
+
+    @staticmethod
+    def acos(expr, assumptions):
+        x = expr.args[0]
+        if ask(Q.nonpositive(x - 1) & Q.nonnegative(x + 1), assumptions):
+            return True
+
+    @staticmethod
+    def acot(expr, assumptions):
+        return ask(Q.real(expr.args[0]), assumptions)
