@@ -25,7 +25,7 @@ class Partition(C.FiniteSet):
     _rank = None
     _partition = None
 
-    def __new__(cls, partition):
+    def __new__(cls, *partition):
         """
         Generates a new partition object.
 
@@ -36,9 +36,9 @@ class Partition(C.FiniteSet):
         ========
 
         >>> from sympy.combinatorics.partitions import Partition
-        >>> a = Partition([[1, 2], [3]])
+        >>> a = Partition([1, 2], [3])
         >>> a
-        {{1, 2}, {3}}
+        {{3}, {1, 2}}
         >>> a.partition
         [[1, 2], [3]]
         >>> len(a)
@@ -48,15 +48,16 @@ class Partition(C.FiniteSet):
 
         """
         args = partition
-        if not all(isinstance(part, list) for part in args):
-            raise ValueError("Partition should be a list of lists.")
+        if not all(isinstance(part, (list, C.FiniteSet)) for part in args):
+            raise ValueError(
+                "Each argument to Partition should be a list or a FiniteSet")
 
         # sort so we have a canonical reference for RGS
         partition = sorted(sum(partition, []), key=default_sort_key)
         if has_dups(partition):
             raise ValueError("Partition contained duplicated elements.")
 
-        obj = C.FiniteSet.__new__(cls, list(map(C.FiniteSet, args)))
+        obj = C.FiniteSet.__new__(cls, *list(map(lambda x: C.FiniteSet(*x), args)))
         obj.members = tuple(partition)
         obj.size = len(partition)
         return obj
@@ -73,10 +74,10 @@ class Partition(C.FiniteSet):
         >>> from sympy.utilities.iterables import default_sort_key
         >>> from sympy.combinatorics.partitions import Partition
         >>> from sympy.abc import x
-        >>> a = Partition([[1, 2]])
-        >>> b = Partition([[3, 4]])
-        >>> c = Partition([[1, x]])
-        >>> d = Partition([list(range(4))])
+        >>> a = Partition([1, 2])
+        >>> b = Partition([3, 4])
+        >>> c = Partition([1, x])
+        >>> d = Partition(list(range(4)))
         >>> l = [d, b, a + 1, a, c]
         >>> l.sort(key=default_sort_key); l
         [{{1, 2}}, {{1}, {2}}, {{1, x}}, {{3, 4}}, {{0, 1, 2, 3}}]
@@ -96,7 +97,7 @@ class Partition(C.FiniteSet):
         ========
 
         >>> from sympy.combinatorics.partitions import Partition
-        >>> Partition([[1], [2, 3]]).partition
+        >>> Partition([1], [2, 3]).partition
         [[1], [2, 3]]
         """
         if self._partition is None:
@@ -113,7 +114,7 @@ class Partition(C.FiniteSet):
         ========
 
         >>> from sympy.combinatorics.partitions import Partition
-        >>> a = Partition([[1, 2], [3]])
+        >>> a = Partition([1, 2], [3])
         >>> a.rank
         1
         >>> (a + 1).rank
@@ -137,7 +138,7 @@ class Partition(C.FiniteSet):
         ========
 
         >>> from sympy.combinatorics.partitions import Partition
-        >>> a = Partition([[1, 2], [3]])
+        >>> a = Partition([1, 2], [3])
         >>> a.rank
         1
         >>> (a - 1).rank
@@ -156,8 +157,8 @@ class Partition(C.FiniteSet):
         ========
 
         >>> from sympy.combinatorics.partitions import Partition
-        >>> a = Partition([[1, 2], [3, 4, 5]])
-        >>> b = Partition([[1], [2, 3], [4], [5]])
+        >>> a = Partition([1, 2], [3, 4, 5])
+        >>> b = Partition([1], [2, 3], [4], [5])
         >>> a.rank, b.rank
         (9, 34)
         >>> a <= a
@@ -175,8 +176,8 @@ class Partition(C.FiniteSet):
         ========
 
         >>> from sympy.combinatorics.partitions import Partition
-        >>> a = Partition([[1, 2], [3, 4, 5]])
-        >>> b = Partition([[1], [2, 3], [4], [5]])
+        >>> a = Partition([1, 2], [3, 4, 5])
+        >>> b = Partition([1], [2, 3], [4], [5])
         >>> a.rank, b.rank
         (9, 34)
         >>> a < b
@@ -193,7 +194,7 @@ class Partition(C.FiniteSet):
         ========
 
         >>> from sympy.combinatorics.partitions import Partition
-        >>> a = Partition([[1, 2], [3], [4, 5]])
+        >>> a = Partition([1, 2], [3], [4, 5])
         >>> a.rank
         13
         """
@@ -216,13 +217,13 @@ class Partition(C.FiniteSet):
         ========
 
         >>> from sympy.combinatorics.partitions import Partition
-        >>> a = Partition([[1, 2], [3], [4, 5]])
+        >>> a = Partition([1, 2], [3], [4, 5])
         >>> a.members
         (1, 2, 3, 4, 5)
         >>> a.RGS
         (0, 0, 1, 2, 2)
         >>> a + 1
-        {{1, 2}, {3}, {4}, {5}}
+        {{3}, {4}, {5}, {1, 2}}
         >>> _.RGS
         (0, 0, 1, 2, 3)
         """
@@ -253,9 +254,9 @@ class Partition(C.FiniteSet):
         {{c}, {a, d}, {b, e}}
         >>> Partition.from_rgs([0, 1, 2, 0, 1], list('cbead'))
         {{e}, {a, c}, {b, d}}
-        >>> a = Partition([[1, 4], [2], [3, 5]])
+        >>> a = Partition([1, 4], [2], [3, 5])
         >>> Partition.from_rgs(a.RGS, a.members)
-        {{1, 4}, {2}, {3, 5}}
+        {{2}, {1, 4}, {3, 5}}
         """
         if len(rgs) != len(elements):
             raise ValueError('mismatch in rgs and element lengths')
@@ -267,7 +268,7 @@ class Partition(C.FiniteSet):
             j += 1
         if not all(p for p in partition):
             raise ValueError('some blocks of the partition were empty.')
-        return Partition(partition)
+        return Partition(*partition)
 
 
 class IntegerPartition(Basic):
@@ -625,7 +626,7 @@ def RGS_enum(m):
     We can check that the enumeration is correct by actually generating
     the partitions. Here, the 15 partitions of 4 items are generated:
 
-    >>> a = Partition([list(range(4))])
+    >>> a = Partition(list(range(4)))
     >>> s = set()
     >>> for i in range(20):
     ...     s.add(a)
