@@ -1,15 +1,20 @@
+from __future__ import print_function, division
+
 from sympy.core.containers import Tuple
 from sympy.core.core import C
 from sympy.core.expr import Expr
 from sympy.core.mul import Mul
 from sympy.core.singleton import S
 from sympy.core.sympify import sympify
+from sympy.concrete.expr_with_intlimits import ExprWithIntLimits
 from sympy.functions.elementary.piecewise import piecewise_fold
+from sympy.functions.elementary.exponential import exp, log
 from sympy.polys import quo, roots
 from sympy.simplify import powsimp
+from sympy.core.compatibility import xrange
 
 
-class Product(Expr):
+class Product(ExprWithIntLimits):
     r"""Represents unevaluated products.
 
     ``Product`` represents a finite or infinite product, with the first
@@ -187,106 +192,22 @@ class Product(Expr):
     __slots__ = ['is_commutative']
 
     def __new__(cls, function, *symbols, **assumptions):
-        from sympy.integrals.integrals import _process_limits
-
-        # Any embedded piecewise functions need to be brought out to the
-        # top level so that integration can go into piecewise mode at the
-        # earliest possible moment.
-        function = piecewise_fold(sympify(function))
-
-        if function is S.NaN:
-            return S.NaN
-
-        if not symbols:
-            raise ValueError("Product variables must be given")
-
-        limits, sign = _process_limits(*symbols)
-
-        # Only limits with lower and upper bounds are supported; the indefinite
-        # Product is not supported
-        if any(len(l) != 3 or None in l for l in limits):
-            raise ValueError(
-                'Product requires values for lower and upper bounds.')
-
-        obj = Expr.__new__(cls, **assumptions)
-        arglist = [sign*function]
-        arglist.extend(limits)
-        obj._args = tuple(arglist)
-        obj.is_commutative = function.is_commutative  # limits already checked
-
+        obj = ExprWithIntLimits.__new__(cls, function, *symbols, **assumptions)
         return obj
 
+    def _eval_rewrite_as_Sum(self, *args):
+        from sympy.concrete.summations import Sum
+        return exp(Sum(log(self.function), *self.limits))
+
     @property
     def term(self):
         return self._args[0]
     function = term
 
-    @property
-    def limits(self):
-        return self._args[1:]
-
-    @property
-    def variables(self):
-        """Return a list of the product variables
-
-        >>> from sympy import Product
-        >>> from sympy.abc import x, i
-        >>> Product(x**i, (i, 1, 3)).variables
-        [i]
-        """
-        return [l[0] for l in self.limits]
-
-    @property
-    def free_symbols(self):
-        """
-        This method returns the symbols that will affect the value of
-        the Product when evaluated. This is useful if one is trying to
-        determine whether a product depends on a certain symbol or not.
-
-        >>> from sympy import Product
-        >>> from sympy.abc import x, y
-        >>> Product(x, (x, y, 1)).free_symbols
-        set([y])
-        """
-        from sympy.integrals.integrals import _free_symbols
-        if self.function.is_zero or self.function == 1:
-            return set()
-        return _free_symbols(self)
-
-    @property
-    def is_zero(self):
-        """A Product is zero only if its term is zero.
-        """
+    def _eval_is_zero(self):
+        # a Product is zero only if its term is zero.
         return self.term.is_zero
 
-    @property
-    def is_number(self):
-        """
-        Return True if the Product will result in a number, else False.
-
-        Examples
-        ========
-
-        >>> from sympy import log, Product
-        >>> from sympy.abc import x, y, z
-        >>> log(2).is_number
-        True
-        >>> Product(x, (x, 1, 2)).is_number
-        True
-        >>> Product(y, (x, 1, 2)).is_number
-        False
-        >>> Product(1, (x, y, z)).is_number
-        True
-        >>> Product(2, (x, y, z)).is_number
-        False
-        """
-
-        return self.function.is_zero or self.function == 1 or not self.free_symbols
-
-    def as_dummy(self):
-        from sympy.integrals.integrals import _as_dummy
-        return _as_dummy(self)
-
     def doit(self, **hints):
         f = self.function
 
@@ -299,7 +220,7 @@ class Product(Expr):
 
             g = self._eval_product(f, (i, a, b))
             if g is None:
-                return Product(powsimp(f), *self.limits[index:])
+                return self.func(powsimp(f), *self.limits[index:])
             else:
                 f = g
 
@@ -310,11 +231,11 @@ class Product(Expr):
 
     def _eval_adjoint(self):
         if self.is_commutative:
-            return Product(self.function.adjoint(), *self.limits)
+            return self.func(self.function.adjoint(), *self.limits)
         return None
 
     def _eval_conjugate(self):
-        return Product(self.function.conjugate(), *self.limits)
+        return self.func(self.function.conjugate(), *self.limits)
 
     def _eval_product(self, term, limits):
         from sympy.concrete.delta import deltaproduct, _has_simple_delta
@@ -341,15 +262,17 @@ class Product(Expr):
 
             A = B = Q = S.One
 
-            all_roots = roots(poly, multiple=True)
+            all_roots = roots(poly)
 
-            for r in all_roots:
-                A *= C.RisingFactorial(a - r, n - a + 1)
-                Q *= n - r
+            M = 0
+            for r, m in all_roots.items():
+                M += m
+                A *= C.RisingFactorial(a - r, n - a + 1)**m
+                Q *= (n - r)**m
 
-            if len(all_roots) < poly.degree():
+            if M < poly.degree():
                 arg = quo(poly, Q.as_poly(k))
-                B = Product(arg, (k, a, n)).doit()
+                B = self.func(arg, (k, a, n)).doit()
 
             return poly.LC()**(n - a + 1) * A * B
 
@@ -377,7 +300,7 @@ class Product(Expr):
             else:
                 arg = term._new_rawargs(*include)
                 A = Mul(*exclude)
-                B = Product(arg, (k, a, n)).doit()
+                B = self.func(arg, (k, a, n)).doit()
                 return A * B
 
         elif term.is_Pow:
@@ -395,19 +318,101 @@ class Product(Expr):
             evaluated = term.doit()
             f = self._eval_product(evaluated, limits)
             if f is None:
-                return Product(evaluated, limits)
+                return self.func(evaluated, limits)
             else:
                 return f
 
+    def _eval_simplify(self, ratio, measure):
+        from sympy.simplify.simplify import product_simplify
+        return product_simplify(self)
+
     def _eval_transpose(self):
         if self.is_commutative:
-            return Product(self.function.transpose(), *self.limits)
+            return self.func(self.function.transpose(), *self.limits)
         return None
 
+    def reverse_order(expr, *indices):
+        """
+        Reverse the order of a limit in a Product.
 
-    def _eval_subs(self, old, new):
-        from sympy.integrals.integrals import _eval_subs
-        return _eval_subs(self, old, new)
+        Usage
+        =====
+
+        ``reverse_order(expr, *indices)`` reverses some limits in the expression
+        ``expr`` which can be either a ``Sum`` or a ``Product``. The selectors in
+        the argument ``indices`` specify some indices whose limits get reversed.
+        These selectors are either variable names or numerical indices counted
+        starting from the inner-most limit tuple.
+
+        Examples
+        ========
+
+        >>> from sympy import Product, simplify, RisingFactorial, gamma, Sum
+        >>> from sympy.abc import x, y, a, b, c, d
+        >>> P = Product(x, (x, a, b))
+        >>> Pr = P.reverse_order(x)
+        >>> Pr
+        Product(1/x, (x, b + 1, a - 1))
+        >>> Pr = Pr.doit()
+        >>> Pr
+        1/RisingFactorial(b + 1, a - b - 1)
+        >>> simplify(Pr)
+        gamma(b + 1)/gamma(a)
+        >>> P = P.doit()
+        >>> P
+        RisingFactorial(a, -a + b + 1)
+        >>> simplify(P)
+        gamma(b + 1)/gamma(a)
+
+        While one should prefer variable names when specifying which limits
+        to reverse, the index counting notation comes in handy in case there
+        are several symbols with the same name.
+
+        >>> S = Sum(x*y, (x, a, b), (y, c, d))
+        >>> S
+        Sum(x*y, (x, a, b), (y, c, d))
+        >>> S0 = S.reverse_order( 0)
+        >>> S0
+        Sum(-x*y, (x, b + 1, a - 1), (y, c, d))
+        >>> S1 = S0.reverse_order( 1)
+        >>> S1
+        Sum(x*y, (x, b + 1, a - 1), (y, d + 1, c - 1))
+
+        Of course we can mix both notations:
+
+        >>> Sum(x*y, (x, a, b), (y, 2, 5)).reverse_order( x, 1)
+        Sum(x*y, (x, b + 1, a - 1), (y, 6, 1))
+        >>> Sum(x*y, (x, a, b), (y, 2, 5)).reverse_order( y, x)
+        Sum(x*y, (x, b + 1, a - 1), (y, 6, 1))
+
+        See Also
+        ========
+
+        index, reorder_limit, reorder
+
+        References
+        ==========
+
+        .. [1] Michael Karr, "Summation in Finite Terms", Journal of the ACM,
+               Volume 28 Issue 2, April 1981, Pages 305-350
+               http://dl.acm.org/citation.cfm?doid=322248.322255
+        """
+        l_indices = list(indices)
+
+        for i, indx in enumerate(l_indices):
+            if not isinstance(indx, int):
+                l_indices[i] = expr.index(indx)
+
+        e = 1
+        limits = []
+        for i, limit in enumerate(expr.limits):
+            l = limit
+            if i in l_indices:
+                e = -e
+                l = (limit[0], limit[2] + 1 , limit[1] - 1)
+            limits.append(l)
+
+        return Product(expr.function ** e, *limits)
 
 
 def product(*args, **kwargs):
