@@ -8,7 +8,8 @@ from .singleton import S
 from .expr import Expr, AtomicExpr
 from .symbol import Symbol, Wild, Dummy, symbols, var
 from .numbers import Number, Float, Rational, Integer, NumberSymbol, \
-    RealNumber, igcd, ilcm, seterr, E, I, nan, oo, pi, zoo
+    RealNumber, igcd, ilcm, seterr, E, I, nan, oo, pi, zoo, \
+    AlgebraicNumber
 from .power import Pow, integer_nthroot
 from .mul import Mul, prod
 from .add import Add
@@ -22,11 +23,10 @@ from .function import Lambda, WildFunction, Derivative, diff, FunctionClass, \
     expand_mul, expand_log, expand_func, \
     expand_trig, expand_complex, expand_multinomial, nfloat, \
     expand_power_base, expand_power_exp
-from .sets import (Set, Interval, Union, EmptySet, FiniteSet, ProductSet,
-        Intersection, imageset)
 from .evalf import PrecisionExhausted, N
 from .containers import Tuple, Dict
 from .exprtools import gcd_terms, factor_terms, factor_nc
+from .evaluate import evaluate
 
 # expose singletons
 Catalan = S.Catalan
