@@ -11,6 +11,55 @@ from __future__ import print_function, division
 from sympy.core.compatibility import iterable
 
 
+def _fuzzy_group(args, quick_exit=False):
+    """Return True if all args are True, None if there is any None else False
+    unless ``quick_exit`` is True (then return None as soon as a second False
+    is seen.
+
+     ``_fuzzy_group`` is like ``fuzzy_and`` except that it is more
+    conservative in returning a False, waiting to make sure that all
+    arguments are True or False and returning None if any arguments are
+    None. It also has the capability of permiting only a single False and
+    returning None if more than one is seen. For example, the presence of a
+    single transcendental amongst rationals would indicate that the group is
+    no longer rational; but a second transcendental in the group would make the
+    determination impossible.
+
+
+    Examples
+    ========
+
+    >>> from sympy.core.logic import _fuzzy_group
+
+    By default, multiple Falses mean the group is broken:
+
+    >>> _fuzzy_group([False, False, True])
+    False
+
+    If multiple Falses mean the group status is unknown then set
+    `quick_exit` to True so None can be returned when the 2nd False is seen:
+
+    >>> _fuzzy_group([False, False, True], quick_exit=True)
+
+    But if only a single False is seen then the group is known to
+    be broken:
+
+    >>> _fuzzy_group([False, True, True], quick_exit=True)
+    False
+
+    """
+    saw_other = False
+    for a in args:
+        if a is True:
+            continue
+        if a is None:
+            return
+        if quick_exit and saw_other:
+            return
+        saw_other = True
+    return not saw_other
+
+
 def fuzzy_bool(x):
     """Return True, False or None according to x.
 
@@ -25,6 +74,9 @@ def fuzzy_bool(x):
 def fuzzy_and(args):
     """Return True (all True), False (any False) or None.
 
+    Examples
+    ========
+
     >>> from sympy.core.logic import fuzzy_and
     >>> from sympy import Dummy
 
@@ -59,10 +111,10 @@ def fuzzy_not(v):
     """
     Not in fuzzy logic
 
-    Will return Not if arg is a boolean value, and None if argument
-    is None.
+    Return None if `v` is None else `not v`.
 
-    Examples:
+    Examples
+    ========
 
     >>> from sympy.core.logic import fuzzy_not
     >>> fuzzy_not(True)
@@ -148,11 +200,11 @@ class Logic(object):
 
     @staticmethod
     def fromstring(text):
-        """Logic from string
+        """Logic from string with space around & and | but none after !.
 
            e.g.
 
-           !a & !b | c
+           !a & b | c
         """
         lexpr = None  # current logical expression
         schedop = None  # scheduled operation
@@ -167,7 +219,11 @@ class Logic(object):
                         '%s cannot be in the beginning of expression' % term)
                 schedop = term
                 continue
+            if '&' in term or '|' in term:
+                raise ValueError('& and | must have space around them')
             if term[0] == '!':
+                if len(term) == 1:
+                    raise ValueError('do not include space after "!"')
                 term = Not(term[1:])
 
             # already scheduled operation, e.g. '&'
@@ -298,6 +354,7 @@ class Not(Logic):
     def arg(self):
         return self.args[0]
 
+
 Logic.op_2class['&'] = And
 Logic.op_2class['|'] = Or
 Logic.op_2class['!'] = Not
