@@ -93,7 +93,8 @@ class vectorize:
         If no argument is given, everything is treated multidimensional.
         """
         for a in mdargs:
-            assert isinstance(a, (int, str))
+            if not isinstance(a, (int, str)):
+                raise TypeError("a is of invalid type")
         self.mdargs = mdargs
 
     def __call__(self, f):
