@@ -5,6 +5,7 @@ from .expr import Expr
 from .evalf import EvalfMixin
 from .symbol import Symbol
 from .sympify import _sympify
+from .evaluate import global_evaluate
 
 from sympy.logic.boolalg import Boolean
 
@@ -15,10 +16,21 @@ __all__ = (
 )
 
 
-def Rel(a, b, op):
-    """
-    A handy wrapper around the Relational class.
-    Rel(a,b, op)
+# Note, see issue 4986.  Ideally, we wouldn't want to subclass both Boolean
+# and Expr.
+
+class Relational(Boolean, Expr, EvalfMixin):
+    """Base class for all relation types.
+
+    Subclasses of Relational should generally be instantiated directly, but
+    Relational can be instantiated with a valid `rop` value to dispatch to
+    the appropriate subclass.
+
+    Parameters
+    ==========
+    rop : str or None
+        Indicates what subclass to instantiate.  Valid values can be found
+        in the keys of Relational.ValidRelationalOperator.
 
     Examples
     ========
@@ -29,13 +41,108 @@ def Rel(a, b, op):
     y == x**2 + x
 
     """
-    return Relational(a, b, op)
+    __slots__ = []
+
+    is_Relational = True
+
+    # ValidRelationOperator - Defined below, because the necessary classes
+    #   have not yet been defined
+
+    def __new__(cls, lhs, rhs, rop=None, **assumptions):
+        # If called by a subclass, do nothing special and pass on to Expr.
+        if cls is not Relational:
+            return Expr.__new__(cls, lhs, rhs, **assumptions)
+        # If called directly with an operator, look up the subclass
+        # corresponding to that operator and delegate to it
+        try:
+            cls = cls.ValidRelationOperator[rop]
+            return cls(lhs, rhs, **assumptions)
+        except KeyError:
+            raise ValueError("Invalid relational operator symbol: %r" % rop)
+
+    @property
+    def lhs(self):
+        """The left-hand side of the relation."""
+        return self._args[0]
+
+    @property
+    def rhs(self):
+        """The right-hand side of the relation."""
+        return self._args[1]
+
+    def _eval_evalf(self, prec):
+        return self.func(*[s._evalf(prec) for s in self.args])
+
+    def _eval_simplify(self, ratio, measure):
+        r = self.func(self.lhs.simplify(ratio=ratio, measure=measure),
+                      self.rhs.simplify(ratio=ratio, measure=measure))
+        if r not in (S.true, S.false):
+            if isinstance(self.lhs, Expr) and isinstance(self.rhs, Expr):
+                dif = self.lhs - self.rhs
+                # We want a Number to compare with zero and be sure to get a
+                # True/False answer.  Check if we can deduce that dif is
+                # definitively zero or non-zero.  If non-zero, replace with an
+                # approximation.  If .equals(0) gives None, cannot be deduced.
+                if not dif.has(Symbol):
+                    know = dif.equals(0)
+                    if know == True:
+                        dif = S.Zero
+                    elif know == False:
+                        dif = dif.evalf()
+                # Can definitively compare a Number to zero, if appropriate.
+                if dif.is_Number and (dif.is_real or self.func in (Eq, Ne)):
+                    # Always T/F (we never return an expression w/ the evalf)
+                    r = self.func._eval_relation(dif, S.Zero)
+
+        if measure(r) < ratio*measure(self):
+            return r
+        else:
+            return self
+
+    def __nonzero__(self):
+        raise TypeError("cannot determine truth value of\n%s" % self)
+
+    __bool__ = __nonzero__
+
+    def as_set(self):
+        """
+        Rewrites univariate inequality in terms of real sets
+
+        Examples
+        ========
+
+        >>> from sympy import Symbol, Eq
+        >>> x = Symbol('x', real=True)
+        >>> (x>0).as_set()
+        (0, oo)
+        >>> Eq(x, 0).as_set()
+        {0}
+
+        """
+        from sympy.solvers.inequalities import solve_univariate_inequality
+        syms = self.free_symbols
+
+        if len(syms) == 1:
+            sym = syms.pop()
+        else:
+            raise NotImplementedError("Sorry, Relational.as_set procedure"
+                                      " is not yet implemented for"
+                                      " multivariate expressions")
+
+        return solve_univariate_inequality(self, sym, relational=False)
 
 
-def Eq(a, b=0):
-    """
-    A handy wrapper around the Relational class.
-    Eq(a,b)
+Rel = Relational
+
+
+class Equality(Relational):
+    """An equal relation between two objects.
+
+    Represents that two objects are equal.  If they can be easily shown
+    to be definitively equal (or unequal), this will reduce to True (or
+    False).  Otherwise, the relation is maintained as an unevaluated
+    Equality object.  Use the ``simplify`` function on this object for
+    more nontrivial evaluation of the equality relation.
 
     Examples
     ========
@@ -45,14 +152,75 @@ def Eq(a, b=0):
     >>> Eq(y, x+x**2)
     y == x**2 + x
 
+    See Also
+    ========
+
+    sympy.logic.boolalg.Equivalent : for representing equality between two
+        boolean expressions
+
+    Notes
+    =====
+
+    This class is not the same as the == operator.  The == operator tests
+    for exact structural equality between two expressions; this class
+    compares expressions mathematically.
+
+    If either object defines an `_eval_Eq` method, it can be used in place of
+    the default algorithm.  If `lhs._eval_Eq(rhs)` or `rhs._eval_Eq(lhs)`
+    returns anything other than None, that return value will be substituted for
+    the Equality.  If None is returned by `_eval_Eq`, an Equality object will
+    be created as usual.
+
     """
-    return Relational(a, b, '==')
+    rel_op = '=='
+
+    __slots__ = []
+
+    is_Equality = True
+
+    def __new__(cls, lhs, rhs=0, **options):
+        lhs = _sympify(lhs)
+        rhs = _sympify(rhs)
+
+        evaluate = options.pop('evaluate', global_evaluate[0])
+
+        if evaluate:
+            # If one expression has an _eval_Eq, return its results.
+            if hasattr(lhs, '_eval_Eq'):
+                r = lhs._eval_Eq(rhs)
+                if r is not None:
+                    return r
+            if hasattr(rhs, '_eval_Eq'):
+                r = rhs._eval_Eq(lhs)
+                if r is not None:
+                    return r
+            # If expressions have the same structure, they must be equal.
+            if lhs == rhs:
+                return S.true
+
+            # If appropriate, check if the difference evaluates.  Detect
+            # incompatibility such as lhs real and rhs not real.
+            if lhs.is_complex and rhs.is_complex:
+                r = (lhs - rhs).is_zero
+                if r is not None:
+                    return _sympify(r)
+
+        return Relational.__new__(cls, lhs, rhs, **options)
+
+    @classmethod
+    def _eval_relation(cls, lhs, rhs):
+        return _sympify(lhs == rhs)
+
+Eq = Equality
 
 
-def Ne(a, b):
-    """
-    A handy wrapper around the Relational class.
-    Ne(a,b)
+class Unequality(Relational):
+    """An unequal relation between two objects.
+
+    Represents that two objects are not equal.  If they can be shown to be
+    definitively equal, this will reduce to False; if definitively unequal,
+    this will reduce to True.  Otherwise, the relation is maintained as an
+    Unequality object.
 
     Examples
     ========
@@ -62,211 +230,86 @@ def Ne(a, b):
     >>> Ne(y, x+x**2)
     y != x**2 + x
 
-    """
-    return Relational(a, b, '!=')
-
-
-def Lt(a, b):
-    """
-    A handy wrapper around the Relational class.
-    Lt(a,b)
-
-    Examples
+    See Also
     ========
+    Equality
 
-    >>> from sympy import Lt
-    >>> from sympy.abc import x, y
-    >>> Lt(y, x+x**2)
-    y < x**2 + x
+    Notes
+    =====
+    This class is not the same as the != operator.  The != operator tests
+    for exact structural equality between two expressions; this class
+    compares expressions mathematically.
+
+    This class is effectively the inverse of Equality.  As such, it uses the
+    same algorithms, including any available `_eval_Eq` methods.
 
     """
-    return Relational(a, b, '<')
-
-
-def Le(a, b):
-    """
-    A handy wrapper around the Relational class.
-    Le(a,b)
-
-    Examples
-    ========
-
-    >>> from sympy import Le
-    >>> from sympy.abc import x, y
-    >>> Le(y, x+x**2)
-    y <= x**2 + x
-
-    """
-    return Relational(a, b, '<=')
-
-
-def Gt(a, b):
-    """
-    A handy wrapper around the Relational class.
-    Gt(a,b)
-
-    Examples
-    ========
-
-    >>> from sympy import Gt
-    >>> from sympy.abc import x, y
-    >>> Gt(y, x + x**2)
-    y > x**2 + x
-
-    """
-    return Relational(a, b, '>')
-
-
-def Ge(a, b):
-    """
-    A handy wrapper around the Relational class.
-    Ge(a,b)
-
-    Examples
-    ========
-
-    >>> from sympy import Ge
-    >>> from sympy.abc import x, y
-    >>> Ge(y, x + x**2)
-    y >= x**2 + x
-
-    """
-    return Relational(a, b, '>=')
-
-# Note, see issue 1887.  Ideally, we wouldn't want to subclass both Boolean
-# and Expr.
-
-
-class Relational(Boolean, Expr, EvalfMixin):
-
-    __slots__ = []
-
-    is_Relational = True
-
-    # ValidRelationOperator - Defined below, because the necessary classes
-    #   have not yet been defined
-
-    def __new__(cls, lhs, rhs, rop=None, **assumptions):
-        lhs = _sympify(lhs)
-        rhs = _sympify(rhs)
-        if cls is not Relational:
-            rop_cls = cls
-        else:
-            try:
-                rop_cls = cls.ValidRelationOperator[ rop ]
-            except KeyError:
-                msg = "Invalid relational operator symbol: '%r'"
-                raise ValueError(msg % repr(rop))
-
-        diff = S.NaN
-        if isinstance(lhs, Expr) and isinstance(rhs, Expr):
-            diff = lhs - rhs
-        if not (diff is S.NaN or diff.has(Symbol)):
-            know = diff.equals(0, failing_expression=True)
-            if know is True:  # exclude failing expression case
-                diff = S.Zero
-            elif know is False:
-                diff = diff.n()
-        if rop_cls is Equality:
-            if (lhs == rhs) is True or (diff == S.Zero) is True:
-                return True
-            elif diff is S.NaN:
-                pass
-            elif diff.is_Number or diff.is_Float:
-                return False
-            elif lhs.is_real is not rhs.is_real and \
-                lhs.is_real is not None and \
-                   rhs.is_real is not None:
-                return False
-        elif rop_cls is Unequality:
-            if (lhs == rhs) is True or (diff == S.Zero) is True:
-                return False
-            elif diff is S.NaN:
-                pass
-            elif diff.is_Number or diff.is_Float:
-                return True
-            elif lhs.is_real is not rhs.is_real and \
-                lhs.is_real is not None and \
-                   rhs.is_real is not None:
-                return True
-        elif diff.is_Number and diff.is_real:
-            return rop_cls._eval_relation(diff, S.Zero)
-
-        obj = Expr.__new__(rop_cls, lhs, rhs, **assumptions)
-        return obj
-
-    @property
-    def lhs(self):
-        return self._args[0]
-
-    @property
-    def rhs(self):
-        return self._args[1]
-
-    def _eval_evalf(self, prec):
-        return self.func(*[s._evalf(prec) for s in self.args])
-
-    def doit(self, **hints):
-        lhs = self.lhs
-        rhs = self.rhs
-        if hints.get('deep', True):
-            lhs = lhs.doit(**hints)
-            rhs = rhs.doit(**hints)
-        return self._eval_relation_doit(lhs, rhs)
-
-    @classmethod
-    def _eval_relation_doit(cls, lhs, rhs):
-        return cls._eval_relation(lhs, rhs)
-
-    def _eval_simplify(self, ratio, measure):
-        return self.__class__(self.lhs.simplify(ratio=ratio),
-                              self.rhs.simplify(ratio=ratio))
-
-    def __nonzero__(self):
-        raise TypeError("symbolic boolean expression has no truth value.")
-
-    __bool__ = __nonzero__
-
-
-class Equality(Relational):
-
-    rel_op = '=='
-
-    __slots__ = []
-
-    is_Equality = True
-
-    @classmethod
-    def _eval_relation(cls, lhs, rhs):
-        return lhs == rhs
-
-    @classmethod
-    def _eval_relation_doit(cls, lhs, rhs):
-        return Eq(lhs, rhs)
-
-
-class Unequality(Relational):
-
     rel_op = '!='
 
     __slots__ = []
 
+    def __new__(cls, lhs, rhs, **options):
+        lhs = _sympify(lhs)
+        rhs = _sympify(rhs)
+
+        evaluate = options.pop('evaluate', global_evaluate[0])
+
+        if evaluate:
+            is_equal = Equality(lhs, rhs)
+            if is_equal == True or is_equal == False:
+                return ~is_equal
+
+        return Relational.__new__(cls, lhs, rhs, **options)
+
     @classmethod
     def _eval_relation(cls, lhs, rhs):
-        return lhs != rhs
+        return _sympify(lhs != rhs)
 
-    @classmethod
-    def _eval_relation_doit(cls, lhs, rhs):
-        return Ne(lhs, rhs)
+Ne = Unequality
 
 
-class _Greater(Relational):
+class _Inequality(Relational):
+    """Internal base class for all *Than types.
+
+    Each subclass must implement _eval_relation to provide the method for
+    comparing two real numbers.
+
+    """
+    __slots__ = []
+
+    def __new__(cls, lhs, rhs, **options):
+        lhs = _sympify(lhs)
+        rhs = _sympify(rhs)
+
+        evaluate = options.pop('evaluate', global_evaluate[0])
+
+        if evaluate:
+            # First we invoke the appropriate inequality method of `lhs`
+            # (e.g., `lhs.__lt__`).  That method will try to reduce to
+            # boolean or raise an exception.  It may keep calling
+            # superclasses until it reaches `Expr` (e.g., `Expr.__lt__`).
+            # In some cases, `Expr` will just invoke us again (if neither it
+            # nor a subclass was able to reduce to boolean or raise an
+            # exception).  In that case, it must call us with
+            # `evaluate=False` to prevent infinite recursion.
+            r = cls._eval_relation(lhs, rhs)
+            if r is not None:
+                return r
+            # Note: not sure r could be None, perhaps we never take this
+            # path?  In principle, could use this to shortcut out if a
+            # class realizes the inequality cannot be evaluated further.
+
+        # make a "non-evaluated" Expr for the inequality
+        return Relational.__new__(cls, lhs, rhs, **options)
+
+
+class _Greater(_Inequality):
     """Not intended for general use
 
     _Greater is only used so that GreaterThan and StrictGreaterThan may subclass
     it for the .gts and .lts properties.
-    """
 
+    """
     __slots__ = ()
 
     @property
@@ -278,13 +321,13 @@ class _Greater(Relational):
         return self._args[1]
 
 
-class _Less(Relational):
+class _Less(_Inequality):
     """Not intended for general use.
 
     _Less is only used so that LessThan and StrictLessThan may subclass it for
     the .gts and .lts properties.
-    """
 
+    """
     __slots__ = ()
 
     @property
@@ -500,7 +543,7 @@ class GreaterThan(_Greater):
     .. [1] This implementation detail is that Python provides no reliable
        method to determine that a chained inequality is being built.  Chained
        comparison operators are evaluated pairwise, using "and" logic (see
-       http://docs.python.org/reference/expressions.html#notin).  This is done
+       http://docs.python.org/2/reference/expressions.html#notin).  This is done
        in an efficient way, so that each object being compared is only
        evaluated once and the comparison can short-circuit.  For example, ``1
        > 2 > 3`` is evaluated by Python as ``(1 > 2) and (2 > 3)``.  The
@@ -523,26 +566,28 @@ class GreaterThan(_Greater):
 
            In Python, there is no way to override the ``and`` operator, or to
            control how it short circuits, so it is impossible to make something
-           like ``x > y > z`` work.  There is an open PEP to change this,
-           :pep:`335`, but until that is implemented, this cannot be made to work.
+           like ``x > y > z`` work.  There was a PEP to change this,
+           :pep:`335`, but it was officially closed in March, 2012.
 
     .. [2] For more information, see these two bug reports:
 
        "Separate boolean and symbolic relationals"
-       `Issue 1887 <http://code.google.com/p/sympy/issues/detail?id=1887>`_
+       `Issue 4986 <https://github.com/sympy/sympy/issues/4986>`_
 
        "It right 0 < x < 1 ?"
-       `Issue 2960 <http://code.google.com/p/sympy/issues/detail?id=2960>`_
+       `Issue 6059 <https://github.com/sympy/sympy/issues/6059>`_
 
     """
-
     rel_op = '>='
 
     __slots__ = ()
 
     @classmethod
     def _eval_relation(cls, lhs, rhs):
-        return lhs >= rhs
+        # We don't use the op symbol here: workaround issue #7951
+        return _sympify(lhs.__ge__(rhs))
+
+Ge = GreaterThan
 
 
 class LessThan(_Less):
@@ -553,7 +598,10 @@ class LessThan(_Less):
 
     @classmethod
     def _eval_relation(cls, lhs, rhs):
-        return lhs <= rhs
+        # We don't use the op symbol here: workaround issue #7951
+        return _sympify(lhs.__le__(rhs))
+
+Le = LessThan
 
 
 class StrictGreaterThan(_Greater):
@@ -564,7 +612,10 @@ class StrictGreaterThan(_Greater):
 
     @classmethod
     def _eval_relation(cls, lhs, rhs):
-        return lhs > rhs
+        # We don't use the op symbol here: workaround issue #7951
+        return _sympify(lhs.__gt__(rhs))
+
+Gt = StrictGreaterThan
 
 
 class StrictLessThan(_Less):
@@ -575,7 +626,10 @@ class StrictLessThan(_Less):
 
     @classmethod
     def _eval_relation(cls, lhs, rhs):
-        return lhs < rhs
+        # We don't use the op symbol here: workaround issue #7951
+        return _sympify(lhs.__lt__(rhs))
+
+Lt = StrictLessThan
 
 
 # A class-specific (not object-specific) data item used for a minor speedup.  It
