@@ -1,7 +1,7 @@
 import decimal
 from sympy import (Rational, Symbol, Float, I, sqrt, oo, nan, pi, E, Integer,
                    S, factorial, Catalan, EulerGamma, GoldenRatio, cos, exp,
-                   Number, zoo, log, Mul, Pow, Tuple, latex)
+                   Number, zoo, log, Mul, Pow, Tuple, latex, Gt, Lt, Ge, Le)
 from sympy.core.basic import _aresame
 from sympy.core.compatibility import long, u
 from sympy.core.power import integer_nthroot
@@ -21,19 +21,16 @@ def test_integers_cache():
 
     assert python_int in _intcache
     assert hash(python_int) not in _intcache
-    assert sympy_int not in _intcache
 
     sympy_int_int = Integer(sympy_int)
 
     assert python_int in _intcache
     assert hash(python_int) not in _intcache
-    assert sympy_int_int not in _intcache
 
     sympy_hash_int = Integer(hash(python_int))
 
     assert python_int in _intcache
     assert hash(python_int) in _intcache
-    assert sympy_hash_int not in _intcache
 
 
 def test_seterr():
@@ -189,6 +186,7 @@ def test_igcd():
     assert igcd(7, -3) == 1
     assert igcd(-7, 3) == 1
     assert igcd(-7, -3) == 1
+    assert igcd(*[10, 20, 30]) == 10
     raises(ValueError, lambda: igcd(45.1, 30))
     raises(ValueError, lambda: igcd(45, 30.1))
 
@@ -202,6 +200,7 @@ def test_ilcm():
     assert ilcm(8, 2) == 8
     assert ilcm(8, 6) == 24
     assert ilcm(8, 7) == 56
+    assert ilcm(*[10, 20, 30]) == 60
     raises(ValueError, lambda: ilcm(8.1, 7))
     raises(ValueError, lambda: ilcm(8, 7.1))
 
@@ -333,6 +332,11 @@ def test_Rational_cmp():
     assert not (Rational(-1) > 0)
     assert Rational(-1) < 0
 
+    assert (n1 < S.NaN) is S.false
+    assert (n1 <= S.NaN) is S.false
+    assert (n1 > S.NaN) is S.false
+    assert (n1 >= S.NaN) is S.false
+
 
 def test_Float():
     def eq(a, b):
@@ -363,27 +367,30 @@ def test_Float():
 
     raises(ValueError, lambda: Float((0, 7, 1, 3), ''))
 
-    assert Float('+inf').is_bounded is False
     assert Float('+inf').is_finite is False
     assert Float('+inf').is_negative is False
     assert Float('+inf').is_positive is True
-    assert Float('+inf').is_unbounded is True
+    assert Float('+inf').is_infinite is True
     assert Float('+inf').is_zero is False
 
-    assert Float('-inf').is_bounded is False
     assert Float('-inf').is_finite is False
     assert Float('-inf').is_negative is True
     assert Float('-inf').is_positive is False
-    assert Float('-inf').is_unbounded is True
+    assert Float('-inf').is_infinite is True
     assert Float('-inf').is_zero is False
 
-    assert Float('0.0').is_bounded is True
-    assert Float('0.0').is_finite is False
+    assert Float('0.0').is_finite is True
     assert Float('0.0').is_negative is False
     assert Float('0.0').is_positive is False
-    assert Float('0.0').is_unbounded is False
+    assert Float('0.0').is_infinite is False
     assert Float('0.0').is_zero is True
 
+    # rationality properties
+    assert Float(1).is_rational is None
+    assert Float(1).is_irrational is None
+    assert sqrt(2).n(15).is_rational is None
+    assert sqrt(2).n(15).is_irrational is None
+
     # do not automatically evalf
     def teq(a):
         assert (a.evalf() == a) is False
@@ -439,6 +446,10 @@ def test_Float():
 
     assert Float(decimal.Decimal('0.1'), 3) == Float('.1', 3)
 
+    assert '{0:.3f}'.format(Float(4.236622)) == '4.237'
+    assert '{0:.35f}'.format(Float(pi.n(40), 40)) == '3.14159265358979323846264338327950288'
+
+
 def test_Float_eval():
     a = Float(3.2)
     assert (a**2).is_Float
@@ -657,13 +668,13 @@ def test_Mul_Infinity_Zero():
 
 
 def test_Div_By_Zero():
-    assert 1/S(0) == oo
+    assert 1/S(0) == zoo
     assert 1/Float(0) == Float('inf')
     assert 0/S(0) == nan
     assert 0/Float(0) == nan
     assert S(0)/0 == nan
     assert Float(0)/0 == nan
-    assert -1/S(0) == -oo
+    assert -1/S(0) == zoo
     assert -1/Float(0) == Float('-inf')
 
 
@@ -676,6 +687,45 @@ def test_Infinity_inequations():
     assert not (Float('+inf') < pi)
     assert exp(-3) < Float('+inf')
 
+    raises(TypeError, lambda: oo < I)
+    raises(TypeError, lambda: oo <= I)
+    raises(TypeError, lambda: oo > I)
+    raises(TypeError, lambda: oo >= I)
+    raises(TypeError, lambda: -oo < I)
+    raises(TypeError, lambda: -oo <= I)
+    raises(TypeError, lambda: -oo > I)
+    raises(TypeError, lambda: -oo >= I)
+
+    raises(TypeError, lambda: I < oo)
+    raises(TypeError, lambda: I <= oo)
+    raises(TypeError, lambda: I > oo)
+    raises(TypeError, lambda: I >= oo)
+    raises(TypeError, lambda: I < -oo)
+    raises(TypeError, lambda: I <= -oo)
+    raises(TypeError, lambda: I > -oo)
+    raises(TypeError, lambda: I >= -oo)
+
+    assert oo > -oo and oo >= -oo
+    assert (oo < -oo) == False and (oo <= -oo) == False
+    assert -oo < oo and -oo <= oo
+    assert (-oo > oo) == False and (-oo >= oo) == False
+
+    assert (oo < oo) == False  # issue 7775
+    assert (oo > oo) == False
+    assert (-oo > -oo) == False and (-oo < -oo) == False
+    assert oo >= oo and oo <= oo and -oo >= -oo and -oo <= -oo
+
+    x = Symbol('x')
+    b = Symbol('b', finite=True, real=True)
+    assert (x < oo) == Lt(x, oo)  # issue 7775
+    assert b < oo and b > -oo and b <= oo and b >= -oo
+    assert oo > b and oo >= b and (oo < b) == False and (oo <= b) == False
+    assert (-oo > b) == False and (-oo >= b) == False and -oo < b and -oo <= b
+    assert (oo < x) == Lt(oo, x) and (oo > x) == Gt(oo, x)
+    assert (oo <= x) == Le(oo, x) and (oo >= x) == Ge(oo, x)
+    assert (-oo < x) == Lt(-oo, x) and (-oo > x) == Gt(-oo, x)
+    assert (-oo <= x) == Le(-oo, x) and (-oo >= x) == Ge(-oo, x)
+
 
 def test_NaN():
     assert nan == nan
@@ -710,7 +760,9 @@ def test_NaN():
     assert nan + S.One == nan
     assert nan/S.One == nan
     assert nan**0 == 1  # as per IEEE 754
-    assert 1**nan == 1  # as per IEEE 754
+    assert 1**nan == nan # IEEE 754 is not the best choice for symbolic work
+    # test Pow._eval_power's handling of NaN
+    assert Pow(nan, 0, evaluate=False)**2 == 1
 
 
 def test_special_numbers():
@@ -721,6 +773,7 @@ def test_special_numbers():
     assert S.NaN.is_number is True
     assert S.Infinity.is_number is True
     assert S.NegativeInfinity.is_number is True
+    assert S.ComplexInfinity.is_number is True
 
     assert isinstance(S.NaN, Rational) is False
     assert isinstance(S.Infinity, Rational) is False
@@ -778,14 +831,14 @@ def test_integer_nthroot_overflow():
 def test_powers_Integer():
     """Test Integer._eval_power"""
     # check infinity
-    assert S(1) ** S.Infinity == 1
+    assert S(1) ** S.Infinity == S.NaN
     assert S(-1)** S.Infinity == S.NaN
     assert S(2) ** S.Infinity == S.Infinity
     assert S(-2)** S.Infinity == S.Infinity + S.Infinity * S.ImaginaryUnit
     assert S(0) ** S.Infinity == 0
 
     # check Nan
-    assert S(1) ** S.NaN == S.One
+    assert S(1) ** S.NaN == S.NaN
     assert S(-1) ** S.NaN == S.NaN
 
     # check for exact roots
@@ -980,27 +1033,26 @@ def test_no_len():
     raises(TypeError, lambda: len(Integer(2)))
 
 
-def test_issue222():
+def test_issue_3321():
     assert sqrt(Rational(1, 5)) == sqrt(Rational(1, 5))
     assert 5 * sqrt(Rational(1, 5)) == sqrt(5)
 
 
-def test_issue593():
+def test_issue_3692():
     assert ((-1)**Rational(1, 6)).expand(complex=True) == I/2 + sqrt(3)/2
     assert ((-5)**Rational(1, 6)).expand(complex=True) == \
         5**Rational(1, 6)*I/2 + 5**Rational(1, 6)*sqrt(3)/2
     assert ((-64)**Rational(1, 6)).expand(complex=True) == I + sqrt(3)
 
 
-def test_issue324():
+def test_issue_3423():
     x = Symbol("x")
     assert sqrt(x - 1).as_base_exp() == (x - 1, S.Half)
     assert sqrt(x - 1) != I*sqrt(1 - x)
 
 
-def test_issue350():
-    x = Symbol("x", real=True)
-    assert sqrt(x**2) == abs(x)
+def test_issue_3449():
+    x = Symbol("x")
     assert sqrt(x - 1).subs(x, 5) == 2
 
 
@@ -1075,7 +1127,7 @@ def test_Rational_factors():
     assert str(F(-25, 14*9, visual=True)) == '-5**2/(2*3**2*7)'
 
 
-def test_issue1008():
+def test_issue_4107():
     assert pi*(E + 10) + pi*(-E - 10) != 0
     assert pi*(E + 10**10) + pi*(-E - 10**10) != 0
     assert pi*(E + 10**20) + pi*(-E - 10**20) != 0
@@ -1143,7 +1195,7 @@ def test_Float_gcd_lcm_cofactors():
         (S.One, Float(2.0), Rational(1, 2))
 
 
-def test_issue1512():
+def test_issue_4611():
     assert abs(pi._evalf(50) - 3.14159265358979) < 1e-10
     assert abs(E._evalf(50) - 2.71828182845905) < 1e-10
     assert abs(Catalan._evalf(50) - 0.915965594177219) < 1e-10
@@ -1194,23 +1246,23 @@ def test_Rational_int():
 
 
 def test_zoo():
-    b = Symbol('b', bounded=True)
+    b = Symbol('b', finite=True)
     nz = Symbol('nz', nonzero=True)
     p = Symbol('p', positive=True)
     n = Symbol('n', negative=True)
     im = Symbol('i', imaginary=True)
     c = Symbol('c', complex=True)
-    pb = Symbol('pb', positive=True, bounded=True)
-    nb = Symbol('nb', negative=True, bounded=True)
-    imb = Symbol('ib', imaginary=True, bounded=True)
+    pb = Symbol('pb', positive=True, finite=True)
+    nb = Symbol('nb', negative=True, finite=True)
+    imb = Symbol('ib', imaginary=True, finite=True)
     for i in [I, S.Infinity, S.NegativeInfinity, S.Zero, S.One, S.Pi, S.Half, S(3), log(3),
               b, nz, p, n, im, pb, nb, imb, c]:
-        if i.is_bounded and (i.is_real or i.is_imaginary):
+        if i.is_finite and (i.is_real or i.is_imaginary):
             assert i + zoo is zoo
             assert i - zoo is zoo
             assert zoo + i is zoo
             assert zoo - i is zoo
-        elif i.is_bounded is not False:
+        elif i.is_finite is not False:
             assert (i + zoo).is_Add
             assert (i - zoo).is_Add
             assert (zoo + i).is_Add
@@ -1235,6 +1287,8 @@ def test_zoo():
             assert zoo/i is zoo
         elif (1/i).is_zero:
             assert zoo/i is S.NaN
+        elif i.is_zero:
+            assert zoo/i is zoo
         else:
             assert (zoo/i).is_Mul
 
@@ -1251,41 +1305,25 @@ def test_zoo():
     assert Mul.flatten([S(-1), oo, S(0)]) == ([S.NaN], [], None)
 
 
-def test_issue_1023():
+def test_issue_4122():
     x = Symbol('x', nonpositive=True)
     assert (oo + x).is_Add
-    x = Symbol('x', bounded=True)
-    assert (oo + x).is_Add  # x could be imaginary
     x = Symbol('x', finite=True)
     assert (oo + x).is_Add  # x could be imaginary
-    x = Symbol('x', infinitesimal=True)
-    assert (oo + x).is_Add  # x could be imaginary
     x = Symbol('x', nonnegative=True)
     assert oo + x == oo
-    x = Symbol('x', bounded=True, real=True)
-    assert oo + x == oo
     x = Symbol('x', finite=True, real=True)
     assert oo + x == oo
-    x = Symbol('x', infinitesimal=True, real=True)
-    assert oo + x == oo
 
     # similarily for negative infinity
     x = Symbol('x', nonnegative=True)
     assert (-oo + x).is_Add
-    x = Symbol('x', bounded=True)
-    assert (-oo + x).is_Add
     x = Symbol('x', finite=True)
     assert (-oo + x).is_Add
-    x = Symbol('x', infinitesimal=True)
-    assert (-oo + x).is_Add
     x = Symbol('x', nonpositive=True)
     assert -oo + x == -oo
-    x = Symbol('x', bounded=True, real=True)
-    assert -oo + x == -oo
     x = Symbol('x', finite=True, real=True)
     assert -oo + x == -oo
-    x = Symbol('x', infinitesimal=True, real=True)
-    assert -oo + x == -oo
 
 
 def test_GoldenRatio_expand():
@@ -1300,15 +1338,13 @@ def test_as_content_primitive():
     assert S(3.1).as_content_primitive() == (1, 3.1)
 
 
-@XFAIL
 def test_hashing_sympy_integers():
-    # Test for issue #1973
-    # http://code.google.com/p/sympy/issues/detail?id=1973
-    assert hash(S(4)) == 4
-    assert hash(S(4)) == hash(int(4))
+    # Test for issue 5072
+    assert set([Integer(3)]) == set([int(3)])
+    assert hash(Integer(4)) == hash(int(4))
 
 
-def test_issue_1073():
+def test_issue_4172():
     assert int((E**100).round()) == \
         26881171418161354484126255515800135873611119
     assert int((pi**100).round()) == \
@@ -1359,7 +1395,7 @@ def test_int_NumberSymbols():
         [3, 0, 2, 1, 0]
 
 
-def test_3541():
+def test_issue_6640():
     from sympy.mpmath.libmp.libmpf import (
         _normalize as mpf_normalize, finf, fninf, fzero)
     # fnan is not included because Float no longer returns fnan,
@@ -1369,7 +1405,7 @@ def test_3541():
     assert bool(Float(0)) is False
 
 
-def test_3250():
+def test_issue_6349():
     assert Float('23.e3', '')._prec == 10
     assert Float('23e3', '')._prec == 20
     assert Float('23000', '')._prec == 20
@@ -1389,3 +1425,7 @@ def test_latex():
     assert latex(zoo) == r"\tilde{\infty}"
     assert latex(nan) == r"\mathrm{NaN}"
     assert latex(I) == r"i"
+
+
+def test_issue_7742():
+    assert -oo % 1 == nan
