@@ -15,14 +15,16 @@ from sympy import (Rational, symbols, factorial, sqrt, log, exp, oo, zoo,
     atan, sinh, cosh, tanh, floor, ceiling, solve, asinh, acot, csc, sec,
     LambertW, N, apart, sqrtdenest, factorial2, powdenest, Mul, S, mpmath, ZZ,
     Poly, expand_func, E, Q, And, Or, Ne, Eq, Le, Lt,
-    ask, refine, AlgebraicNumber,
-    elliptic_e, elliptic_f, powsimp, hessian, wronskian, fibonacci, sign,
-    Lambda, Piecewise, Subs, residue, Derivative, logcombine)
+    ask, refine, AlgebraicNumber, continued_fraction_iterator as cf_i,
+    continued_fraction_periodic as cf_p, continued_fraction_convergents as cf_c,
+    continued_fraction_reduce as cf_r, FiniteSet, elliptic_e, elliptic_f,
+    powsimp, hessian, wronskian, fibonacci, sign, Lambda, Piecewise, Subs,
+    residue, Derivative, logcombine, Symbol)
 
 from sympy.functions.combinatorial.numbers import stirling
 from sympy.functions.special.zeta_functions import zeta
 from sympy.integrals.deltafunctions import deltaintegrate
-from sympy.utilities.pytest import XFAIL, slow
+from sympy.utilities.pytest import XFAIL, slow, SKIP, skip, ON_TRAVIS
 from sympy.utilities.iterables import partitions
 from sympy.mpmath import mpi, mpc
 from sympy.matrices import Matrix, GramSchmidt, eye
@@ -45,6 +47,7 @@ from sympy.functions.special.delta_functions import Heaviside
 from sympy.solvers.recurr import rsolve
 from sympy.solvers.ode import dsolve
 from sympy.core.relational import Equality
+from itertools import islice, takewhile
 
 R = Rational
 x, y, z = symbols('x y z')
@@ -56,7 +59,27 @@ g = Function('g')
 #   Not implemented.
 
 # B. Set Theory
-#   Not implemented.
+
+
+def test_B1():
+    assert (FiniteSet(i, j, j, k, k, k) | FiniteSet(l, k, j) |
+            FiniteSet(j, m, j)) == FiniteSet(i, j, k, l, m)
+
+
+def test_B2():
+    assert (FiniteSet(i, j, j, k, k, k) & FiniteSet(l, k, j) &
+            FiniteSet(j, m, j)) == FiniteSet(j)
+
+
+def test_B3():
+    assert (FiniteSet(i, j, k, l, m) - FiniteSet(j) ==
+            FiniteSet(i, k, l, m))
+
+
+def test_B4():
+    assert (FiniteSet(*(FiniteSet(i, j)*FiniteSet(k, l))) ==
+            FiniteSet((i, k), (i, l), (j, k), (j, l)))
+
 
 # C. Numbers
 
@@ -314,7 +337,45 @@ def test_G2():
 def test_G3():
     raise NotImplementedError("(a+b)**p mod p == a**p + b**p mod p; p prime")
 
-# ... G20 Modular equations and continued fractions are not implemented.
+# ... G14 Modular equations are not implemented.
+
+def test_G15():
+    assert Rational(sqrt(3).evalf()).limit_denominator(15) == Rational(26, 15)
+    assert list(takewhile(lambda x: x.q <= 15, cf_c(cf_i(sqrt(3)))))[-1] == \
+        Rational(26, 15)
+
+
+def test_G16():
+    assert list(islice(cf_i(pi),10)) == [3, 7, 15, 1, 292, 1, 1, 1, 2, 1]
+
+
+def test_G17():
+    assert cf_p(0, 1, 23) == [4, [1, 3, 1, 8]]
+
+
+def test_G18():
+    assert cf_p(1, 2, 5) == [[1]]
+    assert cf_r([[1]]) == S.Half + sqrt(5)/2
+
+
+@XFAIL
+def test_G19():
+    s = symbols('s', integer=True, positive=True)
+    it = cf_i((exp(1/s) - 1)/(exp(1/s) + 1))
+    assert list(islice(it, 5)) == [0, 2*s, 6*s, 10*s, 14*s]
+
+
+def test_G20():
+    s = symbols('s', integer=True, positive=True)
+    # Wester erroneously has this as -s + sqrt(s**2 + 1)
+    assert cf_r([[2*s]]) == s + sqrt(s**2 + 1)
+
+
+@XFAIL
+def test_G20b():
+    s = symbols('s', integer=True, positive=True)
+    assert cf_p(s, 1, s**2 + 1) == [[2*s]]
+
 
 # H. Algebra
 
@@ -511,7 +572,7 @@ def test_H31():
 
 
 @XFAIL
-def test_H32():  # issue 3459
+def test_H32():  # issue 6558
     raise NotImplementedError("[A*B*C - (A*B*C)**(-1)]*A*C*B (product \
                               of a non-commuting product and its inverse)")
 
@@ -681,7 +742,6 @@ def test_K1():
     assert im(z1 + I*z2) == im(z1) + re(z2)
 
 
-@XFAIL  # abs(...).n() does evaluate to 1.00000...
 def test_K2():
     assert abs(3 - sqrt(7) + I*sqrt(6*sqrt(7) - 15)) == 1
 
@@ -698,8 +758,8 @@ def test_K4():
 
 def test_K5():
     x, y = symbols('x, y', real=True)
-    assert tan(x + I*y).expand(complex=True) == sin(x)*cos(x) / (cos(x)**2 +
-    sinh(y)**2) + I*sinh(y)*cosh(y) / (cos(x)**2 + sinh(y)**2)
+    assert tan(x + I*y).expand(complex=True) == (sin(2*x)/(cos(2*x) +
+        cosh(2*y)) + I*sinh(2*y)/(cos(2*x) + cosh(2*y)))
 
 
 def test_K6():
@@ -891,6 +951,7 @@ def test_M21():
     assert solve(x + sqrt(x) - 2) == [1]
 
 
+@slow
 def test_M22():
     assert solve(2*sqrt(x) + 3*x**R(1, 4) - 2) == [R(1, 16)]
 
@@ -934,6 +995,7 @@ def test_M28():
 
 
 def test_M29():
+    x = symbols('x', real=True)
     assert solve(abs(x - 1) - 2) == [-1, 3]
 
 
@@ -1093,35 +1155,43 @@ def test_N8():
 
 
 def test_N9():
-    with assuming(Q.real(x)):
-        assert solve(abs(x - 1) > 2) == Or(x < -1, x > 3)
+    x = Symbol('x', real=True)
+    assert solve(abs(x - 1) > 2) == Or(And(Lt(-oo, x), Lt(x, -1)),
+                                           And(Lt(3, x), Lt(x, oo)))
 
 
 def test_N10():
+    x = Symbol('x', real=True)
     p = (x - 1)*(x - 2)*(x - 3)*(x - 4)*(x - 5)
-    assert solve(expand(p) < 0, assume=Q.real(x)) == Or(
-        And(Lt(2, x), Lt(x, 3)), And(Lt(4, x), Lt(x, 5)), Lt(x, 1))
+    assert solve(expand(p) < 0) == Or(
+        And(Lt(-oo, x), Lt(x, 1)), And(Lt(2, x), Lt(x, 3)),
+        And(Lt(4, x), Lt(x, 5)))
 
 
 def test_N11():
-    assert solve(6/(x - 3) <= 3, assume=Q.real(x)) == Or(5 <= x, x < 3)
+    x = Symbol('x', real=True)
+    assert solve(6/(x - 3) <= 3) == \
+        Or(And(Le(5, x), Lt(x, oo)), And(Lt(-oo, x), Lt(x, 3)))
 
 
 @XFAIL
 def test_N12():
-    assert solve(sqrt(x) < 2, assume=Q.real(x)) == And(Le(0, x), Lt(x, 4))
+    x = Symbol('x', real=True)
+    assert solve(sqrt(x) < 2) == And(Le(0, x), Lt(x, 4))
 
 
 @XFAIL
 def test_N13():
     # raises NotImplementedError: can't reduce [sin(x) < 2]
-    assert solve(sin(x) < 2, assume=Q.real(x)) == [] # S.Reals not found
+    x = Symbol('x', real=True)
+    assert solve(sin(x) < 2) == [] # S.Reals not found
 
 
 @XFAIL
 def test_N14():
     # raises NotImplementedError: can't reduce [sin(x) < 1]
-    assert (solve(sin(x) < 1, assume=Q.real(x)) == Ne(x, pi/2))
+    x = Symbol('x', real=True)
+    assert (solve(sin(x) < 1) == Ne(x, pi/2))
 
 
 @XFAIL
@@ -1515,13 +1585,13 @@ def test_P27():
 @XFAIL
 def test_P28():
     raise NotImplementedError("Generalized eigenvectors not supported \
-https://code.google.com/p/sympy/issues/detail?id=2194")
+https://github.com/sympy/sympy/issues/5293")
 
 
 @XFAIL
 def test_P29():
     raise NotImplementedError("Generalized eigenvectors not supported \
-https://code.google.com/p/sympy/issues/detail?id=2194")
+https://github.com/sympy/sympy/issues/5293")
 
 
 def test_P30():
@@ -1573,7 +1643,7 @@ def test_P34():
                 [0, 0, 0, 0, c, 1],
                 [0, 0, 0, 0, 0, c]])
     # raises exception, sin(M) not supported. exp(M*I) also not supported
-    # https://code.google.com/p/sympy/issues/detail?id=3119
+    # https://github.com/sympy/sympy/issues/6218
     assert sin(M) == Matrix([[sin(a), cos(a), 0, 0, 0, 0],
                              [0, sin(a), 0, 0, 0, 0],
                              [0, 0, sin(b), 0, 0, 0],
@@ -1588,7 +1658,7 @@ def test_P35():
                      [2, 3, 2],
                      [1, 1, 2]])
     # raises exception, sin(M) not supported. exp(M*I) also not supported
-    # https://code.google.com/p/sympy/issues/detail?id=3119
+    # https://github.com/sympy/sympy/issues/6218
     assert sin(M) == eye(3)
 
 
@@ -1779,7 +1849,7 @@ def test_R10():
     assert T2 == factorial(m + n)/(factorial(r)*factorial(m + n - r))
     assert T2 == binomial(m + n, r).rewrite(factorial)
     # rewrite(binomial) is not working.
-    # https://code.google.com/p/sympy/issues/detail?id=4036
+    # https://github.com/sympy/sympy/issues/7135
     T3 = T2.rewrite(binomial)
     assert T3 == binomial(m + n, r)
 
@@ -1791,7 +1861,7 @@ def test_R11():
     Sm = Sum(sk, (k, 0, n))
     T = Sm.doit()
     # Fibonacci simplification not implemented
-    # https://code.google.com/p/sympy/issues/detail?id=4035
+    # https://github.com/sympy/sympy/issues/7134
     assert T == fibonacci(2*n)
 
 
@@ -1845,11 +1915,12 @@ def test_R18():
     k = symbols('k', integer=True, positive=True)
     Sm = Sum(1/(2**k*k**2), (k, 1, oo))
     # returns polylog(2, 1/2),  particular value for 1/2 is not known.
-    # https://code.google.com/p/sympy/issues/detail?id=4033
+    # https://github.com/sympy/sympy/issues/7132
     T = Sm.doit()
     assert T.simplify() == -log(2)**2/2 + pi**2/12
 
 
+@slow
 @XFAIL
 def test_R19():
     k = symbols('k', integer=True, positive=True)
@@ -1924,11 +1995,11 @@ def test_S5():
             factorial(n - Rational(1, 2))/(sqrt(pi)*factorial(n)))
 
 
-@XFAIL
+@SKIP("https://github.com/sympy/sympy/issues/7133")
 def test_S6():
     n, k = symbols('n k', integer=True, positive=True)
     # Product raises Infinite recursion error.
-    # https://code.google.com/p/sympy/issues/detail?id=4034
+    # https://github.com/sympy/sympy/issues/7133
     assert (Product(x**2 -2*x*cos(k*pi/n) + 1, (k, 1, n - 1)).doit().simplify()
             == (x**(2*n) - 1)/(x**2 - 1))
 
@@ -1946,27 +2017,27 @@ def test_S8():
     k = symbols('k', integer=True, positive=True)
     Pr = Product(1 - 1/(2*k)**2, (k, 1, oo))
     T = Pr.doit()
-    # T = nan https://code.google.com/p/sympy/issues/detail?id=4037
+    # T = nan https://github.com/sympy/sympy/issues/7136
     assert T.simplify() == 2/pi
 
 
-@XFAIL
+@SKIP("https://github.com/sympy/sympy/issues/7133")
 def test_S9():
     k = symbols('k', integer=True, positive=True)
     Pr = Product(1 + (-1)**(k + 1)/(2*k - 1), (k, 1, oo))
     # Product.doit() raises Infinite recursion error.
-    # https://code.google.com/p/sympy/issues/detail?id=4034
+    # https://github.com/sympy/sympy/issues/7133
     T = Pr.doit()
     assert T.simplify() == sqrt(2)
 
 
-@XFAIL
+@SKIP("https://github.com/sympy/sympy/issues/7137")
 def test_S10():
     k = symbols('k', integer=True, positive=True)
     Pr = Product((k*(k + 1) + 1 + I)/(k*(k + 1) + 1 - I), (k, 0, oo))
     T = Pr.doit()
     # raises OverflowError
-    # https://code.google.com/p/sympy/issues/detail?id=4038
+    # https://github.com/sympy/sympy/issues/7137
     assert T.simplify() == -1
 
 
@@ -1989,6 +2060,7 @@ def test_T4():
                  - exp(x))/x, x, oo) == -exp(2)
 
 
+@slow
 def test_T5():
     assert  limit(x*log(x)*log(x*exp(x) - x**2)**2/log(log(x**2
                   + 2*exp(exp(3*x**3*log(x))))), x, oo) == Rational(1, 3)
@@ -2075,7 +2147,7 @@ def test_U4():
 
 @XFAIL
 def test_U5():
-    # https://code.google.com/p/sympy/issues/detail?id=3582
+    # https://github.com/sympy/sympy/issues/6681
     # f(g(x)).diff(x,2) returns Derivative(g(x), x)**2*Subs(Derivative(
     #  f(_xi_1), _xi_1, _xi_1), (_xi_1,), (g(x),)) + Derivative(g(x), x, x)*
     #  Subs(Derivative(f(_xi_1), _xi_1), (_xi_1,), (g(x),))
@@ -2131,14 +2203,14 @@ def test_U9():
     # to other expressions only if they are atomic, like a symbol or a
     # function.
     # D operator should be added to SymPy
-    # See https://code.google.com/p/sympy/issues/detail?id=1620.
+    # See https://github.com/sympy/sympy/issues/4719.
 
     # raises ValueError: Can't differentiate wrt the variable: x**2 + y**2
     assert s3 == 2*(x + y)*Derivative(g(x**2 + y**2), x**2 + y**2)
 
 
 def test_U10():
-    # see github issue 2519:
+    # see issue 2519:
     assert residue((z**3 + 5)/((z**4 - 1)*(z + 1)), z, -1) == Rational(-9, 4)
 
 
@@ -2196,7 +2268,7 @@ supported in SymPy")
 def test_V1():
     x = symbols('x', real=True)
     # integral not calculated
-    # https://code.google.com/p/sympy/issues/detail?id=1113
+    # https://github.com/sympy/sympy/issues/4212
     assert integrate(abs(x), x) == x*abs(x)/2
 
 
@@ -2218,7 +2290,7 @@ def test_V4():
 @slow
 def test_V5():
     # Takes extremely long time
-    # https://code.google.com/p/sympy/issues/detail?id=4050
+    # https://github.com/sympy/sympy/issues/7149
     assert (integrate((3*x - 5)**2/(2*x - 1)**(Rational(7, 2)), x) ==
             (-41 + 80*x - 45*x**2)/(5*(2*x - 1)**Rational(5, 2)))
 
@@ -2267,10 +2339,11 @@ def test_V11():
 def test_V12():
     r1 = integrate(1/(5 + 3*cos(x) + 4*sin(x)), x)
     # Correct result in python2.7.4 wrong result in python3.3.1
-    # https://code.google.com/p/sympy/issues/detail?id=4058
+    # https://github.com/sympy/sympy/issues/7157
     assert r1 == -1/(tan(x/2) + 2)
 
 
+@slow
 @XFAIL
 def test_V13():
     r1 = integrate(1/(6 + 3*cos(x) + 4*sin(x)), x)
@@ -2279,11 +2352,12 @@ def test_V13():
     assert r1.simplify() == 2*sqrt(11)*atan(sqrt(11)*(3*tan(x/2) + 4)/11)/11
 
 
+@slow
 @XFAIL
 def test_V14():
     r1 = integrate(log(abs(x**2 - y**2)), x)
     # I.simplify() raises AttributeError
-    # https://code.google.com/p/sympy/issues/detail?id=4059
+    # https://github.com/sympy/sympy/issues/7158
     assert (r1.simplify() == x*log(abs(x**2  - y**2))
                             + y*log(x + y) - y*log(x - y) - 2*x)
 
@@ -2305,6 +2379,7 @@ def test_V16():
     raise NotImplementedError("cosine integral function not supported")
 
 
+@slow
 @XFAIL
 def test_V17():
     r1 = integrate((diff(f(x), x)*g(x)
@@ -2317,7 +2392,7 @@ def test_V17():
 def test_W1():
     # The function has a pole at y.
     # The integral has a Cauchy principal value of zero but SymPy returns -I*pi
-    # https://code.google.com/p/sympy/issues/detail?id=4060
+    # https://github.com/sympy/sympy/issues/7159
     assert integrate(1/(x - y), (x, y - 1, y + 1)) == 0
 
 
@@ -2325,7 +2400,7 @@ def test_W1():
 def test_W2():
     # The function has a pole at y.
     # The integral is divergent but SymPy returns -2
-    # https://code.google.com/p/sympy/issues/detail?id=4061
+    # https://github.com/sympy/sympy/issues/7160
     # Test case in Macsyma:
     # (c6) errcatch(integrate(1/(x - a)^2, x, a - 1, a + 1));
     # Integral is divergent
@@ -2335,7 +2410,7 @@ def test_W2():
 @XFAIL
 def test_W3():
     # integral is not  calculated
-    # https://code.google.com/p/sympy/issues/detail?id=4062
+    # https://github.com/sympy/sympy/issues/7161
     assert integrate(sqrt(x + 1/x - 2), (x, 0, 1)) == S(4)/3
 
 
@@ -2464,7 +2539,7 @@ def test_W22():
     s = Lambda(x, Piecewise((1, And(x >= 1, x <= 2)), (0, True)))
     assert (integrate(s(t)*cos(t), (t, 0, u)) ==
             Piecewise((sin(u) - sin(1), And(u <= 2, u >= 1)),
-                      (0, u <= 1),
+                      (0, And(u <= 1, u >= -oo)),
                       (-sin(1) + sin(2), True)))
 
 
@@ -2474,6 +2549,15 @@ def test_W23():
     a, b = symbols('a b', real=True, positive=True)
     r1 = integrate(integrate(x/(x**2 + y**2), (x, a, b)), (y, -oo, oo))
     assert r1.simplify() == pi*(-a + b)
+
+@SKIP("integrate raises RuntimeError: maximum recursion depth exceeded")
+@slow
+def test_W23b():
+    # this used to be test_W23.  Can't really split since r1 is needed
+    # in the second assert
+    a, b = symbols('a b', real=True, positive=True)
+    r1 = integrate(integrate(x/(x**2 + y**2), (x, a, b)), (y, -oo, oo))
+    assert r1.simplify() == pi*(-a + b)
     # integrate raises RuntimeError: maximum recursion depth exceeded
     r2 = integrate(integrate(x/(x**2 + y**2), (y, -oo, oo)), (x, a, b))
     assert r1 == r2
@@ -2482,6 +2566,8 @@ def test_W23():
 @XFAIL
 @slow
 def test_W24():
+    if ON_TRAVIS:
+        skip("Too slow for travis.")
     x, y = symbols('x y', real=True)
     r1 = integrate(integrate(sqrt(x**2 + y**2), (x, 0, 1)), (y, 0, 1))
     assert (r1 - (sqrt(2) + asinh(1))/3).simplify() == 0
@@ -2490,6 +2576,8 @@ def test_W24():
 @XFAIL
 @slow
 def test_W25():
+    if ON_TRAVIS:
+        skip("Too slow for travis.")
     a, x, y = symbols('a x y', real=True)
     i1 = integrate(sin(a)*sin(y)/sqrt(1- sin(a)**2*sin(x)**2*sin(y)**2),
                    (x, 0, pi/2))
@@ -2501,7 +2589,7 @@ def test_W25():
 def test_W26():
     x, y = symbols('x y', real=True)
     # integrate(abs(y - x**2), (y,0,2)) raises ValueError: gamma function pole
-    # https://code.google.com/p/sympy/issues/detail?id=4066
+    # https://github.com/sympy/sympy/issues/7165
     assert integrate(integrate(abs(y - x**2), (y, 0, 2)),
                      (x, -1, 1)) == S(46)/15
 
@@ -2579,10 +2667,11 @@ def test_X8():
     # Puiseux series (terms with fractional degree):
     # => 1/sqrt(x - 3/2 pi) + (x - 3/2 pi)^(3/2) / 12 + O([x - 3/2 pi]^(7/2))
 
-    # see issue 4068:
+    # see issue 7167:
     x = symbols('x', real=True)
     assert (series(sqrt(sec(x)), x, x0=pi*3/2, n=4) ==
-            1/sqrt(x) +x**(S(3)/2)/12 + x**(S(7)/2)/160 + O(x**4))
+            1/sqrt(x - 3*pi/2) + (x - 3*pi/2)**(S(3)/2)/12 +
+            (x - 3*pi/2)**(S(7)/2)/160 + O((x - 3*pi/2)**4, (x, 3*pi/2)))
 
 
 def test_X9():
@@ -2608,7 +2697,7 @@ def test_X12():
     # Result => (x - 1)^a/e^b [1 - (a + 2 b) (x - 1) / 2 + O((x - 1)^2)]
     a, b, x = symbols('a b x', real=True)
     # series returns O(log(x)**2)
-    # https://code.google.com/p/sympy/issues/detail?id=4069
+    # https://github.com/sympy/sympy/issues/7168
     assert (series(log(x)**a*exp(-b*x), x, x0=1, n=2) ==
             (x - 1)**a/exp(b)*(1 - (a + 2*b)*(x - 1)/2 + O((x - 1)**2)))
 
@@ -2624,12 +2713,12 @@ def test_X14():
                   n, x==oo, n=1) == 1/(sqrt(pi)*sqrt(n)) + O(1/x, (x, oo))
 
 
-@XFAIL
+@SKIP("https://github.com/sympy/sympy/issues/7164")
 def test_X15():
     # => 0!/x - 1!/x^2 + 2!/x^3 - 3!/x^4 + O(1/x^5)   [Knopp, p. 544]
     x, t = symbols('x t', real=True)
     # raises RuntimeError: maximum recursion depth exceeded
-    # https://code.google.com/p/sympy/issues/detail?id=4065
+    # https://github.com/sympy/sympy/issues/7164
     e1 = integrate(exp(-t)/t, (t, x, oo))
     assert (series(e1, x, x0=oo, n=5) ==
             6/x**4 + 2/x**3 - 1/x**2 + 1/x + O(x**(-5), (x, oo)))
@@ -2781,6 +2870,7 @@ def test_Y2():
     assert f == cos(t*abs(w - 1))
 
 
+@slow
 @XFAIL
 def test_Y3():
     t = symbols('t', real=True, positive=True)
@@ -2814,7 +2904,7 @@ def test_Y5_Y6():
                                 - 4*(Heaviside(t - 1)
                                 - Heaviside(t - 2)), t, s)
     # Laplace transform for diff() not calculated
-    # https://code.google.com/p/sympy/issues/detail?id=4077
+    # https://github.com/sympy/sympy/issues/7176
     assert (F == s**2*LaplaceTransform(y(t), t, s) - s
             + LaplaceTransform(y(t), t, s) - 4*exp(-s)/s + 4*exp(-2*s)/s)
 # TODO implement second part of test case
@@ -2835,7 +2925,7 @@ def test_Y7():
                                           (n, 1, oo)), t, s)
     # returns 2*LaplaceTransform(Sum((-1)**n*Heaviside(-a*n + t),
     #                                (n, 1, oo)), t, s) + 1/s
-    # https://code.google.com/p/sympy/issues/detail?id=4078
+    # https://github.com/sympy/sympy/issues/7177
     assert F == 2*Sum((-1)**n*exp(-a*n*s)/s, (n, 1, oo)) + 1/s
 
 
@@ -2854,13 +2944,13 @@ def test_Y10():
             (-8*pi**2*z**2 + 18)/(16*pi**4*z**4 + 72*pi**2*z**2 + 81))
 
 
-@XFAIL
+@SKIP("https://github.com/sympy/sympy/issues/7181")
 @slow
 def test_Y11():
     # => pi cot(pi s)   (0 < Re s < 1)   [Gradshteyn and Ryzhik 17.43(5)]
     x, s = symbols('x s')
     # raises RuntimeError: maximum recursion depth exceeded
-    # https://code.google.com/p/sympy/issues/detail?id=4082
+    # https://github.com/sympy/sympy/issues/7181
     F, _, _ =  mellin_transform(1/(1 - x), x, s)
     assert F == pi*cot(pi*s)
 
@@ -2871,7 +2961,7 @@ def test_Y12():
     # [Gradshteyn and Ryzhik 17.43(16)]
     x, s = symbols('x s')
     # returns Wrong value -2**(s - 4)*gamma(s/2 - 3)/gamma(-s/2 + 1)
-    # https://code.google.com/p/sympy/issues/detail?id=4083
+    # https://github.com/sympy/sympy/issues/7182
     F, _, _ = mellin_transform(besselj(3, x)/x**3, x, s)
     assert F == -2**(s - 4)*gamma(s/2)/gamma(-s/2 + 4)
 
@@ -2932,7 +3022,7 @@ def test_Z5():
     # transform: f(t) = sin(2 t)/8 - t cos(2 t)/4
     C1, C2 = symbols('C1 C2')
     # initial conditions not supported, this is a manual workaround
-    # https://code.google.com/p/sympy/issues/detail?id=1621
+    # https://github.com/sympy/sympy/issues/4720
     eq = Derivative(f(x), x, 2) + 4*f(x) - sin(2*x)
     sol = dsolve(eq, f(x))
     f0 = Lambda(x, sol.rhs)
@@ -2956,7 +3046,7 @@ def test_Z6():
     eq = Derivative(f(t), t, 2) + 4*f(t) - sin(2*t)
     F, _, _ = laplace_transform(eq, t, s)
     # Laplace transform for diff() not calculated
-    # https://code.google.com/p/sympy/issues/detail?id=4077
+    # https://github.com/sympy/sympy/issues/7176
     assert (F == s**2*LaplaceTransform(f(t), t, s) +
             4*LaplaceTransform(f(t), t, s) - 2/(s**2 + 4))
     # rest of test case not implemented
