@@ -2,7 +2,10 @@ from __future__ import print_function, division
 
 from sympy.core import S, C
 from sympy.core.compatibility import u
-from sympy.core.function import Function, Derivative, ArgumentIndexError
+from sympy.core.exprtools import factor_terms
+from sympy.core.function import (Function, Derivative, ArgumentIndexError,
+    AppliedUndef)
+from sympy.core.logic import fuzzy_not
 from sympy.functions.elementary.miscellaneous import sqrt
 from sympy.functions.elementary.piecewise import Piecewise
 from sympy.core import Add, Mul
@@ -51,9 +54,9 @@ class re(Function):
             return S.NaN
         elif arg.is_real:
             return arg
-        elif arg.is_imaginary:
+        elif arg.is_imaginary or (S.ImaginaryUnit*arg).is_real:
             return S.Zero
-        elif arg.is_Function and arg.func == conjugate:
+        elif arg.is_Function and arg.func is conjugate:
             return re(arg.args[0])
         else:
 
@@ -96,6 +99,10 @@ class re(Function):
             return -S.ImaginaryUnit \
                 * im(Derivative(self.args[0], x, evaluate=True))
 
+    def _sage_(self):
+        import sage.all as sage
+        return sage.real_part(self.args[0]._sage_())
+
 
 class im(Function):
     """
@@ -138,9 +145,9 @@ class im(Function):
             return S.NaN
         elif arg.is_real:
             return S.Zero
-        elif arg.is_imaginary:
+        elif arg.is_imaginary or (S.ImaginaryUnit*arg).is_real:
             return -S.ImaginaryUnit * arg
-        elif arg.is_Function and arg.func == conjugate:
+        elif arg.is_Function and arg.func is conjugate:
             return -im(arg.args[0])
         else:
             included, reverted, excluded = [], [], []
@@ -190,6 +197,10 @@ class im(Function):
             return -S.ImaginaryUnit \
                 * re(Derivative(self.args[0], x, evaluate=True))
 
+    def _sage_(self):
+        import sage.all as sage
+        return sage.imag_part(self.args[0]._sage_())
+
 
 ###############################################################################
 ############### SIGN, ABSOLUTE VALUE, ARGUMENT and CONJUGATION ################
@@ -197,20 +208,38 @@ class im(Function):
 
 class sign(Function):
     """
-    Returns the sign of an expression, that is:
+    Returns the complex sign of an expression:
 
-    * 1 if expression is positive
-    * 0 if expression is equal to zero
-    * -1 if expression is negative
+    If the expresssion is real the sign will be:
+
+        * 1 if expression is positive
+        * 0 if expression is equal to zero
+        * -1 if expression is negative
+
+    If the expresssion is imaginary the sign will be:
+
+        * I if im(expression) is positive
+        * -I if im(expression) is negative
+
+    Otherwise an unevaluated expression will be returned. When evaluated, the
+    result (in general) will be ``cos(arg(expr)) + I*sin(arg(expr))``.
 
     Examples
     ========
 
     >>> from sympy.functions import sign
+    >>> from sympy.core.numbers import I
+
     >>> sign(-1)
     -1
     >>> sign(0)
     0
+    >>> sign(-3*I)
+    -I
+    >>> sign(1 + I)
+    sign(1 + I)
+    >>> _.evalf()
+    0.707106781186548 + 0.707106781186548*I
 
     See Also
     ========
@@ -218,7 +247,7 @@ class sign(Function):
     Abs, conjugate
     """
 
-    is_bounded = True
+    is_finite = True
     is_complex = True
 
     def doit(self):
@@ -232,26 +261,25 @@ class sign(Function):
         if arg.is_Mul:
             c, args = arg.as_coeff_mul()
             unk = []
-            is_imag = c.is_imaginary
-            is_neg = c.is_negative
+            s = sign(c)
             for a in args:
                 if a.is_negative:
-                    is_neg = not is_neg
+                    s = -s
                 elif a.is_positive:
                     pass
                 else:
                     ai = im(a)
                     if a.is_imaginary and ai.is_comparable:  # i.e. a = I*real
-                        is_imag = not is_imag
+                        s *= S.ImaginaryUnit
                         if ai.is_negative:
-                            is_neg = not is_neg
+                            # can't use sign(ai) here since ai might not be
+                            # a Number
+                            s = -s
                     else:
                         unk.append(a)
             if c is S.One and len(unk) == len(args):
                 return None
-            return (S.NegativeOne if is_neg else S.One) \
-                * (S.ImaginaryUnit if is_imag else S.One) \
-                * cls(arg._new_rawargs(*unk))
+            return s * cls(arg._new_rawargs(*unk))
         if arg is S.NaN:
             return S.NaN
         if arg.is_zero:  # it may be an Expr that is zero
@@ -264,6 +292,10 @@ class sign(Function):
             if arg.func is sign:
                 return arg
         if arg.is_imaginary:
+            if arg.is_Pow and arg.exp is S.Half:
+                # we catch this because non-trivial sqrt args are not expanded
+                # e.g. sqrt(1-sqrt(2)) --x-->  to I*sqrt(sqrt(2) - 1)
+                return S.ImaginaryUnit
             arg2 = -S.ImaginaryUnit * arg
             if arg2.is_positive:
                 return S.ImaginaryUnit
@@ -287,6 +319,14 @@ class sign(Function):
             return 2 * Derivative(self.args[0], x, evaluate=True) \
                 * DiracDelta(-S.ImaginaryUnit * self.args[0])
 
+    def _eval_is_nonnegative(self):
+        if self.args[0].is_nonnegative:
+            return True
+
+    def _eval_is_nonpositive(self):
+        if self.args[0].is_nonpositive:
+            return True
+
     def _eval_is_imaginary(self):
         return self.args[0].is_imaginary
 
@@ -313,6 +353,10 @@ class sign(Function):
         if arg.is_real:
             return Piecewise((1, arg > 0), (-1, arg < 0), (0, True))
 
+    def _eval_rewrite_as_Heaviside(self, arg):
+        if arg.is_real:
+            return C.Heaviside(arg)*2-1
+
     def _eval_simplify(self, ratio, measure):
         return self.func(self.args[0].factor())
 
@@ -378,11 +422,13 @@ class Abs(Function):
 
     @classmethod
     def eval(cls, arg):
+        from sympy.simplify.simplify import signsimp
         if hasattr(arg, '_eval_Abs'):
             obj = arg._eval_Abs()
             if obj is not None:
                 return obj
         # handle what we can
+        arg = signsimp(arg, evaluate=False)
         if arg.is_Mul:
             known = []
             unk = []
@@ -410,6 +456,10 @@ class Abs(Function):
         if arg.is_real is False and arg.is_imaginary is False:
             from sympy import expand_mul
             return sqrt( expand_mul(arg * arg.conjugate()) )
+        if arg.is_real is None and arg.is_imaginary is None and arg.is_Add:
+            if all(a.is_real or a.is_imaginary or (S.ImaginaryUnit*a).is_real for a in arg.args):
+                from sympy import expand_mul
+                return sqrt(expand_mul(arg * arg.conjugate()))
         if arg.is_Pow:
             base, exponent = arg.as_base_exp()
             if exponent.is_even and base.is_real:
@@ -463,19 +513,32 @@ class Abs(Function):
         if arg.is_real:
             return Piecewise((arg, arg >= 0), (-arg, True))
 
+    def _eval_rewrite_as_sign(self, arg):
+        return arg/C.sign(arg)
+
 
 class arg(Function):
     """Returns the argument (in radians) of a complex number"""
 
     is_real = True
-    is_bounded = True
+    is_finite = True
 
     @classmethod
     def eval(cls, arg):
-        x, y = re(arg), im(arg)
-        arg = C.atan2(y, x)
-        if arg.is_number:
-            return arg
+        if not arg.is_Atom:
+            c, arg_ = factor_terms(arg).as_coeff_Mul()
+            if arg_.is_Mul:
+                arg_ = Mul(*[a if (sign(a) not in (-1, 1)) else
+                    sign(a) for a in arg_.args])
+            arg_ = sign(c)*arg_
+        else:
+            arg_ = arg
+        x, y = re(arg_), im(arg_)
+        rv = C.atan2(y, x)
+        if rv.is_number and not rv.atoms(AppliedUndef):
+            return rv
+        if arg_ != arg:
+            return cls(arg_, evaluate=False)
 
     def _eval_derivative(self, t):
         x, y = re(self.args[0]), im(self.args[0])
@@ -596,7 +659,7 @@ class adjoint(Function):
 
 class polar_lift(Function):
     """
-    Lift argument to the riemann surface of the logarithm, using the
+    Lift argument to the Riemann surface of the logarithm, using the
     standard branch.
 
     >>> from sympy import Symbol, polar_lift, I
@@ -661,10 +724,13 @@ class polar_lift(Function):
         """ Careful! any evalf of polar numbers is flaky """
         return self.args[0]._eval_evalf(prec)
 
+    def _eval_Abs(self):
+        return Abs(self.args[0], evaluate=True)
+
 
 class periodic_argument(Function):
     """
-    Represent the argument on a quotient of the riemann surface of the
+    Represent the argument on a quotient of the Riemann surface of the
     logarithm. That is, given a period P, always return a value in
     (-P/2, P/2], by using exp(P*I) == 1.
 
@@ -685,7 +751,7 @@ class periodic_argument(Function):
     ========
 
     sympy.functions.elementary.exponential.exp_polar
-    polar_lift : Lift argument to the riemann surface of the logarithm
+    polar_lift : Lift argument to the Riemann surface of the logarithm
     principal_branch
     """
 
@@ -714,7 +780,7 @@ class periodic_argument(Function):
 
     @classmethod
     def eval(cls, ar, period):
-        # Our strategy is to evaluate the argument on the riemann surface of the
+        # Our strategy is to evaluate the argument on the Riemann surface of the
         # logarithm, and then reduce.
         # NOTE evidently this means it is a rather bad idea to use this with
         # period != 2*pi and non-polar numbers.
@@ -761,7 +827,7 @@ def unbranched_argument(arg):
 class principal_branch(Function):
     """
     Represent a polar number reduced to its principal branch on a quotient
-    of the riemann surface of the logarithm.
+    of the Riemann surface of the logarithm.
 
     This is a function of two arguments. The first argument is a polar
     number `z`, and the second one a positive real number of infinity, `p`.
@@ -780,7 +846,7 @@ class principal_branch(Function):
     ========
 
     sympy.functions.elementary.exponential.exp_polar
-    polar_lift : Lift argument to the riemann surface of the logarithm
+    polar_lift : Lift argument to the Riemann surface of the logarithm
     periodic_argument
     """
 
@@ -830,7 +896,7 @@ class principal_branch(Function):
             if arg == 0:
                 return abs(c)*principal_branch(Mul(*m), period)
             return principal_branch(exp_polar(I*arg)*Mul(*m), period)*abs(c)
-        if arg.is_number and ((abs(arg) < period/2) is True or arg == period/2) \
+        if arg.is_number and ((abs(arg) < period/2) == True or arg == period/2) \
                 and m == ():
             return exp_polar(arg*I)*abs(c)
 
