@@ -34,7 +34,6 @@ class sinh(HyperbolicFunction):
 
     cosh, tanh, asinh
     """
-    nargs = 1
 
     def fdiff(self, argindex=1):
         """
@@ -178,7 +177,7 @@ class sinh(HyperbolicFunction):
     def _eval_is_real(self):
         return self.args[0].is_real
 
-    def _eval_is_bounded(self):
+    def _eval_is_finite(self):
         arg = self.args[0]
         if arg.is_imaginary:
             return True
@@ -199,7 +198,6 @@ class cosh(HyperbolicFunction):
 
     sinh, tanh, acosh
     """
-    nargs = 1
 
     def fdiff(self, argindex=1):
         if argindex == 1:
@@ -327,7 +325,7 @@ class cosh(HyperbolicFunction):
     def _eval_is_real(self):
         return self.args[0].is_real
 
-    def _eval_is_bounded(self):
+    def _eval_is_finite(self):
         arg = self.args[0]
         if arg.is_imaginary:
             return True
@@ -348,7 +346,6 @@ class tanh(HyperbolicFunction):
 
     sinh, cosh, atanh
     """
-    nargs = 1
 
     def fdiff(self, argindex=1):
         if argindex == 1:
@@ -465,7 +462,7 @@ class tanh(HyperbolicFunction):
     def _eval_is_real(self):
         return self.args[0].is_real
 
-    def _eval_is_bounded(self):
+    def _eval_is_finite(self):
         arg = self.args[0]
         if arg.is_real:
             return True
@@ -481,7 +478,6 @@ class coth(HyperbolicFunction):
 
     * coth(x) -> Returns the hyperbolic cotangent of x
     """
-    nargs = 1
 
     def fdiff(self, argindex=1):
         if argindex == 1:
@@ -507,7 +503,7 @@ class coth(HyperbolicFunction):
             elif arg is S.NegativeInfinity:
                 return S.NegativeOne
             elif arg is S.Zero:
-                return S.Zero
+                return S.ComplexInfinity
             elif arg.is_negative:
                 return -cls(-arg)
         else:
@@ -615,7 +611,6 @@ class asinh(Function):
 
     acosh, atanh, sinh
     """
-    nargs = 1
 
     def fdiff(self, argindex=1):
         if argindex == 1:
@@ -700,7 +695,6 @@ class acosh(Function):
 
     asinh, atanh, cosh
     """
-    nargs = 1
 
     def fdiff(self, argindex=1):
         if argindex == 1:
@@ -816,7 +810,6 @@ class atanh(Function):
 
     asinh, acosh, tanh
     """
-    nargs = 1
 
     def fdiff(self, argindex=1):
         if argindex == 1:
@@ -889,7 +882,6 @@ class acoth(Function):
 
     * acoth(x) -> Returns the inverse hyperbolic cotangent of x
     """
-    nargs = 1
 
     def fdiff(self, argindex=1):
         if argindex == 1:
