@@ -7,6 +7,7 @@ from sympy.utilities.pytest import XFAIL
 def test_floor():
 
     x = Symbol('x')
+    i = Symbol('i', imaginary=True)
     y = Symbol('y', real=True)
     k, n = symbols('k,n', integer=True)
 
@@ -43,6 +44,8 @@ def test_floor():
 
     assert floor(I) == I
     assert floor(-I) == -I
+    e = floor(i)
+    assert e.func is floor and e.args[0] == i
 
     assert floor(oo*I) == oo*I
     assert floor(-oo*I) == -oo*I
@@ -105,6 +108,7 @@ def test_floor():
 def test_ceiling():
 
     x = Symbol('x')
+    i = Symbol('i', imaginary=True)
     y = Symbol('y', real=True)
     k, n = symbols('k,n', integer=True)
 
@@ -141,6 +145,8 @@ def test_ceiling():
 
     assert ceiling(I) == I
     assert ceiling(-I) == -I
+    e = ceiling(i)
+    assert e.func is ceiling and e.args[0] == i
 
     assert ceiling(oo*I) == oo*I
     assert ceiling(-oo*I) == -oo*I
@@ -213,7 +219,7 @@ def test_series():
 
 
 @XFAIL
-def test_issue_1050():
+def test_issue_4149():
     assert floor(3 + pi*I + y*I) == 3 + floor(pi + y)*I
     assert floor(3*I + pi*I + y*I) == floor(3 + pi + y)*I
     assert floor(3 + E + pi*I + y*I) == 5 + floor(pi + y)*I
