@@ -2,7 +2,7 @@ from sympy import (symbols, Symbol, nan, oo, zoo, I, sinh, sin, pi, atan,
         acos, Rational, sqrt, asin, acot, coth, E, S, tan, tanh, cos,
         cosh, atan2, exp, log, asinh, acoth, atanh, O, cancel, Matrix, re, im,
         Float, Pow, gcd, sec, csc, cot, diff, simplify, Heaviside, arg,
-        conjugate, series)
+        conjugate, series, FiniteSet, asec, acsc)
 
 from sympy.utilities.pytest import XFAIL, slow, raises
 from sympy.core.compatibility import xrange
@@ -10,11 +10,16 @@ from sympy.core.compatibility import xrange
 x, y, z = symbols('x y z')
 r = Symbol('r', real=True)
 k = Symbol('k', integer=True)
+p = Symbol('p', positive=True)
+n = Symbol('n', negative=True)
+a = Symbol('a', algebraic=True)
+na = Symbol('na', nonzero=True, algebraic=True)
 
 
 def test_sin():
     x, y = symbols('x y')
 
+    assert sin.nargs == FiniteSet(1)
     assert sin(nan) == nan
 
     assert sin(oo*I) == oo*I
@@ -45,8 +50,13 @@ def test_sin():
     assert sin(5*pi/2) == 1
     assert sin(7*pi/2) == -1
 
-    n = symbols('n', integer=True)
-    assert sin(pi*n/2) == (-1)**(n/2 - S.Half)
+    ne = symbols('ne', integer=True, even=False)
+    e = symbols('e', even=True)
+    assert sin(pi*ne/2) == (-1)**(ne/2 - S.Half)
+    assert sin(pi*k/2).func == sin
+    assert sin(pi*e/2) == 0
+    assert sin(pi*k) == 0
+    assert sin(pi*k).subs(k, 3) == sin(pi*k/2).subs(k, 6)  # issue 8298
 
     assert sin(pi/3) == S.Half*sqrt(3)
     assert sin(-2*pi/3) == -S.Half*sqrt(3)
@@ -87,6 +97,12 @@ def test_sin():
 
     assert sin(r).is_real is True
 
+    assert sin(0, evaluate=False).is_algebraic
+    assert sin(a).is_algebraic is None
+    assert sin(na).is_algebraic is False
+    q = Symbol('q', rational=True)
+    assert sin(pi*q).is_algebraic
+
     assert isinstance(sin( re(x) - im(y)), sin) is True
     assert isinstance(sin(-re(x) + im(y)), sin) is False
 
@@ -133,6 +149,7 @@ def test_sin_rewrite():
     assert sin(cot(x)).rewrite(
         exp).subs(x, 3).n() == sin(x).rewrite(exp).subs(x, cot(3)).n()
     assert sin(log(x)).rewrite(Pow) == I*x**-I / 2 - I*x**I /2
+    assert sin(x).rewrite(csc) == 1/csc(x)
 
 
 def test_sin_expansion():
@@ -188,6 +205,7 @@ def test_trig_symmetry():
 def test_cos():
     x, y = symbols('x y')
 
+    assert cos.nargs == FiniteSet(1)
     assert cos(nan) == nan
 
     assert cos(oo*I) == oo
@@ -212,8 +230,10 @@ def test_cos():
     assert cos((-3*10**73 + 1)*pi/2) == 0
     assert cos((7*10**103 + 1)*pi/2) == 0
 
-    n = symbols('n', integer=True)
+    n = symbols('n', integer=True, even=False)
+    e = symbols('e', even=True)
     assert cos(pi*n/2) == 0
+    assert cos(pi*e/2) == (-1)**(e/2)
 
     assert cos(pi) == -1
     assert cos(-pi) == -1
@@ -256,6 +276,13 @@ def test_cos():
 
     assert cos(r).is_real is True
 
+    assert cos(0, evaluate=False).is_algebraic
+    assert cos(a).is_algebraic is None
+    assert cos(na).is_algebraic is False
+    q = Symbol('q', rational=True)
+    assert cos(pi*q).is_algebraic
+    assert cos(2*pi/7).is_algebraic
+
     assert cos(k*pi) == (-1)**k
     assert cos(2*k*pi) == 1
 
@@ -266,7 +293,7 @@ def test_cos():
             assert e < 1e-12
 
 
-def test_issue_3091():
+def test_issue_6190():
     c = Float('123456789012345678901234567890.25', '')
     for cls in [sin, cos, tan, cot]:
         assert cls(c*pi) == cls(pi/4)
@@ -300,6 +327,7 @@ def test_cos_rewrite():
     assert cos(cot(x)).rewrite(
         exp).subs(x, 3).n() == cos(x).rewrite(exp).subs(x, cot(3)).n()
     assert cos(log(x)).rewrite(Pow) == x**I/2 + x**-I/2
+    assert cos(x).rewrite(sec) == 1/sec(x)
 
 
 def test_cos_expansion():
@@ -316,6 +344,7 @@ def test_cos_expansion():
 def test_tan():
     assert tan(nan) == nan
 
+    assert tan.nargs == FiniteSet(1)
     assert tan(oo*I) == I
     assert tan(-oo*I) == -I
 
@@ -362,6 +391,10 @@ def test_tan():
 
     assert tan(r).is_real is True
 
+    assert tan(0, evaluate=False).is_algebraic
+    assert tan(a).is_algebraic is None
+    assert tan(na).is_algebraic is False
+
     assert tan(10*pi/7) == tan(3*pi/7)
     assert tan(11*pi/7) == -tan(3*pi/7)
     assert tan(-11*pi/7) == tan(3*pi/7)
@@ -421,6 +454,7 @@ def test_tan_expansion():
 def test_cot():
     assert cot(nan) == nan
 
+    assert cot.nargs == FiniteSet(1)
     assert cot(oo*I) == -I
     assert cot(-oo*I) == I
 
@@ -463,19 +497,27 @@ def test_cot():
 
     assert cot(r).is_real is True
 
+    assert cot(a).is_algebraic is None
+    assert cot(na).is_algebraic is False
+
     assert cot(10*pi/7) == cot(3*pi/7)
     assert cot(11*pi/7) == -cot(3*pi/7)
     assert cot(-11*pi/7) == cot(3*pi/7)
 
+    assert cot(x).is_finite is None
+    assert cot(r).is_finite is None
+    i = Symbol('i', imaginary=True)
+    assert cot(i).is_finite is True
+
+    assert cot(x).subs(x, 3*pi) == zoo
+
 
 def test_cot_series():
     assert cot(x).series(x, 0, 9) == \
         1/x - x/3 - x**3/45 - 2*x**5/945 - x**7/4725 + O(x**9)
-    # issue 3111:
-    assert cot(x**20 + x**21 + x**22).series(x, 0, 4) == \
-        x**(-20) - 1/x**19 + x**(-17) - 1/x**16 + x**(-14) - 1/x**13 + \
-        x**(-11) - 1/x**10 + x**(-8) - 1/x**7 + x**(-5) - 1/x**4 + \
-        x**(-2) - 1/x + x - x**2 + O(x**4)
+    # issue 6210
+    assert cot(x**4 + x**5).series(x, 0, 1) == \
+        x**(-4) - 1/x**3 + x**(-2) - 1/x + 1 + O(x)
 
 
 def test_cot_rewrite():
@@ -524,6 +566,7 @@ def test_cot_expansion():
 def test_asin():
     assert asin(nan) == nan
 
+    assert asin.nargs == FiniteSet(1)
     assert asin(oo) == -I*oo
     assert asin(-oo) == I*oo
 
@@ -550,9 +593,14 @@ def test_asin():
 
     assert asin(0.2).is_real is True
     assert asin(-2).is_real is False
+    assert asin(r).is_real is None
 
     assert asin(-2*I) == -I*asinh(2)
 
+    assert asin(Rational(1, 7), evaluate=False).is_positive is True
+    assert asin(Rational(-1, 7), evaluate=False).is_positive is False
+    assert asin(p).is_positive is None
+
 
 def test_asin_series():
     assert asin(x).series(x, 0, 9) == \
@@ -566,10 +614,15 @@ def test_asin_rewrite():
     assert asin(x).rewrite(log) == -I*log(I*x + sqrt(1 - x**2))
     assert asin(x).rewrite(atan) == 2*atan(x/(1 + sqrt(1 - x**2)))
     assert asin(x).rewrite(acos) == S.Pi/2 - acos(x)
+    assert asin(x).rewrite(acot) == 2*acot((sqrt(-x**2 + 1) + 1)/x)
+    assert asin(x).rewrite(asec) == -asec(1/x) + pi/2
+    assert asin(x).rewrite(acsc) == acsc(1/x)
 
 
 def test_acos():
     assert acos(nan) == nan
+
+    assert acos.nargs == FiniteSet(1)
     assert acos(oo) == I*oo
     assert acos(-oo) == -I*oo
 
@@ -586,6 +639,19 @@ def test_acos():
 
     assert acos(0.2).is_real is True
     assert acos(-2).is_real is False
+    assert acos(r).is_real is None
+
+    assert acos(Rational(1, 7), evaluate=False).is_positive is True
+    assert acos(Rational(-1, 7), evaluate=False).is_positive is True
+    assert acos(Rational(3, 2), evaluate=False).is_positive is False
+    assert acos(p).is_positive is None
+
+    assert acos(2 + p).conjugate() != acos(10 + p)
+    assert acos(-3 + n).conjugate() != acos(-3 + n)
+    assert acos(S.One/3).conjugate() == acos(S.One/3)
+    assert acos(-S.One/3).conjugate() == acos(-S.One/3)
+    assert acos(p + n*I).conjugate() == acos(p - n*I)
+    assert acos(z).conjugate() != acos(conjugate(z))
 
 
 def test_acos_series():
@@ -604,11 +670,15 @@ def test_acos_rewrite():
     assert acos(0).rewrite(atan) == S.Pi/2
     assert acos(0.5).rewrite(atan) == acos(0.5).rewrite(log)
     assert acos(x).rewrite(asin) == S.Pi/2 - asin(x)
+    assert acos(x).rewrite(acot) == -2*acot((sqrt(-x**2 + 1) + 1)/x) + pi/2
+    assert acos(x).rewrite(asec) == asec(1/x)
+    assert acos(x).rewrite(acsc) == -acsc(1/x) + pi/2
 
 
 def test_atan():
     assert atan(nan) == nan
 
+    assert atan.nargs == FiniteSet(1)
     assert atan(oo) == pi/2
     assert atan(-oo) == -pi/2
 
@@ -621,13 +691,22 @@ def test_atan():
     assert atan(r).is_real is True
 
     assert atan(-2*I) == -I*atanh(2)
+    assert atan(p).is_positive is True
+    assert atan(n).is_positive is False
+    assert atan(x).is_positive is None
 
 
 def test_atan_rewrite():
     assert atan(x).rewrite(log) == I*log((1 - I*x)/(1 + I*x))/2
+    assert atan(x).rewrite(asin) == (-asin(1/sqrt(x**2 + 1)) + pi/2)*sqrt(x**2)/x
+    assert atan(x).rewrite(acos) == sqrt(x**2)*acos(1/sqrt(x**2 + 1))/x
+    assert atan(x).rewrite(acot) == acot(1/x)
+    assert atan(x).rewrite(asec) == sqrt(x**2)*asec(sqrt(x**2 + 1))/x
+    assert atan(x).rewrite(acsc) == (-acsc(sqrt(x**2 + 1)) + pi/2)*sqrt(x**2)/x
 
 
 def test_atan2():
+    assert atan2.nargs == FiniteSet(2)
     assert atan2(0, 0) == S.NaN
     assert atan2(0, 1) == 0
     assert atan2(1, 1) == pi/4
@@ -637,6 +716,12 @@ def test_atan2():
     assert atan2(-1, -1) == -3*pi/4
     assert atan2(-1, 0) == -pi/2
     assert atan2(-1, 1) == -pi/4
+    i = symbols('i', imaginary=True)
+    r = symbols('r', real=True)
+    eq = atan2(r, i)
+    ans = -I*log((i + I*r)/sqrt(i**2 + r**2))
+    reps = ((r, 2), (i, I))
+    assert eq.subs(reps) == ans.subs(reps)
 
     u = Symbol("u", positive=True)
     assert atan2(0, u) == 0
@@ -651,9 +736,16 @@ def test_atan2():
 
     ex = atan2(y, x) - arg(x + I*y)
     assert ex.subs({x:2, y:3}).rewrite(arg) == 0
-    assert ex.subs({x:2, y:3*I}).rewrite(arg) == 0
-    assert ex.subs({x:2*I, y:3}).rewrite(arg) == 0
-    assert ex.subs({x:2*I, y:3*I}).rewrite(arg) == 0
+    assert ex.subs({x:2, y:3*I}).rewrite(arg) == -pi - I*log(sqrt(5)*I/5)
+    assert ex.subs({x:2*I, y:3}).rewrite(arg) == -pi/2 - I*log(sqrt(5)*I)
+    assert ex.subs({x:2*I, y:3*I}).rewrite(arg) == -pi + atan(2/S(3)) + atan(3/S(2))
+    i = symbols('i', imaginary=True)
+    r = symbols('r', real=True)
+    e = atan2(i, r)
+    rewrite = e.rewrite(arg)
+    reps = {i: I, r: -2}
+    assert rewrite == -I*log(abs(I*i + r)/sqrt(abs(i**2 + r**2))) + arg((I*i + r)/sqrt(i**2 + r**2))
+    assert (e - rewrite).subs(reps).equals(0)
 
     assert conjugate(atan2(x, y)) == atan2(conjugate(x), conjugate(y))
 
@@ -663,12 +755,11 @@ def test_atan2():
     assert simplify(diff(atan2(y, x).rewrite(log), x)) == -y/(x**2 + y**2)
     assert simplify(diff(atan2(y, x).rewrite(log), y)) ==  x/(x**2 + y**2)
 
-    assert isinstance(atan2(2, 3*I).n(), atan2)
-
 
 def test_acot():
     assert acot(nan) == nan
 
+    assert acot.nargs == FiniteSet(1)
     assert acot(-oo) == 0
     assert acot(oo) == 0
     assert acot(1) == pi/4
@@ -682,10 +773,19 @@ def test_acot():
 
     assert acot(I*pi) == -I*acoth(pi)
     assert acot(-2*I) == I*acoth(2)
+    assert acot(x).is_positive is None
+    assert acot(r).is_positive is True
+    assert acot(p).is_positive is True
+    assert acot(I).is_positive is False
 
 
 def test_acot_rewrite():
     assert acot(x).rewrite(log) == I*log((x - I)/(x + I))/2
+    assert acot(x).rewrite(asin) == x*(-asin(sqrt(-x**2)/sqrt(-x**2 - 1)) + pi/2)*sqrt(x**(-2))
+    assert acot(x).rewrite(acos) == x*sqrt(x**(-2))*acos(sqrt(-x**2)/sqrt(-x**2 - 1))
+    assert acot(x).rewrite(atan) == atan(1/x)
+    assert acot(x).rewrite(asec) == x*sqrt(x**(-2))*asec(sqrt((x**2 + 1)/x**2))
+    assert acot(x).rewrite(acsc) == x*(-acsc(sqrt((x**2 + 1)/x**2)) + pi/2)*sqrt(x**(-2))
 
 
 def test_attributes():
@@ -738,14 +838,14 @@ def test_evenodd_rewrite():
             x - y) == -func(y - x)  # it doesn't matter which form is canonical
 
 
-def test_issue1448():
+def test_issue_4547():
     assert sin(x).rewrite(cot) == 2*cot(x/2)/(1 + cot(x/2)**2)
     assert cos(x).rewrite(cot) == -(1 - cot(x/2)**2)/(1 + cot(x/2)**2)
     assert tan(x).rewrite(cot) == 1/cot(x)
     assert cot(x).fdiff() == -1 - cot(x)**2
 
 
-def test_as_leading_term_issue2173():
+def test_as_leading_term_issue_5272():
     assert sin(x).as_leading_term(x) == x
     assert cos(x).as_leading_term(x) == 1
     assert tan(x).as_leading_term(x) == x
@@ -768,9 +868,9 @@ def test_atan2_expansion():
     assert cancel(atan(y/x).series(y, 0, 5) - atan2(y, x).series(y, 0, 5)
                   + atan2(0, x) - atan(0)) == O(y**5)
     assert cancel(atan(y/x).series(x, 1, 4) - atan2(y, x).series(x, 1, 4)
-                  + atan2(y, 1) - atan(y)) == O(x**4)
+                  + atan2(y, 1) - atan(y)) == O((x - 1)**4, (x, 1))
     assert cancel(atan((y + x)/x).series(x, 1, 3) - atan2(y + x, x).series(x, 1, 3)
-                  + atan2(1 + y, 1) - atan(1 + y)) == O(x**3)
+                  + atan2(1 + y, 1) - atan(1 + y)) == O((x - 1)**3, (x, 1))
     assert Matrix([atan2(y, x)]).jacobian([y, x]) == \
         Matrix([[x/(y**2 + x**2), -y/(y**2 + x**2)]])
 
@@ -785,7 +885,7 @@ def test_aseries():
     t(acot, -0.1, '-', 1e-5)
 
 
-def test_issue_1321():
+def test_issue_4420():
     i = Symbol('i', integer=True)
     e = Symbol('e', even=True)
     o = Symbol('o', odd=True)
@@ -916,10 +1016,10 @@ def test_real_imag():
             z).as_real_imag(deep=deep) == (sin(a)*cosh(b), cos(a)*sinh(b))
         assert cos(
             z).as_real_imag(deep=deep) == (cos(a)*cosh(b), -sin(a)*sinh(b))
-        assert tan(z).as_real_imag(deep=deep) == (sin(a)*cos(
-            a)/(cos(a)**2 + sinh(b)**2), sinh(b)*cosh(b)/(cos(a)**2 + sinh(b)**2))
-        assert cot(z).as_real_imag(deep=deep) == (sin(a)*cos(a)/(
-            sin(a)**2 + sinh(b)**2), -sinh(b)*cosh(b)/(sin(a)**2 + sinh(b)**2))
+        assert tan(z).as_real_imag(deep=deep) == (sin(2*a)/(cos(2*a) +
+            cosh(2*b)), sinh(2*b)/(cos(2*a) + cosh(2*b)))
+        assert cot(z).as_real_imag(deep=deep) == (-sin(2*a)/(cos(2*a) -
+            cosh(2*b)), -sinh(2*b)/(cos(2*a) - cosh(2*b)))
         assert sin(a).as_real_imag(deep=deep) == (sin(a), 0)
         assert cos(a).as_real_imag(deep=deep) == (cos(a), 0)
         assert tan(a).as_real_imag(deep=deep) == (tan(a), 0)
@@ -928,8 +1028,8 @@ def test_real_imag():
 
 @XFAIL
 def test_sin_cos_with_infinity():
-    # Test for issue 2097
-    # http://code.google.com/p/sympy/issues/detail?id=2097
+    # Test for issue 5196
+    # https://github.com/sympy/sympy/issues/5196
     assert sin(oo) == S.NaN
     assert cos(oo) == S.NaN
 
@@ -949,6 +1049,7 @@ def test_sincos_rewrite_sqrt():
                     assert not c1.has(cos, sin), "fails for %d*pi/%d" % (i, n)
                     assert 1e-3 > abs(sin(x.evalf(5)) - s1.evalf(2)), "fails for %d*pi/%d" % (i, n)
                     assert 1e-3 > abs(cos(x.evalf(5)) - c1.evalf(2)), "fails for %d*pi/%d" % (i, n)
+    assert cos(pi/14).rewrite(sqrt) == sqrt(cos(pi/7)/2 + S.Half)
 
 
 @slow
@@ -973,26 +1074,29 @@ def test_sec():
     x = symbols('x', real=True)
     z = symbols('z')
 
-    assert sec.nargs == 1
+    assert sec.nargs == FiniteSet(1)
 
     assert sec(0) == 1
     assert sec(pi) == -1
-    assert sec(pi/2) == oo
-    assert sec(-pi/2) == oo
+    assert sec(pi/2) == zoo
+    assert sec(-pi/2) == zoo
     assert sec(pi/6) == 2*sqrt(3)/3
     assert sec(pi/3) == 2
-    assert sec(5*pi/2) == oo
+    assert sec(5*pi/2) == zoo
     assert sec(9*pi/7) == -sec(2*pi/7)
     assert sec(I) == 1/cosh(1)
     assert sec(x*I) == 1/cosh(x)
     assert sec(-x) == sec(x)
 
+    assert sec(asec(x)) == x
+
     assert sec(x).rewrite(exp) == 1/(exp(I*x)/2 + exp(-I*x)/2)
     assert sec(x).rewrite(sin) == sec(x)
     assert sec(x).rewrite(cos) == 1/cos(x)
     assert sec(x).rewrite(tan) == (tan(x/2)**2 + 1)/(-tan(x/2)**2 + 1)
     assert sec(x).rewrite(pow) == sec(x)
     assert sec(x).rewrite(sqrt) == sec(x)
+    assert sec(z).rewrite(cot) == (cot(z/2)**2 + 1)/(cot(z/2)**2 - 1)
 
     assert sec(z).conjugate() == sec(conjugate(z))
 
@@ -1008,38 +1112,47 @@ def test_sec():
     assert sec(x).is_real == True
     assert sec(z).is_real == None
 
+    assert sec(a).is_algebraic is None
+    assert sec(na).is_algebraic is False
+
     assert sec(x).as_leading_term() == sec(x)
 
-    assert sec(0).is_bounded == True
-    assert sec(x).is_bounded == None
-    assert sec(pi/2).is_bounded == False
+    assert sec(0).is_finite == True
+    assert sec(x).is_finite == None
+    assert sec(pi/2).is_finite == False
 
     assert series(sec(x), x, x0=0, n=6) == 1 + x**2/2 + 5*x**4/24 + O(x**6)
 
-    # https://code.google.com/p/sympy/issues/detail?id=4067
+    # https://github.com/sympy/sympy/issues/7166
     assert series(sqrt(sec(x))) == 1 + x**2/4 + 7*x**4/96 + O(x**6)
 
-    # https://code.google.com/p/sympy/issues/detail?id=4068
+    # https://github.com/sympy/sympy/issues/7167
     assert (series(sqrt(sec(x)), x, x0=pi*3/2, n=4) ==
-            1/sqrt(x) +x**(S(3)/2)/12 + x**(S(7)/2)/160 + O(x**4))
+            1/sqrt(x - 3*pi/2) + (x - 3*pi/2)**(S(3)/2)/12 +
+            (x - 3*pi/2)**(S(7)/2)/160 + O((x - 3*pi/2)**4, (x, 3*pi/2)))
 
     assert sec(x).diff(x) == tan(x)*sec(x)
 
+    # Taylor Term checks
+    assert sec(z).taylor_term(4, z) == 5*z**4/24
+    assert sec(z).taylor_term(6, z) == 61*z**6/720
+    assert sec(z).taylor_term(5, z) == 0
+
 
 def test_csc():
     x = symbols('x', real=True)
     z = symbols('z')
 
-    # https://code.google.com/p/sympy/issues/detail?id=3608
+    # https://github.com/sympy/sympy/issues/6707
     cosecant = csc('x')
     alternate = 1/sin('x')
     assert cosecant.equals(alternate) == True
     assert alternate.equals(cosecant) == True
 
-    assert csc.nargs == 1
+    assert csc.nargs == FiniteSet(1)
 
-    assert csc(0) == oo
-    assert csc(pi) == oo
+    assert csc(0) == zoo
+    assert csc(pi) == zoo
 
     assert csc(pi/2) == 1
     assert csc(-pi/2) == -1
@@ -1051,10 +1164,13 @@ def test_csc():
     assert csc(x*I) == -I/sinh(x)
     assert csc(-x) == -csc(x)
 
+    assert csc(acsc(x)) == x
+
     assert csc(x).rewrite(exp) == 2*I/(exp(I*x) - exp(-I*x))
     assert csc(x).rewrite(sin) == 1/sin(x)
     assert csc(x).rewrite(cos) == csc(x)
     assert csc(x).rewrite(tan) == (tan(x/2)**2 + 1)/(2*tan(x/2))
+    assert csc(x).rewrite(cot) == (cot(x/2)**2 + 1)/(2*cot(x/2))
 
     assert csc(z).conjugate() == csc(conjugate(z))
 
@@ -1070,24 +1186,70 @@ def test_csc():
     assert csc(x).is_real == True
     assert csc(z).is_real == None
 
+    assert csc(a).is_algebraic is None
+    assert csc(na).is_algebraic is False
+
     assert csc(x).as_leading_term() == csc(x)
 
-    assert csc(0).is_bounded == False
-    assert csc(x).is_bounded == None
-    assert csc(pi/2).is_bounded == True
+    assert csc(0).is_finite == False
+    assert csc(x).is_finite == None
+    assert csc(pi/2).is_finite == True
 
-    assert series(csc(x), x, x0=pi/2, n=6) == 1 + x**2/2 + 5*x**4/24 + O(x**6)
+    assert series(csc(x), x, x0=pi/2, n=6) == \
+        1 + (x - pi/2)**2/2 + 5*(x - pi/2)**4/24 + O((x - pi/2)**6, (x, pi/2))
     assert series(csc(x), x, x0=0, n=6) == \
             1/x + x/6 + 7*x**3/360 + 31*x**5/15120 + O(x**6)
 
     assert csc(x).diff(x) == -cot(x)*csc(x)
 
+    assert csc(x).taylor_term(2, x) == 0
+    assert csc(x).taylor_term(3, x) == 7*x**3/360
+    assert csc(x).taylor_term(5, x) == 31*x**5/15120
+
+
+def test_asec():
+    assert asec(nan) == nan
+    assert asec(1) == 0
+    assert asec(-1) == pi
+    assert asec(oo) == pi/2
+    assert asec(-oo) == pi/2
+    assert asec(zoo) == pi/2
+
+    assert asec(x).diff(x) == 1/(x**2*sqrt(1 - 1/x**2))
+    assert asec(x).as_leading_term(x) == log(x)
+
+    assert asec(x).rewrite(log) == I*log(sqrt(1 - 1/x**2) + I/x) + pi/2
+    assert asec(x).rewrite(asin) == -asin(1/x) + pi/2
+    assert asec(x).rewrite(acos) == acos(1/x)
+    assert asec(x).rewrite(atan) == (2*atan(x + sqrt(x**2 - 1)) - pi/2)*sqrt(x**2)/x
+    assert asec(x).rewrite(acot) == (2*acot(x - sqrt(x**2 - 1)) - pi/2)*sqrt(x**2)/x
+    assert asec(x).rewrite(acsc) == -acsc(x) + pi/2
+
+
+def test_acsc():
+    assert acsc(nan) == nan
+    assert acsc(1) == pi/2
+    assert acsc(-1) == -pi/2
+    assert acsc(oo) == 0
+    assert acsc(-oo) == 0
+    assert acsc(zoo) == 0
+
+    assert acsc(x).diff(x) == -1/(x**2*sqrt(1 - 1/x**2))
+    assert acsc(x).as_leading_term(x) == log(x)
+
+    assert acsc(x).rewrite(log) == -I*log(sqrt(1 - 1/x**2) + I/x)
+    assert acsc(x).rewrite(asin) == asin(1/x)
+    assert acsc(x).rewrite(acos) == -acos(1/x) + pi/2
+    assert acsc(x).rewrite(atan) == (-atan(sqrt(x**2 - 1)) + pi/2)*sqrt(x**2)/x
+    assert acsc(x).rewrite(acot) == (-acot(1/sqrt(x**2 - 1)) + pi/2)*sqrt(x**2)/x
+    assert acsc(x).rewrite(asec) == -asec(x) + pi/2
+
 
 @XFAIL
 @slow
 def test_csc_rewrite_failing():
     # Move these 2 tests to test_csc() once bugs fixed
     # sin(x).rewrite(pow) raises RuntimeError: maximum recursion depth
-    # https://code.google.com/p/sympy/issues/detail?id=4072
+    # https://github.com/sympy/sympy/issues/7171
     assert csc(x).rewrite(pow) == csc(x)
     assert csc(x).rewrite(sqrt) == csc(x)
