@@ -4,7 +4,7 @@ from sympy.core import S, sympify, diff
 from sympy.core.function import Function, ArgumentIndexError
 from sympy.core.relational import Eq
 from sympy.polys.polyerrors import PolynomialError
-from sympy.functions.elementary.complexes import im
+from sympy.functions.elementary.complexes import im, sign
 from sympy.functions.elementary.piecewise import Piecewise
 
 ###############################################################################
@@ -42,8 +42,6 @@ class DiracDelta(Function):
     .. [1] http://mathworld.wolfram.com/DeltaFunction.html
     """
 
-    nargs = (1, 2)
-
     is_real = True
 
     def fdiff(self, argindex=1):
@@ -103,15 +101,17 @@ class DiracDelta(Function):
         if not self.args[0].has(x) or (len(self.args) > 1 and self.args[1] != 0 ):
             return self
         try:
-            argroots = roots(self.args[0], x, multiple=True)
+            argroots = roots(self.args[0], x)
             result = 0
             valid = True
-            darg = diff(self.args[0], x)
-            for r in argroots:
-                #should I care about multiplicities of roots?
-                if r.is_real is not False and not darg.subs(x, r).is_zero:
-                    result += self.func(x - r)/abs(darg.subs(x, r))
+            darg = abs(diff(self.args[0], x))
+            for r, m in argroots.items():
+                if r.is_real is not False and m == 1:
+                    result += self.func(x - r)/darg.subs(x, r)
                 else:
+                    # don't handle non-real and if m != 1 then
+                    # a polynomial will have a zero in the derivative (darg)
+                    # at r
                     valid = False
                     break
             if valid:
@@ -213,7 +213,6 @@ class Heaviside(Function):
     .. [1] http://mathworld.wolfram.com/HeavisideStepFunction.html
 
     """
-    nargs = 1
 
     is_real = True
 
@@ -241,3 +240,7 @@ class Heaviside(Function):
     def _eval_rewrite_as_Piecewise(self, arg):
         if arg.is_real:
             return Piecewise((1, arg > 0), (S(1)/2, Eq(arg, 0)), (0, True))
+
+    def _eval_rewrite_as_sign(self, arg):
+        if arg.is_real:
+            return (sign(arg)+1)/2
