@@ -80,7 +80,7 @@ class gamma(Function):
     loggamma: Log Gamma function.
     digamma: Digamma function.
     trigamma: Trigamma function.
-    beta: Euler Beta function.
+    sympy.functions.special.beta_functions.beta: Euler Beta function.
 
     References
     ==========
@@ -224,7 +224,7 @@ class lowergamma(Function):
     loggamma: Log Gamma function.
     digamma: Digamma function.
     trigamma: Trigamma function.
-    beta: Euler Beta function.
+    sympy.functions.special.beta_functions.beta: Euler Beta function.
 
     References
     ==========
@@ -296,14 +296,12 @@ class lowergamma(Function):
                     return (cls(a + 1, x) + x**a * C.exp(-x))/a
 
     def _eval_evalf(self, prec):
-        from sympy.mpmath import mp
+        from sympy.mpmath import mp, workprec
         from sympy import Expr
         a = self.args[0]._to_mpmath(prec)
         z = self.args[1]._to_mpmath(prec)
-        oprec = mp.prec
-        mp.prec = prec
-        res = mp.gammainc(a, 0, z)
-        mp.prec = oprec
+        with workprec(prec):
+            res = mp.gammainc(a, 0, z)
         return Expr._from_mpmath(res, prec)
 
     def _eval_conjugate(self):
@@ -370,7 +368,7 @@ class uppergamma(Function):
     loggamma: Log Gamma function.
     digamma: Digamma function.
     trigamma: Trigamma function.
-    beta: Euler Beta function.
+    sympy.functions.special.beta_functions.beta: Euler Beta function.
 
     References
     ==========
@@ -397,14 +395,12 @@ class uppergamma(Function):
             raise ArgumentIndexError(self, argindex)
 
     def _eval_evalf(self, prec):
-        from sympy.mpmath import mp
+        from sympy.mpmath import mp, workprec
         from sympy import Expr
         a = self.args[0]._to_mpmath(prec)
         z = self.args[1]._to_mpmath(prec)
-        oprec = mp.prec
-        mp.prec = prec
-        res = mp.gammainc(a, z, mp.inf)
-        mp.prec = oprec
+        with workprec(prec):
+            res = mp.gammainc(a, z, mp.inf)
         return Expr._from_mpmath(res, prec)
 
     @classmethod
@@ -421,11 +417,11 @@ class uppergamma(Function):
 
         # We extract branching information here. C/f lowergamma.
         nx, n = z.extract_branch_factor()
-        if a.is_integer and (a > 0) is True:
+        if a.is_integer and (a > 0) == True:
             nx = unpolarify(z)
             if z != nx:
                 return uppergamma(a, nx)
-        elif a.is_integer and (a <= 0) is True:
+        elif a.is_integer and (a <= 0) == True:
             if n != 0:
                 return -2*pi*I*n*(-1)**(-a)/factorial(-a) + uppergamma(a, nx)
         elif n != 0:
@@ -549,7 +545,7 @@ class polygamma(Function):
     loggamma: Log Gamma function.
     digamma: Digamma function.
     trigamma: Trigamma function.
-    beta: Euler Beta function.
+    sympy.functions.special.beta_functions.beta: Euler Beta function.
 
     References
     ==========
@@ -569,11 +565,11 @@ class polygamma(Function):
             raise ArgumentIndexError(self, argindex)
 
     def _eval_is_positive(self):
-        if self.args[1].is_positive and (self.args[0] > 0) is True:
+        if self.args[1].is_positive and (self.args[0] > 0) == True:
             return self.args[0].is_odd
 
     def _eval_is_negative(self):
-        if self.args[1].is_positive and (self.args[0] > 0) is True:
+        if self.args[1].is_positive and (self.args[0] > 0) == True:
             return self.args[0].is_even
 
     def _eval_is_real(self):
@@ -617,7 +613,7 @@ class polygamma(Function):
             elif n == 1:
                 o = C.Order(1/z**2, x)
             r = e0._eval_nseries(z, n, logx) + o
-            return -1 * (-1/z)**N * r
+            return (-1 * (-1/z)**N * r)._eval_nseries(x, n, logx)
 
     @classmethod
     def eval(cls, n, z):
@@ -739,17 +735,66 @@ class loggamma(Function):
     Examples
     ========
 
-    >>> from sympy import S, I, pi, oo, loggamma
-    >>> from sympy.abc import x
+    Several special values are known. For numerical integral
+    arguments we have:
+
+    >>> from sympy import loggamma
+    >>> loggamma(-2)
+    oo
+    >>> loggamma(0)
+    oo
+    >>> loggamma(1)
+    0
+    >>> loggamma(2)
+    0
+    >>> loggamma(3)
+    log(2)
+
+    and for symbolic values:
+
+    >>> from sympy import Symbol
+    >>> n = Symbol("n", integer=True, positive=True)
+    >>> loggamma(n)
+    log(gamma(n))
+    >>> loggamma(-n)
+    oo
+
+    for half-integral values:
+
+    >>> from sympy import S, pi
+    >>> loggamma(S(5)/2)
+    log(3*sqrt(pi)/4)
+    >>> loggamma(n/2)
+    log(2**(-n + 1)*sqrt(pi)*gamma(n)/gamma(n/2 + 1/2))
+
+    and general rational arguments:
+
+    >>> from sympy import expand_func
+    >>> L = loggamma(S(16)/3)
+    >>> expand_func(L).doit()
+    -5*log(3) + loggamma(1/3) + log(4) + log(7) + log(10) + log(13)
+    >>> L = loggamma(S(19)/4)
+    >>> expand_func(L).doit()
+    -4*log(4) + loggamma(3/4) + log(3) + log(7) + log(11) + log(15)
+    >>> L = loggamma(S(23)/7)
+    >>> expand_func(L).doit()
+    -3*log(7) + log(2) + loggamma(2/7) + log(9) + log(16)
+
+    The loggamma function has the following limits towards infinity:
+
+    >>> from sympy import oo
+    >>> loggamma(oo)
+    oo
+    >>> loggamma(-oo)
+    zoo
 
     The loggamma function obeys the mirror symmetry
     if `x \in \mathbb{C} \setminus \{-\infty, 0\}`:
 
+    >>> from sympy.abc import x
     >>> from sympy import conjugate
     >>> conjugate(loggamma(x))
     loggamma(conjugate(x))
-    >>> conjugate(loggamma(-oo))
-    conjugate(loggamma(-oo))
 
     Differentiation with respect to x is supported:
 
@@ -766,6 +811,7 @@ class loggamma(Function):
     We can numerically evaluate the gamma function to arbitrary precision
     on the whole complex plane:
 
+    >>> from sympy import I
     >>> loggamma(5).evalf(30)
     3.17805383034794561964694160130
     >>> loggamma(I).evalf(20)
@@ -780,7 +826,7 @@ class loggamma(Function):
     polygamma: Polygamma function.
     digamma: Digamma function.
     trigamma: Trigamma function.
-    beta: Euler Beta function.
+    sympy.functions.special.beta_functions.beta: Euler Beta function.
 
     References
     ==========
@@ -790,10 +836,47 @@ class loggamma(Function):
     .. [3] http://mathworld.wolfram.com/LogGammaFunction.html
     .. [4] http://functions.wolfram.com/GammaBetaErf/LogGamma/
     """
+    @classmethod
+    def eval(cls, z):
+        z = sympify(z)
 
-    nargs = 1  # there is no eval defined so we must define this
+        if z.is_integer:
+            if z.is_nonpositive:
+                return S.Infinity
+            elif z.is_positive:
+                return log(gamma(z))
+        elif z.is_rational:
+            p, q = z.as_numer_denom()
+            # Half-integral values:
+            if p.is_positive and q == 2:
+                return log(sqrt(S.Pi) * 2**(1 - p) * gamma(p) / gamma((p + 1)*S.Half))
 
-    # TODO: Implement various special known values
+        if z is S.Infinity:
+            return S.Infinity
+        elif abs(z) is S.Infinity:
+            return S.ComplexInfinity
+        if z is S.NaN:
+            return S.NaN
+
+    def _eval_expand_func(self, **hints):
+        z = self.args[0]
+
+        if z.is_Rational:
+            p, q = z.as_numer_denom()
+            # General rational arguments (u + p/q)
+            # Split z as n + p/q with p < q
+            n = p // q
+            p = p - n*q
+            if p.is_positive and q.is_positive and p < q:
+                k = Dummy("k")
+                if n.is_positive:
+                    return loggamma(p / q) - n*log(q) + C.Sum(log((k - 1)*q + p), (k, 1, n))
+                elif n.is_negative:
+                    return loggamma(p / q) - n*log(q) + S.Pi*S.ImaginaryUnit*n - C.Sum(log(k*q - p), (k, 1, -n))
+                elif n.is_zero:
+                    return loggamma(p / q)
+
+        return self
 
     def _eval_nseries(self, x, n, logx=None):
         x0 = self.args[0].limit(x, 0)
@@ -854,7 +937,7 @@ def digamma(x):
     polygamma: Polygamma function.
     loggamma: Log Gamma function.
     trigamma: Trigamma function.
-    beta: Euler Beta function.
+    sympy.functions.special.beta_functions.beta: Euler Beta function.
 
     References
     ==========
@@ -884,7 +967,7 @@ def trigamma(x):
     polygamma: Polygamma function.
     loggamma: Log Gamma function.
     digamma: Digamma function.
-    beta: Euler Beta function.
+    sympy.functions.special.beta_functions.beta: Euler Beta function.
 
     References
     ==========
@@ -894,36 +977,3 @@ def trigamma(x):
     .. [3] http://functions.wolfram.com/GammaBetaErf/PolyGamma2/
     """
     return polygamma(1, x)
-
-
-###############################################################################
-############################### BETA FUNCTIONS ################################
-###############################################################################
-
-def beta(x, y):
-    r"""
-    Euler Beta function:
-
-    .. math::
-        \mathrm{B}(x, y) := \frac{\Gamma(x) \Gamma(y)}{\Gamma(x+y)}
-
-    See Also
-    ========
-
-    gamma: Gamma function.
-    lowergamma: Lower incomplete gamma function.
-    uppergamma: Upper incomplete gamma function.
-    polygamma: Polygamma function.
-    loggamma: Log Gamma function.
-    digamma: Digamma function.
-    trigamma: Trigamma function.
-
-    References
-    ==========
-
-    .. [1] https://en.wikipedia.org/wiki/Beta_function
-    .. [2] http://dlmf.nist.gov/5.12
-    .. [3] http://mathworld.wolfram.com/BetaFunction.html
-    .. [4] http://functions.wolfram.com/GammaBetaErf/Beta/
-    """
-    return gamma(x)*gamma(y) / gamma(x + y)
