@@ -277,12 +277,12 @@ def test_erf2inv():
 
 
 def mytn(expr1, expr2, expr3, x, d=0):
-    from sympy.utilities.randtest import test_numerically, random_complex_number
+    from sympy.utilities.randtest import verify_numerically, random_complex_number
     subs = {}
     for a in expr1.free_symbols:
         if a != x:
             subs[a] = random_complex_number()
-    return expr2 == expr3 and test_numerically(expr1.subs(subs),
+    return expr2 == expr3 and verify_numerically(expr1.subs(subs),
                                                expr2.subs(subs), x, d=d)
 
 
@@ -514,7 +514,7 @@ def test_si():
         x + x**3/18 + x**5/600 + x**7/35280 + O(x**9)
     assert Si(sin(x)).nseries(x, n=5) == x - 2*x**3/9 + 17*x**5/450 + O(x**6)
     assert Si(x).nseries(x, 1, n=3) == \
-        Si(1) + x*sin(1) + x**2*(-sin(1)/2 + cos(1)/2) + O(x**3)
+        Si(1) + (x - 1)*sin(1) + (x - 1)**2*(-sin(1)/2 + cos(1)/2) + O((x - 1)**3, (x, 1))
 
 
 def test_ci():
@@ -626,6 +626,20 @@ def test_fresnel():
     assert fresnelc(z).series(z, n=15) == \
         z - pi**2*z**5/40 + pi**4*z**9/3456 - pi**6*z**13/599040 + O(z**15)
 
+    # issue 6510
+    assert fresnels(z).series(z, S.Infinity) == \
+        (-1/(pi**2*z**3) + O(z**(-6), (z, oo)))*sin(pi*z**2/2) + \
+        (3/(pi**3*z**5) - 1/(pi*z) + O(z**(-6), (z, oo)))*cos(pi*z**2/2) + S.Half
+    assert fresnelc(z).series(z, S.Infinity) == \
+        (-1/(pi**2*z**3) + O(z**(-6), (z, oo)))*cos(pi*z**2/2) + \
+        (-3/(pi**3*z**5) + 1/(pi*z) + O(z**(-6), (z, oo)))*sin(pi*z**2/2) + S.Half
+    assert fresnels(1/z).series(z) == \
+        (-z**3/pi**2 + O(z**6))*sin(pi/(2*z**2)) + (-z/pi + 3*z**5/pi**3 + \
+        O(z**6))*cos(pi/(2*z**2)) + S.Half
+    assert fresnelc(1/z).series(z) == \
+        (-z**3/pi**2 + O(z**6))*cos(pi/(2*z**2)) + (z/pi - 3*z**5/pi**3 + \
+        O(z**6))*sin(pi/(2*z**2)) + S.Half
+
     assert fresnelc(w).is_real is True
 
     assert fresnelc(z).as_real_imag() == \
@@ -647,14 +661,14 @@ def test_fresnel():
         meijerg(((), (1,)), ((S(1)/4,),
         (S(3)/4, 0)), -pi**2*z**4/16)/(2*(-z)**(S(1)/4)*(z**2)**(S(1)/4))
 
-    from sympy.utilities.randtest import test_numerically
+    from sympy.utilities.randtest import verify_numerically
 
-    test_numerically(re(fresnels(z)), fresnels(z).as_real_imag()[0], z)
-    test_numerically(im(fresnels(z)), fresnels(z).as_real_imag()[1], z)
-    test_numerically(fresnels(z), fresnels(z).rewrite(hyper), z)
-    test_numerically(fresnels(z), fresnels(z).rewrite(meijerg), z)
+    verify_numerically(re(fresnels(z)), fresnels(z).as_real_imag()[0], z)
+    verify_numerically(im(fresnels(z)), fresnels(z).as_real_imag()[1], z)
+    verify_numerically(fresnels(z), fresnels(z).rewrite(hyper), z)
+    verify_numerically(fresnels(z), fresnels(z).rewrite(meijerg), z)
 
-    test_numerically(re(fresnelc(z)), fresnelc(z).as_real_imag()[0], z)
-    test_numerically(im(fresnelc(z)), fresnelc(z).as_real_imag()[1], z)
-    test_numerically(fresnelc(z), fresnelc(z).rewrite(hyper), z)
-    test_numerically(fresnelc(z), fresnelc(z).rewrite(meijerg), z)
+    verify_numerically(re(fresnelc(z)), fresnelc(z).as_real_imag()[0], z)
+    verify_numerically(im(fresnelc(z)), fresnelc(z).as_real_imag()[1], z)
+    verify_numerically(fresnelc(z), fresnelc(z).rewrite(hyper), z)
+    verify_numerically(fresnelc(z), fresnelc(z).rewrite(meijerg), z)
