@@ -1,18 +1,17 @@
 from sympy import (
     Symbol, gamma, I, oo, nan, zoo, factorial, sqrt, Rational, log,
     polygamma, EulerGamma, pi, uppergamma, S, expand_func, loggamma, sin,
-    cos, O, cancel, lowergamma, exp, erf, beta, exp_polar, harmonic, zeta,
-    factorial)
+    cos, O, lowergamma, exp, erf, exp_polar, harmonic, zeta,conjugate)
 from sympy.core.function import ArgumentIndexError
 from sympy.utilities.randtest import (test_derivative_numerically as td,
                                       random_complex_number as randcplx,
-                                      test_numerically as tn)
+                                      verify_numerically as tn)
 from sympy.utilities.pytest import raises
 
 x = Symbol('x')
 y = Symbol('y')
 n = Symbol('n', integer=True)
-
+w = Symbol('w', real=True)
 
 def test_gamma():
     assert gamma(nan) == nan
@@ -55,6 +54,9 @@ def test_gamma():
     assert gamma(x - 1).expand(func=True) == gamma(x)/(x - 1)
     assert gamma(x + 2).expand(func=True, mul=False) == x*(x + 1)*gamma(x)
 
+    assert conjugate(gamma(x)) == gamma(conjugate(x))
+    assert gamma(w).is_real is True
+
     assert expand_func(gamma(x + Rational(3, 2))) == \
         (x + Rational(1, 2))*gamma(x + Rational(1, 2))
 
@@ -72,9 +74,9 @@ def test_gamma_series():
     assert gamma(x + 1).series(x, 0, 3) == \
         1 - EulerGamma*x + x**2*(EulerGamma**2/2 + pi**2/12) + O(x**3)
     assert gamma(x).series(x, -1, 3) == \
-        -1/x + EulerGamma - 1 + x*(-1 - pi**2/12 - EulerGamma**2/2 + EulerGamma) \
-        + x**2*(-1 - pi**2/12 - EulerGamma**2/2 + EulerGamma**3/6 -
-        polygamma(2, 1)/6 + EulerGamma*pi**2/12 + EulerGamma) + O(x**3)
+        -1/(x + 1) + EulerGamma - 1 + (x + 1)*(-1 - pi**2/12 - EulerGamma**2/2 + \
+       EulerGamma) + (x + 1)**2*(-1 - pi**2/12 - EulerGamma**2/2 + EulerGamma**3/6 - \
+       polygamma(2, 1)/6 + EulerGamma*pi**2/12 + EulerGamma) + O((x + 1)**3, (x, -1))
 
 
 def tn_branch(s, func):
@@ -105,8 +107,6 @@ def test_lowergamma():
     assert tn(lowergamma(S.Half - 3, x, evaluate=False),
               lowergamma(S.Half - 3, x), x)
 
-    assert lowergamma(x, y).rewrite(uppergamma) == gamma(x) - uppergamma(x, y)
-
     assert tn_branch(-3, lowergamma)
     assert tn_branch(-4, lowergamma)
     assert tn_branch(S(1)/3, lowergamma)
@@ -117,6 +117,10 @@ def test_lowergamma():
     assert lowergamma(-2, exp_polar(5*pi*I)*x) == \
         lowergamma(-2, x*exp_polar(I*pi)) + 2*pi*I
 
+    assert conjugate(lowergamma(x, y)) == lowergamma(conjugate(x), conjugate(y))
+    assert conjugate(lowergamma(x, 0)) == conjugate(lowergamma(x, 0))
+    assert conjugate(lowergamma(x, -oo)) == conjugate(lowergamma(x, -oo))
+
     assert lowergamma(
         x, y).rewrite(expint) == -y**x*expint(-x + 1, y) + gamma(x)
     k = Symbol('k', integer=True)
@@ -124,7 +128,7 @@ def test_lowergamma():
         k, y).rewrite(expint) == -y**k*expint(-k + 1, y) + gamma(k)
     k = Symbol('k', integer=True, positive=False)
     assert lowergamma(k, y).rewrite(expint) == lowergamma(k, y)
-
+    assert lowergamma(x, y).rewrite(uppergamma) == gamma(x) - uppergamma(x, y)
 
 def test_uppergamma():
     from sympy import meijerg, exp_polar, I, expint
@@ -144,8 +148,6 @@ def test_uppergamma():
     assert tn(uppergamma(S.Half - 3, x, evaluate=False),
               uppergamma(S.Half - 3, x), x)
 
-    assert uppergamma(x, y).rewrite(lowergamma) == gamma(x) - lowergamma(x, y)
-
     assert tn_branch(-3, uppergamma)
     assert tn_branch(-4, uppergamma)
     assert tn_branch(S(1)/3, uppergamma)
@@ -158,7 +160,13 @@ def test_uppergamma():
         uppergamma(-2, x*exp_polar(I*pi)) - 2*pi*I
 
     assert uppergamma(-2, x) == expint(3, x)/x**2
+
+    assert conjugate(uppergamma(x, y)) == uppergamma(conjugate(x), conjugate(y))
+    assert conjugate(uppergamma(x, 0)) == gamma(conjugate(x))
+    assert conjugate(uppergamma(x, -oo)) == conjugate(uppergamma(x, -oo))
+
     assert uppergamma(x, y).rewrite(expint) == y**x*expint(-x + 1, y)
+    assert uppergamma(x, y).rewrite(lowergamma) == gamma(x) - lowergamma(x, y)
 
 
 def test_polygamma():
@@ -167,6 +175,9 @@ def test_polygamma():
     assert polygamma(n, nan) == nan
 
     assert polygamma(0, oo) == oo
+    assert polygamma(0, -oo) == oo
+    assert polygamma(0, I*oo) == oo
+    assert polygamma(0, -I*oo) == oo
     assert polygamma(1, oo) == 0
     assert polygamma(5, oo) == 0
 
@@ -282,6 +293,54 @@ def test_polygamma_expand_func():
 def test_loggamma():
     raises(TypeError, lambda: loggamma(2, 3))
     raises(ArgumentIndexError, lambda: loggamma(x).fdiff(2))
+
+    assert loggamma(-1) == oo
+    assert loggamma(-2) == oo
+    assert loggamma(0) == oo
+    assert loggamma(1) == 0
+    assert loggamma(2) == 0
+    assert loggamma(3) == log(2)
+    assert loggamma(4) == log(6)
+
+    n = Symbol("n", integer=True, positive=True)
+    assert loggamma(n) == log(gamma(n))
+    assert loggamma(-n) == oo
+    assert loggamma(n/2) == log(2**(-n + 1)*sqrt(pi)*gamma(n)/gamma(n/2 + S.Half))
+
+    from sympy import I
+
+    assert loggamma(oo) == oo
+    assert loggamma(-oo) == zoo
+    assert loggamma(I*oo) == zoo
+    assert loggamma(-I*oo) == zoo
+    assert loggamma(zoo) == zoo
+    assert loggamma(nan) == nan
+
+    L = loggamma(S(16)/3)
+    E = -5*log(3) + loggamma(S(1)/3) + log(4) + log(7) + log(10) + log(13)
+    assert expand_func(L).doit() == E
+    assert L.n() == E.n()
+
+    L = loggamma(19/S(4))
+    E = -4*log(4) + loggamma(S(3)/4) + log(3) + log(7) + log(11) + log(15)
+    assert expand_func(L).doit() == E
+    assert L.n() == E.n()
+
+    L = loggamma(S(23)/7)
+    E = -3*log(7) + log(2) + loggamma(S(2)/7) + log(9) + log(16)
+    assert expand_func(L).doit() == E
+    assert L.n() == E.n()
+
+    L = loggamma(19/S(4)-7)
+    E = -log(9) - log(5) + loggamma(S(3)/4) + 3*log(4) - 3*I*pi
+    assert expand_func(L).doit() == E
+    assert L.n() == E.n()
+
+    L = loggamma(23/S(7)-6)
+    E = -log(19) - log(12) - log(5) + loggamma(S(2)/7) + 3*log(7) - 3*I*pi
+    assert expand_func(L).doit() == E
+    assert L.n() == E.n()
+
     assert loggamma(x).diff(x) == polygamma(0, x)
     s1 = loggamma(1/(x + sin(x)) + cos(x)).nseries(x, n=4)
     s2 = (-log(2*x) - 1)/(2*x) - log(x/pi)/2 + (4 - log(2*x))*x/24 + O(x**2) + \
@@ -299,6 +358,10 @@ def test_loggamma():
         pi**4*x**4/360 + x**5*polygamma(4, 1)/120 + O(x**6)
     assert s1 == loggamma(x).rewrite('intractable').series(x)
 
+    assert conjugate(loggamma(x)) == loggamma(conjugate(x))
+    assert conjugate(loggamma(0)) == conjugate(loggamma(0))
+    assert conjugate(loggamma(1)) == loggamma(conjugate(1))
+    assert conjugate(loggamma(-oo)) == conjugate(loggamma(-oo))
     assert loggamma(x).is_real is None
     y, z = Symbol('y', real=True), Symbol('z', imaginary=True)
     assert loggamma(y).is_real
@@ -322,9 +385,3 @@ def test_polygamma_expansion():
         x + x**2/2 + x**3/6 + O(x**5)
     assert polygamma(3, 1/x).nseries(x, n=11) == \
         2*x**3 + 3*x**4 + 2*x**5 - x**7 + 4*x**9/3 + O(x**11)
-
-
-def test_beta_function():
-    x, y = Symbol('x'), Symbol('y')
-    assert beta(x, y) == gamma(x)*gamma(y)/gamma(x + y)
-    assert beta(x, y) == beta(y, x)  # Symmetric
