@@ -5,7 +5,7 @@ from sympy.abc import x, z, k
 from sympy.utilities.pytest import raises
 from sympy.utilities.randtest import (
     random_complex_number as randcplx,
-    test_numerically as tn,
+    verify_numerically as tn,
     test_derivative_numerically as td)
 
 
@@ -330,6 +330,6 @@ def test_limits():
            hyper((1,), (S(4)/3, S(5)/3), 0) + \
            9*k**2*hyper((2,), (S(7)/3, S(8)/3), 0)/20 + \
            81*k**4*hyper((3,), (S(10)/3, S(11)/3), 0)/1120 + \
-           O(k**6) # issue 3251
+           O(k**6) # issue 6350
     assert limit(meijerg((), (), (1,), (0,), -x), x, 0) == \
-            meijerg(((), ()), ((1,), (0,)), 0) # issue 2953
+            meijerg(((), ()), ((1,), (0,)), 0) # issue 6052
