@@ -11,14 +11,20 @@ Segment
 from __future__ import print_function, division
 
 from sympy.core import S, C, sympify, Dummy
-from sympy.functions.elementary.trigonometric import _pi_coeff as pi_coeff
 from sympy.core.logic import fuzzy_and
+from sympy.core.exprtools import factor_terms
+from sympy.core.relational import Eq
+from sympy.functions.elementary.trigonometric import _pi_coeff as pi_coeff, \
+    sqrt
+from sympy.functions.elementary.piecewise import Piecewise
+from sympy.logic.boolalg import And
 from sympy.simplify.simplify import simplify
 from sympy.solvers import solve
 from sympy.geometry.exceptions import GeometryError
 from .entity import GeometryEntity
 from .point import Point
 from .util import _symbol
+from sympy.core.compatibility import is_sequence
 
 # TODO: this should be placed elsewhere and reused in other modules
 
@@ -28,7 +34,7 @@ class Undecidable(ValueError):
 
 
 class LinearEntity(GeometryEntity):
-    """An abstract base class for all linear entities (line, ray and segment)
+    """A base class for all linear entities (line, ray and segment)
     in a 2-dimensional Euclidean space.
 
     Attributes
@@ -44,10 +50,6 @@ class LinearEntity(GeometryEntity):
     =====
 
     This is an abstract class and is not meant to be instantiated.
-    Subclasses should implement the following methods:
-
-        * __eq__
-        * contains
 
     See Also
     ========
@@ -60,8 +62,9 @@ class LinearEntity(GeometryEntity):
         p1 = Point(p1)
         p2 = Point(p2)
         if p1 == p2:
-            # Rolygon returns lower priority classes...should LinearEntity, too?
-            return p1  # raise ValueError("%s.__new__ requires two unique Points." % cls.__name__)
+            # if it makes sense to return a Point, handle in subclass
+            raise ValueError(
+                "%s.__new__ requires two unique Points." % cls.__name__)
 
         return GeometryEntity.__new__(cls, p1, p2, **kwargs)
 
@@ -109,7 +112,7 @@ class LinearEntity(GeometryEntity):
 
     @property
     def coefficients(self):
-        """The coefficients (`a`, `b`, `c`) for the linear equation `ax + by + c = 0`.
+        """The coefficients (`a`, `b`, `c`) for `ax + by + c = 0`.
 
         See Also
         ========
@@ -142,7 +145,8 @@ class LinearEntity(GeometryEntity):
                 self.p2.x - self.p1.x,
                 self.p1.x*self.p2.y - self.p1.y*self.p2.x)])
 
-    def is_concurrent(*lines):
+    @staticmethod
+    def are_concurrent(*lines):
         """Is a sequence of linear entities concurrent?
 
         Two or more linear entities are concurrent if they all
@@ -177,15 +181,15 @@ class LinearEntity(GeometryEntity):
         Examples
         ========
 
-        >>> from sympy import Point, Line
+        >>> from sympy import Point, Line, Line3D
         >>> p1, p2 = Point(0, 0), Point(3, 5)
         >>> p3, p4 = Point(-2, -2), Point(0, 2)
         >>> l1, l2, l3 = Line(p1, p2), Line(p1, p3), Line(p1, p4)
-        >>> l1.is_concurrent(l2, l3)
+        >>> Line.are_concurrent(l1, l2, l3)
         True
 
         >>> l4 = Line(p2, p3)
-        >>> l4.is_concurrent(l2, l3)
+        >>> Line.are_concurrent(l2, l3, l4)
         False
 
         """
@@ -460,8 +464,20 @@ class LinearEntity(GeometryEntity):
         """
         if p in self:
             return p
-        pl = self.perpendicular_line(p)
-        p2 = Line(self).intersection(pl)[0]
+        a, b, c = self.coefficients
+        if a == 0:  # horizontal
+            p2 = Point(p.x, self.p1.y)
+        elif b == 0:  # vertical
+            p2 = Point(self.p1.x, p.y)
+        else:
+            # ax + by + c = 0
+            y = (-c - a*p.x)/b
+            m = self.slope
+            d2 = 1 + m**2
+            H = p.y - y
+            dx = m*H/d2
+            dy = m*dx
+            p2 = (p.x + dx, y + dy)
         return Segment(p, p2)
 
     @property
@@ -568,9 +584,8 @@ class LinearEntity(GeometryEntity):
         Line and then reforming the linear entity using these
         projections.
         A point P is projected onto a line L by finding the point
-        on L that is closest to P. This is done by creating a
-        perpendicular line through P and L and finding its
-        intersection with L.
+        on L that is closest to P. This point is the intersection
+        of L and the line perpendicular to L that passes through P.
 
         See Also
         ========
@@ -664,6 +679,7 @@ class LinearEntity(GeometryEntity):
                 return [o]
             else:
                 return []
+
         elif isinstance(o, LinearEntity):
             a1, b1, c1 = self.coefficients
             a2, b2, c2 = o.coefficients
@@ -680,10 +696,9 @@ class LinearEntity(GeometryEntity):
                 elif isinstance(self, Ray):
                     if isinstance(o, Ray):
                         # case 1, rays in the same direction
-                        if self.xdirection == o.xdirection:
-                            if self.source.x < o.source.x:
-                                return [o]
-                            return [self]
+                        if self.xdirection == o.xdirection and \
+                                self.ydirection == o.ydirection:
+                            return [self] if (self.source in o) else [o]
                         # case 2, rays in the opposite directions
                         else:
                             if o.source in self:
@@ -752,27 +767,32 @@ class LinearEntity(GeometryEntity):
                     return True
 
             def inray(self):
+                if self.p1 == inter:
+                    return True
                 sray = Ray(self.p1, inter)
                 if sray.xdirection == self.xdirection and \
                         sray.ydirection == self.ydirection:
                     return True
-            for i in range(2):
-                if isinstance(self, Line):
-                    if isinstance(o, Line):
-                        return [inter]
-                    elif isinstance(o, Ray) and inray(o):
-                        return [inter]
-                    elif isinstance(o, Segment) and inseg(o):
-                        return [inter]
-                elif isinstance(self, Ray) and inray(self):
-                    if isinstance(o, Ray) and inray(o):
-                        return [inter]
-                    elif isinstance(o, Segment) and inseg(o):
-                        return [inter]
-                elif isinstance(self, Segment) and inseg(self):
-                    if isinstance(o, Segment) and inseg(o):
-                        return [inter]
+
+            prec = (Line, Ray, Segment)
+            if prec.index(self.func) > prec.index(o.func):
                 self, o = o, self
+            rv = [inter]
+            if isinstance(self, Line):
+                if isinstance(o, Line):
+                    return rv
+                elif isinstance(o, Ray) and inray(o):
+                    return rv
+                elif isinstance(o, Segment) and inseg(o):
+                    return rv
+            elif isinstance(self, Ray) and inray(self):
+                if isinstance(o, Ray) and inray(o):
+                    return rv
+                elif isinstance(o, Segment) and inseg(o):
+                    return rv
+            elif isinstance(self, Segment) and inseg(self):
+                if isinstance(o, Segment) and inseg(o):
+                    return rv
             return []
 
         return o.intersection(self)
@@ -924,14 +944,6 @@ class LinearEntity(GeometryEntity):
             None if a determination cannot be made."""
         raise NotImplementedError()
 
-    def __eq__(self, other):
-        """Subclasses should implement this method."""
-        raise NotImplementedError()
-
-    def __hash__(self):
-        return super(LinearEntity, self).__hash__()
-
-
 class Line(LinearEntity):
     """An infinite line in space.
 
@@ -996,16 +1008,18 @@ class Line(LinearEntity):
             except NotImplementedError:
                 raise ValueError('The 2nd argument was not a valid Point. '
                 'If it was a slope, enter it with keyword "slope".')
-            if p1 == p2:
-                raise ValueError('A line requires two distinct points.')
         elif slope is not None and pt is None:
             slope = sympify(slope)
-            if slope.is_bounded is False:
-                # when unbounded slope, don't change x
-                p2 = p1 + Point(0, 1)
+            if slope.is_finite is False:
+                # when infinite slope, don't change x
+                dx = 0
+                dy = 1
             else:
                 # go over 1 up slope
-                p2 = p1 + Point(1, slope)
+                dx = 1
+                dy = slope
+            # XXX avoiding simplification by adding to coords directly
+            p2 = Point(p1.x + dx, p1.y + dy)
         else:
             raise ValueError('A 2nd Point or keyword "slope" must be used.')
 
@@ -1083,8 +1097,26 @@ class Line(LinearEntity):
         return simplify(a*x + b*y + c)
 
     def contains(self, o):
-        """Return True if o is on this Line, or False otherwise."""
+        """
+        Return True if o is on this Line, or False otherwise.
+
+        Examples
+        ========
+
+        >>> from sympy import Line,Point
+        >>> p1, p2 = Point(0, 1), Point(3, 4)
+        >>> l = Line(p1, p2)
+        >>> l.contains(p1)
+        True
+        >>> l.contains((0, 1))
+        True
+        >>> l.contains((0, 0))
+        False
+        """
+        if is_sequence(o):
+            o = Point(o)
         if isinstance(o, Point):
+            o = o.func(*[simplify(i) for i in o.args])
             x, y = Dummy(), Dummy()
             eq = self.equation(x, y)
             if not eq.has(y):
@@ -1101,15 +1133,42 @@ class Line(LinearEntity):
         else:
             return o.p1 in self and o.p2 in self
 
-    def __eq__(self, other):
-        """Return True if other is equal to this Line, or False otherwise."""
+    def distance(self, o):
+        """
+        Finds the shortest distance between a line and a point.
+
+        Raises
+        ======
+
+        NotImplementedError is raised if o is not a Point
+
+        Examples
+        ========
+
+        >>> from sympy import Point, Line
+        >>> p1, p2 = Point(0, 0), Point(1, 1)
+        >>> s = Line(p1, p2)
+        >>> s.distance(Point(-1, 1))
+        sqrt(2)
+        >>> s.distance((-1, 2))
+        3*sqrt(2)/2
+        """
+        if not isinstance(o, Point):
+            if is_sequence(o):
+                o = Point(o)
+        a, b, c = self.coefficients
+        if 0 in (a, b):
+            return self.perpendicular_segment(o).length
+        m = self.slope
+        x = o.x
+        y = m*x - c/b
+        return abs(factor_terms(o.y - y))/sqrt(1 + m**2)
+
+    def equal(self, other):
+        """Returns True if self and other are the same mathematical entities"""
         if not isinstance(other, Line):
             return False
-        return Point.is_collinear(self.p1, self.p2, other.p1, other.p2)
-
-    def __hash__(self):
-        return super(Line, self).__hash__()
-
+        return Point.is_collinear(self.p1, other.p1, self.p2, other.p2)
 
 class Ray(LinearEntity):
     """
@@ -1175,10 +1234,11 @@ class Ray(LinearEntity):
             try:
                 p2 = Point(pt)
             except NotImplementedError:
-                raise ValueError(
-                    'The 2nd argument was not a valid Point;\nif '
-                    'it was meant to be an angle it should be '
-                    'given with keyword "angle".')
+                from sympy.utilities.misc import filldedent
+                raise ValueError(filldedent('''
+                    The 2nd argument was not a valid Point; if
+                    it was meant to be an angle it should be
+                    given with keyword "angle".'''))
             if p1 == p2:
                 raise ValueError('A Ray requires two distinct points.')
         elif angle is not None and pt is None:
@@ -1200,9 +1260,13 @@ class Ray(LinearEntity):
                 if p2 is None:
                     c *= S.Pi
             else:
-                c = angle
+                c = angle % (2*S.Pi)
             if not p2:
-                p2 = p1 + Point(1, C.tan(c))
+                m = 2*c/S.Pi
+                left = And(1 < m, m < 3)  # is it in quadrant 2 or 3?
+                x = Piecewise((-1, left), (Piecewise((0, Eq(m % 1, 0)), (1, True)), True))
+                y = Piecewise((-C.tan(c), left), (Piecewise((1, Eq(m, 1)), (-1, Eq(m, 3)), (C.tan(c), True)), True))
+                p2 = p1 + Point(x, y)
         else:
             raise ValueError('A 2nd point or keyword "angle" must be used.')
 
@@ -1293,6 +1357,43 @@ class Ray(LinearEntity):
         else:
             return S.NegativeInfinity
 
+
+    def distance(self, o):
+        """
+        Finds the shortest distance between the ray and a point.
+
+        Raises
+        ======
+
+        NotImplementedError is raised if o is not a Point
+
+        Examples
+        ========
+
+        >>> from sympy import Point, Ray
+        >>> p1, p2 = Point(0, 0), Point(1, 1)
+        >>> s = Ray(p1, p2)
+        >>> s.distance(Point(-1, -1))
+        sqrt(2)
+        >>> s.distance((-1, 2))
+        3*sqrt(2)/2
+        """
+        if not isinstance(o, Point):
+            if is_sequence(o):
+                o = Point(o)
+        s = self.perpendicular_segment(o)
+        if isinstance(s, Point):
+            if self.contains(s):
+                return S.Zero
+        else:
+            # since arg-order is arbitrary, find the non-o point
+            non_o = s.p1 if s.p1 != o else s.p2
+            if self.contains(non_o):
+                return Line(self).distance(o)  # = s.length but simpler
+        # the following applies when neither of the above apply
+        return self.source.distance(o)
+
+
     def plot_interval(self, parameter='t'):
         """The plot interval for the default geometric plot of the Ray. Gives
         values that will produce a ray that is 10 units long (where a unit is
@@ -1322,24 +1423,50 @@ class Ray(LinearEntity):
         t = _symbol(parameter)
         return [t, 0, 10]
 
-    def __eq__(self, other):
-        """Is the other GeometryEntity equal to this Ray?"""
+    def equals(self, other):
+        """Returns True if self and other are the same mathematical entities"""
         if not isinstance(other, Ray):
             return False
-        return (self.source == other.source) and (other.p2 in self)
-
-    def __hash__(self):
-        return super(Ray, self).__hash__()
+        return self.source == other.source and other.p2 in self
 
     def contains(self, o):
-        """Is other GeometryEntity contained in this Ray?"""
+        """
+        Is other GeometryEntity contained in this Ray?
+
+        Examples
+        ========
+
+        >>> from sympy import Ray,Point,Segment
+        >>> p1, p2 = Point(0, 0), Point(4, 4)
+        >>> r = Ray(p1, p2)
+        >>> r.contains(p1)
+        True
+        >>> r.contains((1, 1))
+        True
+        >>> r.contains((1, 3))
+        False
+        >>> s = Segment((1, 1), (2, 2))
+        >>> r.contains(s)
+        True
+        >>> s = Segment((1, 2), (2, 5))
+        >>> r.contains(s)
+        False
+        >>> r1 = Ray((2, 2), (3, 3))
+        >>> r.contains(r1)
+        True
+        >>> r1 = Ray((2, 2), (3, 5))
+        >>> r.contains(r1)
+        False
+        """
         if isinstance(o, Ray):
             return (Point.is_collinear(self.p1, self.p2, o.p1, o.p2) and
                     self.xdirection == o.xdirection and
                     self.ydirection == o.ydirection)
         elif isinstance(o, Segment):
             return o.p1 in self and o.p2 in self
-        elif isinstance(o, Point):
+        elif is_sequence(o):
+            o = Point(o)
+        if isinstance(o, Point):
             if Point.is_collinear(self.p1, self.p2, o):
                 if self.xdirection is S.Infinity:
                     rv = o.x >= self.source.x
@@ -1349,8 +1476,8 @@ class Ray(LinearEntity):
                     rv = o.y >= self.source.y
                 else:
                     rv = o.y <= self.source.y
-                if isinstance(rv, bool):
-                    return rv
+                if rv == True or rv == False:
+                    return bool(rv)
                 raise Undecidable(
                     'Cannot determine if %s is in %s' % (o, self))
             else:
@@ -1363,7 +1490,7 @@ class Ray(LinearEntity):
 
 
 class Segment(LinearEntity):
-    """An undirected line segment in space.
+    """A undirected line segment in space.
 
     Parameters
     ==========
@@ -1419,14 +1546,14 @@ class Segment(LinearEntity):
         p2 = Point(p2)
         if p1 == p2:
             return Point(p1)
-        if (p1.x > p2.x) is True:
+        if (p1.x > p2.x) == True:
             p1, p2 = p2, p1
-        elif (p1.x == p2.x) is (p1.y > p2.y) is True:
+        elif (p1.x == p2.x) == True and (p1.y > p2.y) == True:
             p1, p2 = p2, p1
         return LinearEntity.__new__(cls, p1, p2, **kwargs)
 
     def plot_interval(self, parameter='t'):
-        """The plot interval for the default geometric plot of the Segment. Gives
+        """The plot interval for the default geometric plot of the Segment gives
         values that will produce the full segment in a plot.
 
         Parameters
@@ -1555,35 +1682,25 @@ class Segment(LinearEntity):
         >>> s = Segment(p1, p2)
         >>> s.distance(Point(10, 15))
         sqrt(170)
+        >>> s.distance((0, 12))
+        sqrt(73)
         """
+        if is_sequence(o):
+            o = Point(o)
         if isinstance(o, Point):
-            return self._do_point_distance(o)
+            seg_vector = self.p2 - self.p1
+            pt_vector = o - self.p1
+            t = seg_vector.dot(pt_vector)/self.length**2
+            if t >= 1:
+                distance = Point.distance(self.p2, o)
+            elif t <= 0:
+                distance = Point.distance(self.p1, o)
+            else:
+                distance = Point.distance(
+                    self.p1 + Point(t*seg_vector.x, t*seg_vector.y), o)
+            return distance
         raise NotImplementedError()
 
-    def _do_point_distance(self, pt):
-        """Calculates the distance between a point and a line segment."""
-
-        seg_vector = self.p2 - self.p1
-        pt_vector = pt - self.p1
-        t = seg_vector.dot(pt_vector)/self.length**2
-        if t >= 1:
-            distance = Point.distance(self.p2, pt)
-        elif t <= 0:
-            distance = Point.distance(self.p1, pt)
-        else:
-            distance = Point.distance(
-                self.p1 + Point(t*seg_vector.x, t*seg_vector.y), pt)
-        return distance
-
-    def __eq__(self, other):
-        """Is the other GeometryEntity equal to this Ray?"""
-        if not isinstance(other, Segment):
-            return False
-        return (self.p1 == other.p1) and (self.p2 == other.p2)
-
-    def __hash__(self):
-        return super(Segment, self).__hash__()
-
     def contains(self, other):
         """
         Is the other GeometryEntity contained within this Segment?
