@@ -1,23 +1,35 @@
+from __future__ import division
 import warnings
 
-from sympy import (Abs, C, Dummy, Rational, Float, S, Symbol, cos, oo, pi,
-                   simplify, sin, sqrt, symbols, tan)
+from sympy import (Abs, C, I, Dummy, Rational, Float, S, Symbol, cos, oo, pi,
+                   simplify, sin, sqrt, symbols, tan, Derivative, asin, acos)
 from sympy.geometry import (Circle, Curve, Ellipse, GeometryError, Line, Point,
                             Polygon, Ray, RegularPolygon, Segment, Triangle,
-                            are_similar, convex_hull, intersection, centroid)
+                            are_similar, convex_hull, intersection,
+                            Point3D, Line3D, Ray3D, Segment3D, Plane, centroid)
 from sympy.geometry.line import Undecidable
 from sympy.geometry.entity import rotate, scale, translate
 from sympy.geometry.polygon import _asa as asa, rad, deg
-from sympy.utilities.randtest import test_numerically
-from sympy.utilities.pytest import raises
+from sympy.geometry.util import idiff, are_coplanar
+from sympy.solvers.solvers import solve
+from sympy.utilities.iterables import cartes
+from sympy.utilities.randtest import verify_numerically
+from sympy.utilities.pytest import raises, slow
 
 x = Symbol('x', real=True)
 y = Symbol('y', real=True)
+z = Symbol('z', real=True)
 t = Symbol('t', real=True)
+k = Symbol('k', real=True)
 x1 = Symbol('x1', real=True)
 x2 = Symbol('x2', real=True)
+x3 = Symbol('x3', real=True)
 y1 = Symbol('y1', real=True)
 y2 = Symbol('y2', real=True)
+y3 = Symbol('y3', real=True)
+z1 = Symbol('z1', real=True)
+z2 = Symbol('z2', real=True)
+z3 = Symbol('z3', real=True)
 half = Rational(1, 2)
 
 
@@ -83,7 +95,11 @@ def test_point():
     assert (p2 - p1) == Point(y1 - x1, y2 - x2)
     assert p4*5 == Point(5, 5)
     assert -p2 == Point(-y1, -y2)
+    raises(ValueError, lambda: Point(3, I))
+    raises(ValueError, lambda: Point(2*I, I))
+    raises(ValueError, lambda: Point(3 + I, I))
 
+    assert Point(34.05, sqrt(3)) == Point(Rational(681, 20), sqrt(3))
     assert Point.midpoint(p3, p4) == Point(half, half)
     assert Point.midpoint(p1, p4) == Point(half + half*x1, half + half*x2)
     assert Point.midpoint(p2, p2) == p2
@@ -101,6 +117,9 @@ def test_point():
     assert Point.is_collinear(p3, p4, p1_1, p1_2)
     assert Point.is_collinear(p3, p4, p1_1, p1_3) is False
     assert Point.is_collinear(p3, p3, p4, p5) is False
+    line = Line(Point(1,0), slope = 1)
+    raises(TypeError, lambda: Point.is_collinear(line))
+    raises(TypeError, lambda: p1_1.is_collinear(line))
 
     assert p3.intersection(Point(0, 0)) == [p3]
     assert p3.intersection(p4) == []
@@ -148,8 +167,68 @@ def test_point():
     assert p.translate(y=1) == Point(1, 2)
     assert p.translate(*p.args) == Point(2, 2)
 
+def test_point3D():
+    p1 = Point3D(x1, x2, x3)
+    p2 = Point3D(y1, y2, y3)
+    p3 = Point3D(0, 0, 0)
+    p4 = Point3D(1, 1, 1)
+    p5 = Point3D(0, 1, 2)
 
-def test_line():
+    assert p1 in p1
+    assert p1 not in p2
+    assert p2.y == y2
+    assert (p3 + p4) == p4
+    assert (p2 - p1) == Point3D(y1 - x1, y2 - x2, y3 - x3)
+    assert p4*5 == Point3D(5, 5, 5)
+    assert -p2 == Point3D(-y1, -y2, -y3)
+
+    assert Point(34.05, sqrt(3)) == Point(Rational(681, 20), sqrt(3))
+    assert Point3D.midpoint(p3, p4) == Point3D(half, half, half)
+    assert Point3D.midpoint(p1, p4) == Point3D(half + half*x1, half + half*x2,
+                                         half + half*x3)
+    assert Point3D.midpoint(p2, p2) == p2
+    assert p2.midpoint(p2) == p2
+
+    assert Point3D.distance(p3, p4) == sqrt(3)
+    assert Point3D.distance(p1, p1) == 0
+    assert Point3D.distance(p3, p2) == sqrt(p2.x**2 + p2.y**2 + p2.z**2)
+
+    p1_1 = Point3D(x1, x1, x1)
+    p1_2 = Point3D(y2, y2, y2)
+    p1_3 = Point3D(x1 + 1, x1, x1)
+    assert Point3D.are_collinear(p3) is False
+    assert Point3D.are_collinear(p3, p4)
+    assert Point3D.are_collinear(p3, p4, p1_1, p1_2)
+    assert Point3D.are_collinear(p3, p4, p1_1, p1_3) is False
+    assert Point3D.are_collinear(p3, p3, p4, p5) is False
+
+    assert p3.intersection(Point3D(0, 0, 0)) == [p3]
+    assert p3.intersection(p4) == []
+
+
+    assert p4 * 5 == Point3D(5, 5, 5)
+    assert p4 / 5 == Point3D(0.2, 0.2, 0.2)
+
+    raises(ValueError, lambda: Point3D(0, 0, 0) + 10)
+
+    # Point differences should be simplified
+    assert Point3D(x*(x - 1), y, 2) - Point3D(x**2 - x, y + 1, 1) == \
+        Point3D(0, -1, 1)
+
+    a, b = Rational(1, 2), Rational(1, 3)
+    assert Point(a, b).evalf(2) == \
+        Point(a.n(2), b.n(2))
+    raises(ValueError, lambda: Point(1, 2) + 1)
+
+    # test transformations
+    p = Point3D(1, 1, 1)
+    assert p.scale(2, 3) == Point3D(2, 3, 1)
+    assert p.translate(1, 2) == Point3D(2, 3, 1)
+    assert p.translate(1) == Point3D(2, 1, 1)
+    assert p.translate(z=1) == Point3D(1, 1, 2)
+    assert p.translate(*p.args) == Point3D(2, 2, 2)
+
+def test_line_geom():
     p1 = Point(0, 0)
     p2 = Point(1, 1)
     p3 = Point(x1, x1)
@@ -174,8 +253,9 @@ def test_line():
     assert Line((1, 1), slope=oo) == Line((1, 1), (1, 2))
     assert Line((1, 1), slope=-oo) == Line((1, 1), (1, 2))
     raises(ValueError, lambda: Line((1, 1), 1))
-    assert Line(p1, p2) == Line(p2, p1)
-    assert l1 == l2
+    assert Line(p1, p2) == Line(p1, p2)
+    assert Line(p1, p2) != Line(p2, p1)
+    assert l1 != l2
     assert l1 != l3
     assert l1.slope == 1
     assert l1.length == oo
@@ -204,17 +284,16 @@ def test_line():
     # Orthogonality
     p1_1 = Point(-x1, x1)
     l1_1 = Line(p1, p1_1)
-    assert l1.perpendicular_line(p1) == l1_1
+    assert l1.perpendicular_line(p1) == Line(Point(0, 0), Point(1, -1))
     assert Line.is_perpendicular(l1, l1_1)
     assert Line.is_perpendicular(l1, l2) is False
     p = l1.random_point()
     assert l1.perpendicular_segment(p) == p
 
     # Parallelity
-    p2_1 = Point(-2*x1, 0)
     l2_1 = Line(p3, p5)
-    assert l2.parallel_line(p1_1) == Line(p2_1, p1_1)
-    assert l2_1.parallel_line(p1) == Line(p1, Point(0, 2))
+    assert l2.parallel_line(p1_1) == Line(Point(-x1, x1), Point(-y1, 2*x1 - y1))
+    assert l2_1.parallel_line(p1) == Line(Point(0, 0), Point(0, -1))
     assert Line.is_parallel(l1, l2)
     assert Line.is_parallel(l2, l3) is False
     assert Line.is_parallel(l2, l2.parallel_line(p1_1))
@@ -228,10 +307,10 @@ def test_line():
 
     # Concurrency
     l3_1 = Line(Point(5, x1), Point(-Rational(3, 5), x1))
-    assert Line.is_concurrent(l1) is False
-    assert Line.is_concurrent(l1, l3)
-    assert Line.is_concurrent(l1, l3, l3_1)
-    assert Line.is_concurrent(l1, l1_1, l3) is False
+    assert Line.are_concurrent(l1) is False
+    assert Line.are_concurrent(l1, l3)
+    assert Line.are_concurrent(l1, l3, l3_1)
+    assert Line.are_concurrent(l1, l1_1, l3) is False
 
     # Projection
     assert l2.projection(p4) == p4
@@ -260,6 +339,14 @@ def test_line():
     assert Ray((1, 1), angle=5) == Ray((1, 1), (2, 1 + C.tan(5)))
     raises(ValueError, lambda: Ray((1, 1), 1))
 
+    # issue 7963
+    r = Ray((0, 0), angle=x)
+    assert r.subs(x, 3*pi/4) == Ray((0, 0), (-1, 1))
+    assert r.subs(x, 5*pi/4) == Ray((0, 0), (-1, -1))
+    assert r.subs(x, -pi/4) == Ray((0, 0), (1, -1))
+    assert r.subs(x, pi/2) == Ray((0, 0), (0, 1))
+    assert r.subs(x, -pi/2) == Ray((0, 0), (0, -1))
+
     r1 = Ray(p1, Point(-1, 5))
     r2 = Ray(p1, Point(-1, 1))
     r3 = Ray(p3, p5)
@@ -267,20 +354,22 @@ def test_line():
     r5 = Ray(p2, p1)
     r6 = Ray(Point(0, 1), Point(1, 2))
     r7 = Ray(Point(0.5, 0.5), Point(1, 1))
-    assert l1.projection(r1) == Ray(p1, p2)
+    assert l1.projection(r1) == Ray(Point(0, 0), Point(2, 2))
     assert l1.projection(r2) == p1
     assert r3 != r1
     t = Symbol('t', real=True)
     assert Ray((1, 1), angle=pi/4).arbitrary_point() == \
         Point(t + 1, t + 1)
+    r8 = Ray(Point(0, 0), Point(0, 4))
+    r9 = Ray(Point(0, 1), Point(0, -1))
+    assert r8.intersection(r9) == [Segment(Point(0, 0), Point(0, 1))]
 
     s1 = Segment(p1, p2)
     s2 = Segment(p1, p1_1)
     assert s1.midpoint == Point(Rational(1, 2), Rational(1, 2))
     assert s2.length == sqrt( 2*(x1**2) )
-    assert s1.perpendicular_bisector() == Line(Point(0, 1), Point(1, 0))
     assert Segment((1, 1), (2, 3)).arbitrary_point() == Point(1 + t, 1 + 2*t)
-
+    assert s1.perpendicular_bisector() == Line(Point(1/2, 1/2), Point(3/2, -1/2))
     # intersections
     assert s1.intersection(Line(p6, p9)) == []
     s3 = Segment(Point(0.25, 0.25), Point(0.5, 0.5))
@@ -317,8 +406,54 @@ def test_line():
     pt1 = Point(0, 0)
     pt2 = Point(Rational(3)/2, Rational(3)/2)
     assert s1.distance(pt1) == 0
+    assert s1.distance((0, 0)) == 0
     assert s2.distance(pt1) == 2**(half)/2
     assert s2.distance(pt2) == 2**(half)
+    # Line to point
+    p1, p2 = Point(0, 0), Point(1, 1)
+    s = Line(p1, p2)
+    assert s.distance(Point(-1, 1)) == sqrt(2)
+    assert s.distance(Point(1, -1)) == sqrt(2)
+    assert s.distance(Point(2, 2)) == 0
+    assert s.distance((-1, 1)) == sqrt(2)
+    assert Line((0, 0), (0, 1)).distance(p1) == 0
+    assert Line((0, 0), (0, 1)).distance(p2) == 1
+    assert Line((0, 0), (1, 0)).distance(p1) == 0
+    assert Line((0, 0), (1, 0)).distance(p2) == 1
+    m = symbols('m')
+    l = Line((0, 5), slope=m)
+    p = Point(2, 3)
+    assert l.distance(p) == 2*abs(m + 1)/sqrt(m**2 + 1)
+    # Ray to point
+    r = Ray(p1, p2)
+    assert r.distance(Point(-1, -1)) == sqrt(2)
+    assert r.distance(Point(1, 1)) == 0
+    assert r.distance(Point(-1, 1)) == sqrt(2)
+    assert Ray((1, 1), (2, 2)).distance(Point(1.5, 3)) == 3*sqrt(2)/4
+    assert r.distance((1, 1)) == 0
+
+    #Line contains
+    p1, p2 = Point(0, 1), Point(3, 4)
+    l = Line(p1, p2)
+    assert l.contains(p1) is True
+    assert l.contains((0, 1)) is True
+    assert l.contains((0, 0)) is False
+
+    #Ray contains
+    p1, p2 = Point(0, 0), Point(4, 4)
+    r = Ray(p1, p2)
+    assert r.contains(p1) is True
+    assert r.contains((1, 1)) is True
+    assert r.contains((1, 3)) is False
+    s = Segment((1, 1), (2, 2))
+    assert r.contains(s) is True
+    s = Segment((1, 2), (2, 5))
+    assert r.contains(s) is False
+    r1 = Ray((2, 2), (3, 3))
+    assert r.contains(r1) is True
+    r1 = Ray((2, 2), (3, 5))
+    assert r.contains(r1) is False
+
 
     # Special cases of projection and intersection
     r1 = Ray(Point(1, 1), Point(2, 2))
@@ -371,9 +506,9 @@ def test_line():
     p10 = Point(2000, 2000)
     s1 = Segment(p1, p10)
     p_s1 = s1.random_point()
-    assert p1.x <= p_s1.x and p_s1.x <= p10.x and p1.y <= p_s1.y and p_s1.y <= p10.y
+    assert p1.x <= p_s1.x and p_s1.x <= p10.x and \
+        p1.y <= p_s1.y and p_s1.y <= p10.y
     s2 = Segment(p10, p1)
-
     assert hash(s1) == hash(s2)
     p11 = p10.scale(2, 2)
     assert s1.is_similar(Segment(p10, p11))
@@ -382,14 +517,304 @@ def test_line():
     assert Segment(p1, p2) in s1
     assert s1.plot_interval() == [t, 0, 1]
     assert s1 in Line(p1, p10)
-    assert Line(p1, p10) == Line(p10, p1)
+    assert Line(p1, p10) != Line(p10, p1)
     assert Line(p1, p10) != p1
     assert Line(p1, p10).plot_interval() == [t, -5, 5]
     assert Ray((0, 0), angle=pi/4).plot_interval() == \
         [t, 0, 10]
 
+def test_line3d():
+    p1 = Point3D(0, 0, 0)
+    p2 = Point3D(1, 1, 1)
+    p3 = Point3D(x1, x1, x1)
+    p4 = Point3D(y1, y1, y1)
+    p5 = Point3D(x1, 1 + x1, 1)
+    p6 = Point3D(1, 0, 1)
+    p7 = Point3D(0, 1, 1)
+    p8 = Point3D(2, 0, 3)
+    p9 = Point3D(2, 1, 4)
 
-def test_ellipse():
+    l1 = Line3D(p1, p2)
+    l2 = Line3D(p3, p4)
+    l3 = Line3D(p3, p5)
+    l4 = Line3D(p1, p6)
+    l5 = Line3D(p1, p7)
+    l6 = Line3D(p8, p9)
+    l7 = Line3D(p2, p9)
+    raises(ValueError, lambda: Line3D(Point3D(0, 0, 0), Point3D(0, 0, 0)))
+
+    assert Line3D((1, 1, 1), direction_ratio=[2, 3, 4]) == Line3D(Point3D(1, 1, 1), Point3D(3, 4, 5))
+    assert Line3D((1, 1, 1), direction_ratio=[1, 5, 7 ]) == Line3D(Point3D(1, 1, 1), Point3D(2, 6, 8))
+    assert Line3D((1, 1, 1), direction_ratio=[1, 2, 3]) == Line3D(Point3D(1, 1, 1), Point3D(2, 3, 4))
+    raises(TypeError, lambda: Line3D((1, 1), 1))
+    assert Line3D(p1, p2) != Line3D(p2, p1)
+    assert l1 != l2
+    assert l1 != l3
+    assert l1.direction_ratio == [1, 1, 1]
+    assert l1.length == oo
+    assert l1.equation() == (x, y, z, k)
+    assert l2.equation() == ((x - x1)/(-x1 + y1), (-x1 + y)/(-x1 + y1), (-x1 + z)/(-x1 + y1), k)
+    assert p1 in l1
+    assert p1 not in l3
+
+    # Orthogonality
+    p1_1 = Point3D(x1, x1, x1)
+    l1_1 = Line3D(p1, p1_1)
+    assert Line3D.is_perpendicular(l1, l2) is False
+    p = l1.arbitrary_point()
+    raises(NotImplementedError , lambda: l1.perpendicular_segment(p))
+
+    # Parallelity
+    assert l1.parallel_line(p1_1) == Line3D(Point3D(x1, x1, x1), Point3D(x1 + 1, x1 + 1, x1 + 1))
+
+    # Intersection
+    assert intersection(l1, p1) == [p1]
+    assert intersection(l1, p5) == []
+    assert intersection(l1, l1.parallel_line(p1)) == [Line3D(Point3D(0, 0, 0), Point3D(1, 1, 1))]
+
+    p = Ray3D(Point3D(1, 0, 0), Point3D(-1, 0, 0))
+    q = Ray3D(Point3D(0, 1, 0), Point3D(0, -1, 0))
+    assert intersection(p, q) == [Point3D(0, 0, 0)]
+
+    # Concurrency
+    assert Line3D.are_concurrent(l1) is False
+    assert Line3D.are_concurrent(l1, l2)
+    assert Line3D.are_concurrent(l1, l1_1, l3) is False
+
+    # Finding angles
+    l1_1 = Line3D(p1, Point3D(5, 0, 0))
+    assert Line3D.angle_between(l1, l1_1), acos(sqrt(3)/3)
+
+    # Testing Rays and Segments (very similar to Lines)
+    assert Ray3D((1, 1, 1), direction_ratio=[4, 4, 4]) == Ray3D(Point3D(1, 1, 1), Point3D(5, 5, 5))
+    assert Ray3D((1, 1, 1), direction_ratio=[1, 2, 3]) == Ray3D(Point3D(1, 1, 1), Point3D(2, 3, 4))
+    assert Ray3D((1, 1, 1), direction_ratio=[1, 1, 1]) == Ray3D(Point3D(1, 1, 1), Point3D(2, 2, 2))
+
+    r1 = Ray3D(p1, Point3D(-1, 5, 0))
+    r2 = Ray3D(p1, Point3D(-1, 1, 1))
+    r3 = Ray3D(p1, p2)
+    r4 = Ray3D(p2, p1)
+    r5 = Ray3D(Point3D(0, 1, 1), Point3D(1, 2, 0))
+    assert l1.projection(r1) == [Ray3D(Point3D(0, 0, 0), Point3D(4/3, 4/3, 4/3))]
+    assert l1.projection(r2) == [Ray3D(Point3D(0, 0, 0), Point3D(1/3, 1/3, 1/3))]
+    assert r3 != r1
+    t = Symbol('t', real=True)
+    assert Ray3D((1, 1, 1), direction_ratio=[1, 2, 3]).arbitrary_point() == \
+        Point3D(t + 1, 2*t + 1, 3*t + 1)
+    r6 = Ray3D(Point3D(0, 0, 0), Point3D(0, 4, 0))
+    r7 = Ray3D(Point3D(0, 1, 1), Point3D(0, -1, 1))
+    assert r6.intersection(r7) == []
+
+    s1 = Segment3D(p1, p2)
+    s2 = Segment3D(p3, p4)
+    assert s1.midpoint == Point3D(Rational(1, 2), Rational(1, 2), Rational(1, 2))
+    assert s2.length == sqrt(3)*sqrt((x1 - y1)**2)
+    assert Segment3D((1, 1, 1), (2, 3, 4)).arbitrary_point() == Point3D(t + 1, 2*t + 1, 3*t + 1)
+
+    # Segment contains
+    s = Segment3D((0, 1, 0), (0, 1, 0))
+    assert Point3D(0, 1, 0) in s
+    s = Segment3D((1, 0, 0), (1, 0, 0))
+    assert Point3D(1, 0, 0) in s
+
+    # Testing distance from a Segment to an object
+    s1 = Segment3D(Point3D(0, 0, 0), Point3D(1, 1, 1))
+    s2 = Segment3D(Point3D(1/2, 1/2, 1/2), Point3D(1, 0, 1))
+    pt1 = Point3D(0, 0, 0)
+    pt2 = Point3D(Rational(3)/2, Rational(3)/2, Rational(3)/2)
+    assert s1.distance(pt1) == 0
+    assert s2.distance(pt1) == sqrt(3)/2
+    assert s2.distance(pt2) == 2
+    assert s1.distance((0,0,0)) == 0
+    assert s2.distance((0,0,0)) == sqrt(3)/2
+    # Line to point
+    p1, p2 = Point3D(0, 0, 0), Point3D(1, 1, 1)
+    s = Line3D(p1, p2)
+    assert s.distance(Point3D(-1, 1, 1)) == 2*sqrt(6)/3
+    assert s.distance(Point3D(1, -1, 1)) == 2*sqrt(6)/3
+    assert s.distance(Point3D(2, 2, 2)) == 0
+    assert s.distance((2, 2, 2)) == 0
+    assert s.distance((1, -1, 1)) == 2*sqrt(6)/3
+    assert Line3D((0, 0, 0), (0, 1, 0)).distance(p1) == 0
+    assert Line3D((0, 0, 0), (0, 1, 0)).distance(p2) == sqrt(2)
+    assert Line3D((0, 0, 0), (1, 0, 0)).distance(p1) == 0
+    assert Line3D((0, 0, 0), (1, 0, 0)).distance(p2) == sqrt(2)
+    # Ray to point
+    r = Ray3D(p1, p2)
+    assert r.distance(Point3D(-1, -1, -1)) == sqrt(3)
+    assert r.distance(Point3D(1, 1, 1)) == 0
+    assert r.distance((-1, -1, -1)) == sqrt(3)
+    assert r.distance((1, 1, 1)) == 0
+    assert Ray3D((1, 1, 1), (2, 2, 2)).distance(Point3D(1.5, 3, 1)) == sqrt(17)/2
+
+
+    # Special cases of projection and intersection
+    r1 = Ray3D(Point3D(1, 1, 1), Point3D(2, 2, 2))
+    r2 = Ray3D(Point3D(2, 2, 2), Point3D(0, 0, 0))
+    r3 = Ray3D(Point3D(1, 1, 1), Point3D(-1, -1, -1))
+    r4 = Ray3D(Point3D(0, 4, 2), Point3D(-1, -5, -1))
+    r5 = Ray3D(Point3D(2, 2, 2), Point3D(3, 3, 3))
+    assert intersection(r1, r2) == [Segment3D(Point3D(1, 1, 1), Point3D(2, 2, 2))]
+    assert intersection(r1, r3) == [Point3D(1, 1, 1)]
+
+    r5 = Ray3D(Point3D(0, 0, 0), Point3D(1, 1, 1))
+    r6 = Ray3D(Point3D(0, 0, 0), Point3D(2, 2, 2))
+    assert r5 in r6
+    assert r6 in r5
+
+    s1 = Segment3D(Point3D(0, 0, 0), Point3D(2, 2, 2))
+    s2 = Segment3D(Point3D(-1, 5, 2), Point3D(-5, -10, 0))
+    assert intersection(r1, s1) == [Segment3D(Point3D(1, 1, 1), Point3D(2, 2, 2))]
+
+    l1 = Line3D(Point3D(0, 0, 0), Point3D(3, 4, 0))
+    r1 = Ray3D(Point3D(0, 0, 0), Point3D(3, 4, 0))
+    s1 = Segment3D(Point3D(0, 0, 0), Point3D(3, 4, 0))
+    assert intersection(l1, r1) == [r1]
+    assert intersection(l1, s1) == [s1]
+    assert intersection(r1, l1) == [r1]
+    assert intersection(s1, r1) == [s1]
+
+def test_plane():
+    p1 = Point3D(0, 0, 0)
+    p2 = Point3D(1, 1, 1)
+    p3 = Point3D(1, 2, 3)
+    p4 = Point3D(x, x, x)
+    p5 = Point3D(y, y, y)
+
+    raises(NotImplementedError, lambda: Plane(p1, p2, p4))
+    raises(NotImplementedError, lambda: Plane(p1, p2, p5))
+    raises(ValueError, lambda: Plane(p1, p2))
+    pl3 = Plane(p1, p2, p3)
+    pl4 = Plane(p1, normal_vector=(1, 1, 1))
+    pl5 = Plane(p3, normal_vector=(1, 2, 3))
+    pl6 = Plane(Point3D(2, 3, 7), normal_vector=(2, 2, 2))
+    pl7 = Plane(Point3D(1, -5, -6), normal_vector=(1, -2, 1))
+
+    l1 = Line3D(Point3D(5, 0, 0), Point3D(1, -1, 1))
+    l2 = Line3D(Point3D(0, -2, 0), Point3D(3, 1, 1))
+    l3 = Line3D(Point3D(0, -1, 0), Point3D(5, -1, 9))
+
+    assert Plane(p1, p2, p3) != Plane(p1, p3, p2)
+    assert Plane(p1, p2, p3).is_coplanar(Plane(p1, p3, p2))
+    assert pl3 == Plane(Point3D(0, 0, 0), normal_vector=(1, -2, 1))
+    assert pl3 != pl4
+    assert pl5 == Plane(Point3D(1, 2, 3), normal_vector=(1, 2, 3))
+
+    assert pl5.equation(x, y, z) == x + 2*y + 3*z - 14
+    assert pl3.equation(x, y, z) == x - 2*y + z
+
+    assert pl3.p1 == p1
+    assert pl4.p1 == p1
+    assert pl5.p1 == p3
+
+    assert pl4.normal_vector == (1, 1, 1)
+    assert pl5.normal_vector == (1, 2, 3)
+
+    assert p1 in pl3
+    assert p1 in pl4
+    assert p3 in pl5
+
+    assert pl3.projection(Point(0, 0)) == p1
+    p = pl3.projection(Point3D(1, 1, 0))
+    assert p == Point3D(7/6, 2/3, 1/6)
+    assert p in pl3
+
+    l = pl3.projection_line(Line(Point(0, 0), Point(1, 1)))
+    assert l == Line3D(Point3D(0, 0, 0), Point3D(7/6, 2/3, 1/6))
+    assert l in pl3
+    # get a segment that does not intersect the plane which is also
+    # parallel to pl3's normal veector
+    t = Dummy()
+    r = pl3.random_point()
+    a = pl3.perpendicular_line(r).arbitrary_point(t)
+    s = Segment3D(a.subs(t, 1), a.subs(t, 2))
+    assert s.p1 not in pl3 and s.p2 not in pl3
+    assert pl3.projection_line(s).equals(r)
+    assert pl3.projection_line(Segment(Point(1, 0), Point(1, 1))) == \
+               Segment3D(Point3D(5/6, 1/3, -1/6), Point3D(7/6, 2/3, 1/6))
+    assert pl6.projection_line(Ray(Point(1, 0), Point(1, 1))) == \
+               Ray3D(Point3D(14/3, 11/3, 11/3), Point3D(13/3, 13/3, 10/3))
+
+
+    assert pl3.is_parallel(pl6) is False
+    assert pl4.is_parallel(pl6)
+    assert pl6.is_parallel(l1) is False
+
+    assert pl3.is_perpendicular(pl6)
+    assert pl4.is_perpendicular(pl7)
+    assert pl6.is_perpendicular(pl7)
+    assert pl6.is_perpendicular(l1) is False
+
+    assert pl7.distance(Point3D(1, 3, 5)) == 5*sqrt(6)/6
+    assert pl6.distance(Point3D(0, 0, 0)) == 4*sqrt(3)
+    assert pl6.distance(pl6.p1) == 0
+    assert pl7.distance(pl6) == 0
+    assert pl7.distance(l1) == 0
+    assert pl6.distance(Segment3D(Point3D(2, 3, 1), Point3D(1, 3, 4))) == 0
+    pl6.distance(Plane(Point3D(5, 5, 5), normal_vector=(8, 8, 8))) == sqrt(3)
+
+    assert pl6.angle_between(pl3) == pi/2
+    assert pl6.angle_between(pl6) == 0
+    assert pl6.angle_between(pl4) == 0
+    assert pl7.angle_between(Line3D(Point3D(2, 3, 5), Point3D(2, 4, 6))) == -asin(sqrt(3)/6)
+    assert pl6.angle_between(Ray3D(Point3D(2, 4, 1), Point3D(6, 5, 3))) == asin(sqrt(7)/3)
+    assert pl7.angle_between(Segment3D(Point3D(5, 6, 1), Point3D(1, 2, 4))) == -asin(7*sqrt(246)/246)
+
+    assert are_coplanar(l1, l2, l3) is False
+    assert are_coplanar(l1) is False
+    assert are_coplanar(Point3D(2, 7, 2), Point3D(0, 0, 2), Point3D(1, 1, 2), Point3D(1, 2, 2))
+    assert are_coplanar(Plane(p1, p2, p3), Plane(p1, p3, p2))
+    assert Plane.are_concurrent(pl3, pl4, pl5) is False
+    assert Plane.are_concurrent(pl6) is False
+
+    assert pl3.parallel_plane(Point3D(1, 2, 5)) == Plane(Point3D(1, 2, 5), \
+                                                      normal_vector=(1, -2, 1))
+
+    # perpendicular_plane
+    p = Plane((0, 0, 0), (1, 0, 0))
+    # default
+    assert p.perpendicular_plane() == Plane(Point3D(0, 0, 0), (0, 1, 0))
+    # 1 pt
+    assert p.perpendicular_plane(Point3D(1, 0, 1)) == Plane(Point3D(1, 0, 1), (0, 1, 0))
+    # pts as tuples
+    assert p.perpendicular_plane((1, 0, 1), (1, 1, 1)) == Plane(Point3D(1, 0, 1), (0, 0, -1))
+
+    a, b = Point3D(0, 0, 0), Point3D(0, 1, 0)
+    Z = (0, 0, 1)
+    p = Plane(a, normal_vector=Z)
+    # case 4
+    assert p.perpendicular_plane(a, b) == Plane(a, (1, 0, 0))
+    n = Point3D(*Z)
+    # case 1
+    assert p.perpendicular_plane(a, n) == Plane(a, (-1, 0, 0))
+    # case 2
+    assert Plane(a, normal_vector=b.args).perpendicular_plane(a, a + b) == Plane(Point3D(0, 0, 0), (1, 0, 0))
+    # case 1&3
+    assert Plane(b, normal_vector=Z).perpendicular_plane(b, b + n) == Plane(Point3D(0, 1, 0), (-1, 0, 0))
+    # case 2&3
+    assert Plane(b, normal_vector=b.args).perpendicular_plane(n, n + b) == Plane(Point3D(0, 0, 1), (1, 0, 0))
+
+    assert pl6.intersection(pl6) == [pl6]
+    assert pl4.intersection(pl4.p1) == [pl4.p1]
+    assert pl3.intersection(pl6) == [
+        Line3D(Point3D(8, 4, 0), Point3D(2, 4, 6))]
+    assert pl3.intersection(Line3D(Point3D(1,2,4), Point3D(4,4,2))) == [
+        Point3D(2, 8/3, 10/3)]
+    assert pl3.intersection(Plane(Point3D(6, 0, 0), normal_vector=(2, -5, 3))) == [
+        Line3D(Point3D(-24, -12, 0), Point3D(-25, -13, -1))]
+    assert pl6.intersection(Ray3D(Point3D(2, 3, 1), Point3D(1, 3, 4))) == [
+        Point3D(-1, 3, 10)]
+    assert pl6.intersection(Segment3D(Point3D(2, 3, 1), Point3D(1, 3, 4))) == [
+        Point3D(-1, 3, 10)]
+    assert pl7.intersection(Line(Point(2, 3), Point(4, 2))) == [
+        Point3D(13/2, 3/4, 0)]
+    r = Ray(Point(2, 3), Point(4, 2))
+    assert Plane((1,2,0), normal_vector=(0,0,1)).intersection(r) == [
+        Ray3D(Point(2, 3), Point(4, 2))]
+
+    assert pl3.random_point() in pl3
+
+def test_ellipse_geom():
     p1 = Point(0, 0)
     p2 = Point(1, 1)
     p4 = Point(0, 1)
@@ -469,9 +894,9 @@ def test_ellipse():
     p1_2 = p2 + Point(half, 0)
     p1_3 = p2 + Point(0, 1)
     assert e1.tangent_lines(p4) == c1.tangent_lines(p4)
-    assert e2.tangent_lines(p1_2) == [Line(p1_2, p2 + Point(half, 1))]
-    assert e2.tangent_lines(p1_3) == [Line(p1_3, p2 + Point(half, 1))]
-    assert c1.tangent_lines(p1_1) == [Line(p1_1, Point(0, sqrt(2)))]
+    assert e2.tangent_lines(p1_2) == [Line(Point(3/2, 1), Point(3/2, 1/2))]
+    assert e2.tangent_lines(p1_3) == [Line(Point(1, 2), Point(5/4, 2))]
+    assert c1.tangent_lines(p1_1) != [Line(p1_1, Point(0, sqrt(2)))]
     assert c1.tangent_lines(p1) == []
     assert e2.is_tangent(Line(p1_2, p2 + Point(half, 1)))
     assert e2.is_tangent(Line(p1_3, p2 + Point(half, 1)))
@@ -483,18 +908,41 @@ def test_ellipse():
         Polygon(Point(1, 1), Point(1, -1), Point(2, 0))) is True
     assert c1.is_tangent(
         Polygon(Point(1, 1), Point(1, 0), Point(2, 0))) is False
+    assert Circle(Point(5, 5), 3).is_tangent(Circle(Point(0, 5), 1)) is False
 
     assert Ellipse(Point(5, 5), 2, 1).tangent_lines(Point(0, 0)) == \
-        [Line(Point(0, 0), Point(S(77)/25, S(132)/25)),
-     Line(Point(0, 0), Point(S(33)/5, S(22)/5))]
+        [Line(Point(0, 0), Point(77/25, 132/25)),
+     Line(Point(0, 0), Point(33/5, 22/5))]
     assert Ellipse(Point(5, 5), 2, 1).tangent_lines(Point(3, 4)) == \
-        [Line(Point(3, 4), Point(3, 5)), Line(Point(3, 4), Point(5, 4))]
+        [Line(Point(3, 4), Point(4, 4)), Line(Point(3, 4), Point(3, 5))]
     assert Circle(Point(5, 5), 2).tangent_lines(Point(3, 3)) == \
-        [Line(Point(3, 3), Point(3, 5)), Line(Point(3, 3), Point(5, 3))]
+        [Line(Point(3, 3), Point(4, 3)), Line(Point(3, 3), Point(3, 4))]
     assert Circle(Point(5, 5), 2).tangent_lines(Point(5 - 2*sqrt(2), 5)) == \
         [Line(Point(5 - 2*sqrt(2), 5), Point(5 - sqrt(2), 5 - sqrt(2))),
      Line(Point(5 - 2*sqrt(2), 5), Point(5 - sqrt(2), 5 + sqrt(2))), ]
 
+    e = Ellipse(Point(0, 0), 2, 1)
+    assert e.normal_lines(Point(0, 0)) == \
+        [Line(Point(0, 0), Point(0, 1)), Line(Point(0, 0), Point(1, 0))]
+    assert e.normal_lines(Point(1, 0)) == \
+        [Line(Point(0, 0), Point(1, 0))]
+    assert e.normal_lines((0, 1)) == \
+        [Line(Point(0, 0), Point(0, 1))]
+    assert e.normal_lines(Point(1, 1), 1) == \
+        [Line(Point(-2, -1/5), Point(-1, 1/5)),
+         Line(Point(1, -9/10), Point(2, -43/11))]
+    # test the failure of Poly.intervals and checks a point on the boundary
+    p = Point(sqrt(3), S.Half)
+    assert p in e
+    assert e.normal_lines(p, 1) == \
+        [Line(Point(7/4, 1/2), Point(11/4, 3/2)),
+        Line(Point(-2, -26/337), Point(-1, 1/8))]
+    # be sure to use the slope that isn't undefined on boundary
+    e = Ellipse((0, 0), 2, 2*sqrt(3)/3)
+    assert e.normal_lines((1, 1), 1) == \
+        [Line(Point(-2, -1/3), Point(-1, 1/6)),
+        Line(Point(1, -1), Point(2, -4))]
+
     # Properties
     major = 3
     minor = 1
@@ -566,13 +1014,13 @@ def test_ellipse():
 
     e1 = Ellipse(Point(0, 0), 5, 10)
     e2 = Ellipse(Point(2, 1), 4, 8)
-    a = S(53)/17
+    a = 53/17
     c = 2*sqrt(3991)/17
     ans = [Point(a - c/8, a/2 + c), Point(a + c/8, a/2 - c)]
     assert e1.intersection(e2) == ans
     e2 = Ellipse(Point(x, y), 4, 8)
     c = sqrt(3991)
-    ans = [Point(c/68 + a, -2*c/17 + a/2), Point(-c/68 + a, 2*c/17 + a/2)]
+    ans = [Point(-c/68 + a, 2*c/17 + a/2), Point(c/68 + a, -2*c/17 + a/2)]
     assert [p.subs({x: 2, y:1}) for p in e1.intersection(e2)] == ans
 
     # Combinations of above
@@ -581,7 +1029,7 @@ def test_ellipse():
     e = Ellipse((1, 2), 3, 2)
     assert e.tangent_lines(Point(10, 0)) == \
         [Line(Point(10, 0), Point(1, 0)),
-        Line(Point(10, 0), Point(S(14)/5, S(18)/5))]
+        Line(Point(10, 0), Point(14/5, 18/5))]
 
     # encloses_point
     e = Ellipse((0, 0), 1, 2)
@@ -603,9 +1051,9 @@ def test_ellipse():
 
     assert e.scale(2, 3) == Ellipse((0, 0), 4, 3)
     assert e.scale(3, 6) == Ellipse((0, 0), 6, 6)
-    assert e.rotate(pi/3) == e
-    assert e.rotate(pi/3, (1, 2)) == \
-        Ellipse(Point(S(1)/2 + sqrt(3), -sqrt(3)/2 + 1), 2, 1)
+    assert e.rotate(pi) == e
+    assert e.rotate(pi, (1, 2)) == Ellipse(Point(2, 4), 2, 1)
+    raises(NotImplementedError, lambda: e.rotate(pi/3))
 
     # transformations
     c = Circle((1, 1), 2)
@@ -624,10 +1072,22 @@ def test_ellipse_random_point():
 
 
 def test_polygon():
-    t = Triangle(Point(0, 0), Point(2, 0), Point(3, 3))
-    assert Polygon(Point(0, 0), Point(1, 0), Point(2, 0), Point(3, 3)) == t
-    assert Polygon(Point(1, 0), Point(2, 0), Point(3, 3), Point(0, 0)) == t
-    assert Polygon(Point(2, 0), Point(3, 3), Point(0, 0), Point(1, 0)) == t
+    a, b, c = Point(0, 0), Point(2, 0), Point(3, 3)
+    t = Triangle(a, b, c)
+    assert Polygon(a, Point(1, 0), b, c) == t
+    assert Polygon(Point(1, 0), b, c, a) == t
+    assert Polygon(b, c, a, Point(1, 0)) == t
+    # 2 "remove folded" tests
+    assert Polygon(a, Point(3, 0), b, c) == t
+    assert Polygon(a, b, Point(3, -1), b, c) == t
+    raises(GeometryError, lambda: Polygon((0, 0), (1, 0), (0, 1), (1, 1)))
+    # remove multiple collinear points
+    assert Polygon(Point(-4, 15), Point(-11, 15), Point(-15, 15),
+        Point(-15, 33/5), Point(-15, -87/10), Point(-15, -15),
+        Point(-42/5, -15), Point(-2, -15), Point(7, -15), Point(15, -15),
+        Point(15, -3), Point(15, 10), Point(15, 15)) == \
+        Polygon(Point(-15,-15), Point(15,-15), Point(15,15), Point(-15,15))
+
 
     p1 = Polygon(
         Point(0, 0), Point(3, -1),
@@ -646,7 +1106,10 @@ def test_polygon():
     p5 = Polygon(
         Point(0, 0), Point(4, 4),
         Point(0, 4))
-
+    p6 = Polygon(
+        Point(-11, 1), Point(-9, 6.6),
+        Point(-4, -3), Point(-8.4, -8.7))
+    r = Ray(Point(-9,6.6), Point(-9,5.5))
     #
     # General polygon
     #
@@ -674,7 +1137,9 @@ def test_polygon():
     warnings.filterwarnings(
         "error", message="Polygons may intersect producing erroneous output")
     raises(UserWarning,
-           lambda: Polygon(Point(0, 0), Point(1, 0), Point(1, 1)).distance(Polygon(Point(0, 0), Point(0, 1), Point(1, 1))))
+           lambda: Polygon(Point(0, 0), Point(1, 0),
+           Point(1, 1)).distance(
+           Polygon(Point(0, 0), Point(0, 1), Point(1, 1))))
     warnings.filterwarnings(
         "ignore", message="Polygons may intersect producing erroneous output")
     assert hash(p5) == hash(Polygon(Point(0, 0), Point(4, 4), Point(0, 4)))
@@ -686,7 +1151,7 @@ def test_polygon():
         Point(0, 0)
     raises(ValueError, lambda: Polygon(
         Point(x, 0), Point(0, y), Point(x, y)).arbitrary_point('x'))
-
+    assert p6.intersection(r) == [Point(-9, 33/5), Point(-9, -84/13)]
     #
     # Regular polygon
     #
@@ -732,7 +1197,7 @@ def test_polygon():
     assert p1 == p1_old
 
     assert p1.area == (-250*sqrt(5) + 1250)/(4*tan(pi/5))
-    assert p1.length == 20*sqrt(-sqrt(5)/8 + S(5)/8)
+    assert p1.length == 20*sqrt(-sqrt(5)/8 + 5/8)
     assert p1.scale(2, 2) == \
         RegularPolygon(p1.center, p1.radius*2, p1._n, p1.rotation)
     assert RegularPolygon((0, 0), 1, 4).scale(2, 3) == \
@@ -932,7 +1397,7 @@ def test_encloses():
     # square with a dimpled left side
     s = Polygon(Point(0, 0), Point(1, 0), Point(1, 1), Point(0, 1),
         Point(S.Half, S.Half))
-    # the following will be True if the polygon isn't treated as closing on itself
+    # the following is True if the polygon isn't treated as closing on itself
     assert s.encloses(Point(0, S.Half)) is False
     assert s.encloses(Point(S.Half, S.Half)) is False  # it's a vertex
     assert s.encloses(Point(Rational(3, 4), S.Half)) is True
@@ -966,7 +1431,7 @@ def test_util_centroid():
     assert centroid(p, q) == Point(20, 40)/3
     p = Segment((0, 0), (2, 0))
     q = Segment((0, 0), (2, 2))
-    assert centroid(p, q) == Point(1, 2*sqrt(2)/(2 + 2*sqrt(2)))
+    assert centroid(p, q) == Point(1, -sqrt(2) + 2)
     assert centroid(Point(0, 0), Point(2, 0)) == Point(2, 0)/2
     assert centroid(Point(0, 0), Point(0, 0), Point(2, 0)) == Point(2, 0)/3
 
@@ -1026,9 +1491,9 @@ def test_triangle_kwargs():
 def test_geometry_transforms():
     from sympy import Tuple
     c = Curve((x, x**2), (x, 0, 1))
-    pts = [Point(0, 0), Point(S(1)/2, S(1)/4), Point(1, 1)]
+    pts = [Point(0, 0), Point(1/2, 1/4), Point(1, 1)]
     cout = Curve((2*x - 4, 3*x**2 - 10), (x, 0, 1))
-    pts_out = [Point(-4, -10), Point(-3, -S(37)/4), Point(-2, -7)]
+    pts_out = [Point(-4, -10), Point(-3, -37/4), Point(-2, -7)]
     assert c.scale(2, 3, (4, 5)) == cout
     assert [c.subs(x, xi/2) for xi in Tuple(0, 1, 2)] == pts
     assert [cout.subs(x, xi/2) for xi in Tuple(0, 1, 2)] == pts_out
@@ -1042,10 +1507,10 @@ def test_geometry_transforms():
         Ellipse(Point(-8, -10), 6, 9)
     assert Circle((0, 0), 2).scale(3, 3, (4, 5)) == \
         Circle(Point(-8, -10), 6)
-    assert Circle(Point(-8, -10), 6).scale(S(1)/3, S(1)/3, (4, 5)) == \
+    assert Circle(Point(-8, -10), 6).scale(1/3, 1/3, (4, 5)) == \
         Circle((0, 0), 2)
     assert Curve((x + y, 3*x), (x, 0, 1)).subs(y, S.Half) == \
-        Curve((x + S(1)/2, 3*x), (x, 0, 1))
+        Curve((x + 1/2, 3*x), (x, 0, 1))
     assert Curve((x, 3*x), (x, 0, 1)).translate(4, 5) == \
         Curve((x + 4, 3*x + 5), (x, 0, 1))
     assert Circle((0, 0), 2).translate(4, 5) == \
@@ -1061,6 +1526,7 @@ def test_geometry_transforms():
     assert RegularPolygon((0, 0), 1, 4).scale(2, 3, (4, 5)) == \
         Polygon(Point(-2, -10), Point(-4, -7), Point(-6, -10), Point(-4, -13))
 
+
 def test_reflect():
     b = Symbol('b')
     m = Symbol('m')
@@ -1069,13 +1535,13 @@ def test_reflect():
     r = p.reflect(l)
     dp = l.perpendicular_segment(p).length
     dr = l.perpendicular_segment(r).length
-    assert test_numerically(dp, dr)
+    assert verify_numerically(dp, dr)
     t = Triangle((0, 0), (1, 0), (2, 3))
     assert t.area == -t.reflect(l).area
     e = Ellipse((1, 0), 1, 2)
     assert e.area == -e.reflect(Line((1, 0), slope=0)).area
     assert e.area == -e.reflect(Line((1, 0), slope=oo)).area
-    raises(NotImplementedError, lambda: e.reflect(Line((1,0), slope=m)))
+    raises(NotImplementedError, lambda: e.reflect(Line((1, 0), slope=m)))
     assert Polygon((1, 0), (2, 0), (2, 2)).reflect(Line((3, 0), slope=oo)) \
         == Triangle(Point(5, 0), Point(4, 0), Point(4, 2))
     assert Polygon((1, 0), (2, 0), (2, 2)).reflect(Line((0, 3), slope=oo)) \
@@ -1100,3 +1566,42 @@ def test_reflect():
         'Point(-2.41, 3.73), Point(-1.74, 2.76), '
         'Point(-0.616, 3.10)]')
     assert pent.area.equals(-rpent.area)
+
+
+def test_idiff():
+    # the use of idiff in ellipse also provides coverage
+    circ = x**2 + y**2 - 4
+    ans = -3*x*(x**2 + y**2)/y**5
+    assert ans == idiff(circ, y, x, 3).simplify()
+    assert ans == idiff(circ, [y], x, 3).simplify()
+    assert idiff(circ, y, x, 3).simplify() == ans
+    explicit  = 12*x/sqrt(-x**2 + 4)**5
+    assert ans.subs(y, solve(circ, y)[0]).simplify() == \
+        explicit
+    assert explicit in [sol.diff(x, 3).simplify() for sol in solve(circ, y)]
+    assert idiff(x + t + y, [y, t], x) == -Derivative(t, x) - 1
+
+
+def test_issue_2941():
+    def _check():
+        for f, g in cartes(*[(Line, Ray, Segment)]*2):
+          l1 = f(a, b)
+          l2 = g(c, d)
+          assert l1.intersection(l2) == l2.intersection(l1)
+    # intersect at end point
+    c, d = (-2, -2), (-2, 0)
+    a, b = (0, 0), (1, 1)
+    _check()
+    # midline intersection
+    c, d = (-2, -3), (-2, 0)
+    a, b = (0, 0), (1, 1)
+    _check()
+
+
+@slow
+def test_symbolic_intersect():
+    # Issue 7814.
+    circle = Circle(Point(x, 0), y)
+    line = Line(Point(k, z), slope=0)
+    assert line.intersection(circle) == [
+        Point(x - sqrt(y**2 - z**2), z), Point(x + sqrt(y**2 - z**2), z)]
