@@ -9,8 +9,8 @@
     >>> integrate(sin(x),x)
     -cos(x)
 """
-from integrals import integrate, Integral, line_integrate
-from transforms import (mellin_transform, inverse_mellin_transform,
+from .integrals import integrate, Integral, line_integrate
+from .transforms import (mellin_transform, inverse_mellin_transform,
                         MellinTransform, InverseMellinTransform,
                         laplace_transform, inverse_laplace_transform,
                         LaplaceTransform, InverseLaplaceTransform,
