@@ -1,4 +1,5 @@
-from sympy.core import Set, Dict, Tuple, Rational
+from sympy.core import Dict, Tuple, Rational
+from sympy.sets import Set
 from .cartan_type import Standard_Cartan
 from sympy.matrices import Matrix
 
