@@ -1,6 +1,6 @@
 from __future__ import print_function, division
 
-from sympy import Basic, Expr, S, Q
+from sympy import Basic, Expr, S, Q, sympify
 from .matexpr import ShapeError
 
 
@@ -19,6 +19,7 @@ class Determinant(Expr):
     """
 
     def __new__(cls, mat):
+        mat = sympify(mat)
         if not mat.is_Matrix:
             raise TypeError("Input to Determinant, %s, not a matrix" % str(mat))
 
@@ -50,3 +51,30 @@ def det(matexpr):
     """
 
     return Determinant(matexpr).doit()
+
+
+from sympy.assumptions.ask import ask, Q
+from sympy.assumptions.refine import handlers_dict
+
+
+def refine_Determinant(expr, assumptions):
+    """
+    >>> from sympy import MatrixSymbol, Q, assuming, refine, det
+    >>> X = MatrixSymbol('X', 2, 2)
+    >>> det(X)
+    Determinant(X)
+    >>> with assuming(Q.orthogonal(X)):
+    ...     print(refine(det(X)))
+    1
+    """
+    if ask(Q.orthogonal(expr.arg), assumptions):
+        return S.One
+    elif ask(Q.singular(expr.arg), assumptions):
+        return S.Zero
+    elif ask(Q.unit_triangular(expr.arg), assumptions):
+        return S.One
+
+    return expr
+
+
+handlers_dict['Determinant'] = refine_Determinant
