@@ -1,5 +1,8 @@
 from __future__ import print_function, division
 
+from functools import reduce
+from operator import mul
+
 from sympy.core import Mul, Basic, sympify, Add
 from sympy.functions import transpose, adjoint
 from sympy.matrices.expressions.transpose import transpose
@@ -7,6 +10,8 @@ from sympy.strategies import (rm_id, unpack, typed, debug, flatten, exhaust,
         do_one, new)
 from sympy.matrices.expressions.matexpr import (MatrixExpr, ShapeError,
         Identity, ZeroMatrix)
+from sympy.utilities import sift
+from sympy.matrices.matrices import MatrixBase
 
 
 class MatMul(MatrixExpr):
@@ -47,8 +52,8 @@ class MatMul(MatrixExpr):
             return coeff * matrices[0][i, j]
 
         head, tail = matrices[0], matrices[1:]
-        assert len(tail) != 0
-
+        if len(tail) == 0:
+            raise ValueError("lenth of tail cannot be 0")
         X = head
         Y = MatMul(*tail)
 
@@ -131,6 +136,48 @@ def any_zeros(mul):
         return ZeroMatrix(matrices[0].rows, matrices[-1].cols)
     return mul
 
+def merge_explicit(matmul):
+    """ Merge explicit MatrixBase arguments
+
+    >>> from sympy import MatrixSymbol, eye, Matrix, MatMul, pprint
+    >>> from sympy.matrices.expressions.matmul import merge_explicit
+    >>> A = MatrixSymbol('A', 2, 2)
+    >>> B = Matrix([[1, 1], [1, 1]])
+    >>> C = Matrix([[1, 2], [3, 4]])
+    >>> X = MatMul(A, B, C)
+    >>> pprint(X)
+    A*[1  1]*[1  2]
+      [    ] [    ]
+      [1  1] [3  4]
+    >>> pprint(merge_explicit(X))
+    A*[4  6]
+      [    ]
+      [4  6]
+
+    >>> X = MatMul(B, A, C)
+    >>> pprint(X)
+    [1  1]*A*[1  2]
+    [    ]   [    ]
+    [1  1]   [3  4]
+    >>> pprint(merge_explicit(X))
+    [1  1]*A*[1  2]
+    [    ]   [    ]
+    [1  1]   [3  4]
+    """
+    if not any(isinstance(arg, MatrixBase) for arg in matmul.args):
+        return matmul
+    newargs = []
+    last = matmul.args[0]
+    for arg in matmul.args[1:]:
+        if isinstance(arg, MatrixBase) and isinstance(last, MatrixBase):
+            last = last * arg
+        else:
+            newargs.append(last)
+            last = arg
+    newargs.append(last)
+
+    return MatMul(*newargs)
+
 def xxinv(mul):
     """ Y * X * X.I -> Y """
     from sympy.matrices.expressions import Inverse
@@ -172,13 +219,14 @@ def factor_in_front(mul):
     return mul
 
 rules = (any_zeros, remove_ids, xxinv, unpack, rm_id(lambda x: x == 1),
-         factor_in_front, flatten)
+         merge_explicit, factor_in_front, flatten)
 
 canonicalize = exhaust(typed({MatMul: do_one(*rules)}))
 
 def only_squares(*matrices):
     """ factor matrices only if they are square """
-    assert matrices[0].rows == matrices[-1].cols
+    if matrices[0].rows != matrices[-1].cols:
+        raise RuntimeError("Invalid matrices being multiplied")
     out = []
     start = 0
     for i, M in enumerate(matrices):
@@ -186,3 +234,36 @@ def only_squares(*matrices):
             out.append(MatMul(*matrices[start:i+1]).doit())
             start = i+1
     return out
+
+
+from sympy.assumptions.ask import ask, Q
+from sympy.assumptions.refine import handlers_dict
+
+
+def refine_MatMul(expr, assumptions):
+    """
+    >>> from sympy import MatrixSymbol, Q, assuming, refine
+    >>> X = MatrixSymbol('X', 2, 2)
+    >>> expr = X * X.T
+    >>> print(expr)
+    X*X'
+    >>> with assuming(Q.orthogonal(X)):
+    ...     print(refine(expr))
+    I
+    """
+    newargs = []
+    last = expr.args[0]
+    for arg in expr.args[1:]:
+        if arg == last.T and ask(Q.orthogonal(arg), assumptions):
+            last = Identity(arg.shape[0])
+        elif arg == last.conjugate() and ask(Q.unitary(arg), assumptions):
+            last = Identity(arg.shape[0])
+        else:
+            newargs.append(last)
+            last = arg
+    newargs.append(last)
+
+    return MatMul(*newargs)
+
+
+handlers_dict['MatMul'] = refine_MatMul
