@@ -2,6 +2,7 @@ from sympy.functions import adjoint, conjugate, transpose
 from sympy.matrices.expressions import MatrixSymbol, Adjoint, trace, Transpose
 from sympy.matrices import eye, Matrix
 from sympy import symbols, S, assuming, Q
+from sympy import refine, Q
 
 n, m, l, k, p = symbols('n m l k p', integer=True)
 A = MatrixSymbol('A', n, m)
@@ -33,3 +34,7 @@ def test_transpose():
     assert Transpose(Sq)[0, 1] == Sq[1, 0]
 
     assert Transpose(A*B).doit() == Transpose(B) * Transpose(A)
+
+
+def test_refine():
+    assert refine(C.T, Q.symmetric(C)) == C
