@@ -284,7 +284,7 @@ class TanhSinh(QuadratureRule):
 
     Various documents describing the algorithm are available online, e.g.:
 
-      * http://crd.lbl.gov/~dhbailey/dhbpapers/dhb-tanh-sinh.pdf
+      * http://crd-legacy.lbl.gov/~dhbailey/dhbpapers/dhb-tanh-sinh.pdf
       * http://users.cs.dal.ca/~jborwein/tanh-sinh.pdf
     """
 
@@ -453,7 +453,7 @@ class GaussLegendre(QuadratureRule):
         ctx.prec = orig
         return nodes
 
-class QuadratureMethods:
+class QuadratureMethods(object):
 
     def __init__(ctx, *args, **kwargs):
         ctx._gauss_legendre = GaussLegendre(ctx)
@@ -464,7 +464,7 @@ class QuadratureMethods:
         Computes a single, double or triple integral over a given
         1D interval, 2D rectangle, or 3D cuboid. A basic example::
 
-            >>> from mpmath import *
+            >>> from sympy.mpmath import *
             >>> mp.dps = 15; mp.pretty = True
             >>> quad(sin, [0, pi])
             2.0
@@ -840,7 +840,7 @@ class QuadratureMethods:
         specify the `n`-th zero by providing the *zeros* arguments.
         Below is an example of each::
 
-            >>> from mpmath import *
+            >>> from sympy.mpmath import *
             >>> mp.dps = 15; mp.pretty = True
             >>> f = lambda x: sin(3*x)/(x**2+1)
             >>> quadosc(f, [0,inf], omega=3)
