@@ -939,7 +939,7 @@ def secondzeta(ctx, s, a = 0.015, **kwargs):
 
     **Examples**
 
-        >>> from mpmath import *
+        >>> from sympy.mpmath import *
         >>> mp.pretty = True; mp.dps = 15
         >>> secondzeta(2)
         0.023104993115419
@@ -1079,7 +1079,7 @@ def lerchphi(ctx, z, s, a):
 
     Several evaluations in terms of simpler functions::
 
-        >>> from mpmath import *
+        >>> from sympy.mpmath import *
         >>> mp.dps = 25; mp.pretty = True
         >>> lerchphi(-1,2,0.5); 4*catalan
         3.663862376708876060218414
