@@ -1,5 +1,3 @@
-from __future__ import with_statement
-
 import os
 import tempfile
 import pickle
@@ -9,12 +7,13 @@ from sympy.mpmath import *
 def pickler(obj):
     fn = tempfile.mktemp()
 
-    with open(fn, 'wb') as f:
-        pickle.dump(obj, f)
-
-    with open(fn, 'rb') as f:
-        obj2 = pickle.load(f)
+    f = open(fn, 'wb')
+    pickle.dump(obj, f)
+    f.close()
 
+    f = open(fn, 'rb')
+    obj2 = pickle.load(f)
+    f.close()
     os.remove(fn)
 
     return obj2
