@@ -1,11 +1,12 @@
-from sympy.core import Symbol, Float, Rational, Integer, I, Mul, Pow
+from sympy.core import Symbol, Function, Float, Rational, Integer, I, Mul, Pow
 from sympy.functions import exp, factorial, sin
 from sympy.logic import And
 from sympy.series import Limit
 from sympy.utilities.pytest import raises
 
 from sympy.parsing.sympy_parser import (
-    parse_expr, standard_transformations, rationalize, TokenError
+    parse_expr, standard_transformations, rationalize, TokenError,
+    split_symbols, implicit_multiplication,
 )
 
 
@@ -54,6 +55,7 @@ def test_factorial_fail():
         except TokenError:
             assert True
 
+
 def test_local_dict():
     local_dict = {
         'my_function': lambda x: x + 2
@@ -64,6 +66,7 @@ def test_local_dict():
     for text, result in inputs.items():
         assert parse_expr(text, local_dict=local_dict) == result
 
+
 def test_global_dict():
     global_dict = {
         'Symbol': Symbol
@@ -74,6 +77,37 @@ def test_global_dict():
     for text, result in inputs.items():
         assert parse_expr(text, global_dict=global_dict) == result
 
-def test_issue_2515_github():
+
+def test_issue_2515():
     raises(TokenError, lambda: parse_expr('(()'))
     raises(TokenError, lambda: parse_expr('"""'))
+
+
+def test_issue_7663():
+    x = Symbol('x')
+    e = '2*(x+1)'
+    assert parse_expr(e, evaluate=0) == parse_expr(e, evaluate=False)
+
+
+def test_split_symbols():
+    transformations = standard_transformations + \
+                      (split_symbols, implicit_multiplication,)
+    x = Symbol('x')
+    y = Symbol('y')
+    xy = Symbol('xy')
+
+    assert parse_expr("xy") == xy
+    assert parse_expr("xy", transformations=transformations) == x*y
+
+
+def test_split_symbols_function():
+    transformations = standard_transformations + \
+                      (split_symbols, implicit_multiplication,)
+    x = Symbol('x')
+    y = Symbol('y')
+    a = Symbol('a')
+    f = Function('f')
+
+    assert parse_expr("ay(x+1)", transformations=transformations) == a*y*(x+1)
+    assert parse_expr("af(x+1)", transformations=transformations,
+                      local_dict={'f':f}) == a*f(x+1)
