@@ -1,8 +1,14 @@
-from sympy.tensor.tensor import tensor_indices, TensorIndexType, tensorhead, TensorManager, TensMul, TensAdd, get_lines
+from sympy.tensor.tensor import tensor_indices, TensorIndexType, tensorhead, TensorManager, TensMul, TensAdd, get_lines, TensExpr
 from sympy import simplify, trace
 from sympy.physics.hep.gamma_matrices import GammaMatrix as G, GammaMatrixHead, DiracSpinorIndex
 from sympy.utilities.pytest import XFAIL, raises
 
+def _is_tensor_eq(arg1, arg2):
+    if isinstance(arg1, TensExpr):
+        return arg1.equals(arg2)
+    elif isinstance(arg2, TensExpr):
+        return arg2.equals(arg1)
+    return arg1 == arg2
 
 def execute_gamma_simplify_tests_for_function(tfunc, D):
     """
@@ -28,7 +34,7 @@ def execute_gamma_simplify_tests_for_function(tfunc, D):
     # Some examples taken from Kahane's paper, 4 dim only:
     if D == 4:
         t = (G(a1)*G(mu11)*G(a2)*G(mu21)*G(-a1)*G(mu31)*G(-a2))
-        assert tfunc(t) == -4*G(mu11)*G(mu31)*G(mu21) - 4*G(mu31)*G(mu11)*G(mu21)
+        assert _is_tensor_eq(tfunc(t), -4*G(mu11)*G(mu31)*G(mu21) - 4*G(mu31)*G(mu11)*G(mu21))
 
         t = (G(a1)*G(mu11)*G(mu12)*\
                               G(a2)*G(mu21)*\
@@ -38,8 +44,8 @@ def execute_gamma_simplify_tests_for_function(tfunc, D):
                               G(-a1)*G(mu61)*\
                               G(-a3)*G(mu71)*G(mu72)*\
                               G(-a4))
-        assert tfunc(t) == \
-            16*G(mu31)*G(mu32)*G(mu72)*G(mu71)*G(mu11)*G(mu52)*G(mu51)*G(mu12)*G(mu61)*G(mu21)*G(mu41) + 16*G(mu31)*G(mu32)*G(mu72)*G(mu71)*G(mu12)*G(mu51)*G(mu52)*G(mu11)*G(mu61)*G(mu21)*G(mu41) + 16*G(mu71)*G(mu72)*G(mu32)*G(mu31)*G(mu11)*G(mu52)*G(mu51)*G(mu12)*G(mu61)*G(mu21)*G(mu41) + 16*G(mu71)*G(mu72)*G(mu32)*G(mu31)*G(mu12)*G(mu51)*G(mu52)*G(mu11)*G(mu61)*G(mu21)*G(mu41)
+        assert _is_tensor_eq(tfunc(t), \
+            16*G(mu31)*G(mu32)*G(mu72)*G(mu71)*G(mu11)*G(mu52)*G(mu51)*G(mu12)*G(mu61)*G(mu21)*G(mu41) + 16*G(mu31)*G(mu32)*G(mu72)*G(mu71)*G(mu12)*G(mu51)*G(mu52)*G(mu11)*G(mu61)*G(mu21)*G(mu41) + 16*G(mu71)*G(mu72)*G(mu32)*G(mu31)*G(mu11)*G(mu52)*G(mu51)*G(mu12)*G(mu61)*G(mu21)*G(mu41) + 16*G(mu71)*G(mu72)*G(mu32)*G(mu31)*G(mu12)*G(mu51)*G(mu52)*G(mu11)*G(mu61)*G(mu21)*G(mu41))
 
     # Fully G.Lorentz-contracted expressions, these return scalars:
 
@@ -48,98 +54,98 @@ def execute_gamma_simplify_tests_for_function(tfunc, D):
 
     t = (G(mu)*G(-mu))
     ts = add_delta(D)
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(mu)*G(nu)*G(-mu)*G(-nu))
     ts = add_delta(2*D - D**2)  # -8
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(mu)*G(nu)*G(-nu)*G(-mu))
     ts = add_delta(D**2)  # 16
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(mu)*G(nu)*G(-rho)*G(-nu)*G(-mu)*G(rho))
     ts = add_delta(4*D - 4*D**2 + D**3)  # 16
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(mu)*G(nu)*G(rho)*G(-rho)*G(-nu)*G(-mu))
     ts = add_delta(D**3)  # 64
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(a1)*G(a2)*G(a3)*G(a4)*G(-a3)*G(-a1)*G(-a2)*G(-a4))
     ts = add_delta(-8*D + 16*D**2 - 8*D**3 + D**4)  # -32
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(-mu)*G(-nu)*G(-rho)*G(-sigma)*G(nu)*G(mu)*G(sigma)*G(rho))
     ts = add_delta(-16*D + 24*D**2 - 8*D**3 + D**4)  # 64
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(-mu)*G(nu)*G(-rho)*G(sigma)*G(rho)*G(-nu)*G(mu)*G(-sigma))
     ts = add_delta(8*D - 12*D**2 + 6*D**3 - D**4)  # -32
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(a1)*G(a2)*G(a3)*G(a4)*G(a5)*G(-a3)*G(-a2)*G(-a1)*G(-a5)*G(-a4))
     ts = add_delta(64*D - 112*D**2 + 60*D**3 - 12*D**4 + D**5)  # 256
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(a1)*G(a2)*G(a3)*G(a4)*G(a5)*G(-a3)*G(-a1)*G(-a2)*G(-a4)*G(-a5))
     ts = add_delta(64*D - 120*D**2 + 72*D**3 - 16*D**4 + D**5)  # -128
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(a1)*G(a2)*G(a3)*G(a4)*G(a5)*G(a6)*G(-a3)*G(-a2)*G(-a1)*G(-a6)*G(-a5)*G(-a4))
     ts = add_delta(416*D - 816*D**2 + 528*D**3 - 144*D**4 + 18*D**5 - D**6)  # -128
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     t = (G(a1)*G(a2)*G(a3)*G(a4)*G(a5)*G(a6)*G(-a2)*G(-a3)*G(-a1)*G(-a6)*G(-a4)*G(-a5))
     ts = add_delta(416*D - 848*D**2 + 584*D**3 - 172*D**4 + 22*D**5 - D**6)  # -128
-    assert tfunc(t) == ts
+    assert _is_tensor_eq(tfunc(t), ts)
 
     # Expressions with free indices:
 
     t = (G(mu)*G(nu)*G(rho)*G(sigma)*G(-mu))
-    assert tfunc(t) == (-2*G(sigma)*G(rho)*G(nu) + (4-D)*G(nu)*G(rho)*G(sigma))
+    assert _is_tensor_eq(tfunc(t), (-2*G(sigma)*G(rho)*G(nu) + (4-D)*G(nu)*G(rho)*G(sigma)))
 
     t = (G(mu)*G(nu)*G(-mu))
-    assert tfunc (t) == (2-D)*G(nu)
+    assert _is_tensor_eq(tfunc(t), (2-D)*G(nu))
 
     t = (G(mu)*G(nu)*G(rho)*G(-mu))
-    assert tfunc(t) == 2*G(nu)*G(rho) + 2*G(rho)*G(nu) - (4-D)*G(nu)*G(rho)
+    assert _is_tensor_eq(tfunc(t), 2*G(nu)*G(rho) + 2*G(rho)*G(nu) - (4-D)*G(nu)*G(rho))
 
     t = 2*G(m2)*G(m0)*G(m1)*G(-m0)*G(-m1)
     st = tfunc(t)
-    assert st == (D*(-2*D + 4))*G(m2)
+    assert _is_tensor_eq(st, (D*(-2*D + 4))*G(m2))
 
     t = G(m2)*G(m0)*G(m1)*G(-m0)*G(-m2)
     st = tfunc(t)
-    assert st == ((-D + 2)**2)*G(m1)
+    assert _is_tensor_eq(st, ((-D + 2)**2)*G(m1))
 
     t = G(m0)*G(m1)*G(m2)*G(m3)*G(-m1)
     st = tfunc(t)
-    assert st == (D - 4)*G(m0)*G(m2)*G(m3) + 4*G(m0)*g(m2, m3)
+    assert _is_tensor_eq(st, (D - 4)*G(m0)*G(m2)*G(m3) + 4*G(m0)*g(m2, m3))
 
     t = G(m0)*G(m1)*G(m2)*G(m3)*G(-m1)*G(-m0)
     st = tfunc(t)
-    assert st == ((D - 4)**2)*G(m2)*G(m3) + (8*D - 16)*g(m2, m3)
+    assert _is_tensor_eq(st, ((D - 4)**2)*G(m2)*G(m3) + (8*D - 16)*g(m2, m3))
 
     t = G(m2)*G(m0)*G(m1)*G(-m2)*G(-m0)
     st = tfunc(t)
-    assert st == ((-D + 2)*(D - 4) + 4)*G(m1)
+    assert _is_tensor_eq(st, ((-D + 2)*(D - 4) + 4)*G(m1))
 
     t = G(m3)*G(m1)*G(m0)*G(m2)*G(-m3)*G(-m0)*G(-m2)
     st = tfunc(t)
-    assert st == (-4*D + (-D + 2)**2*(D - 4) + 8)*G(m1)
+    assert _is_tensor_eq(st, (-4*D + (-D + 2)**2*(D - 4) + 8)*G(m1))
 
     t = 2*G(m0)*G(m1)*G(m2)*G(m3)*G(-m0)
     st = tfunc(t)
-    assert st == ((-2*D + 8)*G(m1)*G(m2)*G(m3) - 4*G(m3)*G(m2)*G(m1))
+    assert _is_tensor_eq(st, ((-2*D + 8)*G(m1)*G(m2)*G(m3) - 4*G(m3)*G(m2)*G(m1)))
 
     t = G(m5)*G(m0)*G(m1)*G(m4)*G(m2)*G(-m4)*G(m3)*G(-m0)
     st = tfunc(t)
-    assert st == (((-D + 2)*(-D + 4))*G(m5)*G(m1)*G(m2)*G(m3) + (2*D - 4)*G(m5)*G(m3)*G(m2)*G(m1))
+    assert _is_tensor_eq(st, (((-D + 2)*(-D + 4))*G(m5)*G(m1)*G(m2)*G(m3) + (2*D - 4)*G(m5)*G(m3)*G(m2)*G(m1)))
 
     t = -G(m0)*G(m1)*G(m2)*G(m3)*G(-m0)*G(m4)
     st = tfunc(t)
-    assert st == ((D - 4)*G(m1)*G(m2)*G(m3)*G(m4) + 2*G(m3)*G(m2)*G(m1)*G(m4))
+    assert _is_tensor_eq(st, ((D - 4)*G(m1)*G(m2)*G(m3)*G(m4) + 2*G(m3)*G(m2)*G(m1)*G(m4)))
 
     t = G(-m5)*G(m0)*G(m1)*G(m2)*G(m3)*G(m4)*G(-m0)*G(m5)
     st = tfunc(t)
@@ -154,23 +160,23 @@ def execute_gamma_simplify_tests_for_function(tfunc, D):
     result2 = 8*G(m1)*G(m2)*G(m3)*G(m4) + 8*G(m4)*G(m3)*G(m2)*G(m1)
 
     if D == 4:
-        assert st == (result1) or st == (result2)
+        assert _is_tensor_eq(st, (result1)) or _is_tensor_eq(st, (result2))
     else:
-        assert st == (result1)
+        assert _is_tensor_eq(st, (result1))
 
     # and a few very simple cases, with no contracted indices:
 
     t = G(m0)
     st = tfunc(t)
-    assert st == t
+    assert _is_tensor_eq(st, t)
 
     t = -7*G(m0)
     st = tfunc(t)
-    assert st == t
+    assert _is_tensor_eq(st, t)
 
     t = 224*G(m0)*G(m1)*G(-m2)*G(m3)
     st = tfunc(t)
-    assert st == t
+    assert _is_tensor_eq(st, t)
 
 
 def test_kahane_algorithm():
@@ -264,11 +270,11 @@ def test_gamma_matrix_class():
 
     t = A(k)*G(i)*G(-i)
     ts = simplify(t)
-    assert ts == 4*A(k)*DiracSpinorIndex.delta(DiracSpinorIndex.auto_left, -DiracSpinorIndex.auto_right)
+    assert _is_tensor_eq(ts, 4*A(k)*DiracSpinorIndex.delta(DiracSpinorIndex.auto_left, -DiracSpinorIndex.auto_right))
 
     t = G(i)*A(k)*G(j)
     ts = simplify(t)
-    assert ts == A(k)*G(i)*G(j)
+    assert _is_tensor_eq(ts, A(k)*G(i)*G(j))
 
     execute_gamma_simplify_tests_for_function(simplify, D=4)
 
@@ -302,19 +308,19 @@ def test_gamma_matrix_trace():
     # traces without internal contractions:
     t = G(m0)*G(m1)
     t1 = gamma_trace(t)
-    assert t1 == 4*g(m0, m1)
+    assert _is_tensor_eq(t1, 4*g(m0, m1))
 
     t = G(m0)*G(m1)*G(m2)*G(m3)
     t1 = gamma_trace(t)
     t2 = -4*g(m0, m2)*g(m1, m3) + 4*g(m0, m1)*g(m2, m3) + 4*g(m0, m3)*g(m1, m2)
     st2 = str(t2)
-    assert t1 == t2
+    assert _is_tensor_eq(t1, t2)
 
     t = G(m0)*G(m1)*G(m2)*G(m3)*G(m4)*G(m5)
     t1 = gamma_trace(t)
     t2 = t1*g(-m0, -m5)
     t2 = t2.contract_metric(g)
-    assert t2 == D*gamma_trace(G(m1)*G(m2)*G(m3)*G(m4))
+    assert _is_tensor_eq(t2, D*gamma_trace(G(m1)*G(m2)*G(m3)*G(m4)))
 
     # traces of expressions with internal contractions:
     t = G(m0)*G(-m0)
@@ -366,8 +372,8 @@ def test_gamma_matrix_trace():
 #    t1 = t1.expand_coeff()
     c1 = -4*D**5 + 120*D**4 - 1200*D**3 + 5280*D**2 - 10560*D + 7808
     c2 = -4*D**5 + 88*D**4 - 560*D**3 + 1440*D**2 - 1600*D + 640
-    assert t1 == c1*g(n1, n4)*g(n2, n3) + c2*g(n1, n2)*g(n3, n4) + \
-            (-c1)*g(n1, n3)*g(n2, n4)
+    assert _is_tensor_eq(t1, c1*g(n1, n4)*g(n2, n3) + c2*g(n1, n2)*g(n3, n4) + \
+            (-c1)*g(n1, n3)*g(n2, n4))
 
     p, q = tensorhead('p,q', [G.LorentzIndex], [[1]])
     ps = p(m0)*G(-m0)
@@ -377,7 +383,7 @@ def test_gamma_matrix_trace():
     pq = p(m0)*q(-m0)
     t = ps*qs*ps*qs
     r = gamma_trace(t)
-    assert r == 8*pq*pq - 4*p2*q2
+    assert _is_tensor_eq(r, 8*pq*pq - 4*p2*q2)
     t = ps*qs*ps*qs*ps*qs
     r = gamma_trace(t)
     assert r.equals(-12*p2*pq*q2 + 16*pq*pq*pq)
@@ -386,7 +392,7 @@ def test_gamma_matrix_trace():
     assert r.equals(-32*pq*pq*p2*q2 + 32*pq*pq*pq*pq + 4*p2*p2*q2*q2)
 
     t = 4*p(m1)*p(m0)*p(-m0)*q(-m1)*q(m2)*q(-m2)
-    assert gamma_trace(t) == t
+    assert _is_tensor_eq(gamma_trace(t), t)
     t = ps*ps*ps*ps*ps*ps*ps*ps
     r = gamma_trace(t)
     assert r.equals(4*p2*p2*p2*p2)
@@ -401,12 +407,12 @@ def test_simple_trace_cases_symbolic_dim():
 
     t = G(m0)*G(m1)
     t1 = G._trace_single_line(t)
-    assert t1 == 4 * G.LorentzIndex.metric(m0, m1)
+    assert _is_tensor_eq(t1, 4 * G.LorentzIndex.metric(m0, m1))
 
     t = G(m0)*G(m1)*G(m2)*G(m3)
     t1 = G._trace_single_line(t)
     t2 = -4*g(m0, m2)*g(m1, m3) + 4*g(m0, m1)*g(m2, m3) + 4*g(m0, m3)*g(m1, m2)
-    assert t1 == t2
+    assert _is_tensor_eq(t1, t2)
 
 def test_get_lines():
     i0,i1,i2,i3,i4,i5,i6,i7,i8,i9,i10,i11,i12,i13 = \
