@@ -2,11 +2,13 @@
 
 from __future__ import print_function, division
 
-from sympy import Matrix, I
+from sympy import Matrix, I, pi, sqrt
+from sympy.functions import exp
+from sympy.core.compatibility import xrange
 
 
 def msigma(i):
-    """Returns a Pauli matrix sigma_i. i=1,2,3
+    r"""Returns a Pauli matrix `\sigma_i` with `i=1,2,3`
 
     References
     ==========
@@ -44,25 +46,21 @@ def msigma(i):
 
 def pat_matrix(m, dx, dy, dz):
     """Returns the Parallel Axis Theorem matrix to translate the inertia
-    matrix a distance of (dx, dy, dz) for a body of mass m.
+    matrix a distance of `(dx, dy, dz)` for a body of mass m.
 
     Examples
-    --------
-    If the point we want the inertia about is a distance of 2 units of
-    length and 1 unit along the x-axis we get:
+    ========
+
+    To translate a body having a mass of 2 units a distance of 1 unit along
+    the `x`-axis we get:
+
     >>> from sympy.physics.matrices import pat_matrix
-    >>> pat_matrix(2,1,0,0)
+    >>> pat_matrix(2, 1, 0, 0)
     Matrix([
     [0, 0, 0],
     [0, 2, 0],
     [0, 0, 2]])
 
-    In case we want to find the inertia along a vector of (1,1,1):
-    >>> pat_matrix(2,1,1,1)
-    Matrix([
-    [ 4, -2, -2],
-    [-2,  4, -2],
-    [-2, -2,  4]])
     """
     dxdy = -dx*dy
     dydz = -dy*dz
@@ -77,15 +75,16 @@ def pat_matrix(m, dx, dy, dz):
 
 
 def mgamma(mu, lower=False):
-    """Returns a Dirac gamma matrix gamma^mu in the standard
+    r"""Returns a Dirac gamma matrix `\gamma^\mu` in the standard
     (Dirac) representation.
 
-    If you want gamma_mu, use gamma(mu, True).
+    If you want `\gamma_\mu`, use ``gamma(mu, True)``.
 
     We use a convention:
 
-    gamma^5 = I * gamma^0 * gamma^1 * gamma^2 * gamma^3
-    gamma_5 = I * gamma_0 * gamma_1 * gamma_2 * gamma_3 = - gamma^5
+    `\gamma^5 = i \cdot \gamma^0 \cdot \gamma^1 \cdot \gamma^2 \cdot \gamma^3`
+
+    `\gamma_5 = i \cdot \gamma_0 \cdot \gamma_1 \cdot \gamma_2 \cdot \gamma_3 = - \gamma^5`
 
     References
     ==========
@@ -154,3 +153,33 @@ minkowski_tensor = Matrix( (
     (0, 0, -1, 0),
     (0, 0, 0, -1)
 ))
+
+def mdft(n):
+    r"""
+    Returns an expression of a discrete Fourier transform as a matrix multiplication.
+    It is an n X n matrix.
+
+    References
+    ==========
+
+    .. [1] https://en.wikipedia.org/wiki/DFT_matrix
+
+    Examples
+    ========
+
+    >>> from sympy.physics.matrices import mdft
+    >>> mdft(3)
+    Matrix([
+    [sqrt(3)/3,                sqrt(3)/3,                sqrt(3)/3],
+    [sqrt(3)/3, sqrt(3)*exp(-2*I*pi/3)/3, sqrt(3)*exp(-4*I*pi/3)/3],
+    [sqrt(3)/3, sqrt(3)*exp(-4*I*pi/3)/3, sqrt(3)*exp(-8*I*pi/3)/3]])
+    """
+    mat = [[None for x in xrange(n)] for y in xrange(n)]
+    base = exp(-2*pi*I/n)
+    mat[0] = [1]*n
+    for i in range(n):
+        mat[i][0] = 1
+    for i in xrange(1, n):
+        for j in xrange(i, n):
+            mat[i][j] = mat[j][i] = base**(i*j)
+    return (1/sqrt(n))*Matrix(mat)
