@@ -34,3 +34,7 @@ __all__.extend(lagrange.__all__)
 from sympy.physics import vector
 from sympy.physics.vector import *
 __all__.extend(vector.__all__)
+
+from . import linearize
+from .linearize import *
+__all__.extend(linearize.__all__)
