@@ -11,6 +11,7 @@ from sympy.physics.quantum.qexpr import QuantumError
 from sympy.physics.quantum.dagger import Dagger
 from sympy.physics.quantum.commutator import Commutator
 from sympy.physics.quantum.anticommutator import AntiCommutator
+from sympy.physics.quantum.state import Ket, Bra
 from sympy.physics.quantum.matrixutils import (
     numpy_ndarray,
     scipy_sparse_matrix,
@@ -26,6 +27,24 @@ __all__ = [
 # Tensor product
 #-----------------------------------------------------------------------------
 
+_combined_printing = False
+
+
+def combined_tensor_printing(combined):
+    """Set flag controlling whether tensor products of states should be
+    printed as a combined bra/ket or as an explicit tensor product of different
+    bra/kets. This is a global setting for all TensorProduct class instances.
+
+    Parameters
+    ----------
+    combine : bool
+        When true, tensor product states are combined into one ket/bra, and
+        when false explicit tensor product notation is used between each
+        ket/bra.
+    """
+    global _combined_printing
+    _combined_printing = combined
+
 
 class TensorProduct(Expr):
     """The tensor product of two or more arguments.
@@ -105,10 +124,10 @@ class TensorProduct(Expr):
         if len(new_args) == 0:
             return c_part
         elif len(new_args) == 1:
-            return c_part*new_args[0]
+            return c_part * new_args[0]
         else:
             tp = Expr.__new__(cls, *new_args)
-            return c_part*tp
+            return c_part * tp
 
     @classmethod
     def flatten(cls, args):
@@ -126,7 +145,7 @@ class TensorProduct(Expr):
 
     def _eval_rewrite(self, pattern, rule, **hints):
         sargs = self.args
-        terms = [ t._eval_rewrite(pattern, rule, **hints) for t in sargs]
+        terms = [t._eval_rewrite(pattern, rule, **hints) for t in sargs]
         return TensorProduct(*terms).expand(tensorproduct=True)
 
     def _sympystr(self, printer, *args):
@@ -144,6 +163,33 @@ class TensorProduct(Expr):
         return s
 
     def _pretty(self, printer, *args):
+
+        if (_combined_printing and
+                (all([isinstance(arg, Ket) for arg in self.args]) or
+                 all([isinstance(arg, Bra) for arg in self.args]))):
+
+            length = len(self.args)
+            pform = printer._print('', *args)
+            for i in range(length):
+                next_pform = printer._print('', *args)
+                length_i = len(self.args[i].args)
+                for j in range(length_i):
+                    part_pform = printer._print(self.args[i].args[j], *args)
+                    next_pform = prettyForm(*next_pform.right(part_pform))
+                    if j != length_i - 1:
+                        next_pform = prettyForm(*next_pform.right(', '))
+
+                if len(self.args[i].args) > 1:
+                    next_pform = prettyForm(
+                        *next_pform.parens(left='{', right='}'))
+                pform = prettyForm(*pform.right(next_pform))
+                if i != length - 1:
+                    pform = prettyForm(*pform.right(',' + ' '))
+
+            pform = prettyForm(*pform.left(self.args[0].lbracket))
+            pform = prettyForm(*pform.right(self.args[0].rbracket))
+            return pform
+
         length = len(self.args)
         pform = printer._print('', *args)
         for i in range(length):
@@ -161,6 +207,20 @@ class TensorProduct(Expr):
         return pform
 
     def _latex(self, printer, *args):
+
+        if (_combined_printing and
+                (all([isinstance(arg, Ket) for arg in self.args]) or
+                 all([isinstance(arg, Bra) for arg in self.args]))):
+
+            def _label_wrap(label, nlabels):
+                return label if nlabels == 1 else r"\left\{%s\right\}" % label
+
+            s = r", ".join([_label_wrap(arg._print_label_latex(printer, *args),
+                                        len(arg.args)) for arg in self.args])
+
+            return r"{%s%s%s}" % (self.args[0].lbracket_latex, s,
+                                  self.args[0].rbracket_latex)
+
         length = len(self.args)
         s = ''
         for i in range(length):
@@ -205,7 +265,7 @@ class TensorProduct(Expr):
             return Mul(*[Tr(arg).doit() for arg in exp.args])
         else:
             return Mul(*[Tr(value).doit() if idx in indices else value
-                        for idx, value in enumerate(exp.args)])
+                         for idx, value in enumerate(exp.args)])
 
 
 def tensor_product_simp_Mul(e):
@@ -273,13 +333,14 @@ def tensor_product_simp_Mul(e):
                         (current, next)
                     )
                 for i in range(len(new_args)):
-                    new_args[i] = new_args[i]*next.args[i]
+                    new_args[i] = new_args[i] * next.args[i]
             else:
-                # this won't quite work as we don't want next in the TensorProduct
+                # this won't quite work as we don't want next in the
+                # TensorProduct
                 for i in range(len(new_args)):
-                    new_args[i] = new_args[i]*next
+                    new_args[i] = new_args[i] * next
             current = next
-        return Mul(*c_part)*TensorProduct(*new_args)
+        return Mul(*c_part) * TensorProduct(*new_args)
     else:
         return e
 
@@ -321,7 +382,7 @@ def tensor_product_simp(e, **hints):
     if isinstance(e, Add):
         return Add(*[tensor_product_simp(arg) for arg in e.args])
     elif isinstance(e, Pow):
-        return tensor_product_simp(e.base)**e.exp
+        return tensor_product_simp(e.base) ** e.exp
     elif isinstance(e, Mul):
         return tensor_product_simp_Mul(e)
     elif isinstance(e, Commutator):
