@@ -5,11 +5,14 @@ from sympy.physics.quantum.dagger import Dagger
 from sympy.physics.quantum.hilbert import HilbertSpace
 from sympy.physics.quantum.operator import (Operator, UnitaryOperator,
                                             HermitianOperator, OuterProduct,
-                                            DifferentialOperator)
+                                            DifferentialOperator,
+                                            IdentityOperator)
 from sympy.physics.quantum.state import Ket, Bra, Wavefunction
 from sympy.physics.quantum.qapply import qapply
+from sympy.physics.quantum.represent import represent
 from sympy.core.trace import Tr
 from sympy.physics.quantum.spin import JzKet, JzBra
+from sympy.matrices import eye
 
 
 class CustomKet(Ket):
@@ -80,6 +83,28 @@ def test_unitary():
     assert Dagger(U).is_commutative is False
 
 
+def test_identity():
+    I = IdentityOperator()
+    O = Operator('O')
+    x = Symbol("x")
+
+    assert isinstance(I, IdentityOperator)
+    assert isinstance(I, Operator)
+
+    assert I * O == O
+    assert O * I == O
+    assert isinstance(I * I, IdentityOperator)
+    assert isinstance(3 * I, Mul)
+    assert isinstance(I * x, Mul)
+    assert I.inv() == I
+    assert Dagger(I) == I
+    assert qapply(I * O) == O
+    assert qapply(O * I) == O
+
+    for n in [2, 3, 5]:
+        assert represent(IdentityOperator(n)) == eye(n)
+
+
 def test_outer_product():
     k = Ket('k')
     b = Bra('b')
