@@ -29,9 +29,10 @@ from itertools import chain
 from collections import Callable
 import warnings
 
-from sympy import sympify, Expr, Tuple, Dummy
+from sympy import sympify, Expr, Tuple, Dummy, Symbol
 from sympy.external import import_module
 from sympy.utilities.decorator import doctest_depends_on
+from sympy.utilities.iterables import is_sequence
 from .experimental_lambdify import (vectorized_lambdify, lambdify)
 
 # N.B.
@@ -204,19 +205,66 @@ class Plot(object):
     def __delitem__(self, index):
         del self._series[index]
 
-    def append(self, *args):
-        """Adds one more graph to the figure."""
-        if len(args) == 1 and isinstance(args[0], BaseSeries):
-            self._series.append(*args)
-        else:
-            self._series.append(Series(*args))
+    @doctest_depends_on(modules=('numpy', 'matplotlib',))
+    def append(self, arg):
+        """Adds an element from a plot's series to an existing plot.
 
+        Examples
+        ========
+
+        Consider two ``Plot`` objects, ``p1`` and ``p2``. To add the
+        second plot's first series object to the first, use the
+        ``append`` method, like so:
+
+        >>> from sympy import symbols
+        >>> from sympy.plotting import plot
+        >>> x = symbols('x')
+        >>> p1 = plot(x*x)
+        >>> p2 = plot(x)
+        >>> p1.append(p2[0])
+        >>> p1
+        Plot object containing:
+        [0]: cartesian line: x**2 for x over (-10.0, 10.0)
+        [1]: cartesian line: x for x over (-10.0, 10.0)
+
+        See Also
+        ========
+        extend
+
+        """
+        if isinstance(arg, BaseSeries):
+            self._series.append(arg)
+        else:
+            raise TypeError('Must specify element of plot to append.')
+
+    @doctest_depends_on(modules=('numpy', 'matplotlib',))
     def extend(self, arg):
-        """Adds the series from another plot or a list of series."""
+        """Adds all series from another plot.
+
+        Examples
+        ========
+
+        Consider two ``Plot`` objects, ``p1`` and ``p2``. To add the
+        second plot to the first, use the ``extend`` method, like so:
+
+        >>> from sympy import symbols
+        >>> from sympy.plotting import plot
+        >>> x = symbols('x')
+        >>> p1 = plot(x*x)
+        >>> p2 = plot(x)
+        >>> p1.extend(p2)
+        >>> p1
+        Plot object containing:
+        [0]: cartesian line: x**2 for x over (-10.0, 10.0)
+        [1]: cartesian line: x for x over (-10.0, 10.0)
+
+        """
         if isinstance(arg, Plot):
             self._series.extend(arg._series)
-        else:
+        elif is_sequence(arg):
             self._series.extend(arg)
+        else:
+            raise TypeError('Expecting Plot or sequence of BaseSeries')
 
 
 ##############################################################################
@@ -370,7 +418,7 @@ class List2DSeries(Line2DBaseSeries):
 
 
 class LineOver1DRangeSeries(Line2DBaseSeries):
-    """Representation for a line consisting of a sympy expression over a range."""
+    """Representation for a line consisting of a SymPy expression over a range."""
 
     def __init__(self, expr, var_start_end, **kwargs):
         super(LineOver1DRangeSeries, self).__init__()
@@ -829,7 +877,7 @@ class MatplotlibBackend(BaseBackend):
             self.ax.spines['bottom'].set_position('zero')
             self.ax.spines['top'].set_color('none')
             self.ax.spines['left'].set_smart_bounds(True)
-            self.ax.spines['bottom'].set_smart_bounds(True)
+            self.ax.spines['bottom'].set_smart_bounds(False)
             self.ax.xaxis.set_ticks_position('bottom')
             self.ax.yaxis.set_ticks_position('left')
         elif all(are_3D):
@@ -925,6 +973,11 @@ class MatplotlibBackend(BaseBackend):
             self.ax.set_yscale(parent.yscale)
         if parent.xlim:
             self.ax.set_xlim(parent.xlim)
+        else:
+            if all(isinstance(s, LineOver1DRangeSeries) for s in parent._series):
+                starts = [s.start for s in parent._series]
+                ends = [s.end for s in parent._series]
+                self.ax.set_xlim(min(starts), max(ends))
         if parent.ylim:
             self.ax.set_ylim(parent.ylim)
         if not isinstance(self.ax, Axes3D) or self.matplotlib.__version__ >= '1.2.0':  # XXX in the distant future remove this check
@@ -949,8 +1002,8 @@ class MatplotlibBackend(BaseBackend):
         if not parent.axis:
             self.ax.set_axis_off()
         if parent.legend:
-            self.ax.legend()
-            self.ax.legend_.set_visible(parent.legend)
+            if self.ax.legend():
+                self.ax.legend_.set_visible(parent.legend)
         if parent.margin:
             self.ax.set_xmargin(parent.margin)
             self.ax.set_ymargin(parent.margin)
@@ -1149,20 +1202,20 @@ def plot(*args, **kwargs):
     ``title`` : str. Title of the plot. It is set to the latex representation of
     the expression, if the plot has only one expression.
 
-    ``xlabel`` : str. Label for the x - axis.
+    ``xlabel`` : str. Label for the x-axis.
 
-    ``ylabel`` : str. Label for the y - axis.
+    ``ylabel`` : str. Label for the y-axis.
 
-    ``xscale``: {'linear', 'log'} Sets the scaling of the x - axis.
+    ``xscale``: {'linear', 'log'} Sets the scaling of the x-axis.
 
-    ``yscale``: {'linear', 'log'} Sets the scaling if the y - axis.
+    ``yscale``: {'linear', 'log'} Sets the scaling if the y-axis.
 
     ``axis_center``: tuple of two floats denoting the coordinates of the center or
     {'center', 'auto'}
 
-    ``xlim`` : tuple of two floats, denoting the x - axis limits.
+    ``xlim`` : tuple of two floats, denoting the x-axis limits.
 
-    ``ylim`` : tuple of two floats, denoting the y - axis limits.
+    ``ylim`` : tuple of two floats, denoting the y-axis limits.
 
     Examples
     ========
@@ -1206,6 +1259,17 @@ def plot(*args, **kwargs):
 
     """
     args = list(map(sympify, args))
+    free = set()
+    for a in args:
+        if isinstance(a, Expr):
+            free |= a.free_symbols
+            if len(free) > 1:
+                raise ValueError(
+                    'The same variable should be used in all '
+                    'univariate expressions being plotted.')
+    x = free.pop() if free else Symbol('x')
+    kwargs.setdefault('xlabel', x.name)
+    kwargs.setdefault('ylabel', 'f(%s)' % x.name)
     show = kwargs.pop('show', True)
     series = []
     plot_expr = check_arguments(args, 1, 1)
@@ -1287,20 +1351,20 @@ def plot_parametric(*args, **kwargs):
 
     Arguments for ``Plot`` class:
 
-    ``xlabel`` : str. Label for the x - axis.
+    ``xlabel`` : str. Label for the x-axis.
 
-    ``ylabel`` : str. Label for the y - axis.
+    ``ylabel`` : str. Label for the y-axis.
 
-    ``xscale``: {'linear', 'log'} Sets the scaling of the x - axis.
+    ``xscale``: {'linear', 'log'} Sets the scaling of the x-axis.
 
-    ``yscale``: {'linear', 'log'} Sets the scaling if the y - axis.
+    ``yscale``: {'linear', 'log'} Sets the scaling if the y-axis.
 
     ``axis_center``: tuple of two floats denoting the coordinates of the center
     or {'center', 'auto'}
 
-    ``xlim`` : tuple of two floats, denoting the x - axis limits.
+    ``xlim`` : tuple of two floats, denoting the x-axis limits.
 
-    ``ylim`` : tuple of two floats, denoting the y - axis limits.
+    ``ylim`` : tuple of two floats, denoting the y-axis limits.
 
     Examples
     ========
@@ -1656,9 +1720,12 @@ def check_arguments(args, expr_len, nb_of_free_symbols):
     Checks the arguments and converts into tuples of the
     form (exprs, ranges)
 
+    Examples
+    ========
+
     >>> from sympy import plot, cos, sin, symbols
     >>> from sympy.plotting.plot import check_arguments
-    >>> x,y,u,v = symbols('x y u v')
+    >>> x = symbols('x')
     >>> check_arguments([cos(x), sin(x)], 2, 1)
         [(cos(x), sin(x), (x, -10, 10))]
 
