@@ -1,3 +1,3 @@
 """Module for algebraic geomery and commutative algebra."""
 
-from homomorphisms import homomorphism
+from .homomorphisms import homomorphism
