@@ -1,14 +1,13 @@
 """Basic tools for dense recursive polynomials in ``K[x]`` or ``K[X]``. """
 
+from __future__ import print_function, division
+
 from sympy.core import igcd
+from sympy import oo
 
-from sympy.polys.monomialtools import (
-    monomial_key, monomial_min, monomial_div
-)
-
-from sympy.polys.distributedpolys import sdp_sort
-
-from sympy.utilities import cythonized
+from sympy.polys.monomials import monomial_min, monomial_div
+from sympy.polys.orderings import monomial_key
+from sympy.core.compatibility import xrange
 
 import random
 
@@ -33,6 +32,7 @@ def poly_LC(f, K):
     else:
         return f[0]
 
+
 def poly_TC(f, K):
     """
     Return trailing coefficient of ``f``.
@@ -57,10 +57,10 @@ def poly_TC(f, K):
 dup_LC = dmp_LC = poly_LC
 dup_TC = dmp_TC = poly_TC
 
-@cythonized("u")
+
 def dmp_ground_LC(f, u, K):
     """
-    Return ground leading coefficient.
+    Return the ground leading coefficient.
 
     Examples
     ========
@@ -80,10 +80,10 @@ def dmp_ground_LC(f, u, K):
 
     return dup_LC(f, K)
 
-@cythonized("u")
+
 def dmp_ground_TC(f, u, K):
     """
-    Return ground trailing coefficient.
+    Return the ground trailing coefficient.
 
     Examples
     ========
@@ -103,10 +103,10 @@ def dmp_ground_TC(f, u, K):
 
     return dup_TC(f, K)
 
-@cythonized("u")
+
 def dmp_true_LT(f, u, K):
     """
-    Return leading term ``c * x_1**n_1 ... x_k**n_k``.
+    Return the leading term ``c * x_1**n_1 ... x_k**n_k``.
 
     Examples
     ========
@@ -133,9 +133,12 @@ def dmp_true_LT(f, u, K):
 
     return tuple(monom), dup_LC(f, K)
 
+
 def dup_degree(f):
     """
-    Return leading degree of ``f`` in ``K[x]``.
+    Return the leading degree of ``f`` in ``K[x]``.
+
+    Note that the degree of 0 is negative infinity (the SymPy object -oo).
 
     Examples
     ========
@@ -149,12 +152,16 @@ def dup_degree(f):
     3
 
     """
+    if not f:
+        return -oo
     return len(f) - 1
 
-@cythonized("u")
+
 def dmp_degree(f, u):
     """
-    Return leading degree of ``f`` in ``x_0`` in ``K[X]``.
+    Return the leading degree of ``f`` in ``x_0`` in ``K[X]``.
+
+    Note that the degree of 0 is negative infinity (the SymPy object -oo).
 
     Examples
     ========
@@ -163,7 +170,7 @@ def dmp_degree(f, u):
     >>> from sympy.polys.densebasic import dmp_degree
 
     >>> dmp_degree([[[]]], 2)
-    -1
+    -oo
 
     >>> f = ZZ.map([[2], [1, 2, 3]])
 
@@ -172,24 +179,24 @@ def dmp_degree(f, u):
 
     """
     if dmp_zero_p(f, u):
-        return -1
+        return -oo
     else:
         return len(f) - 1
 
-@cythonized("v,i,j")
+
 def _rec_degree_in(g, v, i, j):
     """Recursive helper function for :func:`dmp_degree_in`."""
     if i == j:
         return dmp_degree(g, v)
 
-    v, i = v-1, i+1
+    v, i = v - 1, i + 1
 
     return max([ _rec_degree_in(c, v, i, j) for c in g ])
 
-@cythonized("j,u")
+
 def dmp_degree_in(f, j, u):
     """
-    Return leading degree of ``f`` in ``x_j`` in ``K[X]``.
+    Return the leading degree of ``f`` in ``x_j`` in ``K[X]``.
 
     Examples
     ========
@@ -208,22 +215,22 @@ def dmp_degree_in(f, j, u):
     if not j:
         return dmp_degree(f, u)
     if j < 0 or j > u:
-        raise IndexError("-%s <= j < %s expected, got %s" % (u, u, j))
+        raise IndexError("0 <= j <= %s expected, got %s" % (u, j))
 
     return _rec_degree_in(f, u, 0, j)
 
-@cythonized("v,i")
+
 def _rec_degree_list(g, v, i, degs):
     """Recursive helper for :func:`dmp_degree_list`."""
     degs[i] = max(degs[i], dmp_degree(g, v))
 
     if v > 0:
-        v, i = v-1, i+1
+        v, i = v - 1, i + 1
 
         for c in g:
             _rec_degree_list(c, v, i, degs)
 
-@cythonized("u")
+
 def dmp_degree_list(f, u):
     """
     Return a list of degrees of ``f`` in ``K[X]``.
@@ -240,11 +247,11 @@ def dmp_degree_list(f, u):
     (1, 2)
 
     """
-    degs = [-1]*(u+1)
+    degs = [-oo]*(u + 1)
     _rec_degree_list(f, u, 0, degs)
     return tuple(degs)
 
-@cythonized("i")
+
 def dup_strip(f):
     """
     Remove leading zeros from ``f`` in ``K[x]``.
@@ -271,7 +278,7 @@ def dup_strip(f):
 
     return f[i:]
 
-@cythonized("u,v,i")
+
 def dmp_strip(f, u):
     """
     Remove leading zeros from ``f`` in ``K[X]``.
@@ -291,7 +298,7 @@ def dmp_strip(f, u):
     if dmp_zero_p(f, u):
         return f
 
-    i, v = 0, u-1
+    i, v = 0, u - 1
 
     for c in f:
         if not dmp_zero_p(c, v):
@@ -304,38 +311,38 @@ def dmp_strip(f, u):
     else:
         return f[i:]
 
-@cythonized("i,j")
+
 def _rec_validate(f, g, i, K):
     """Recursive helper for :func:`dmp_validate`."""
     if type(g) is not list:
         if K is not None and not K.of_type(g):
             raise TypeError("%s in %s in not of type %s" % (g, f, K.dtype))
 
-        return set([i-1])
+        return set([i - 1])
     elif not g:
         return set([i])
     else:
-        j, levels = i+1, set([])
+        j, levels = i + 1, set([])
 
         for c in g:
-            levels |= _rec_validate(f, c, i+1, K)
+            levels |= _rec_validate(f, c, i + 1, K)
 
         return levels
 
-@cythonized("v,w")
+
 def _rec_strip(g, v):
     """Recursive helper for :func:`_rec_strip`."""
     if not v:
         return dup_strip(g)
 
-    w = v-1
+    w = v - 1
 
     return dmp_strip([ _rec_strip(c, w) for c in g ], v)
 
-@cythonized("u")
+
 def dmp_validate(f, K=None):
     """
-    Return number of levels in ``f`` and recursively strips it.
+    Return the number of levels in ``f`` and recursively strip it.
 
     Examples
     ========
@@ -358,7 +365,9 @@ def dmp_validate(f, K=None):
     if not levels:
         return _rec_strip(f, u), u
     else:
-        raise ValueError("invalid data structure for a multivariate polynomial")
+        raise ValueError(
+            "invalid data structure for a multivariate polynomial")
+
 
 def dup_reverse(f):
     """
@@ -378,6 +387,7 @@ def dup_reverse(f):
     """
     return dup_strip(list(reversed(f)))
 
+
 def dup_copy(f):
     """
     Create a new copy of a polynomial ``f`` in ``K[x]``.
@@ -396,7 +406,7 @@ def dup_copy(f):
     """
     return list(f)
 
-@cythonized("u,v")
+
 def dmp_copy(f, u):
     """
     Create a new copy of a polynomial ``f`` in ``K[X]``.
@@ -416,10 +426,11 @@ def dmp_copy(f, u):
     if not u:
         return list(f)
 
-    v = u-1
+    v = u - 1
 
     return [ dmp_copy(c, v) for c in f ]
 
+
 def dup_to_tuple(f):
     """
     Convert `f` into a tuple.
@@ -440,7 +451,7 @@ def dup_to_tuple(f):
     """
     return tuple(f)
 
-@cythonized("u,v")
+
 def dmp_to_tuple(f, u):
     """
     Convert `f` into a nested tuple of tuples.
@@ -465,6 +476,7 @@ def dmp_to_tuple(f, u):
 
     return tuple(dmp_to_tuple(c, v) for c in f)
 
+
 def dup_normal(f, K):
     """
     Normalize univariate polynomial in the given domain.
@@ -481,10 +493,10 @@ def dup_normal(f, K):
     """
     return dup_strip([ K.normal(c) for c in f ])
 
-@cythonized("u,v")
+
 def dmp_normal(f, u, K):
     """
-    Normalize multivariate polynomial in the given domain.
+    Normalize a multivariate polynomial in the given domain.
 
     Examples
     ========
@@ -499,25 +511,27 @@ def dmp_normal(f, u, K):
     if not u:
         return dup_normal(f, K)
 
-    v = u-1
+    v = u - 1
 
     return dmp_strip([ dmp_normal(c, v, K) for c in f ], u)
 
+
 def dup_convert(f, K0, K1):
     """
-    Convert ground domain of ``f`` from ``K0`` to ``K1``.
+    Convert the ground domain of ``f`` from ``K0`` to ``K1``.
 
     Examples
     ========
 
+    >>> from sympy.polys.rings import ring
     >>> from sympy.polys.domains import ZZ
-    >>> from sympy.polys.polyclasses import DMP
     >>> from sympy.polys.densebasic import dup_convert
 
-    >>> dup_convert([DMP([1], ZZ), DMP([2], ZZ)], ZZ['x'], ZZ)
-    [1, 2]
+    >>> R, x = ring("x", ZZ)
 
-    >>> dup_convert([ZZ(1), ZZ(2)], ZZ, ZZ['x'])
+    >>> dup_convert([R(1), R(2)], R.to_domain(), ZZ)
+    [1, 2]
+    >>> dup_convert([ZZ(1), ZZ(2)], ZZ, R.to_domain())
     [1, 2]
 
     """
@@ -526,25 +540,23 @@ def dup_convert(f, K0, K1):
     else:
         return dup_strip([ K1.convert(c, K0) for c in f ])
 
-@cythonized("u,v")
+
 def dmp_convert(f, u, K0, K1):
     """
-    Convert ground domain of ``f`` from ``K0`` to ``K1``.
+    Convert the ground domain of ``f`` from ``K0`` to ``K1``.
 
     Examples
     ========
 
+    >>> from sympy.polys.rings import ring
     >>> from sympy.polys.domains import ZZ
-    >>> from sympy.polys.polyclasses import DMP
     >>> from sympy.polys.densebasic import dmp_convert
 
-    >>> f = [[DMP([1], ZZ)], [DMP([2], ZZ)]]
-    >>> g = [[ZZ(1)], [ZZ(2)]]
+    >>> R, x = ring("x", ZZ)
 
-    >>> dmp_convert(f, 1, ZZ['x'], ZZ)
+    >>> dmp_convert([[R(1)], [R(2)]], 1, R.to_domain(), ZZ)
     [[1], [2]]
-
-    >>> dmp_convert(g, 1, ZZ, ZZ['x'])
+    >>> dmp_convert([[ZZ(1)], [ZZ(2)]], 1, ZZ, R.to_domain())
     [[1], [2]]
 
     """
@@ -553,13 +565,14 @@ def dmp_convert(f, u, K0, K1):
     if K0 is not None and K0 == K1:
         return f
 
-    v = u-1
+    v = u - 1
 
     return dmp_strip([ dmp_convert(c, v, K0, K1) for c in f ], u)
 
+
 def dup_from_sympy(f, K):
     """
-    Convert ground domain of ``f`` from SymPy to ``K``.
+    Convert the ground domain of ``f`` from SymPy to ``K``.
 
     Examples
     ========
@@ -574,10 +587,10 @@ def dup_from_sympy(f, K):
     """
     return dup_strip([ K.from_sympy(c) for c in f ])
 
-@cythonized("u,v")
+
 def dmp_from_sympy(f, u, K):
     """
-    Convert ground domain of ``f`` from SymPy to ``K``.
+    Convert the ground domain of ``f`` from SymPy to ``K``.
 
     Examples
     ========
@@ -593,14 +606,14 @@ def dmp_from_sympy(f, u, K):
     if not u:
         return dup_from_sympy(f, K)
 
-    v = u-1
+    v = u - 1
 
     return dmp_strip([ dmp_from_sympy(c, v, K) for c in f ], u)
 
-@cythonized("n")
+
 def dup_nth(f, n, K):
     """
-    Return ``n``-th coefficient of ``f`` in ``K[x]``.
+    Return the ``n``-th coefficient of ``f`` in ``K[x]``.
 
     Examples
     ========
@@ -621,12 +634,12 @@ def dup_nth(f, n, K):
     elif n >= len(f):
         return K.zero
     else:
-        return f[dup_degree(f)-n]
+        return f[dup_degree(f) - n]
+
 
-@cythonized("n,u")
 def dmp_nth(f, n, u, K):
     """
-    Return ``n``-th coefficient of ``f`` in ``K[x]``.
+    Return the ``n``-th coefficient of ``f`` in ``K[x]``.
 
     Examples
     ========
@@ -645,14 +658,14 @@ def dmp_nth(f, n, u, K):
     if n < 0:
         raise IndexError("'n' must be non-negative, got %i" % n)
     elif n >= len(f):
-        return dmp_zero(u-1)
+        return dmp_zero(u - 1)
     else:
-        return f[dmp_degree(f, u)-n]
+        return f[dmp_degree(f, u) - n]
+
 
-@cythonized("n,u,v")
 def dmp_ground_nth(f, N, u, K):
     """
-    Return ground ``n``-th coefficient of ``f`` in ``K[x]``.
+    Return the ground ``n``-th coefficient of ``f`` in ``K[x]``.
 
     Examples
     ========
@@ -674,11 +687,14 @@ def dmp_ground_nth(f, N, u, K):
         elif n >= len(f):
             return K.zero
         else:
-            f, v = f[dmp_degree(f, v)-n], v-1
+            d = dmp_degree(f, v)
+            if d == -oo:
+                d = -1
+            f, v = f[d - n], v - 1
 
     return f
 
-@cythonized("u")
+
 def dmp_zero_p(f, u):
     """
     Return ``True`` if ``f`` is zero in ``K[X]``.
@@ -703,7 +719,7 @@ def dmp_zero_p(f, u):
 
     return not f
 
-@cythonized("u")
+
 def dmp_zero(u):
     """
     Return a multivariate zero.
@@ -724,7 +740,7 @@ def dmp_zero(u):
 
     return r
 
-@cythonized("u")
+
 def dmp_one_p(f, u, K):
     """
     Return ``True`` if ``f`` is one in ``K[X]``.
@@ -741,7 +757,7 @@ def dmp_one_p(f, u, K):
     """
     return dmp_ground_p(f, K.one, u)
 
-@cythonized("u")
+
 def dmp_one(u, K):
     """
     Return a multivariate one over ``K``.
@@ -758,7 +774,7 @@ def dmp_one(u, K):
     """
     return dmp_ground(K.one, u)
 
-@cythonized("u")
+
 def dmp_ground_p(f, c, u):
     """
     Return True if ``f`` is constant in ``K[X]``.
@@ -788,7 +804,7 @@ def dmp_ground_p(f, c, u):
     else:
         return f == [c]
 
-@cythonized("i,u")
+
 def dmp_ground(c, u):
     """
     Return a multivariate constant.
@@ -807,12 +823,12 @@ def dmp_ground(c, u):
     if not c:
         return dmp_zero(u)
 
-    for i in xrange(u+1):
+    for i in xrange(u + 1):
         c = [c]
 
     return c
 
-@cythonized("n,u")
+
 def dmp_zeros(n, u, K):
     """
     Return a list of multivariate zeros.
@@ -837,7 +853,7 @@ def dmp_zeros(n, u, K):
     else:
         return [ dmp_zero(u) for i in xrange(n) ]
 
-@cythonized("n,u")
+
 def dmp_grounds(c, n, u):
     """
     Return a list of multivariate constants.
@@ -862,7 +878,7 @@ def dmp_grounds(c, n, u):
     else:
         return [ dmp_ground(c, u) for i in xrange(n) ]
 
-@cythonized("u")
+
 def dmp_negative_p(f, u, K):
     """
     Return ``True`` if ``LC(f)`` is negative.
@@ -881,7 +897,7 @@ def dmp_negative_p(f, u, K):
     """
     return K.is_negative(dmp_ground_LC(f, u, K))
 
-@cythonized("u")
+
 def dmp_positive_p(f, u, K):
     """
     Return ``True`` if ``LC(f)`` is positive.
@@ -900,10 +916,10 @@ def dmp_positive_p(f, u, K):
     """
     return K.is_positive(dmp_ground_LC(f, u, K))
 
-@cythonized("n,k")
+
 def dup_from_dict(f, K):
     """
-    Create ``K[x]`` polynomial from a ``dict``.
+    Create a ``K[x]`` polynomial from a ``dict``.
 
     Examples
     ========
@@ -920,7 +936,7 @@ def dup_from_dict(f, K):
     if not f:
         return []
 
-    n, h = max(f.iterkeys()), []
+    n, h = max(f.keys()), []
 
     if type(n) is int:
         for k in xrange(n, -1, -1):
@@ -933,10 +949,10 @@ def dup_from_dict(f, K):
 
     return dup_strip(h)
 
-@cythonized("n,k")
+
 def dup_from_raw_dict(f, K):
     """
-    Create ``K[x]`` polynomial from a raw ``dict``.
+    Create a ``K[x]`` polynomial from a raw ``dict``.
 
     Examples
     ========
@@ -951,17 +967,17 @@ def dup_from_raw_dict(f, K):
     if not f:
         return []
 
-    n, h = max(f.iterkeys()), []
+    n, h = max(f.keys()), []
 
     for k in xrange(n, -1, -1):
         h.append(f.get(k, K.zero))
 
     return dup_strip(h)
 
-@cythonized("u,v,n,k")
+
 def dmp_from_dict(f, u, K):
     """
-    Create ``K[X]`` polynomial from a ``dict``.
+    Create a ``K[X]`` polynomial from a ``dict``.
 
     Examples
     ========
@@ -982,15 +998,15 @@ def dmp_from_dict(f, u, K):
 
     coeffs = {}
 
-    for monom, coeff in f.iteritems():
+    for monom, coeff in f.items():
         head, tail = monom[0], monom[1:]
 
         if head in coeffs:
             coeffs[head][tail] = coeff
         else:
-            coeffs[head] = { tail : coeff }
+            coeffs[head] = { tail: coeff }
 
-    n, v, h = max(coeffs.iterkeys()), u-1, []
+    n, v, h = max(coeffs.keys()), u - 1, []
 
     for k in xrange(n, -1, -1):
         coeff = coeffs.get(k)
@@ -1002,7 +1018,7 @@ def dmp_from_dict(f, u, K):
 
     return dmp_strip(h, u)
 
-@cythonized("n,k")
+
 def dup_to_dict(f, K=None, zero=False):
     """
     Convert ``K[x]`` polynomial to a ``dict``.
@@ -1021,18 +1037,18 @@ def dup_to_dict(f, K=None, zero=False):
     if not f and zero:
         return {(0,): K.zero}
 
-    n, result = dup_degree(f), {}
+    n, result = len(f) - 1, {}
 
-    for k in xrange(0, n+1):
-        if f[n-k]:
-            result[(k,)] = f[n-k]
+    for k in xrange(0, n + 1):
+        if f[n - k]:
+            result[(k,)] = f[n - k]
 
     return result
 
-@cythonized("n,k")
+
 def dup_to_raw_dict(f, K=None, zero=False):
     """
-    Convert ``K[x]`` polynomial to a raw ``dict``.
+    Convert a ``K[x]`` polynomial to a raw ``dict``.
 
     Examples
     ========
@@ -1046,18 +1062,18 @@ def dup_to_raw_dict(f, K=None, zero=False):
     if not f and zero:
         return {0: K.zero}
 
-    n, result = dup_degree(f), {}
+    n, result = len(f) - 1, {}
 
-    for k in xrange(0, n+1):
-        if f[n-k]:
-            result[k] = f[n-k]
+    for k in xrange(0, n + 1):
+        if f[n - k]:
+            result[k] = f[n - k]
 
     return result
 
-@cythonized("u,v,n,k")
+
 def dmp_to_dict(f, u, K=None, zero=False):
     """
-    Convert ``K[X]`` polynomial to a ``dict````.
+    Convert a ``K[X]`` polynomial to a ``dict````.
 
     Examples
     ========
@@ -1076,17 +1092,20 @@ def dmp_to_dict(f, u, K=None, zero=False):
     if dmp_zero_p(f, u) and zero:
         return {(0,)*(u + 1): K.zero}
 
-    n, v, result = dmp_degree(f, u), u-1, {}
+    n, v, result = dmp_degree(f, u), u - 1, {}
 
-    for k in xrange(0, n+1):
-        h = dmp_to_dict(f[n-k], v)
+    if n == -oo:
+        n = -1
 
-        for exp, coeff in h.iteritems():
-            result[(k,)+exp] = coeff
+    for k in xrange(0, n + 1):
+        h = dmp_to_dict(f[n - k], v)
+
+        for exp, coeff in h.items():
+            result[(k,) + exp] = coeff
 
     return result
 
-@cythonized("u,i,j")
+
 def dmp_swap(f, i, j, u, K):
     """
     Transform ``K[..x_i..x_j..]`` to ``K[..x_j..x_i..]``.
@@ -1114,14 +1133,14 @@ def dmp_swap(f, i, j, u, K):
 
     F, H = dmp_to_dict(f, u), {}
 
-    for exp, coeff in F.iteritems():
-        H[exp[:i]    + (exp[j],) +
-          exp[i+1:j] +
-          (exp[i],)  + exp[j+1:]] = coeff
+    for exp, coeff in F.items():
+        H[exp[:i] + (exp[j],) +
+          exp[i + 1:j] +
+          (exp[i],) + exp[j + 1:]] = coeff
 
     return dmp_from_dict(H, u, K)
 
-@cythonized("u")
+
 def dmp_permute(f, P, u, K):
     """
     Return a polynomial in ``K[x_{P(1)},..,x_{P(n)}]``.
@@ -1142,7 +1161,7 @@ def dmp_permute(f, P, u, K):
     """
     F, H = dmp_to_dict(f, u), {}
 
-    for exp, coeff in F.iteritems():
+    for exp, coeff in F.items():
         new_exp = [0]*len(exp)
 
         for e, p in zip(exp, P):
@@ -1152,10 +1171,10 @@ def dmp_permute(f, P, u, K):
 
     return dmp_from_dict(H, u, K)
 
-@cythonized("i,l")
+
 def dmp_nest(f, l, K):
     """
-    Return multivariate value nested ``l``-levels.
+    Return a multivariate value nested ``l``-levels.
 
     Examples
     ========
@@ -1175,10 +1194,10 @@ def dmp_nest(f, l, K):
 
     return f
 
-@cythonized("l,k,u,v")
+
 def dmp_raise(f, l, u, K):
     """
-    Return multivariate polynomial raised ``l``-levels.
+    Return a multivariate polynomial raised ``l``-levels.
 
     Examples
     ========
@@ -1199,15 +1218,15 @@ def dmp_raise(f, l, u, K):
         if not f:
             return dmp_zero(l)
 
-        k = l-1
+        k = l - 1
 
         return [ dmp_ground(c, k) for c in f ]
 
-    v = u-1
+    v = u - 1
 
     return [ dmp_raise(c, l, v, K) for c in f ]
 
-@cythonized("g,i")
+
 def dup_deflate(f, K):
     """
     Map ``x**m`` to ``y`` in a polynomial in ``K[x]``.
@@ -1230,7 +1249,7 @@ def dup_deflate(f, K):
     g = 0
 
     for i in xrange(len(f)):
-        if not f[-i-1]:
+        if not f[-i - 1]:
             continue
 
         g = igcd(g, i)
@@ -1240,7 +1259,7 @@ def dup_deflate(f, K):
 
     return g, f[::g]
 
-@cythonized("u,i,m,a,b")
+
 def dmp_deflate(f, u, K):
     """
     Map ``x_i**m_i`` to ``y_i`` in a polynomial in ``K[X]``.
@@ -1258,12 +1277,12 @@ def dmp_deflate(f, u, K):
 
     """
     if dmp_zero_p(f, u):
-        return (1,)*(u+1), f
+        return (1,)*(u + 1), f
 
     F = dmp_to_dict(f, u)
-    B = [0]*(u+1)
+    B = [0]*(u + 1)
 
-    for M in F.iterkeys():
+    for M in F.keys():
         for i, m in enumerate(M):
             B[i] = igcd(B[i], m)
 
@@ -1278,13 +1297,13 @@ def dmp_deflate(f, u, K):
 
     H = {}
 
-    for A, coeff in F.iteritems():
+    for A, coeff in F.items():
         N = [ a // b for a, b in zip(A, B) ]
         H[tuple(N)] = coeff
 
     return B, dmp_from_dict(H, u, K)
 
-@cythonized("G,g,i")
+
 def dup_multi_deflate(polys, K):
     """
     Map ``x**m`` to ``y`` in a set of polynomials in ``K[x]``.
@@ -1311,7 +1330,7 @@ def dup_multi_deflate(polys, K):
         g = 0
 
         for i in xrange(len(p)):
-            if not p[-i-1]:
+            if not p[-i - 1]:
                 continue
 
             g = igcd(g, i)
@@ -1323,7 +1342,7 @@ def dup_multi_deflate(polys, K):
 
     return G, tuple([ p[::G] for p in polys ])
 
-@cythonized("u,G,g,m,a,b")
+
 def dmp_multi_deflate(polys, u, K):
     """
     Map ``x_i**m_i`` to ``y_i`` in a set of polynomials in ``K[X]``.
@@ -1345,13 +1364,13 @@ def dmp_multi_deflate(polys, u, K):
         M, H = dup_multi_deflate(polys, K)
         return (M,), H
 
-    F, B = [], [0]*(u+1)
+    F, B = [], [0]*(u + 1)
 
     for p in polys:
         f = dmp_to_dict(p, u)
 
         if not dmp_zero_p(p, u):
-            for M in f.iterkeys():
+            for M in f.keys():
                 for i, m in enumerate(M):
                     B[i] = igcd(B[i], m)
 
@@ -1371,7 +1390,7 @@ def dmp_multi_deflate(polys, u, K):
     for f in F:
         h = {}
 
-        for A, coeff in f.iteritems():
+        for A, coeff in f.items():
             N = [ a // b for a, b in zip(A, B) ]
             h[tuple(N)] = coeff
 
@@ -1379,7 +1398,7 @@ def dmp_multi_deflate(polys, u, K):
 
     return B, tuple(H)
 
-@cythonized("m")
+
 def dup_inflate(f, m, K):
     """
     Map ``y`` to ``x**m`` in a polynomial in ``K[x]``.
@@ -1404,12 +1423,12 @@ def dup_inflate(f, m, K):
     result = [f[0]]
 
     for coeff in f[1:]:
-        result.extend([K.zero]*(m-1))
+        result.extend([K.zero]*(m - 1))
         result.append(coeff)
 
     return result
 
-@cythonized("u,v,i,j")
+
 def _rec_inflate(g, M, v, i, K):
     """Recursive helper for :func:`dmp_inflate`."""
     if not v:
@@ -1417,7 +1436,7 @@ def _rec_inflate(g, M, v, i, K):
     if M[i] <= 0:
         raise IndexError("all M[i] must be positive, got %s" % M[i])
 
-    w, j = v-1, i+1
+    w, j = v - 1, i + 1
 
     g = [ _rec_inflate(c, M, w, j, K) for c in g ]
 
@@ -1431,7 +1450,7 @@ def _rec_inflate(g, M, v, i, K):
 
     return result
 
-@cythonized("u,m")
+
 def dmp_inflate(f, M, u, K):
     """
     Map ``y_i`` to ``x_i**k_i`` in a polynomial in ``K[X]``.
@@ -1456,7 +1475,7 @@ def dmp_inflate(f, M, u, K):
     else:
         return _rec_inflate(f, M, u, 0, K)
 
-@cythonized("u,j")
+
 def dmp_exclude(f, u, K):
     """
     Exclude useless levels from ``f``.
@@ -1480,8 +1499,8 @@ def dmp_exclude(f, u, K):
 
     J, F = [], dmp_to_dict(f, u)
 
-    for j in xrange(0, u+1):
-        for monom in F.iterkeys():
+    for j in xrange(0, u + 1):
+        for monom in F.keys():
             if monom[j]:
                 break
         else:
@@ -1492,7 +1511,7 @@ def dmp_exclude(f, u, K):
 
     f = {}
 
-    for monom, coeff in F.iteritems():
+    for monom, coeff in F.items():
         monom = list(monom)
 
         for j in reversed(J):
@@ -1504,7 +1523,7 @@ def dmp_exclude(f, u, K):
 
     return J, dmp_from_dict(f, u, K), u
 
-@cythonized("u,j")
+
 def dmp_include(f, J, u, K):
     """
     Include useless levels in ``f``.
@@ -1526,7 +1545,7 @@ def dmp_include(f, J, u, K):
 
     F, f = dmp_to_dict(f, u), {}
 
-    for monom, coeff in F.iteritems():
+    for monom, coeff in F.items():
         monom = list(monom)
 
         for j in J:
@@ -1538,7 +1557,7 @@ def dmp_include(f, J, u, K):
 
     return dmp_from_dict(f, u, K)
 
-@cythonized("u,v,w")
+
 def dmp_inject(f, u, K, front=False):
     """
     Convert ``f`` from ``K[X][Y]`` to ``K[X,Y]``.
@@ -1546,25 +1565,26 @@ def dmp_inject(f, u, K, front=False):
     Examples
     ========
 
+    >>> from sympy.polys.rings import ring
     >>> from sympy.polys.domains import ZZ
     >>> from sympy.polys.densebasic import dmp_inject
 
-    >>> K = ZZ['x', 'y']
+    >>> R, x,y = ring("x,y", ZZ)
 
-    >>> dmp_inject([K([[1]]), K([[1], [2]])], 0, K)
+    >>> dmp_inject([R(1), x + 2], 0, R.to_domain())
     ([[[1]], [[1], [2]]], 2)
-    >>> dmp_inject([K([[1]]), K([[1], [2]])], 0, K, front=True)
+    >>> dmp_inject([R(1), x + 2], 0, R.to_domain(), front=True)
     ([[[1]], [[1, 2]]], 2)
 
     """
     f, h = dmp_to_dict(f, u), {}
 
-    v = len(K.gens) - 1
+    v = K.ngens - 1
 
-    for f_monom, g in f.iteritems():
+    for f_monom, g in f.items():
         g = g.to_dict()
 
-        for g_monom, c in g.iteritems():
+        for g_monom, c in g.items():
             if front:
                 h[g_monom + f_monom] = c
             else:
@@ -1574,7 +1594,7 @@ def dmp_inject(f, u, K, front=False):
 
     return dmp_from_dict(h, w, K.dom), w
 
-@cythonized("u,v")
+
 def dmp_eject(f, u, K, front=False):
     """
     Convert ``f`` from ``K[X,Y]`` to ``K[X][Y]``.
@@ -1585,33 +1605,32 @@ def dmp_eject(f, u, K, front=False):
     >>> from sympy.polys.domains import ZZ
     >>> from sympy.polys.densebasic import dmp_eject
 
-    >>> K = ZZ['x', 'y']
-
-    >>> dmp_eject([[[1]], [[1], [2]]], 2, K)
+    >>> dmp_eject([[[1]], [[1], [2]]], 2, ZZ['x', 'y'])
     [1, x + 2]
 
     """
     f, h = dmp_to_dict(f, u), {}
 
-    v = u - len(K.gens) + 1
+    n = K.ngens
+    v = u - K.ngens + 1
 
-    for monom, c in f.iteritems():
+    for monom, c in f.items():
         if front:
-            g_monom, f_monom = monom[:v], monom[v:]
+            g_monom, f_monom = monom[:n], monom[n:]
         else:
-            f_monom, g_monom = monom[:v], monom[v:]
+            g_monom, f_monom = monom[-n:], monom[:-n]
 
         if f_monom in h:
             h[f_monom][g_monom] = c
         else:
             h[f_monom] = {g_monom: c}
 
-    for monom, c in h.iteritems():
+    for monom, c in h.items():
         h[monom] = K(c)
 
-    return dmp_from_dict(h, v-1, K)
+    return dmp_from_dict(h, v - 1, K)
+
 
-@cythonized("i")
 def dup_terms_gcd(f, K):
     """
     Remove GCD of terms from ``f`` in ``K[x]``.
@@ -1641,7 +1660,7 @@ def dup_terms_gcd(f, K):
 
     return i, f[:-i]
 
-@cythonized("u,g")
+
 def dmp_terms_gcd(f, u, K):
     """
     Remove GCD of terms from ``f`` in ``K[X]``.
@@ -1659,22 +1678,22 @@ def dmp_terms_gcd(f, u, K):
 
     """
     if dmp_ground_TC(f, u, K) or dmp_zero_p(f, u):
-        return (0,)*(u+1), f
+        return (0,)*(u + 1), f
 
     F = dmp_to_dict(f, u)
-    G = monomial_min(*F.keys())
+    G = monomial_min(*list(F.keys()))
 
     if all(g == 0 for g in G):
         return G, f
 
     f = {}
 
-    for monom, coeff in F.iteritems():
+    for monom, coeff in F.items():
         f[monomial_div(monom, G)] = coeff
 
     return G, dmp_from_dict(f, u, K)
 
-@cythonized("v,w,d,i")
+
 def _rec_list_terms(g, v, monom):
     """Recursive helper for :func:`dmp_list_terms`."""
     d, terms = dmp_degree(g, v), []
@@ -1684,16 +1703,16 @@ def _rec_list_terms(g, v, monom):
             if not c:
                 continue
 
-            terms.append((monom + (d-i,), c))
+            terms.append((monom + (d - i,), c))
     else:
-        w = v-1
+        w = v - 1
 
         for i, c in enumerate(g):
-            terms.extend(_rec_list_terms(c, w, monom + (d-i,)))
+            terms.extend(_rec_list_terms(c, w, monom + (d - i,)))
 
     return terms
 
-@cythonized("u")
+
 def dmp_list_terms(f, u, K, order=None):
     """
     List all non-zero terms from ``f`` in the given order ``order``.
@@ -1712,17 +1731,20 @@ def dmp_list_terms(f, u, K, order=None):
     [((1, 1), 1), ((1, 0), 1), ((0, 1), 2), ((0, 0), 3)]
 
     """
+    def sort(terms, O):
+        return sorted(terms, key=lambda term: O(term[0]), reverse=True)
+
     terms = _rec_list_terms(f, u, ())
 
     if not terms:
-        return [((0,)*(u+1), K.zero)]
+        return [((0,)*(u + 1), K.zero)]
 
     if order is None:
         return terms
     else:
-        return sdp_sort(terms, monomial_key(order))
+        return sort(terms, monomial_key(order))
+
 
-@cythonized("n,m")
 def dup_apply_pairs(f, g, h, args, K):
     """
     Apply ``h`` to pairs of coefficients of ``f`` and ``g``.
@@ -1743,9 +1765,9 @@ def dup_apply_pairs(f, g, h, args, K):
 
     if n != m:
         if n > m:
-            g = [K.zero]*(n-m) + g
+            g = [K.zero]*(n - m) + g
         else:
-            f = [K.zero]*(m-n) + f
+            f = [K.zero]*(m - n) + f
 
     result = []
 
@@ -1754,7 +1776,7 @@ def dup_apply_pairs(f, g, h, args, K):
 
     return dup_strip(result)
 
-@cythonized("u,v,n,m")
+
 def dmp_apply_pairs(f, g, h, args, u, K):
     """
     Apply ``h`` to pairs of coefficients of ``f`` and ``g``.
@@ -1774,13 +1796,13 @@ def dmp_apply_pairs(f, g, h, args, u, K):
     if not u:
         return dup_apply_pairs(f, g, h, args, K)
 
-    n, m, v = len(f), len(g), u-1
+    n, m, v = len(f), len(g), u - 1
 
     if n != m:
         if n > m:
-            g = dmp_zeros(n-m, v, K) + g
+            g = dmp_zeros(n - m, v, K) + g
         else:
-            f = dmp_zeros(m-n, v, K) + f
+            f = dmp_zeros(m - n, v, K) + f
 
     result = []
 
@@ -1789,13 +1811,19 @@ def dmp_apply_pairs(f, g, h, args, u, K):
 
     return dmp_strip(result, u)
 
-@cythonized("m,n,k,M,N")
+
 def dup_slice(f, m, n, K):
     """Take a continuous subsequence of terms of ``f`` in ``K[x]``. """
     k = len(f)
 
-    M = k - m
-    N = k - n
+    if k >= m:
+        M = k - m
+    else:
+        M = 0
+    if k >= n:
+        N = k - n
+    else:
+        N = 0
 
     f = f[N:M]
 
@@ -1804,12 +1832,12 @@ def dup_slice(f, m, n, K):
     else:
         return f + [K.zero]*m
 
-@cythonized("m,n,u")
+
 def dmp_slice(f, m, n, u, K):
     """Take a continuous subsequence of terms of ``f`` in ``K[X]``. """
     return dmp_slice_in(f, m, n, 0, u, K)
 
-@cythonized("m,n,j,u,k")
+
 def dmp_slice_in(f, m, n, j, u, K):
     """Take a continuous subsequence of terms of ``f`` in ``x_j`` in ``K[X]``. """
     if j < 0 or j > u:
@@ -1820,11 +1848,11 @@ def dmp_slice_in(f, m, n, j, u, K):
 
     f, g = dmp_to_dict(f, u), {}
 
-    for monom, coeff in f.iteritems():
+    for monom, coeff in f.items():
         k = monom[j]
 
         if k < m or k >= n:
-            monom = monom[:j] + (0,) + monom[j+1:]
+            monom = monom[:j] + (0,) + monom[j + 1:]
 
         if monom in g:
             g[monom] += coeff
@@ -1833,6 +1861,7 @@ def dmp_slice_in(f, m, n, j, u, K):
 
     return dmp_from_dict(g, u, K)
 
+
 def dup_random(n, a, b, K):
     """
     Return a polynomial of degree ``n`` with coefficients in ``[a, b]``.
@@ -1847,7 +1876,7 @@ def dup_random(n, a, b, K):
     [-2, -8, 9, -4]
 
     """
-    f = [ K.convert(random.randint(a, b)) for _ in xrange(0, n+1) ]
+    f = [ K.convert(random.randint(a, b)) for _ in xrange(0, n + 1) ]
 
     while not f[0]:
         f[0] = K.convert(random.randint(a, b))
