@@ -6,12 +6,16 @@ import math
 
 from sympy.core.symbol import Dummy, Symbol, symbols
 from sympy.core import S, I, pi
+from sympy.core.compatibility import ordered
 from sympy.core.mul import expand_2arg
+from sympy.core.relational import Eq
 from sympy.core.sympify import sympify
 from sympy.core.numbers import Rational, igcd
 
 from sympy.ntheory import divisors, isprime, nextprime
-from sympy.functions import exp, sqrt, re, im, Abs, cos, sin
+from sympy.functions import exp, sqrt, re, im, Abs, cos, acos, sin, Piecewise
+from sympy.functions.elementary.miscellaneous import root
+from sympy.functions.elementary.complexes import sign
 
 from sympy.polys.polytools import Poly, cancel, factor, gcd_list, discriminant
 from sympy.polys.specialpolys import cyclotomic_poly
@@ -40,7 +44,13 @@ def roots_linear(f):
 
 
 def roots_quadratic(f):
-    """Returns a list of roots of a quadratic polynomial."""
+    """Returns a list of roots of a quadratic polynomial. If the domain is ZZ
+    then the roots will be sorted with negatives coming before positives.
+    The ordering will be the same for any numerical coefficients as long as
+    the assumptions tested are correct, otherwise the ordering will not be
+    sorted (but will be canonical).
+    """
+
     a, b, c = f.all_coeffs()
     dom = f.get_domain()
 
@@ -55,39 +65,49 @@ def roots_quadratic(f):
 
         if not dom.is_Numerical:
             r1 = _simplify(r1)
+        elif r1.is_negative:
+            r0, r1 = r1, r0
     elif b is S.Zero:
         r = -c/a
-
         if not dom.is_Numerical:
-            R = sqrt(_simplify(r))
-        else:
-            R = sqrt(r)
+            r = _simplify(r)
 
-        r0 = R
-        r1 = -R
+        R = sqrt(r)
+        r0 = -R
+        r1 = R
     else:
         d = b**2 - 4*a*c
+        A = 2*a
+        B = -b/A
 
-        if dom.is_Numerical:
-            D = sqrt(d)
+        if not dom.is_Numerical:
+            d = _simplify(d)
+            B = _simplify(B)
 
-            r0 = (-b + D) / (2*a)
-            r1 = (-b - D) / (2*a)
-        else:
-            D = sqrt(_simplify(d))
-            A = 2*a
+        D = sqrt(d)/A
+        r0 = B - D
+        r1 = B + D
+        if a.is_negative:
+            r0, r1 = r1, r0
+        elif not dom.is_Numerical:
+            r0, r1 = [expand_2arg(i) for i in (r0, r1)]
 
-            E = _simplify(-b/A)
-            F = D/A
-
-            r0 = E + F
-            r1 = E - F
-
-    return sorted([expand_2arg(i) for i in (r0, r1)], key=default_sort_key)
+    return [r0, r1]
 
 
-def roots_cubic(f):
+def roots_cubic(f, trig=False):
     """Returns a list of roots of a cubic polynomial."""
+    if trig:
+        a, b, c, d = f.all_coeffs()
+        p = (3*a*c - b**2)/3/a**2
+        q = (2*b**3 - 9*a*b*c + 27*a**2*d)/(27*a**3)
+        D = 18*a*b*c*d - 4*b**3*d + b**2*c**2 - 4*a*c**3 - 27*a**2*d**2
+        if (D > 0) == True:
+            rv = []
+            for k in range(3):
+                rv.append(2*sqrt(-p/3)*cos(acos(3*q/2/p*sqrt(-3/p))/3 - k*2*pi/3))
+            return [i - b/3/a for i in rv]
+
     _, a, b, c = f.monic().all_coeffs()
 
     if c is S.Zero:
@@ -105,21 +125,21 @@ def roots_cubic(f):
             return [-aon3]*3
         else:
             if q.is_real:
-                if (q > 0) is True:
-                    u1 = -q**Rational(1, 3)
+                if (q > 0) == True:
+                    u1 = -root(q, 3)
                 else:
-                    u1 = (-q)**Rational(1, 3)
+                    u1 = root(-q, 3)
             else:
-                u1 = (-q)**Rational(1, 3)
+                u1 = root(-q, 3)
     elif q is S.Zero:
         y1, y2 = roots([1, 0, p], multiple=True)
         return [tmp - aon3 for tmp in [y1, S.Zero, y2]]
     elif q.is_real and q < 0:
-        u1 = -(-q/2 + sqrt(q**2/4 + pon3**3))**Rational(1, 3)
+        u1 = -root(-q/2 + sqrt(q**2/4 + pon3**3), 3)
     else:
-        u1 = (q/2 + sqrt(q**2/4 + pon3**3))**Rational(1, 3)
+        u1 = root(q/2 + sqrt(q**2/4 + pon3**3), 3)
 
-    coeff = S.ImaginaryUnit*sqrt(3)/2
+    coeff = I*sqrt(3)/2
 
     u2 = u1*(-S.Half + coeff)
     u3 = u1*(-S.Half - coeff)
@@ -206,8 +226,9 @@ def roots_quartic(f):
     The quasisymmetric case solution [6] looks for quartics that have the form
     `x**4 + A*x**3 + B*x**2 + C*x + D = 0` where `(C/A)**2 = D`.
 
-    Although there is a general solution, simpler results can be obtained for
-    certain values of the coefficients. In all cases, 4 roots are returned:
+    Although no general solution that is always applicable for all
+    coefficients is known to this reviewer, certain conditions are tested
+    to determine the simplest 4 expressions that can be returned:
 
       1) `f = c + a*(a**2/8 - b/2) == 0`
       2) `g = d - a*(a*(3*a**2/256 - b/16) + c/4) = 0`
@@ -283,44 +304,92 @@ def roots_quartic(f):
             p = -e**2/12 - g
             q = -e**3/108 + e*g/3 - f**2/8
             TH = Rational(1, 3)
-            if p.is_zero:
-                y = -5*e/6 - q**TH
-            elif p.is_number and p.is_comparable:
-                # with p != 0 then u below is not 0
-                root = sqrt(q**2/4 + p**3/27)
-                r = -q/2 + root  # or -q/2 - root
-                u = r**TH  # primary root of solve(x**3-r, x)
-                y = -5*e/6 + u - p/u/3
-            else:
-                raise PolynomialError('cannot return general quartic solution')
-            w = sqrt(e + 2*y)
-            arg1 = 3*e + 2*y
-            arg2 = 2*f/w
-            ans = []
-            for s in [-1, 1]:
-                root = sqrt(-(arg1 + s*arg2))
-                for t in [-1, 1]:
-                    ans.append((s*w - t*root)/2 - aon4)
 
-            return ans
+            def _ans(y):
+                w = sqrt(e + 2*y)
+                arg1 = 3*e + 2*y
+                arg2 = 2*f/w
+                ans = []
+                for s in [-1, 1]:
+                    root = sqrt(-(arg1 + s*arg2))
+                    for t in [-1, 1]:
+                        ans.append((s*w - t*root)/2 - aon4)
+                return ans
+
+            # p == 0 case
+            y1 = -5*e/6 - q**TH
+            if p.is_zero:
+                return _ans(y1)
+
+            # if p != 0 then u below is not 0
+            root = sqrt(q**2/4 + p**3/27)
+            r = -q/2 + root  # or -q/2 - root
+            u = r**TH  # primary root of solve(x**3 - r, x)
+            y2 = -5*e/6 + u - p/u/3
+            if p.is_nonzero:
+                return _ans(y2)
+
+            # sort it out once they know the values of the coefficients
+            return [Piecewise((a1, Eq(p, 0)), (a2, True))
+                for a1, a2 in zip(_ans(y1), _ans(y2))]
+
 
 def roots_binomial(f):
-    """Returns a list of roots of a binomial polynomial."""
+    """Returns a list of roots of a binomial polynomial. If the domain is ZZ
+    then the roots will be sorted with negatives coming before positives.
+    The ordering will be the same for any numerical coefficients as long as
+    the assumptions tested are correct, otherwise the ordering will not be
+    sorted (but will be canonical).
+    """
     n = f.degree()
 
     a, b = f.nth(n), f.nth(0)
-    alpha = (-cancel(b/a))**Rational(1, n)
+    base = -cancel(b/a)
+    alpha = root(base, n)
 
     if alpha.is_number:
         alpha = alpha.expand(complex=True)
 
-    roots, I = [], S.ImaginaryUnit
+    # define some parameters that will allow us to order the roots.
+    # If the domain is ZZ this is guaranteed to return roots sorted
+    # with reals before non-real roots and non-real sorted according
+    # to real part and imaginary part, e.g. -1, 1, -1 + I, 2 - I
+    neg = base.is_negative
+    even = n % 2 == 0
+    if neg:
+        if even == True and (base + 1).is_positive:
+            big = True
+        else:
+            big = False
 
-    for k in xrange(n):
-        zeta = exp(2*k*S.Pi*I/n).expand(complex=True)
+    # get the indices in the right order so the computed
+    # roots will be sorted when the domain is ZZ
+    ks = []
+    imax = n//2
+    if even:
+        ks.append(imax)
+        imax -= 1
+    if not neg:
+        ks.append(0)
+    for i in range(imax, 0, -1):
+        if neg:
+            ks.extend([i, -i])
+        else:
+            ks.extend([-i, i])
+    if neg:
+        ks.append(0)
+        if big:
+            for i in range(0, len(ks), 2):
+                pair = ks[i: i + 2]
+                pair = list(reversed(pair))
+
+    # compute the roots
+    roots, d = [], 2*I*pi/n
+    for k in ks:
+        zeta = exp(k*d).expand(complex=True)
         roots.append((alpha*zeta).expand(power_base=False))
 
-    return sorted(roots, key=default_sort_key)
+    return roots
 
 
 def _inv_totient_estimate(m):
@@ -383,16 +452,21 @@ def roots_cyclotomic(f, factor=False):
     roots = []
 
     if not factor:
-        for k in xrange(1, n + 1):
-            if igcd(k, n) == 1:
-                roots.append(exp(2*k*S.Pi*I/n).expand(complex=True))
+        # get the indices in the right order so the computed
+        # roots will be sorted
+        h = n//2
+        ks = [i for i in xrange(1, n + 1) if igcd(i, n) == 1]
+        ks.sort(key=lambda x: (x, -1) if x <= h else (abs(x - n), 1))
+        d = 2*I*pi/n
+        for k in reversed(ks):
+            roots.append(exp(k*d).expand(complex=True))
     else:
-        g = Poly(f, extension=(-1)**Rational(1, n))
+        g = Poly(f, extension=root(-1, n))
 
-        for h, _ in g.factor_list()[1]:
+        for h, _ in ordered(g.factor_list()[1]):
             roots.append(-h.TC())
 
-    return sorted(roots, key=default_sort_key)
+    return roots
 
 
 def roots_quintic(f):
@@ -413,7 +487,7 @@ def roots_quintic(f):
         f = Poly(f/coeff_5)
     quintic = PolyQuintic(f)
 
-    # Eqn standardised. Algo for solving starts here
+    # Eqn standardized. Algo for solving starts here
     if not f.is_irreducible:
         return result
 
@@ -542,19 +616,14 @@ def roots_quintic(f):
 
     # Now check if solutions are distinct
 
-    result_n = []
-    for root in result:
-        result_n.append(root.n(5))
-    result_n = sorted(result_n, key=default_sort_key)
-
-    prev_entry = None
-    for r in result_n:
-        if r == prev_entry:
-            # Roots are identical. Abort. Return []
+    saw = set()
+    for r in result:
+        r = r.n(2)
+        if r in saw:
+            # Roots were identical. Abort, return []
             # and fall back to usual solve
             return []
-        prev_entry = r
-
+        saw.add(r)
     return result
 
 
@@ -704,15 +773,22 @@ def roots(f, *gens, **flags):
     a complete set of roots use RootOf class or numerical methods
     instead. By default cubic and quartic formulas are used in
     the algorithm. To disable them because of unreadable output
-    set ``cubics=False`` or ``quartics=False`` respectively.
+    set ``cubics=False`` or ``quartics=False`` respectively. If cubic
+    roots are real but are expressed in terms of complex numbers
+    (casus irreducibilis [1]) the ``trig`` flag can be set to True to
+    have the solutions returned in terms of cosine and inverse cosine
+    functions.
 
     To get roots from a specific domain set the ``filter`` flag with
     one of the following specifiers: Z, Q, R, I, C. By default all
     roots are returned (this is equivalent to setting ``filter='C'``).
 
     By default a dictionary is returned giving a compact result in
-    case of multiple roots.  However to get a tuple containing all
-    those roots set the ``multiple`` flag to True.
+    case of multiple roots.  However to get a list containing all
+    those roots set the ``multiple`` flag to True; the list will
+    have identical roots appearing next to each other in the result.
+    (For a given Poly, the all_roots method will give the roots in
+    sorted numerical order.)
 
     Examples
     ========
@@ -738,12 +814,19 @@ def roots(f, *gens, **flags):
     >>> roots([1, 0, -1])
     {-1: 1, 1: 1}
 
+
+    References
+    ==========
+
+    1. http://en.wikipedia.org/wiki/Cubic_function#Trigonometric_.28and_hyperbolic.29_method
+
     """
     from sympy.polys.polytools import to_rational_coeffs
     flags = dict(flags)
 
     auto = flags.pop('auto', True)
     cubics = flags.pop('cubics', True)
+    trig = flags.pop('trig', False)
     quartics = flags.pop('quartics', True)
     quintics = flags.pop('quintics', False)
     multiple = flags.pop('multiple', False)
@@ -828,7 +911,7 @@ def roots(f, *gens, **flags):
         elif f.is_cyclotomic:
             result += roots_cyclotomic(f)
         elif n == 3 and cubics:
-            result += roots_cubic(f)
+            result += roots_cubic(f, trig=trig)
         elif n == 4 and quartics:
             result += roots_quartic(f)
         elif n == 5 and quintics:
@@ -933,10 +1016,10 @@ def roots(f, *gens, **flags):
     else:
         zeros = []
 
-        for zero, k in result.items():
-            zeros.extend([zero]*k)
+        for zero in ordered(result):
+            zeros.extend([zero]*result[zero])
 
-        return sorted(zeros, key=default_sort_key)
+        return zeros
 
 
 def root_factors(f, *gens, **args):
@@ -973,7 +1056,7 @@ def root_factors(f, *gens, **args):
     else:
         factors, N = [], 0
 
-        for r, n in zeros.items():
+        for r, n in ordered(zeros.items()):
             factors, N = factors + [Poly(x - r, x)]*n, N + n
 
         if N < F.degree():
@@ -983,4 +1066,4 @@ def root_factors(f, *gens, **args):
     if not isinstance(f, Poly):
         factors = [ f.as_expr() for f in factors ]
 
-    return sorted(factors, key=default_sort_key)
+    return factors
