@@ -4,6 +4,8 @@ from __future__ import print_function, division
 
 from sympy.core import (S, Expr, Integer, Float, I, Add, Lambda, symbols,
         sympify, Rational)
+from sympy.core.cache import cacheit
+from sympy.functions.elementary.miscellaneous import root as _root
 
 from sympy.polys.polytools import Poly, PurePoly, factor
 from sympy.polys.rationaltools import together
@@ -11,7 +13,8 @@ from sympy.polys.polyfuncs import symmetrize, viete
 
 from sympy.polys.rootisolation import (
     dup_isolate_complex_roots_sqf,
-    dup_isolate_real_roots_sqf)
+    dup_isolate_real_roots_sqf,
+    ComplexInterval)
 
 from sympy.polys.polyroots import (
     roots_linear, roots_quadratic, roots_binomial,
@@ -25,13 +28,18 @@ from sympy.polys.polyerrors import (
 
 from sympy.polys.domains import QQ
 
-from sympy.mpmath import mp, mpf, mpc, findroot
+from sympy.mpmath import mp, mpf, mpc, findroot, workprec
 from sympy.mpmath.libmp.libmpf import prec_to_dps
 
 from sympy.utilities import lambdify, public
 
 from sympy.core.compatibility import xrange
 
+from math import log as mathlog
+def _ispow2(i):
+    v = mathlog(i, 2)
+    return v == int(v)
+
 _reals_cache = {}
 _complexes_cache = {}
 
@@ -96,9 +104,15 @@ class RootOf(Expr):
         """Construct new ``RootOf`` object from raw data. """
         obj = Expr.__new__(cls)
 
-        obj.poly = poly
+        obj.poly = PurePoly(poly)
         obj.index = index
 
+        try:
+            _reals_cache[obj.poly] = _reals_cache[poly]
+            _complexes_cache[obj.poly] = _complexes_cache[poly]
+        except KeyError:
+            pass
+
         return obj
 
     def _hashable_content(self):
@@ -153,8 +167,7 @@ class RootOf(Expr):
         else:
             _complexes_cache[factor] = complex_part = \
                 dup_isolate_complex_roots_sqf(
-                    factor.rep.rep, factor.rep.dom, blackbox=True)
-
+                factor.rep.rep, factor.rep.dom, blackbox=True)
         return complex_part
 
     @classmethod
@@ -204,20 +217,137 @@ class RootOf(Expr):
 
         return reals
 
+    @classmethod
+    def _separate_imaginary_from_complex(cls, complexes):
+        from sympy.utilities.iterables import sift
+        def is_imag(c):
+            '''
+            return True if all roots are imaginary (ax**2 + b)
+            return False if no roots are imaginary
+            return None if 2 roots are imaginary (ax**N'''
+            u, f, k = c
+            deg = f.degree()
+            if f.length() == 2:
+                if deg == 2:
+                    return True  # both imag
+                elif _ispow2(deg):
+                    if f.LC()*f.TC() < 0:
+                        return None # 2 are imag
+            return False  # none are imag
+        # separate according to the function
+        sifted = sift(complexes, lambda c: c[1])
+        del complexes
+        imag = []
+        complexes = []
+        for f in sifted:
+            isift = sift(sifted[f], lambda c: is_imag(c))
+            imag.extend(isift.pop(True, []))
+            complexes.extend(isift.pop(False, []))
+            mixed = isift.pop(None, [])
+            assert not isift
+            if not mixed:
+                continue
+            while True:
+                # the non-imaginary ones will be on one side or the other
+                # of the y-axis
+                i = 0
+                while i < len(mixed):
+                    u, f, k = mixed[i]
+                    if u.ax*u.bx > 0:
+                        complexes.append(mixed.pop(i))
+                    else:
+                        i += 1
+                if len(mixed) == 2:
+                    imag.extend(mixed)
+                    break
+                # refine
+                for i, (u, f, k) in enumerate(mixed):
+                    u = u._inner_refine()
+                    mixed[i] = u, f, k
+        return imag, complexes
+
+    @classmethod
+    def _refine_complexes(cls, complexes):
+        """return complexes such that no bounding rectangles of non-conjugate
+        roots would intersect if slid horizontally or vertically/
+        """
+        from sympy.utilities.iterables import sift
+        while complexes:  # break when all are distinct
+            # get the intervals pairwise-disjoint. If rectangles were drawn around
+            # the coordinates of the bounding rectangles, no rectangles would
+            # intersect after this procedure
+            for i, (u, f, k) in enumerate(complexes):
+                for j, (v, g, m) in enumerate(complexes[i + 1:]):
+                    u, v = u.refine_disjoint(v)
+                    complexes[i + j + 1] = (v, g, m)
+
+                complexes[i] = (u, f, k)
+            # Although there are no intersecting rectangles, a given rectangle
+            # might intersect another when slid horizontally. We have to refine
+            # intervals until this is not true so we can sort the roots
+            # unambiguously. Since complex roots come in conjugate pairs, we
+            # will always have 2 rectangles above each other but we should not
+            # have more than that.
+            N = len(complexes)//2 - 1
+            # check x (real) parts: there must be N + 1 disjoint x ranges, i.e.
+            # the first one must be different from N others
+            uu = set([(u.ax, u.bx) for u, _, _ in complexes])
+            u = uu.pop()
+            if sum([u[1] <= v[0] or v[1] <= u[0] for v in uu]) < N:
+                # refine
+                for i, (u, f, k) in enumerate(complexes):
+                    u = u._inner_refine()
+                    complexes[i] = u, f, k
+            else:
+                # intervals with identical x-values have disjoint y-values or
+                # else they would not be disjoint so there is no need for
+                # further checks
+                break
+        return complexes
+
     @classmethod
     def _complexes_sorted(cls, complexes):
         """Make complex isolating intervals disjoint and sort roots. """
+        if not complexes:
+            return []
         cache = {}
 
-        for i, (u, f, k) in enumerate(complexes):
-            for j, (v, g, m) in enumerate(complexes[i + 1:]):
-                u, v = u.refine_disjoint(v)
-                complexes[i + j + 1] = (v, g, m)
+        # imaginary roots can cause a problem in terms of sorting since
+        # their x-intervals will never refine as distinct from others
+        # so we handle them separately
+        imag, complexes = cls._separate_imaginary_from_complex(complexes)
+        complexes = cls._refine_complexes(complexes)
 
-            complexes[i] = (u, f, k)
+        # sort imaginary roots
+        def key(c):
+            '''return, for ax**n+b, +/-root(abs(b/a), b) according to the
+            apparent sign of the imaginary interval, e.g. if the interval
+            were (0, 3) the positive root would be returned.
+            '''
+            u, f, k = c
+            r = _root(abs(f.TC()/f.LC()), f.degree())
+            if u.ay < 0 or u.by < 0:
+                return -r
+            return r
+        imag = sorted(imag, key=lambda c: key(c))
 
-        complexes = sorted(complexes, key=lambda r: (r[0].ax, r[0].ay))
+        # sort complexes and combine with imag
+        if complexes:
+            # key is (x1, y1) e.g. (1, 2)x(3, 4) -> (1,3)
+            complexes = sorted(complexes, key=
+                lambda c: c[0].a)
+            # find insertion point for imaginary
+            for i, c in enumerate(reversed(complexes)):
+                if c[0].bx <= 0:
+                    break
+            i = len(complexes) - i - 1
+            if i:
+                i += 1
+            complexes = complexes[:i] + imag + complexes[i:]
+        else:
+            complexes = imag
 
+        # update cache
         for root, factor, _ in complexes:
             if factor in cache:
                 cache[factor].append(root)
@@ -326,6 +456,7 @@ class RootOf(Expr):
         return roots
 
     @classmethod
+    @cacheit
     def _roots_trivial(cls, poly, radicals):
         """Compute roots in linear, quadratic and binomial cases. """
         if poly.degree() == 1:
@@ -334,9 +465,9 @@ class RootOf(Expr):
         if not radicals:
             return None
 
-        if radicals and poly.degree() == 2:
+        if poly.degree() == 2:
             return roots_quadratic(poly)
-        elif radicals and poly.length() == 2 and poly.TC():
+        elif poly.length() == 2 and poly.TC():
             return roots_binomial(poly)
         else:
             return None
@@ -353,7 +484,8 @@ class RootOf(Expr):
         dom = poly.get_domain()
 
         if not dom.is_ZZ:
-            raise NotImplementedError("RootOf is not supported over %s" % dom)
+            raise NotImplementedError(
+                "sorted roots not supported over %s" % dom)
 
         return coeff, poly
 
@@ -400,9 +532,7 @@ class RootOf(Expr):
 
     def _eval_evalf(self, prec):
         """Evaluate this complex root to the given precision. """
-        _prec, mp.prec = mp.prec, prec
-
-        try:
+        with workprec(prec):
             func = lambdify(self.poly.gen, self.expr)
 
             interval = self._get_interval()
@@ -431,7 +561,7 @@ class RootOf(Expr):
                     if self.is_real:
                         a = mpf(str(interval.a))
                         b = mpf(str(interval.b))
-                        # This is needed due to the bug #3364:
+                        # This is needed due to the issue 6463:
                         a, b = min(a, b), max(a, b)
                         if not (a < root < b):
                             raise ValueError("Root not in the interval.")
@@ -440,7 +570,7 @@ class RootOf(Expr):
                         bx = mpf(str(interval.bx))
                         ay = mpf(str(interval.ay))
                         by = mpf(str(interval.by))
-                        # This is needed due to the bug #3364:
+                        # This is needed due to the issue 6463:
                         ax, bx = min(ax, bx), max(ax, bx)
                         ay, by = min(ay, by), max(ay, by)
                         if not (ax < root.real < bx and ay < root.imag < by):
@@ -450,8 +580,6 @@ class RootOf(Expr):
                     continue
                 else:
                     break
-        finally:
-            mp.prec = _prec
 
         return Float._new(root.real._mpf_, prec) + I*Float._new(root.imag._mpf_, prec)
 
@@ -484,7 +612,7 @@ class RootOf(Expr):
         interval = self._get_interval()
         a = Rational(str(interval.a))
         b = Rational(str(interval.b))
-        # This is needed due to the bug #3364:
+        # This is needed due to the issue 6463:
         a, b = min(a, b), max(a, b)
         return bisect(func, a, b, tol)
 
@@ -712,14 +840,15 @@ def bisect(f, a, b, tol):
     fb = f(b)
     if fa * fb >= 0:
         raise ValueError("bisect: f(a) and f(b) must have opposite signs")
-    while (b-a > tol):
-        c = (a+b)/2
+    while (b - a > tol):
+        c = (a + b)/2
         fc = f(c)
-        if (fc == 0): return c # We need to make sure f(c) is not zero below
+        if (fc == 0):
+            return c # We need to make sure f(c) is not zero below
         if (fa * fc < 0):
             b = c
             fb = fc
         else:
             a = c
             fa = fc
-    return (a+b)/2
+    return (a + b)/2
