@@ -1,22 +1,35 @@
 """Tests for algorithms for computing symbolic roots of polynomials. """
 
 from sympy import (S, symbols, Symbol, Wild, Integer, Rational, sqrt,
-    powsimp, Lambda, sin, cos, pi, I, Interval, re, im, exp, ZZ)
+    powsimp, Lambda, sin, cos, pi, I, Interval, re, im, exp, ZZ, Piecewise,
+    acos, default_sort_key, root)
 
-from sympy.polys import (Poly, cyclotomic_poly, intervals, nroots,
+from sympy.polys import (Poly, cyclotomic_poly, intervals, nroots, RootOf,
     PolynomialError)
 
 from sympy.polys.polyroots import (root_factors, roots_linear,
     roots_quadratic, roots_cubic, roots_quartic, roots_cyclotomic,
     roots_binomial, preprocess_roots, roots)
 
-from sympy.utilities.pytest import raises
-from sympy.utilities.randtest import test_numerically
+from sympy.polys.orthopolys import legendre_poly
+
+from sympy.utilities.iterables import cartes
+from sympy.utilities.pytest import raises, XFAIL
+from sympy.utilities.randtest import verify_numerically
+import sympy
 
 
 a, b, c, d, e, q, t, x, y, z = symbols('a,b,c,d,e,q,t,x,y,z')
 
 
+def _nsort(roots):
+    key = [r.n(2) for r in roots]
+    key = [(1 if not r.is_real else 0, re(r), im(r))
+        for r in key]
+    _, roots = zip(*sorted(zip(key, roots)))
+    return list(roots)
+
+
 def test_roots_linear():
     assert roots_linear(Poly(2*x + 1, x)) == [-Rational(1, 2)]
 
@@ -33,6 +46,54 @@ def test_roots_quadratic():
         [-e*(a + c)/(a - c) - sqrt((a*b + c*d - a*d - b*c + 4*a*c*e**2)/(a - c)**2),
          -e*(a + c)/(a - c) + sqrt((a*b + c*d - a*d - b*c + 4*a*c*e**2)/(a - c)**2)]
 
+    # check for simplification
+    f = Poly(y*x**2 - 2*x - 2*y, x)
+    assert roots_quadratic(f) == \
+        [-sqrt(2*y**2 + 1)/y + 1/y, sqrt(2*y**2 + 1)/y + 1/y]
+    f = Poly(x**2 + (-y**2 - 2)*x + y**2 + 1, x)
+    assert roots_quadratic(f) == \
+        [y**2/2 - sqrt(y**4)/2 + 1, y**2/2 + sqrt(y**4)/2 + 1]
+
+    f = Poly(sqrt(2)*x**2 - 1, x)
+    r = roots_quadratic(f)
+    assert r == _nsort(r)
+
+    # issue 8255
+    f = Poly(-24*x**2 - 180*x + 264)
+    assert [w.n(2) for w in f.all_roots(radicals=True)] == \
+           [w.n(2) for w in f.all_roots(radicals=False)]
+    for _a, _b, _c in cartes((-2, 2), (-2, 2), (0, -1)):
+        f = Poly(_a*x**2 + _b*x + _c)
+        roots = roots_quadratic(f)
+        assert roots == _nsort(roots)
+
+
+def test_issue_8285():
+    roots = (Poly(4*x**8 - 1, x)*Poly(x**2 + 1)).all_roots()
+    assert roots == _nsort(roots)
+    f = Poly(x**4 + 5*x**2 + 6, x)
+    ro = [RootOf(f, i) for i in range(4)]
+    roots = Poly(x**4 + 5*x**2 + 6, x).all_roots()
+    assert roots == ro
+    assert roots == _nsort(roots)
+    # more than 2 complex roots from which to identify the
+    # imaginary ones
+    roots = Poly(2*x**8 - 1).all_roots()
+    assert roots == _nsort(roots)
+    assert len(Poly(2*x**10 - 1).all_roots()) == 10  # doesn't fail
+
+
+def test_issue_8289():
+    roots = (Poly(x**2 + 2)*Poly(x**4 + 2)).all_roots()
+    assert roots == _nsort(roots)
+    roots = Poly(x**6 + 3*x**3 + 2, x).all_roots()
+    assert roots == _nsort(roots)
+    roots = Poly(x**6 - x + 1).all_roots()
+    assert roots == _nsort(roots)
+    # all imaginary roots
+    roots = Poly(x**4 + 4*x**2 + 4, x).all_roots()
+    assert roots == _nsort(roots)
+
 
 def test_roots_cubic():
     assert roots_cubic(Poly(2*x**3, x)) == [0, 0, 0]
@@ -42,6 +103,13 @@ def test_roots_cubic():
         [-1, S.Half - I*sqrt(3)/2, S.Half + I*sqrt(3)/2]
     assert roots_cubic(Poly(2*x**3 - 3*x**2 - 3*x - 1, x))[0] == \
          S.Half + 3**Rational(1, 3)/2 + 3**Rational(2, 3)/2
+    eq = -x**3 + 2*x**2 + 3*x - 2
+    assert roots(eq, trig=True, multiple=True) == \
+           roots_cubic(Poly(eq, x), trig=True) == [
+        S(2)/3 + 2*sqrt(13)*cos(acos(8*sqrt(13)/169)/3)/3,
+        -2*sqrt(13)*sin(-acos(8*sqrt(13)/169)/3 + pi/6)/3 + S(2)/3,
+        -2*sqrt(13)*cos(-acos(8*sqrt(13)/169)/3 + pi/3)/3 + S(2)/3,
+        ]
 
 
 def test_roots_quartic():
@@ -83,9 +151,23 @@ def test_roots_quartic():
     # not all symbolic quartics are unresolvable
     eq = Poly(q*x + q/4 + x**4 + x**3 + 2*x**2 - Rational(1, 3), x)
     sol = roots_quartic(eq)
-    assert all(test_numerically(eq.subs(x, i), 0) for i in sol)
-    # but some are (see also iss 1890)
-    raises(PolynomialError, lambda: roots_quartic(Poly(y*x**4 + x + z, x)))
+    assert all(verify_numerically(eq.subs(x, i), 0) for i in sol)
+    z = symbols('z', negative=True)
+    eq = x**4 + 2*x**3 + 3*x**2 + x*(z + 11) + 5
+    zans = roots_quartic(Poly(eq, x))
+    assert all([verify_numerically(eq.subs(((x, i), (z, -1))), 0) for i in zans])
+    # but some are (see also issue 4989)
+    # it's ok if the solution is not Piecewise, but the tests below should pass
+    eq = Poly(y*x**4 + x**3 - x + z, x)
+    ans = roots_quartic(eq)
+    assert all(type(i) == Piecewise for i in ans)
+    reps = (
+        dict(y=-Rational(1, 3), z=-Rational(1, 4)),  # 4 real
+        dict(y=-Rational(1, 3), z=-Rational(1, 2)),  # 2 real
+        dict(y=-Rational(1, 3), z=-2))  # 0 real
+    for rep in reps:
+        sol = roots_quartic(Poly(eq.subs(rep), x))
+        assert all([verify_numerically(w.subs(rep) - s, 0) for w, s in zip(ans, sol)])
 
 
 def test_roots_cyclotomic():
@@ -100,10 +182,10 @@ def test_roots_cyclotomic():
     assert roots_cyclotomic(cyclotomic_poly(7, x, polys=True)) == [
         -cos(pi/7) - I*sin(pi/7),
         -cos(pi/7) + I*sin(pi/7),
-        cos(2*pi/7) - I*sin(2*pi/7),
-        cos(2*pi/7) + I*sin(2*pi/7),
         -cos(3*pi/7) - I*sin(3*pi/7),
         -cos(3*pi/7) + I*sin(3*pi/7),
+        cos(2*pi/7) - I*sin(2*pi/7),
+        cos(2*pi/7) + I*sin(2*pi/7),
     ]
 
     assert roots_cyclotomic(cyclotomic_poly(8, x, polys=True)) == [
@@ -126,14 +208,14 @@ def test_roots_cyclotomic():
         cyclotomic_poly(2, x, polys=True), factor=True) == [-1]
 
     assert roots_cyclotomic(cyclotomic_poly(3, x, polys=True), factor=True) == \
-        [-(-1)**(S(1)/3), -1 + (-1)**(S(1)/3)]
+        [-root(-1, 3), -1 + root(-1, 3)]
     assert roots_cyclotomic(cyclotomic_poly(4, x, polys=True), factor=True) == \
         [-I, I]
     assert roots_cyclotomic(cyclotomic_poly(5, x, polys=True), factor=True) == \
-        [-(-1)**(S(1)/5), (-1)**(S(2)/5), -(-1)**(S(3)/5),
-         -1 + (-1)**(S(1)/5) - (-1)**(S(2)/5) + (-1)**(S(3)/5)]
+        [-root(-1, 5), -root(-1, 5)**3, root(-1, 5)**2, -1 - root(-1, 5)**2 + root(-1, 5) + root(-1, 5)**3]
+
     assert roots_cyclotomic(cyclotomic_poly(6, x, polys=True), factor=True) == \
-        [(-1)**(S(1)/3), 1 - (-1)**(S(1)/3)]
+        [1 - root(-1, 3), root(-1, 3)]
 
 
 def test_roots_binomial():
@@ -154,6 +236,13 @@ def test_roots_binomial():
 
     assert powsimp(r0[0]) == powsimp(r1[0])
     assert powsimp(r0[1]) == powsimp(r1[1])
+    for a, b, s, n in cartes((1, 2), (1, 2), (-1, 1), (2, 3, 4, 5)):
+        if a == b and a != 1:  # a == b == 1 is sufficient
+            continue
+        p = Poly(a*x**n + s*b)
+        roots = roots_binomial(p)
+        assert roots == _nsort(roots)
+
 
 def test_roots_preprocessing():
     f = a*y*x**2 + y - b
@@ -328,7 +417,7 @@ def test_roots():
         (x - 1)*(x + 1), x, predicate=lambda r: r.is_positive) == {S.One: 1}
 
     assert roots(x**4 - 1, x, filter='Z', multiple=True) == [-S.One, S.One]
-    assert roots(x**4 - 1, x, filter='I', multiple=True) == [-I, I]
+    assert roots(x**4 - 1, x, filter='I', multiple=True) == [I, -I]
 
     assert roots(x**3, x, multiple=True) == [S.Zero, S.Zero, S.Zero]
     assert roots(1234, x, multiple=True) == []
@@ -359,7 +448,7 @@ def test_roots():
     r = roots(x**3 + 40*x + 64)
     real_root = [rx for rx in r if rx.is_real][0]
     cr = 4 + 2*sqrt(1074)/9
-    assert real_root == -2*cr**(S(1)/3) + 20/(3*cr**(S(1)/3))
+    assert real_root == -2*root(cr, 3) + 20/(3*root(cr, 3))
 
     eq = Poly((7 + 5*sqrt(2))*x**3 + (-6 - 4*sqrt(2))*x**2 + (-sqrt(2) - 1)*x + 2, x, domain='EX')
     assert roots(eq) == {-1 + sqrt(2): 1, -2 + 2*sqrt(2): 1, -sqrt(2) + 1: 1}
@@ -375,9 +464,9 @@ def test_roots():
     assert roots(eq) == {-2*sqrt(2) + 2: 1, -2*sqrt(2) + 1: 1, -2*sqrt(2) - 1: 1}
 
     assert roots(Poly((x + sqrt(2))**3 - 7, x, domain='EX')) == \
-        {-sqrt(2) - 7**(S(1)/3)/2 - sqrt(3)*7**(S(1)/3)*I/2: 1,
-         -sqrt(2) - 7**(S(1)/3)/2 + sqrt(3)*7**(S(1)/3)*I/2: 1,
-         -sqrt(2) + 7**(S(1)/3): 1}
+        {-sqrt(2) - root(7, 3)/2 - sqrt(3)*root(7, 3)*I/2: 1,
+         -sqrt(2) - root(7, 3)/2 + sqrt(3)*root(7, 3)*I/2: 1,
+         -sqrt(2) + root(7, 3): 1}
 
 def test_roots_slow():
     """Just test that calculating these roots does not hang. """
@@ -480,13 +569,50 @@ def test_root_factors():
     assert root_factors(Poly(1, x)) == [Poly(1, x)]
     assert root_factors(Poly(x, x)) == [Poly(x, x)]
 
-    assert root_factors(x**2 - 1, x) == [x - 1, x + 1]
+    assert root_factors(x**2 - 1, x) == [x + 1, x - 1]
     assert root_factors(x**2 - y, x) == [x - sqrt(y), x + sqrt(y)]
 
     assert root_factors((x**4 - 1)**2) == \
-        [x - 1, x - 1, x + 1, x + 1, x - I, x - I, x + I, x + I]
+        [x + 1, x + 1, x - 1, x - 1, x - I, x - I, x + I, x + I]
 
     assert root_factors(Poly(x**4 - 1, x), filter='Z') == \
-        [Poly(x - 1, x), Poly(x + 1, x), Poly(x**2 + 1, x)]
+        [Poly(x + 1, x), Poly(x - 1, x), Poly(x**2 + 1, x)]
     assert root_factors(8*x**2 + 12*x**4 + 6*x**6 + x**8, x, filter='Q') == \
         [x, x, x**6 + 6*x**4 + 12*x**2 + 8]
+
+def test_nroots1():
+    n = 64
+    p = legendre_poly(n, x, polys=True)
+
+    raises(sympy.mpmath.mp.NoConvergence, lambda: p.nroots(n=3, maxsteps=5))
+
+    roots = p.nroots(n=3)
+    # The order of roots matters. They are ordered from smallest to the
+    # largest.
+    assert [str(r) for r in roots] == \
+            ['-0.999', '-0.996', '-0.991', '-0.983', '-0.973', '-0.961',
+            '-0.946', '-0.930', '-0.911', '-0.889', '-0.866', '-0.841',
+            '-0.813', '-0.784', '-0.753', '-0.720', '-0.685', '-0.649',
+            '-0.611', '-0.572', '-0.531', '-0.489', '-0.446', '-0.402',
+            '-0.357', '-0.311', '-0.265', '-0.217', '-0.170', '-0.121',
+            '-0.0730', '-0.0243', '0.0243', '0.0730', '0.121', '0.170',
+            '0.217', '0.265', '0.311', '0.357', '0.402', '0.446', '0.489',
+            '0.531', '0.572', '0.611', '0.649', '0.685', '0.720', '0.753',
+            '0.784', '0.813', '0.841', '0.866', '0.889', '0.911', '0.930',
+            '0.946', '0.961', '0.973', '0.983', '0.991', '0.996', '0.999']
+
+def test_nroots2():
+    p = Poly(x**5 + 3*x + 1, x)
+
+    roots = p.nroots(n=3)
+    # The order of roots matters. The roots are ordered by their real
+    # components (if they agree, then by their imaginary components),
+    # with real roots appearing first.
+    assert [str(r) for r in roots] == \
+            ['-0.332', '-0.839 - 0.944*I', '-0.839 + 0.944*I',
+                '1.01 - 0.937*I', '1.01 + 0.937*I']
+
+    roots = p.nroots(n=5)
+    assert [str(r) for r in roots] == \
+            ['-0.33199', '-0.83907 - 0.94385*I', '-0.83907 + 0.94385*I',
+              '1.0051 - 0.93726*I', '1.0051 + 0.93726*I']
