@@ -2,10 +2,15 @@
 A MathML printer.
 """
 
-from sympy import Basic, sympify, C, S
-from sympy.simplify import fraction
-from printer import Printer
-from conventions import split_super_sub
+from __future__ import print_function, division
+
+from sympy import sympify, S, Mul
+from sympy.core.function import _coeff_isneg
+from sympy.core.alphabets import greeks
+from sympy.core.compatibility import u
+from .printer import Printer
+from .pretty.pretty_symbology import greek_unicode
+from .conventions import split_super_sub, requires_partial
 
 
 class MathMLPrinter(Printer):
@@ -15,16 +20,26 @@ class MathMLPrinter(Printer):
 
     References: http://www.w3.org/TR/MathML2/
     """
-    printmethod = "_mathml_"
+    printmethod = "_mathml"
+    _default_settings = {
+        "order": None,
+        "encoding": "utf-8"
+    }
 
-    def __init__(self, *args, **kwargs):
-        Printer.__init__(self, *args, **kwargs)
+    def __init__(self, settings=None):
+        Printer.__init__(self, settings)
         from xml.dom.minidom import Document
         self.dom = Document()
 
-    def doprint(self, e):
-        mathML = Printer.doprint(self,expr)
-        return mathML.toxml()
+    def doprint(self, expr):
+        """
+        Prints the expression as MathML.
+        """
+        mathML = Printer._print(self, expr)
+        unistr = mathML.toxml()
+        xmlbstr = unistr.encode('ascii', 'xmlcharrefreplace')
+        res = xmlbstr.decode()
+        return res
 
     def mathml_tag(self, e):
         """Returns the MathML tag for an expression."""
@@ -37,6 +52,7 @@ class MathMLPrinter(Printer):
             'Pow': 'power',
             'Symbol': 'ci',
             'Integral': 'int',
+            'Sum': 'sum',
             'sin': 'sin',
             'cos': 'cos',
             'tan': 'tan',
@@ -49,7 +65,13 @@ class MathMLPrinter(Printer):
             'atanh': 'arctanh',
             'acot': 'arccot',
             'atan2': 'arctan',
-            'log': 'ln'
+            'log': 'ln',
+            'Equality': 'eq',
+            'Unequality': 'neq',
+            'GreaterThan': 'geq',
+            'LessThan': 'leq',
+            'StrictGreaterThan': 'gt',
+            'StrictLessThan': 'lt',
         }
 
         for cls in e.__class__.__mro__:
@@ -61,25 +83,32 @@ class MathMLPrinter(Printer):
         return n.lower()
 
     def _print_Mul(self, expr):
-        coeff, terms  = expr.as_coeff_terms()
 
-        if coeff.is_negative:
+        if _coeff_isneg(expr):
             x = self.dom.createElement('apply')
             x.appendChild(self.dom.createElement('minus'))
             x.appendChild(self._print_Mul(-expr))
             return x
 
+        from sympy.simplify import fraction
         numer, denom = fraction(expr)
 
-        if not denom is S.One:
+        if denom is not S.One:
             x = self.dom.createElement('apply')
             x.appendChild(self.dom.createElement('divide'))
             x.appendChild(self._print(numer))
             x.appendChild(self._print(denom))
             return x
 
-        if coeff == 1 and len(terms) == 1:
+        coeff, terms = expr.as_coeff_mul()
+        if coeff is S.One and len(terms) == 1:
+            # XXX since the negative coefficient has been handled, I don't
+            # thing a coeff of 1 can remain
             return self._print(terms[0])
+
+        if self.order != 'old':
+            terms = Mul._from_args(terms).as_ordered_factors()
+
         x = self.dom.createElement('apply')
         x.appendChild(self.dom.createElement('times'))
         if(coeff != 1):
@@ -88,25 +117,19 @@ class MathMLPrinter(Printer):
             x.appendChild(self._print(term))
         return x
 
-    # This is complicated because we attempt to order then results in order of Basic._compare_pretty
-    # and use minus instead of negative
-    def _print_Add(self, e):
-        args = list(e.args)
-        args.sort(Basic._compare_pretty)
+    def _print_Add(self, expr, order=None):
+        args = self._as_ordered_terms(expr, order=order)
         lastProcessed = self._print(args[0])
-        args.pop(0)
-        plusNodes = list()
-        for i in range(0,len(args)):
-            arg = args[i]
-            coeff, terms = arg.as_coeff_terms()
-            if(coeff.is_negative):
+        plusNodes = []
+        for arg in args[1:]:
+            if _coeff_isneg(arg):
                 #use minus
                 x = self.dom.createElement('apply')
                 x.appendChild(self.dom.createElement('minus'))
                 x.appendChild(lastProcessed)
                 x.appendChild(self._print(-arg))
-                #invert expression  since this is now minused
-                lastProcessed = x;
+                #invert expression since this is now minused
+                lastProcessed = x
                 if(arg == args[-1]):
                     plusNodes.append(lastProcessed)
             else:
@@ -122,12 +145,12 @@ class MathMLPrinter(Printer):
             x.appendChild(plusNodes.pop(0))
         return x
 
-    def _print_Matrix(self, m):
+    def _print_MatrixBase(self, m):
         x = self.dom.createElement('matrix')
         for i in range(m.lines):
             x_r = self.dom.createElement('matrixrow')
             for j in range(m.cols):
-                x_r.appendChild(self._print(m[i,j]))
+                x_r.appendChild(self._print(m[i, j]))
             x.appendChild(x_r)
         return x
 
@@ -163,20 +186,20 @@ class MathMLPrinter(Printer):
         x.appendChild(self._print(e.args[0]))
         return x
 
-    def _print_ImaginaryUnit(self,e):
+    def _print_ImaginaryUnit(self, e):
         return self.dom.createElement('imaginaryi')
 
-    def _print_EulerGamma(self,e):
+    def _print_EulerGamma(self, e):
         return self.dom.createElement('eulergamma')
 
-    def _print_GoldenRatio(self,e):
+    def _print_GoldenRatio(self, e):
         """We use unicode #x3c6 for Greek letter phi as defined here
-        http://www.w3.org/Math/characters/"""
+        http://www.w3.org/2003/entities/2007doc/isogrk1.html"""
         x = self.dom.createElement('cn')
-        x.appendChild(self.dom.createTextNode(u"\u03c6"))
+        x.appendChild(self.dom.createTextNode(u("\u03c6")))
         return x
 
-    def _print_Exp1(self,e):
+    def _print_Exp1(self, e):
         return self.dom.createElement('exponentiale')
 
     def _print_Pi(self, e):
@@ -185,7 +208,7 @@ class MathMLPrinter(Printer):
     def _print_Infinity(self, e):
         return self.dom.createElement('infinity')
 
-    def _print_Negative_Infinity(self,e):
+    def _print_Negative_Infinity(self, e):
         x = self.dom.createElement('apply')
         x.appendChild(self.dom.createElement('minus'))
         x.appendChild(self.dom.createElement('infinity'))
@@ -199,12 +222,16 @@ class MathMLPrinter(Printer):
             bvar_elem.appendChild(self._print(limits[0][0]))
             x.appendChild(bvar_elem)
 
-            if limits[0][1]:
+            if len(limits[0]) == 3:
                 low_elem = self.dom.createElement('lowlimit')
-                low_elem.appendChild(self._print(limits[0][1][0]))
+                low_elem.appendChild(self._print(limits[0][1]))
                 x.appendChild(low_elem)
                 up_elem = self.dom.createElement('uplimit')
-                up_elem.appendChild(self._print(limits[0][1][1]))
+                up_elem.appendChild(self._print(limits[0][2]))
+                x.appendChild(up_elem)
+            if len(limits[0]) == 2:
+                up_elem = self.dom.createElement('uplimit')
+                up_elem.appendChild(self._print(limits[0][1]))
                 x.appendChild(up_elem)
             if len(limits) == 1:
                 x.appendChild(self._print(e.function))
@@ -216,6 +243,11 @@ class MathMLPrinter(Printer):
         limits.reverse()
         return lime_recur(limits)
 
+    def _print_Sum(self, e):
+        # Printer can be shared because Sum and Integral have the
+        # same internal representation.
+        return self._print_Integral(e)
+
     def _print_Symbol(self, sym):
         ci = self.dom.createElement(self.mathml_tag(sym))
 
@@ -223,7 +255,7 @@ class MathMLPrinter(Printer):
             if len(items) > 1:
                 mrow = self.dom.createElement('mml:mrow')
                 for i, item in enumerate(items):
-                    if i>0:
+                    if i > 0:
                         mo = self.dom.createElement('mml:mo')
                         mo.appendChild(self.dom.createTextNode(" "))
                         mrow.appendChild(mo)
@@ -236,7 +268,19 @@ class MathMLPrinter(Printer):
                 mi.appendChild(self.dom.createTextNode(items[0]))
                 return mi
 
+        # translate name, supers and subs to unicode characters
+        greek_letters = set(greeks) # make a copy
+        def translate(s):
+            if s in greek_unicode:
+                return greek_unicode.get(s)
+            else:
+                return s
+
         name, supers, subs = split_super_sub(sym.name)
+        name = translate(name)
+        supers = [translate(sup) for sup in supers]
+        subs = [translate(sub) for sub in subs]
+
         mname = self.dom.createElement('mml:mi')
         mname.appendChild(self.dom.createTextNode(name))
         if len(supers) == 0:
@@ -289,10 +333,13 @@ class MathMLPrinter(Printer):
 
     def _print_Derivative(self, e):
         x = self.dom.createElement('apply')
-        x.appendChild(self.dom.createElement(self.mathml_tag(e)))
+        diff_symbol = self.mathml_tag(e)
+        if requires_partial(e):
+            diff_symbol = 'partialdiff'
+        x.appendChild(self.dom.createElement(diff_symbol))
 
         x_1 = self.dom.createElement('bvar')
-        for sym in e.symbols:
+        for sym in e.variables:
             x_1.appendChild(self._print(sym))
 
         x.appendChild(x_1)
@@ -320,6 +367,13 @@ class MathMLPrinter(Printer):
             x.appendChild(self._print(arg))
         return x
 
+    def _print_Relational(self, e):
+        x = self.dom.createElement('apply')
+        x.appendChild(self.dom.createElement(self.mathml_tag(e)))
+        x.appendChild(self._print(e.lhs))
+        x.appendChild(self._print(e.rhs))
+        return x
+
     def _print_list(self, seq):
         """MathML reference for the <list> element:
         http://www.w3.org/TR/MathML2/chapter4.html#contm.list"""
@@ -333,29 +387,85 @@ class MathMLPrinter(Printer):
         dom_element.appendChild(self.dom.createTextNode(str(p)))
         return dom_element
 
-def mathml(expr):
-    """Returns the MathML representation of expr"""
-    s = MathMLPrinter()
-    return s._print(sympify(expr)).toxml(encoding="utf-8")
+    def apply_patch(self):
+        # Applying the patch of xml.dom.minidom bug
+        # Date: 2011-11-18
+        # Description: http://ronrothman.com/public/leftbraned/xml-dom-minidom-\
+        #                   toprettyxml-and-silly-whitespace/#best-solution
+        # Issue: http://bugs.python.org/issue4147
+        # Patch: http://hg.python.org/cpython/rev/7262f8f276ff/
 
-def print_mathml(expr):
+        from xml.dom.minidom import Element, Text, Node, _write_data
+
+        def writexml(self, writer, indent="", addindent="", newl=""):
+            # indent = current indentation
+            # addindent = indentation to add to higher levels
+            # newl = newline string
+            writer.write(indent + "<" + self.tagName)
+
+            attrs = self._get_attributes()
+            a_names = list(attrs.keys())
+            a_names.sort()
+
+            for a_name in a_names:
+                writer.write(" %s=\"" % a_name)
+                _write_data(writer, attrs[a_name].value)
+                writer.write("\"")
+            if self.childNodes:
+                writer.write(">")
+                if (len(self.childNodes) == 1 and
+                        self.childNodes[0].nodeType == Node.TEXT_NODE):
+                    self.childNodes[0].writexml(writer, '', '', '')
+                else:
+                    writer.write(newl)
+                    for node in self.childNodes:
+                        node.writexml(
+                            writer, indent + addindent, addindent, newl)
+                    writer.write(indent)
+                writer.write("</%s>%s" % (self.tagName, newl))
+            else:
+                writer.write("/>%s" % (newl))
+        self._Element_writexml_old = Element.writexml
+        Element.writexml = writexml
+
+        def writexml(self, writer, indent="", addindent="", newl=""):
+            _write_data(writer, "%s%s%s" % (indent, self.data, newl))
+        self._Text_writexml_old = Text.writexml
+        Text.writexml = writexml
+
+    def restore_patch(self):
+        from xml.dom.minidom import Element, Text
+        Element.writexml = self._Element_writexml_old
+        Text.writexml = self._Text_writexml_old
+
+
+def mathml(expr, **settings):
+    """Returns the MathML representation of expr"""
+    return MathMLPrinter(settings).doprint(expr)
+
+
+def print_mathml(expr, **settings):
     """
     Prints a pretty representation of the MathML code for expr
 
+    Examples
+    ========
+
     >>> ##
     >>> from sympy.printing.mathml import print_mathml
     >>> from sympy.abc import x
     >>> print_mathml(x+1) #doctest: +NORMALIZE_WHITESPACE
     <apply>
         <plus/>
-        <cn>
-                1
-        </cn>
-        <ci>
-                x
-        </ci>
+        <ci>x</ci>
+        <cn>1</cn>
     </apply>
 
     """
-    s = MathMLPrinter()
-    print s._print(sympify(expr)).toprettyxml(encoding="utf-8")
+    s = MathMLPrinter(settings)
+    xml = s._print(sympify(expr))
+    s.apply_patch()
+    pretty_xml = xml.toprettyxml()
+    s.restore_patch()
+
+    print(pretty_xml)
