@@ -1,5 +1,6 @@
 from sympy import (Symbol, Rational, Order, exp, ln, log, nan, oo, O, pi, I,
-    S, Integral, sin, sqrt, conjugate, expand, transpose, symbols, Function)
+    S, Integral, sin, cos, sqrt, conjugate, expand, transpose, symbols,
+    Function)
 from sympy.utilities.pytest import XFAIL, raises
 from sympy.abc import w, x, y, z
 
@@ -131,6 +132,11 @@ def test_contains_3():
     assert Order(x**2*y).contains(Order(x*y**2)) is None
 
 
+def test_contains_4():
+    assert Order(sin(1/x**2)).contains(Order(cos(1/x**2))) is None
+    assert Order(cos(1/x**2)).contains(Order(sin(1/x**2))) is None
+
+
 def test_contains():
     assert Order(1, x) not in Order(1)
     assert Order(1) in Order(1, x)
@@ -196,7 +202,7 @@ def test_multivar_3():
     assert (Order(x**2*y) + Order(y*x)) == Order(x*y)
 
 
-def test_issue369():
+def test_issue_3468():
     y = Symbol('y', negative=True)
     z = Symbol('z', complex=True)
 
@@ -209,10 +215,6 @@ def test_issue369():
     assert y.is_positive is False
     assert z.is_positive is None
 
-    assert x.is_infinitesimal is None
-    assert y.is_infinitesimal is None
-    assert z.is_infinitesimal is None
-
 
 def test_leading_order():
     assert (x + 1 + 1/x**5).extract_leading_order(x) == ((1/x**5, O(1/x**5)),)
@@ -282,15 +284,11 @@ def test_eval():
     assert Order(x).subs(Order(x), 1) == 1
     assert Order(x).subs(x, y) == Order(y)
     assert Order(x).subs(y, x) == Order(x)
-    assert Order(x).subs(x, x + y) == Order(x + y)
+    assert Order(x).subs(x, x + y) == Order(x + y, (x, -y))
     assert (O(1)**x).is_Pow
 
 
-def test_oseries():
-    assert Order(x).oseries(x) == Order(x)
-
-
-def test_issue_1180():
+def test_issue_4279():
     a, b = symbols('a b')
     assert O(a, a, b) + O(1, a, b) == O(1, a, b)
     assert O(b, a, b) + O(1, a, b) == O(1, a, b)
@@ -300,7 +298,7 @@ def test_issue_1180():
     assert O(1, a, b) + O(a + b, a, b) == O(1, a, b)
 
 
-def test_issue_1756():
+def test_issue_4855():
     assert 1/O(1) != O(1)
     assert 1/O(x) != O(1/x)
     assert 1/O(x, (x, oo)) != O(1/x, (x, oo))
@@ -332,7 +330,7 @@ def test_order_noncommutative():
     assert expand((A + Order(x))*A*x) == A*A*x + Order(x**2, x)
 
 
-def test_issue_3654():
+def test_issue_6753():
     assert (1 + x**2)**10000*O(x) == O(x)
 
 
@@ -373,9 +371,9 @@ def test_order_at_infinity():
     assert Order(x**3, (x, oo)) + Order(exp(2/x), (x, oo)) == Order(x**3, (x, oo))
     assert Order(x**-3, (x, oo)) + Order(exp(2/x), (x, oo)) == Order(exp(2/x), (x, oo))
 
-    # issue 4108
+    # issue 7207
     assert Order(exp(x), (x, oo)).expr == Order(2*exp(x), (x, oo)).expr == exp(x)
-    assert Order(y**x, (x, oo)).expr == Order(2*y**x, (x, oo)).expr == y**x
+    assert Order(y**x, (x, oo)).expr == Order(2*y**x, (x, oo)).expr == exp(log(y)*x)
 
 
 def test_mixing_order_at_zero_and_infinity():
@@ -390,9 +388,20 @@ def test_mixing_order_at_zero_and_infinity():
     raises(NotImplementedError, lambda: Order(Order(x), (x, oo)))
 
 
+def test_order_at_some_point():
+    assert Order(x, (x, 1)) == Order(1, (x, 1))
+    assert Order(2*x - 2, (x, 1)) == Order(x - 1, (x, 1))
+    assert Order(-x + 1, (x, 1)) == Order(x - 1, (x, 1))
+    assert Order(x - 1, (x, 1))**2 == Order((x - 1)**2, (x, 1))
+    assert Order(x - 2, (x, 2)) - O(x - 2, (x, 2)) == Order(x - 2, (x, 2))
+
+
 def test_order_subs_limits():
-    # issue 234
+    # issue 3333
     assert (1 + Order(x)).subs(x, 1/x) == 1 + Order(1/x, (x, oo))
     assert (1 + Order(x)).limit(x, 0) == 1
-    # issue 2670
+    # issue 5769
     assert ((x + Order(x**2))/x).limit(x, 0) == 1
+
+    assert Order(x**2).subs(x, y - 1) == Order((y - 1)**2, (y, 1))
+    assert Order(10*x**2, (x, 2)).subs(x, y - 1) == Order(1, (y, 3))
