@@ -4,7 +4,7 @@ for example:
 the expression E**(pi*I) will be converted into -1
 the expression (x+x)**2 will be converted into 4*x**2
 """
-from .simplify import (collect, rcollect, separate, radsimp, ratsimp, fraction,
+from .simplify import (collect, rcollect, radsimp, ratsimp, fraction,
     simplify, trigsimp, powsimp, combsimp, hypersimp, hypersimilar, nsimplify,
     logcombine, separatevars, numer, denom, powdenest, posify, polarify,
     unpolarify, collect_const, signsimp, besselsimp, ratsimpmodprime,
