@@ -4,7 +4,7 @@ from sympy import (
     Wild, acos, asin, atan, atanh, cos, cosh, diff, erf, erfinv, erfc,
     erfcinv, erf2, erf2inv, exp, expand, im, log, pi, re, sec, sin,
     sinh, solve, solve_linear, sqrt, sstr, symbols, sympify, tan, tanh,
-    root, simplify, atan2, arg, Mul, SparseMatrix)
+    root, simplify, atan2, arg, Mul, SparseMatrix, ask, Tuple, nsolve, oo)
 
 from sympy.core.function import nfloat
 from sympy.solvers import solve_linear_system, solve_linear_system_LU, \
@@ -12,10 +12,11 @@ from sympy.solvers import solve_linear_system, solve_linear_system_LU, \
 from sympy.solvers.solvers import _invert, unrad, checksol, posify, _ispow, \
     det_quick, det_perm, det_minor
 
+from sympy.physics.units import cm
 from sympy.polys.rootoftools import RootOf
 
-from sympy.utilities.pytest import slow, XFAIL, raises, skip
-from sympy.utilities.randtest import test_numerically as tn
+from sympy.utilities.pytest import slow, XFAIL, raises, skip, ON_TRAVIS
+from sympy.utilities.randtest import verify_numerically as tn
 
 from sympy.abc import a, b, c, d, k, h, p, x, y, z, t, q, m
 
@@ -91,6 +92,12 @@ def test_guess_transcendental():
 
 
 def test_solve_args():
+    # equation container, issue 5113
+    ans = {x: -3, y: 1}
+    eqs = (x + 5*y - 2, -3*x + 6*y - 15)
+    assert all(solve(container(eqs), x, y) == ans for container in
+        (tuple, list, set, frozenset))
+    assert solve(Tuple(*eqs), x, y) == ans
     # implicit symbol to solve for
     assert set(solve(x**2 - 4)) == set([S(2), -S(2)])
     assert solve([x + y - 3, x - y - 5]) == {x: 4, y: -1}
@@ -112,7 +119,7 @@ def test_solve_args():
     assert solve(a*x**2 + b*x + c -
                 ((x - h)**2 + 4*p*k)/4/p,
                 [h, p, k], exclude=[a, b, c], dict=True) == \
-        [{k: (4*a*c - b**2)/(4*a), h: -b/(2*a), p: 1/(4*a)}]
+        [{k: c - b**2/(4*a), h: -b/(2*a), p: 1/(4*a)}]
     # failing undetermined system
     assert solve(a*x + b**2/(x + 4) - 3*x - 4/x, a, b) == \
         [{a: (-b**2*x + 3*x**3 + 12*x**2 + 4*x + 16)/(x**2*(x + 4))}]
@@ -262,14 +269,14 @@ def test_solve_rational():
 def test_solve_nonlinear():
     assert solve(x**2 - y**2, x, y) == [{x: -y}, {x: y}]
     assert solve(x**2 - y**2/exp(x), x, y) == [{x: 2*LambertW(y/2)}]
-    assert solve(x**2 - y**2/exp(x), y, x) == [{y: -x*exp(x/2)}, {y: x*exp(x/2)}]
+    assert solve(x**2 - y**2/exp(x), y, x) == [{y: -x*sqrt(exp(x))}, {y: x*sqrt(exp(x))}]
 
 
-def test_issue_4129():
+def test_issue_7228():
     assert solve(4**(2*(x**2) + 2*x) - 8, x) == [-Rational(3, 2), S.Half]
 
 
-def test_issue_4091():
+def test_issue_7190():
     assert solve(log(x-3) + log(x+3), x) == [sqrt(10)]
 
 
@@ -313,7 +320,9 @@ def test_linear_systemLU():
 # in such a way that a different branch is chosen
 
 
-def test_tsolve():
+def test_solve_transcendental():
+    from sympy.abc import a, b
+
     assert solve(exp(x) - 3, x) == [log(3)]
     assert set(solve((a*x + b)*(exp(x) - 3), x)) == set([-b/a, log(3)])
     assert solve(cos(x) - y, x) == [-acos(y) + 2*pi, acos(y)]
@@ -366,27 +375,47 @@ def test_tsolve():
 
     assert solve(z*cos(x), x) == [pi/2, 3*pi/2]
 
-    # issue #1409
+    # issue 4508
     assert solve(y - b*x/(a + x), x) in [[-a*y/(y - b)], [a*y/(b - y)]]
     assert solve(y - b*exp(a/x), x) == [a/log(y/b)]
-    # issue #1408
+    # issue 4507
     assert solve(y - b/(1 + a*x), x) in [[(b - y)/(a*y)], [-((y - b)/(a*y))]]
-    # issue #1407
+    # issue 4506
     assert solve(y - a*x**b, x) == [(y/a)**(1/b)]
-    # issue #1406
+    # issue 4505
     assert solve(z**x - y, x) == [log(y)/log(z)]
-    # issue #1405
+    # issue 4504
     assert solve(2**x - 10, x) == [log(10)/log(2)]
-    # issue #3645
+    # issue 6744
     assert solve(x*y) == [{x: 0}, {y: 0}]
     assert solve([x*y]) == [{x: 0}, {y: 0}]
     assert solve(x**y - 1) == [{x: 1}, {y: 0}]
     assert solve([x**y - 1]) == [{x: 1}, {y: 0}]
     assert solve(x*y*(x**2 - y**2)) == [{x: 0}, {x: -y}, {x: y}, {y: 0}]
     assert solve([x*y*(x**2 - y**2)]) == [{x: 0}, {x: -y}, {x: y}, {y: 0}]
-    #issue #1640
+    #issue 4739
     assert solve(exp(log(5)*x) - 2**x, x) == [0]
 
+    # misc
+    # make sure that the right variables is picked up in tsolve
+    raises(NotImplementedError, lambda: solve((exp(x) + 1)**x))
+
+    # shouldn't generate a GeneratorsNeeded error in _tsolve when the NaN is generated
+    # for eq_down. Actual answers, as determined numerically are approx. +/- 0.83
+    assert solve(sinh(x)*sinh(sinh(x)) + cosh(x)*cosh(sinh(x)) - 3) is not None
+
+    # watch out for recursive loop in tsolve
+    raises(NotImplementedError, lambda: solve((x + 2)**y*x - 3, x))
+
+    # issue 7245
+    assert solve(sin(sqrt(x))) == [0, pi**2]
+
+    # issue 7602
+    a, b = symbols('a, b', real=True, negative=False)
+    assert str(solve(Eq(a, 0.5 - cos(pi*b)/2), b)) == \
+        '[-0.318309886183791*acos(-2.0*a + 1.0) + 2.0, 0.318309886183791*acos(-2.0*a + 1.0)]'
+
+
 def test_solve_for_functions_derivatives():
     t = Symbol('t')
     x = Function('x')(t)
@@ -427,14 +456,14 @@ def test_solve_for_functions_derivatives():
             x: (a22*b1 - a12*b2)/(a11*a22 - a12*a21) }
 
 
-def test_issue626():
+def test_issue_3725():
     f = Function('f')
     F = x**2 + f(x)**2 - 4*x - 1
     e = F.diff(x)
     assert solve(e, f(x).diff(x)) in [[(2 - x)/f(x)], [-((x - 2)/f(x))]]
 
 
-def test_issue771():
+def test_issue_3870():
     a, b, c, d = symbols('a b c d')
     A = Matrix(2, 2, [a, b, c, d])
     B = Matrix(2, 2, [0, 2, -3, 0])
@@ -487,19 +516,25 @@ def test_solve_undetermined_coeffs():
 
 
 def test_solve_inequalities():
+    x = Symbol('x')
     system = [Lt(x**2 - 2, 0), Gt(x**2 - 1, 0)]
 
     assert solve(system) == \
         And(Or(And(Lt(-sqrt(2), re(x)), Lt(re(x), -1)),
                And(Lt(1, re(x)), Lt(re(x), sqrt(2)))), Eq(im(x), 0))
-    assert solve(system, assume=Q.real(x)) == \
+
+    x = Symbol('x', real=True)
+    system = [Lt(x**2 - 2, 0), Gt(x**2 - 1, 0)]
+
+    assert solve(system) == \
         Or(And(Lt(-sqrt(2), x), Lt(x, -1)), And(Lt(1, x), Lt(x, sqrt(2))))
 
-    # issue 3528, 3448
-    assert solve((x - 3)/(x - 2) < 0, x, assume=Q.real(x)) == And(Lt(2, x), Lt(x, 3))
-    assert solve(x/(x + 1) > 1, x, assume=Q.real(x)) == Lt(x, -1)
+    # issue 6627, 3448
+    assert solve((x - 3)/(x - 2) < 0, x) == And(Lt(2, x), Lt(x, 3))
+    assert solve(x/(x + 1) > 1, x) == And(Lt(-oo, x), Lt(x, -1))
 
-def test_issue_1694():
+
+def test_issue_4793():
     assert solve(1/x) == []
     assert solve(x*(1 - 5/x)) == [5]
     assert solve(x + sqrt(x) - 2) == [1]
@@ -525,20 +560,20 @@ def test_issue_1694():
 
 
 def test_PR1964():
-    # 2072
+    # issue 5171
     assert solve(sqrt(x)) == solve(sqrt(x**3)) == [0]
     assert solve(sqrt(x - 1)) == [1]
-    # 1363
+    # issue 4462
     a = Symbol('a')
     assert solve(-3*a/sqrt(x), x) == []
-    # 1387
+    # issue 4486
     assert solve(2*x/(x + 2) - 1, x) == [2]
-    # 1397
+    # issue 4496
     assert set(solve((x**2/(7 - x)).diff(x))) == set([S(0), S(14)])
-    # 1596
+    # issue 4695
     f = Function('f')
     assert solve((3 - 5*x/f(x))*f(x), f(x)) == [5*x/3]
-    # 1398
+    # issue 4497
     assert solve(1/(5 + x)**(S(1)/5) - 9, x) == [-295244/S(59049)]
 
     assert solve(sqrt(x) + sqrt(sqrt(x)) - 4) == [-9*sqrt(17)/2 + 49*S.Half]
@@ -568,7 +603,7 @@ def test_PR1964():
     assert solve((1/p + 1)**(p + 1)) == []
 
 
-def test_issue_2098():
+def test_issue_5197():
     x = Symbol('x', real=True)
     assert solve(x**2 + 1, x) == []
     n = Symbol('n', integer=True, positive=True)
@@ -597,7 +632,7 @@ def test_checking():
     assert solve(1/(1/x + 2)) == []
 
 
-def test_issue_1572_1364_1368():
+def test_issue_4671_4463_4467():
     assert solve((sqrt(x**2 - 1) - 2)) in ([sqrt(5), -sqrt(5)],
                                            [-sqrt(5), sqrt(5)])
     assert set(solve((2**exp(y**2/x) + 2)/(x**2 + 15), y)) == set([
@@ -628,14 +663,12 @@ def test_issue_1572_1364_1368():
     assert solve(atan(x) - 1) == [tan(1)]
 
 
-def test_issue_2033():
+def test_issue_5132():
     r, t = symbols('r,t')
     assert set(solve([r - x**2 - y**2, tan(t) - y/x], [x, y])) == \
-        set([
-            (-sqrt(r*tan(t)**2/(tan(t)**2 + 1))/tan(t),
-        -sqrt(r*tan(t)**2/(tan(t)**2 + 1))),
-        (sqrt(r*tan(t)**2/(tan(t)**2 + 1))/tan(t),
-        sqrt(r*tan(t)**2/(tan(t)**2 + 1)))])
+        set([(
+            -sqrt(r*sin(t)**2)/tan(t), -sqrt(r*sin(t)**2)),
+            (sqrt(r*sin(t)**2)/tan(t), sqrt(r*sin(t)**2))])
     assert solve([exp(x) - sin(y), 1/y - 3], [x, y]) == \
         [(log(sin(S(1)/3)), S(1)/3)]
     assert solve([exp(x) - sin(y), 1/exp(y) - 3], [x, y]) == \
@@ -680,7 +713,7 @@ def test_issue_2033():
         set([(S(1), S(3)), (S(3), S(1))])
 
 
-def test_issue_2236():
+def test_issue_5335():
     lam, a0, conc = symbols('lam a0 conc')
     eqs = [lam + 2*y - a0*(1 - x/2)*x - 0.005*x/2*x,
            a0*(1 - x/2)*x - 1*y - 0.743436700916726*y,
@@ -690,7 +723,7 @@ def test_issue_2236():
     assert len(solve(eqs, sym, manual=True, minimal=True, simplify=False)) == 2
 
 
-def test_issue_2236_float():
+def test_issue_5335_float():
     skip("This test hangs.")
     lam, a0, conc = symbols('lam a0 conc')
     eqs = [lam + 2*y - a0*(1 - x/2)*x - 0.005*x/2*x,
@@ -701,7 +734,7 @@ def test_issue_2236_float():
         solve(eqs, sym, rational=False, check=False, simplify=False)) == 2
 
 
-def test_issue_2668():
+def test_issue_5767():
     assert set(solve([x**2 + y + 4], [x])) == \
         set([(-sqrt(-y - 4),), (sqrt(-y - 4),)])
 
@@ -720,7 +753,7 @@ def test_unrad():
     s = symbols('s', cls=Dummy)
 
     # checkers to deal with possibility of answer coming
-    # back with a sign change (cf issue 2104)
+    # back with a sign change (cf issue 5203)
     def check(rv, ans):
         rv, ans = list(rv), list(ans)
         rv[0] = rv[0].expand()
@@ -884,7 +917,7 @@ def test_unrad_slow():
                 sqrt(1 - x) - sqrt(2 + x))
     assert len(ans) == 1 and NS(ans[0])[:4] == '0.73'
     # the fence optimization problem
-    # http://code.google.com/p/sympy/issues/detail?id=1694#c159
+    # https://github.com/sympy/sympy/issues/4793#issuecomment-36994519
     F = Symbol('F')
     eq = F - (2*x + 2*y + sqrt(x**2 + y**2))
     X = solve(eq, x, hint='minimal')[0]
@@ -908,7 +941,7 @@ def test__invert():
     assert _invert(a, x) == (a, 0)
 
 
-def test_issue_1364():
+def test_issue_4463():
     assert solve(-a*x + 2*x*log(x), x) == [exp(a/2)]
     assert solve(a/x + exp(x/2), x) == [2*LambertW(-a/2)]
     assert solve(x**x) == []
@@ -918,7 +951,7 @@ def test_issue_1364():
         (a/x + exp(x/2)).diff(x), x) == [4*LambertW(sqrt(2)*sqrt(a)/4)]
 
 
-def test_issue_2015():
+def test_issue_5114():
     a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r = symbols('a:r')
 
     # there is no 'a' in the equation set but this is how the
@@ -933,12 +966,7 @@ def test_issue_2015():
     assert len(solve(eqs, syms, manual=True, check=False, simplify=False)) == 1
 
 
-def test_misc():
-    # make sure that the right variables is picked up in tsolve
-    raises(NotImplementedError, lambda: solve((exp(x) + 1)**x))
-
-
-def test_issue_2750():
+def test_issue_5849():
     I1, I2, I3, I4, I5, I6 = symbols('I1:7')
     dI1, dI4, dQ2, dQ4, Q2, Q4 = symbols('dI1,dI4,dQ2,dQ4,Q2,Q4')
 
@@ -964,12 +992,12 @@ def test_issue_2750():
     Q4: -I3/2 + 3*I5/2 - dI4/2}]
     assert solve(e, I1, I4, Q2, Q4, dI1, dI4, dQ2, dQ4, manual=True) == ans
     # the matrix solver (tested below) doesn't like this because it produces
-    # a zero row in the matrix. Is this related to issue 1452?
+    # a zero row in the matrix. Is this related to issue 4551?
     assert [ei.subs(
         ans[0]) for ei in e] == [0, 0, I3 - I6, -I3 + I6, 0, 0, 0, 0, 0]
 
 
-def test_2750_matrix():
+def test_issue_5849_matrix():
     '''Same as test_2750 but solved with the matrix solver.'''
     I1, I2, I3, I4, I5, I6 = symbols('I1:7')
     dI1, dI4, dQ2, dQ4, Q2, Q4 = symbols('dI1,dI4,dQ2,dQ4,Q2,Q4')
@@ -995,7 +1023,7 @@ def test_2750_matrix():
         I4: I3 - I5}
 
 
-def test_issue_2802():
+def test_issue_5901():
     f, g, h = map(Function, 'fgh')
     a = Symbol('a')
     D = Derivative(f(x), x)
@@ -1062,7 +1090,7 @@ def test_issue_2802():
         [-x + 3]
 
 
-def test_issue_2813():
+def test_issue_5912():
     assert set(solve(x**2 - x - 0.1, rational=True)) == \
         set([S(1)/2 + sqrt(35)/10, -sqrt(35)/10 + S(1)/2])
     # [-0.0916079783099616, 1.09160797830996]
@@ -1103,13 +1131,7 @@ def test_check_assumptions():
     assert solve(x**2 - 1) == [1]
 
 
-def test_solve_abs():
-    assert set(solve(abs(x - 7) - 8)) == set([-S(1), S(15)])
-    r = symbols('r', real=True)
-    raises(NotImplementedError, lambda: solve(2*abs(r) - abs(r - 1)))
-
-
-def test_issue_2957():
+def test_issue_6056():
     assert solve(tanh(x + 3)*tanh(x - 3) - 1) == []
     assert set([simplify(w) for w in solve(tanh(x - 1)*tanh(x + 1) + 1)]) == set([
         -log(2)/2 + log(1 - I),
@@ -1123,7 +1145,7 @@ def test_issue_2957():
         -log(2)/2 + log(-1 + I),])
 
 
-def test_issue_2961():
+def test_issue_6060():
     x = Symbol('x')
     absxm3 = Piecewise(
         (x - 3, S(0) <= x - 3),
@@ -1138,7 +1160,7 @@ def test_issue_2961():
     assert solve(absxm3 - y, x) == [-y + 3, y + 3]
 
 
-def test_issue_2574():
+def test_issue_5673():
     eq = -x + exp(exp(LambertW(log(x)))*LambertW(log(x)))
     assert checksol(eq, x, 2) is True
     assert checksol(eq, x, 2, numerical=False) is None
@@ -1156,8 +1178,8 @@ def test_exclude():
         {
             Rf: Ri*(C*R*s + 1)**2/(C*R*s),
             Vminus: Vplus,
-            V1: Vplus*(2*C*R*s + 1)/(C*R*s),
-            Vout: Vplus*(C**2*R**2*s**2 + 3*C*R*s + 1)/(C*R*s)},
+            V1: 2*Vplus + Vplus/(C*R*s),
+            Vout: C*R*Vplus*s + 3*Vplus + Vplus/(C*R*s)},
         {
             Vplus: 0,
             Vminus: 0,
@@ -1201,13 +1223,15 @@ def test_minsolve_linear_system():
 
 
 def test_real_roots():
-    # cf. issue 3551
+    # cf. issue 6650
     x = Symbol('x', real=True)
     assert len(solve(x**5 + x**3 + 1)) == 1
 
 
 @slow
-def test_issue3429():
+def test_issue_6528():
+    if ON_TRAVIS:
+        skip("Too slow for travis.")
     eqs = [
         327600995*x**2 - 37869137*x + 1809975124*y**2 - 9998905626,
         895613949*x**2 - 273830224*x*y + 530506983*y**2 - 10000000000]
@@ -1215,13 +1239,14 @@ def test_issue3429():
 
 
 def test_overdetermined():
+    x = symbols('x', real=True)
     eqs = [Abs(4*x - 7) - 5, Abs(3 - 8*x) - 1]
     assert solve(eqs, x) == [(S.Half,)]
     assert solve(eqs, x, manual=True) == [(S.Half,)]
-    assert solve(eqs, x, manual=True, check=False) == [(S.Half/2,), (S.Half,)]
+    assert solve(eqs, x, manual=True, check=False) == [(S.Half,), (S(3),)]
 
 
-def test_issue_3506():
+def test_issue_6605():
     x = symbols('x')
     assert solve(4**(x/2) - 2**(x/3)) == [0]
     # while the first one passed, this one failed
@@ -1237,7 +1262,7 @@ def test__ispow():
     assert not _ispow(True)
 
 
-def test_issue_3545():
+def test_issue_6644():
     eq = -sqrt((m - q)**2 + (-m/(2*q) + S(1)/2)**2) + sqrt((-m**2/2 - sqrt(
     4*m**4 - 4*m**2 + 8*m + 1)/4 - S(1)/4)**2 + (m**2/2 - m - sqrt(
     4*m**4 - 4*m**2 + 8*m + 1)/4 - S(1)/4)**2)
@@ -1246,46 +1271,64 @@ def test_issue_3545():
         m**2/2 + sqrt(4*m**4 - 4*m**2 + 8*m + 1)/4 - S(1)/4]
 
 
-def test_issue_3653():
+def test_issue_6752():
     assert solve([a**2 + a, a - b], [a, b]) == [(-1, -1), (0, 0)]
     assert solve([a**2 + a*c, a - b], [a, b]) == [(0, 0), (-c, -c)]
 
 
-def test_issue_3693():
+def test_issue_6792():
     assert solve(x*(x - 1)**2*(x + 1)*(x**6 - x + 1)) == [
     -1, 0, 1, RootOf(x**6 - x + 1, 0), RootOf(x**6 - x + 1, 1),
     RootOf(x**6 - x + 1, 2), RootOf(x**6 - x + 1, 3), RootOf(x**6 - x + 1, 4),
     RootOf(x**6 - x + 1, 5)]
 
 
-def test_issues_3720_3721_3722_3149():
-    # 3722
-    x, y = symbols('x y')
+def test_issues_6819_6820_6821_6248():
+    # issue 6821
+    x, y = symbols('x y', real=True)
     assert solve(abs(x + 3) - 2*abs(x - 3)) == [1, 9]
-    assert solve([abs(x) - 2, arg(x) - pi], x) == [
-        {re(x): -2, x: -2, im(x): 0}, {re(x): 2, x: 2, im(x): 0}]
+    assert solve([abs(x) - 2, arg(x) - pi], x) == [(-2,), (2,)]
+    assert set(solve(abs(x - 7) - 8)) == set([-S(1), S(15)])
+
+    # issue 7145
+    assert solve(2*abs(x) - abs(x - 1)) == [-1, Rational(1, 3)]
+
+    x = symbols('x')
     assert solve([re(x) - 1, im(x) - 2], x) == [
         {re(x): 1, x: 1 + 2*I, im(x): 2}]
 
+    # check for 'dict' handling of solution
+    eq = sqrt(re(x)**2 + im(x)**2) - 3
+    assert solve(eq) == solve(eq, x)
+
+    i = symbols('i', imaginary=True)
+    assert solve(abs(i) - 3) == [-3*I, 3*I]
+    raises(NotImplementedError, lambda: solve(abs(x) - 3))
+
     w = symbols('w', integer=True)
     assert solve(2*x**w - 4*y**w, w) == solve((x/y)**w - 2, w)
+
     x, y = symbols('x y', real=True)
     assert solve(x + y*I + 3) == {y: 0, x: -3}
-    # github issue 2642
+    # issue 2642
     assert solve(x*(1 + I)) == [0]
+
     x, y = symbols('x y', imaginary=True)
     assert solve(x + y*I + 3 + 2*I) == {x: -2*I, y: 3*I}
+
     x = symbols('x', real=True)
     assert solve(x + y + 3 + 2*I) == {x: -3, y: -2*I}
-    # issue 3149
+
+    # issue 6248
     f = Function('f')
     assert solve(f(x + 1) - f(2*x - 1)) == [2]
     assert solve(log(x + 1) - log(2*x - 1)) == [2]
+
     x = symbols('x')
     assert solve(2**x + 4**x) == [I*pi/log(2)]
 
 
-def test_issue_3890():
+def test_issue_6989():
     f = Function('f')
     assert solve(Eq(-f(x), Piecewise((1, x > 0), (0, True))), f(x)) == \
         [Piecewise((-1, x > 0), (0, True))]
@@ -1324,7 +1367,7 @@ def test_lambert_multivariate():
     assert _solve_lambert(eq, p, _filtered_gens(Poly(eq), p)) == [
         -S(3)/2 - LambertW(-4*log(2))/(2*log(2))]
 
-    # issue 1172
+    # issue 4271
     assert solve((a/x + exp(x/2)).diff(x, 2), x) == [
         6*LambertW((-1)**(S(1)/3)*a**(S(1)/3)/3)]
 
@@ -1364,6 +1407,10 @@ def test_rewrite_trig():
         2*atan(S.Half + sqrt(2 + 2*sqrt(3)*I)/2 + sqrt(3)*I/2)]
     assert solve(sinh(x) + tanh(x)) == [0, I*pi]
 
+    # issue 6157
+    assert solve(2*sin(x) - cos(x), x) == [-2*atan(2 + sqrt(5)),
+                                           -2*atan(-sqrt(5) + 2)]
+
 
 @XFAIL
 def test_rewrite_trigh():
@@ -1394,16 +1441,7 @@ def test_errorinverses():
     assert solve(erfcinv(x)-y,x)==[erfc(y)]
 
 
-def test_misc():
-    # shouldn't generate a GeneratorsNeeded error in _tsolve when the NaN is generated
-    # for eq_down. Actual answers, as determined numerically are approx. +/- 0.83
-    assert solve(sinh(x)*sinh(sinh(x)) + cosh(x)*cosh(sinh(x)) - 3) is not None
-
-    # watch out for recursive loop in tsolve
-    raises(NotImplementedError, lambda: solve((x+2)**y*x-3,x))
-
-
-def test_gh2725():
+def test_issue_2725():
     R = Symbol('R')
     eq = sqrt(2)*R*sqrt(1/(R + 1)) + (R + 1)*(sqrt(2)*sqrt(1/(R + 1)) - 1)
     sol = solve(eq, R, set=True)[1]
@@ -1416,10 +1454,10 @@ def test_gh2725():
                        evaluate=False),)])
 
 
-def test_issue_2015_3512():
+def test_issue_5114_6611():
     # See that it doesn't hang; this solves in about 2 seconds.
     # Also check that the solution is relatively small.
-    # Note: the system in issue 3512 solves in about 5 seconds and has
+    # Note: the system in issue 6611 solves in about 5 seconds and has
     # an op-count of 138336 (with simplify=False).
     b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r = symbols('b:r')
     eqs = Matrix([
@@ -1443,3 +1481,60 @@ def test_det_quick():
     # make sure they work with Sparse
     s = SparseMatrix(2, 2, (1, 2, 1, 4))
     assert det_perm(s) == det_minor(s) == s.det()
+
+
+def test_piecewise():
+    # if no symbol is given the piecewise detection must still work
+    assert solve(Piecewise((x - 2, Gt(x, 2)), (2 - x, True)) - 3) == [-1, 5]
+
+
+def test_real_imag_splitting():
+    a, b = symbols('a b', real=True)
+    assert solve(sqrt(a**2 + b**2) - 3, a) == \
+        [-sqrt(-b**2 + 9), sqrt(-b**2 + 9)]
+    a, b = symbols('a b', imaginary=True)
+    assert solve(sqrt(a**2 + b**2) - 3, a) == []
+
+
+def test_issue_7110():
+    y = -2*x**3 + 4*x**2 - 2*x + 5
+    assert any(ask(Q.real(i)) for i in solve(y))
+
+
+def test_units():
+    assert solve(1/x - 1/(2*cm)) == [2*cm]
+
+
+def test_issue_7547():
+    A, B, V = symbols('A,B,V')
+    eq1 = Eq(630.26*(V - 39.0)*V*(V + 39) - A + B, 0)
+    eq2 = Eq(B, 1.36*10**8*(V - 39))
+    eq3 = Eq(A, 5.75*10**5*V*(V + 39.0))
+    sol = Matrix(nsolve(Tuple(eq1, eq2, eq3), [A, B, V], (0, 0, 0)))
+    assert str(sol) == str(Matrix(
+        [['4442890172.68209'],
+         ['4289299466.1432'],
+         ['70.5389666628177']]))
+
+
+def test_issue_7895():
+    r = symbols('r', real=True)
+    assert solve(sqrt(r) - 2) == [4]
+
+
+def test_issue_2777():
+    # the equations represent two circles
+    x, y = symbols('x y', real=True)
+    e1, e2 = sqrt(x**2 + y**2) - 10, sqrt(y**2 + (-x + 10)**2) - 3
+    a, b = 191/S(20), 3*sqrt(391)/20
+    ans = [(a, -b), (a, b)]
+    assert solve((e1, e2), (x, y)) == ans
+    assert solve((e1, e2/(x - a)), (x, y)) == []
+    # make the 2nd circle's radius be -3
+    e2 += 6
+    assert solve((e1, e2), (x, y)) == []
+    assert solve((e1, e2), (x, y), check=False) == ans
+
+def test_issue_7322():
+    number = 5.62527e-35
+    assert solve(x - number, x)[0] == number
