@@ -1,3 +1,4 @@
+from __future__ import division
 from sympy.stats import (P, E, where, density, variance, covariance, skewness,
                          given, pspace, cdf, ContinuousRV, sample,
                          Arcsin, Benini, Beta, BetaPrime, Cauchy,
@@ -15,7 +16,7 @@ from sympy import (Symbol, Dummy, Abs, exp, S, N, pi, simplify, Interval, erf,
                    Eq, log, lowergamma, Sum, symbols, sqrt, And, gamma, beta,
                    Eq, log, lowergamma, Sum, symbols, sqrt, And, gamma, beta,
                    Piecewise, Integral, sin, cos, besseli, factorial, binomial,
-                   floor)
+                   floor, expand_func)
 
 
 from sympy.stats.crv_types import NormalDistribution
@@ -31,8 +32,8 @@ x, y, z = map(Symbol, 'xyz')
 
 
 def test_single_normal():
-    mu = Symbol('mu', real=True, bounded=True)
-    sigma = Symbol('sigma', real=True, positive=True, bounded=True)
+    mu = Symbol('mu', real=True, finite=True)
+    sigma = Symbol('sigma', real=True, positive=True, finite=True)
     X = Normal('x', 0, 1)
     Y = X*sigma + mu
 
@@ -97,13 +98,13 @@ def test_multiple_normal():
 
 @slow
 def test_symbolic():
-    mu1, mu2 = symbols('mu1 mu2', real=True, bounded=True)
-    s1, s2 = symbols('sigma1 sigma2', real=True, bounded=True, positive=True)
-    rate = Symbol('lambda', real=True, positive=True, bounded=True)
+    mu1, mu2 = symbols('mu1 mu2', real=True, finite=True)
+    s1, s2 = symbols('sigma1 sigma2', real=True, finite=True, positive=True)
+    rate = Symbol('lambda', real=True, positive=True, finite=True)
     X = Normal('x', mu1, s1)
     Y = Normal('y', mu2, s2)
     Z = Exponential('z', rate)
-    a, b, c = symbols('a b c', real=True, bounded=True)
+    a, b, c = symbols('a b c', real=True, finite=True)
 
     assert E(X) == mu1
     assert E(X + Y) == mu1 + mu2
@@ -194,17 +195,16 @@ def test_beta():
     # Full symbolic solution is too much, test with numeric version
     a, b = 1, 2
     B = Beta('x', a, b)
-    assert E(B) == a / S(a + b)
-    assert variance(B) == (a*b) / S((a + b)**2 * (a + b + 1))
+    assert expand_func(E(B)) == a / S(a + b)
+    assert expand_func(variance(B)) == (a*b) / S((a + b)**2 * (a + b + 1))
 
 
 def test_betaprime():
     alpha = Symbol("alpha", positive=True)
-    beta = Symbol("beta", positive=True)
+    betap = Symbol("beta", positive=True)
 
-    X = BetaPrime('x', alpha, beta)
-    assert density(X)(x) == (x**(alpha - 1)*(x + 1)**(-alpha - beta)
-                          *gamma(alpha + beta)/(gamma(alpha)*gamma(beta)))
+    X = BetaPrime('x', alpha, betap)
+    assert density(X)(x) == x**(alpha - 1)*(x + 1)**(-alpha - betap)/beta(alpha, betap)
 
 
 def test_cauchy():
@@ -251,7 +251,7 @@ def test_erlang():
     assert density(X)(x) == x**(k - 1)*l**k*exp(-x*l)/gamma(k)
 
 def test_exponential():
-    rate = Symbol('lambda', positive=True, real=True, bounded=True)
+    rate = Symbol('lambda', positive=True, real=True, finite=True)
     X = Exponential('x', rate)
 
     assert E(X) == 1/rate
@@ -271,17 +271,16 @@ def test_f_distribution():
     d2 = Symbol("d2", positive=True)
 
     X = FDistribution("x", d1, d2)
-    assert density(X)(x) == (d2**(d2/2)*sqrt((x*d1)**d1 *
-        (x*d1 + d2)**(-d1 - d2))*gamma(d1/2 + d2/2)/(x*gamma(d1/2)*gamma(d2/2)))
+    assert density(X)(x) == (d2**(d2/2)*sqrt((d1*x)**d1*(d1*x + d2)**(-d1 - d2))
+                             /(x*beta(d1/2, d2/2)))
 
 def test_fisher_z():
     d1 = Symbol("d1", positive=True)
     d2 = Symbol("d2", positive=True)
 
     X = FisherZ("x", d1, d2)
-    assert density(X)(x) == (2*d1**(d1/2)*d2**(d2/2)*
-            (d1*exp(2*x) + d2)**(-d1/2 - d2/2)*
-             exp(x*d1)*gamma(d1/2 + d2/2)/(gamma(d1/2)*gamma(d2/2)))
+    assert density(X)(x) == (2*d1**(d1/2)*d2**(d2/2)*(d1*exp(2*x) + d2)
+                             **(-d1/2 - d2/2)*exp(d1*x)/beta(d1/2, d2/2))
 
 def test_frechet():
     a = Symbol("a", positive=True)
@@ -304,7 +303,7 @@ def test_gamma():
     # assert simplify(variance(X)) == k*theta**2  # handled numerically below
     assert E(X) == moment(X, 1)
 
-    k, theta = symbols('k theta', real=True, bounded=True, positive=True)
+    k, theta = symbols('k theta', real=True, finite=True, positive=True)
     X = Gamma('x', k, theta)
     assert simplify(E(X)) == k*theta
     # can't get things to simplify on this one so we use subs
@@ -341,8 +340,8 @@ def test_logistic():
     assert density(X)(x) == exp((-x + mu)/s)/(s*(exp((-x + mu)/s) + 1)**2)
 
 def test_lognormal():
-    mean = Symbol('mu', real=True, bounded=True)
-    std = Symbol('sigma', positive=True, real=True, bounded=True)
+    mean = Symbol('mu', real=True, finite=True)
+    std = Symbol('sigma', positive=True, real=True, finite=True)
     X = LogNormal('x', mean, std)
     # The sympy integrator can't do this too well
     #assert E(X) == exp(mean+std**2/2)
@@ -391,7 +390,7 @@ def test_nakagami():
 
 
 def test_pareto():
-    xm, beta = symbols('xm beta', positive=True, bounded=True)
+    xm, beta = symbols('xm beta', positive=True, finite=True)
     alpha = beta + 5
     X = Pareto('x', xm, alpha)
 
@@ -436,8 +435,7 @@ def test_studentt():
     nu = Symbol("nu", positive=True)
 
     X = StudentT('x', nu)
-    assert density(X)(x) == ((x**2/nu + 1)**(-nu/2 - S.Half)
-                        *gamma(nu/2 + S.Half)/(sqrt(pi)*sqrt(nu)*gamma(nu/2)))
+    assert density(X)(x) == (1 + x**2/nu)**(-nu/2 - 1/2)/(sqrt(nu)*beta(1/2, nu/2))
 
 
 @XFAIL
@@ -463,8 +461,8 @@ def test_quadratic_u():
                           And(x <= b, a <= x)), (0, True)))
 
 def test_uniform():
-    l = Symbol('l', real=True, bounded=True)
-    w = Symbol('w', positive=True, bounded=True)
+    l = Symbol('l', real=True, finite=True)
+    w = Symbol('w', positive=True, finite=True)
     X = Uniform('x', l, l + w)
 
     assert simplify(E(X)) == l + w/2
@@ -476,7 +474,7 @@ def test_uniform():
     assert P(X < 3) == 0 and P(X > 5) == 0
     assert P(X < 4) == P(X > 4) == S.Half
 
-@XFAIL
+
 def test_uniform_P():
     """ This stopped working because SingleContinuousPSpace.compute_density no
     longer calls integrate on a DiracDelta but rather just solves directly.
@@ -486,8 +484,8 @@ def test_uniform_P():
     I decided to regress on this class for general cleanliness (and I suspect
     speed) of the algorithm.
     """
-    l = Symbol('l', real=True, bounded=True)
-    w = Symbol('w', positive=True, bounded=True)
+    l = Symbol('l', real=True, finite=True)
+    w = Symbol('w', positive=True, finite=True)
     X = Uniform('x', l, l + w)
     assert P(X < l) == 0 and P(X > l + w) == 0
 
