@@ -2,9 +2,9 @@ from sympy import (EmptySet, FiniteSet, S, Symbol, Interval, exp, erf, sqrt,
         symbols, simplify, Eq, cos, And, Tuple, Or, Dict, sympify, binomial,
         factor, cancel)
 from sympy.stats import (DiscreteUniform, Die, Bernoulli, Coin, Binomial,
-        Hypergeometric, P, E, variance, covariance, skewness, sample, density,
-        given, independent, dependent, where, FiniteRV, pspace, cdf,
-        correlation, moment, cmoment, smoment)
+    Hypergeometric, Rademacher, P, E, variance, covariance, skewness, sample,
+    density, given, independent, dependent, where, FiniteRV, pspace, cdf,
+    correlation, moment, cmoment, smoment)
 from sympy.utilities.pytest import raises, slow
 from sympy.abc import p
 
@@ -116,10 +116,10 @@ def test_domains():
 
     assert where(X > 3).set == FiniteSet(4, 5, 6)
     assert X.pspace.domain.dict == FiniteSet(
-        Dict({X.symbol: i}) for i in range(1, 7))
+        *[Dict({X.symbol: i}) for i in range(1, 7)])
 
-    assert where(X > Y).dict == FiniteSet(Dict({X.symbol: i, Y.symbol: j})
-            for i in range(1, 7) for j in range(1, 7) if i > j)
+    assert where(X > Y).dict == FiniteSet(*[Dict({X.symbol: i, Y.symbol: j})
+            for i in range(1, 7) for j in range(1, 7) if i > j])
 
 
 def test_dice_bayes():
@@ -130,6 +130,16 @@ def test_dice_bayes():
     BayesTest(X > 3, X > 2)
 
 
+def test_die_args():
+    raises(ValueError, lambda: Die('X', -1))  # issue 8105: negative sides.
+    raises(ValueError, lambda: Die('X', 0))
+    raises(ValueError, lambda: Die('X', 1.5))  # issue 8103: non integer sides.
+
+    k = Symbol('k')
+    sym_die = Die('X', k)
+    raises(ValueError, lambda: density(sym_die).dict)
+
+
 def test_bernoulli():
     p, a, b = symbols('p a b')
     X = Bernoulli('B', p, a, b)
@@ -171,6 +181,9 @@ def test_coins():
 
     raises(ValueError, lambda: P(C > D))  # Can't intelligently compare H to T
 
+def test_binomial_verify_parameters():
+    raises(ValueError, lambda: Binomial('b', .2, .5))
+    raises(ValueError, lambda: Binomial('b', 3, 1.5))
 
 def test_binomial_numeric():
     nvals = range(5)
@@ -217,6 +230,15 @@ def test_hypergeometric_numeric():
                         / (sqrt(n*m*(N - m)*(N - n))*(N - 2)))
 
 
+def test_rademacher():
+    X = Rademacher('X')
+
+    assert E(X) == 0
+    assert variance(X) == 1
+    assert density(X)[-1] == S.Half
+    assert density(X)[1] == S.Half
+
+
 def test_FiniteRV():
     F = FiniteRV('F', {1: S.Half, 2: S.One/4, 3: S.One/4})
 
