@@ -1,17 +1,24 @@
+from __future__ import print_function, division
+
+from sympy.core.decorators import wraps
+from sympy.core.compatibility import xrange
+
 
 def recurrence_memo(initial):
     """
     Memo decorator for sequences defined by recurrence
-    
+
     See usage examples e.g. in the specfun/combinatorial module
     """
     cache = initial
+
     def decorator(f):
+        @wraps(f)
         def g(n):
             L = len(cache)
             if n <= L - 1:
                 return cache[n]
-            for i in xrange(L, n+1):
+            for i in xrange(L, n + 1):
                 cache.append(f(i, cache))
             return cache[-1]
         return g
@@ -29,13 +36,15 @@ def assoc_recurrence_memo(base_seq):
     """
 
     cache = []
+
     def decorator(f):
-        def g(n,m):
+        @wraps(f)
+        def g(n, m):
             L = len(cache)
             if n < L:
                 return cache[n][m]
 
-            for i in xrange(L,n+1):
+            for i in xrange(L, n + 1):
                 # get base sequence
                 F_i0 = base_seq(i)
                 F_i_cache = [F_i0]
@@ -43,14 +52,11 @@ def assoc_recurrence_memo(base_seq):
 
                 # XXX only works for m <= n cases
                 # generate assoc sequence
-                for j in xrange(1,i+1):
-                    F_ij = f(i,j, cache)
+                for j in xrange(1, i + 1):
+                    F_ij = f(i, j, cache)
                     F_i_cache.append(F_ij)
 
             return cache[n][m]
 
         return g
     return decorator
-
-
-
