@@ -1,3 +1,4 @@
+from __future__ import print_function
 from textwrap import dedent
 
 from sympy import (
@@ -6,14 +7,17 @@ from sympy import (
 from sympy.combinatorics import RGS_enum, RGS_unrank, Permutation
 from sympy.utilities.iterables import (
     _partition, _set_partitions, binary_partitions, bracelets, capture,
-    cartes, common_prefix, common_suffix, dict_merge, flatten,
-    generate_bell, generate_derangements, generate_involutions,
+    cartes, common_prefix, common_suffix, dict_merge, filter_symbols,
+    flatten, generate_bell, generate_derangements, generate_involutions,
     generate_oriented_forest, group, has_dups, kbins, minlex, multiset,
-    multiset_combinations, multiset_partitions, multiset_permutations,
-    necklaces, numbered_symbols, ordered, partitions, permutations,
-    postfixes, postorder_traversal, prefixes, reshape, rotate_left,
-    rotate_right, runs, sift, subsets, take, topological_sort, unflatten,
-    uniq, variations)
+    multiset_combinations, multiset_partitions,
+    multiset_permutations, necklaces, numbered_symbols, ordered, partitions,
+    permutations, postfixes, postorder_traversal, prefixes, reshape,
+    rotate_left, rotate_right, runs, sift, subsets, take, topological_sort,
+    unflatten, uniq, variations)
+from sympy.utilities.enumerative import (
+    factoring_visitor, multiset_partitions_taocp )
+
 from sympy.core.singleton import S
 from sympy.functions.elementary.piecewise import Piecewise, ExprCondPair
 from sympy.utilities.pytest import raises
@@ -161,10 +165,16 @@ def test_cartes():
     assert list(cartes('a', repeat=2)) == [('a', 'a')]
     assert list(cartes(list(range(2)))) == [(0,), (1,)]
 
+def test_filter_symbols():
+    s = numbered_symbols()
+    filtered = filter_symbols(s, symbols("x0 x2 x3"))
+    assert take(filtered, 3) == list(symbols("x1 x4 x5"))
 
 def test_numbered_symbols():
     s = numbered_symbols(cls=Dummy)
     assert isinstance(next(s), Dummy)
+    assert next(numbered_symbols('C', start=1, exclude=[symbols('C1')])) == \
+        symbols('C2')
 
 
 def test_sift():
@@ -286,7 +296,24 @@ def test_multiset_partitions():
     assert list(multiset_partitions('ab', 1)) == [[['a', 'b']]]
     assert list(multiset_partitions('aaa', 1)) == [['aaa']]
     assert list(multiset_partitions([1, 1], 1)) == [[[1, 1]]]
-
+    ans = [('mpsyy',), ('mpsy', 'y'), ('mps', 'yy'), ('mps', 'y', 'y'),
+           ('mpyy', 's'), ('mpy', 'sy'), ('mpy', 's', 'y'), ('mp', 'syy'),
+           ('mp', 'sy', 'y'), ('mp', 's', 'yy'), ('mp', 's', 'y', 'y'),
+           ('msyy', 'p'), ('msy', 'py'), ('msy', 'p', 'y'), ('ms', 'pyy'),
+           ('ms', 'py', 'y'), ('ms', 'p', 'yy'), ('ms', 'p', 'y', 'y'),
+           ('myy', 'ps'), ('myy', 'p', 's'), ('my', 'psy'), ('my', 'ps', 'y'),
+           ('my', 'py', 's'), ('my', 'p', 'sy'), ('my', 'p', 's', 'y'),
+           ('m', 'psyy'), ('m', 'psy', 'y'), ('m', 'ps', 'yy'),
+           ('m', 'ps', 'y', 'y'), ('m', 'pyy', 's'), ('m', 'py', 'sy'),
+           ('m', 'py', 's', 'y'), ('m', 'p', 'syy'),
+           ('m', 'p', 'sy', 'y'), ('m', 'p', 's', 'yy'),
+           ('m', 'p', 's', 'y', 'y')]
+    assert list(tuple("".join(part) for part in p)
+                for p in multiset_partitions('sympy')) == ans
+    factorings = [[24], [8, 3], [12, 2], [4, 6], [4, 2, 3],
+                  [6, 2, 2], [2, 2, 2, 3]]
+    assert list(factoring_visitor(p, [2,3]) for
+                p in multiset_partitions_taocp([3, 1])) == factorings
 
 def test_multiset_combinations():
     ans = ['iii', 'iim', 'iip', 'iis', 'imp', 'ims', 'ipp', 'ips',
@@ -408,10 +435,20 @@ def test_binary_partitions():
 
 
 def test_bell_perm():
-    assert [len(list(generate_bell(i))) for i in range(1, 7)] == [
+    assert [len(set(generate_bell(i))) for i in range(1, 7)] == [
         factorial(i) for i in range(1, 7)]
     assert list(generate_bell(3)) == [
-        (0, 1, 2), (1, 0, 2), (1, 2, 0), (2, 1, 0), (2, 0, 1), (0, 2, 1)]
+        (0, 1, 2), (0, 2, 1), (2, 0, 1), (2, 1, 0), (1, 2, 0), (1, 0, 2)]
+    # generate_bell and trotterjohnson are advertised to return the same
+    # permutations; this is not technically necessary so this test could
+    # be removed
+    for n in range(1, 5):
+        p = Permutation(range(n))
+        b = generate_bell(n)
+        for bi in b:
+            assert bi == tuple(p.array_form)
+            p = p.next_trotterjohnson()
+    raises(ValueError, lambda: list(generate_bell(0)))  # XXX is this consistent with other permutation algorithms?
 
 
 def test_involutions():
@@ -452,6 +489,30 @@ def test_necklaces():
         [6,  14,  13,  92],
         [7,  20,  18, 198]])
 
+def test_bracelets():
+    bc = [i for i in bracelets(2, 4)]
+    assert Matrix(bc) == Matrix([
+        [0, 0],
+        [0, 1],
+        [0, 2],
+        [0, 3],
+        [1, 1],
+        [1, 2],
+        [1, 3],
+        [2, 2],
+        [2, 3],
+        [3, 3]
+        ])
+    bc = [i for i in bracelets(4, 2)]
+    assert Matrix(bc) == Matrix([
+        [0, 0, 0, 0],
+        [0, 0, 0, 1],
+        [0, 0, 1, 1],
+        [0, 1, 0, 1],
+        [0, 1, 1, 1],
+        [1, 1, 1, 1]
+    ])
+
 
 def test_generate_oriented_forest():
     assert list(generate_oriented_forest(5)) == [[0, 1, 2, 3, 4],
